(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1299590,      24412]
NotebookOptionsPosition[   1238567,      22932]
NotebookOutlinePosition[   1276928,      23779]
CellTagsIndexPosition[   1276846,      23774]
WindowTitle->S24 Working with Imported Data
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Working with Imported Data", "Title"],

Cell[TextData[{
 StyleBox["Wolfram",
  FontSlant->"Plain"],
 " ",
 StyleBox["Online Seminar Series",
  FontColor->RGBColor[0.811765, 0.117647, 0.145098]]
}], "Subtitle"],

Cell[TextData[{
 StyleBox["Presenter:",
  FontSlant->"Plain"],
 " Harry Calkins\nseminars@wolfram.com"
}], "Subsubtitle",
 CellChangeTimes->{{3.5308782849005327`*^9, 3.5308782885963287`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[
     DateString[], FontFamily -> "Calibri"], StandardForm],
   ImageSizeCache->{343., {1., 20.}},
   UpdateInterval:>1]]],
 StyleBox["  (GMT ",
  StripOnInput->False,
  FontFamily->"Calibri"],
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[$TimeZone, FontFamily -> "Calibri"], StandardForm],
   ImageSizeCache->{43., {1., 20.}}]]],
 ")"
}], "DateSection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Overview", "Section"],

Cell[TextData[{
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "provides a number of ways for importing data and a number of tools that \
make manipulating the data easy. In this seminar we will investigate several \
widely-used file formats and data sources and give concrete examples of \
working with the data after it has been imported."
}], "Text"],

Cell["\<\
Below is a list of the file and data types we will work with in this seminar:\
\
\>", "Text"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"XLS\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"XLS\"", "OverviewSection", StripOnInput -> False, LineColor -> 
      GrayLevel[1], FrontFaceColor -> GrayLevel[1], BackFaceColor -> 
      GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> GrayLevel[1]],
      Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"Excel spreadsheets\"", "OverviewSection", StripOnInput -> False], 
     Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.530962471220538*^9}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"Text\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"Text\"", "OverviewSection", StripOnInput -> False, LineColor -> 
      GrayLevel[1], FrontFaceColor -> GrayLevel[1], BackFaceColor -> 
      GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> GrayLevel[1]],
      Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"Comma or tab separated format\"", "OverviewSection", StripOnInput -> 
      False], Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.530962471290127*^9}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"CSV\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"CSV\"", "OverviewSection", StripOnInput -> False, LineColor -> 
      GrayLevel[1], FrontFaceColor -> GrayLevel[1], BackFaceColor -> 
      GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> GrayLevel[1]],
      Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"Comma separated format\"", "OverviewSection", StripOnInput -> False], 
     Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 CellChangeTimes->{
  3.530962471394891*^9, {3.530966809894767*^9, 3.5309668122346973`*^9}}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"HDF\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"HDF\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"Hierarchical Data Format, typically for multidimensional datasets\"", 
      "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.53096247149454*^9}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"DXF\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"DXF\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"3D geometry, CAD format\"", "OverviewSection", StripOnInput -> False],
      FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.530962471596385*^9}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"FASTA\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"FASTA\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"molecular biology format for genomic research\"", "OverviewSection", 
      StripOnInput -> False], FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.530962471701928*^9}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"WeatherData\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"WeatherData\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"Time series data\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.5309624718171883`*^9}],

Cell[TextData[{
 "For each of the data types, we will show how to bring the data into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and work with it. You can view the data files that accompany this seminar \
notebook:"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"SystemOpen", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Import and Export", "Section"],

Cell[TextData[{
 "The functions ",
 ButtonBox["Import",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Import"],
 " and ",
 ButtonBox["Export",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Export"],
 " make it easy to move information in and out of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". They provide a consistent framework and syntax for working with over a \
hundred different file formats. In this section we will briefly look at the \
syntax of these two functions and at how to use optional arguments to work \
with parts of the data you are interested in."
}], "Text"],

Cell[BoxData[
 RowBox[{"?", "Import"}]], "Input"],

Cell[BoxData["$ImportFormats"], "Input"],

Cell[BoxData[
 RowBox[{"?", "Export"}]], "Input"],

Cell[BoxData["$ExportFormats"], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Import and Export: Basic syntax of Import", "Section"],

Cell[TextData[{
 "To use the ",
 ButtonBox["Import",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Import"],
 " function we need two pieces of information:"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "the full file path to the file from the current working directory of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Item"],

Cell[TextData[{
 "information about the parts of the file we wish to bring into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Item"]
}, Open  ]],

Cell["\<\
Set up the working directory, assuming the data files are stored in a \
directory at the same level as the notebook you are using. This seminar uses \
S24ImportedData/Data/ to store its data files.\
\>", "MathCaption",
 CellChangeTimes->{{3.488205784401525*^9, 3.488205786177453*^9}}],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\""}], "}"}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.488205685876549*^9, 3.488205718509076*^9}}],

Cell[TextData[{
 "Import the first sheet from the Excel file, rows 4 through 15, columns 1 \
and 9: ",
 StyleBox["{\"Sheets\", ", "MR"],
 StyleBox["page", "IT"],
 StyleBox[", ", "MR"],
 StyleBox["rows", "IT"],
 StyleBox[", ", "MR"],
 StyleBox["columns", "IT"],
 StyleBox["}", "MR"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<epmxlfile1_1.xls\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Sheets\>\"", ",", "1", ",", 
      RowBox[{"Range", "[", 
       RowBox[{"4", ",", "15"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "9"}], "}"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.488205755609424*^9}],

Cell[TextData[{
 "Display in a table (",
 StyleBox["TableView", "MR"],
 " is currently undocumented)."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"TableView", "[", "data", "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Import and Export: Basic syntax of Export\
\>", "Section"],

Cell[TextData[{
 ButtonBox["Export",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Export"],
 " is even easier in that you need only specify where to put the new file and \
what to include in the file. As with ",
 ButtonBox["Import",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Import"],
 " the first argument is the file name and location and the second argument \
gives the file contents."
}], "Text"],

Cell["\<\
Export the data from the previous slide and give it the name testdata.xls.\
\>", "MathCaption",
 CellChangeTimes->{{3.427645859478765*^9, 3.427645912247163*^9}}],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<testdata.xls\>\"", ",", "data"}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "For basic information on importing and exporting files see the seminar, ",
 ButtonBox["S18 Import and Export Data Formats in ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s18.html"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s18.html"], None}],
  FontSlant->"Italic"],
 "."
}], "Text",
 CellDingbat->"\[LightBulb]"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Excel Spreadsheets", "Section"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3We7XMW5N3jPzCeZrzSv5vXzBXx8OAYjRBDKAUkoHKUj29jYKOecUM45
S2CCBUcEgQQYYwym5zfrf2mpd3fvvWu1Qovz7PvFvtaurlX1rztW1arwf/+v
X/4//+v/+sUvfjH3//jFL/7f//MXv/j/nydMmLCjF23fvr1nOpo0adLq1auH
+3WMBkjtUtteUWHmkROfEirE9jQ34XHQcILuTqxTRtWNx0odWtrzeYR3+0D+
qBrbqJye3G7a3jF6AiQI/ud//meri/71r3+dPXv25s2b3T+h//qv//rv//7v
nj+N0ZOhf/7zn9euXTty5Mi5c+c+++yzTz/99OOPP/7HP/6xb98+UpPy3Xff
+VUemb/66qsPP/xQIrHWJXz99dd79uyRrb3YL7744tChQ3/7299Grv3bb789
fvy4Gi9cuHDv3r1bt27RB7VfuXLlgw8+aC/zhx9+kHitom+++UZOb8nw0Ucf
gQSDovL6999/f/v2bb/6q3VSPvnkk/YyFXX69GlvaYWfJHodYCn+rZvm4dix
Y5cvX1YObAq8e/euDD/99FMyKFkGfPOTqv/6178CpiKQpPz973+XwUNqD847
d+7Ipjr/gpFyANaoS5cuya8i2UgB60DCapk///zzjytSpr/vv//+l19+qS5F
BbBnKT05rBAGiMlXr15VewqHB2wY8AfflOP1H3/8Uc6TJ092lKB8b6UJNCGs
3rt3r7ewAhiq0iF9LMVtNeYtzPGgCpn9qznnz5/3V41hu78yKDBMltMrMuCM
B9l6Ng0w5Vy/ft0D7h04cODGjRtU9HBFX1cEp3LaX3n33XcpNo5BiC0YiAn+
RmG8EhhYjVHAYJoMUuAEhqq/99577YoN/JkzZyQqBHLZ1OgVLY2kkqgcBb5X
keddu3b95S9/IV9trFnk3wi61g2kNEJhICoFmAgoCZDs6+LFixqS9mr4iKY2
Rk+C/rOi7nSKd/To0W3btrV7zprG4uDAicGyR7ITGnjjP/7xjxMnTuReFi1a
tGbNmjfeeIPZMsOdO3cytPnz5y9ZsmThwoVsvy6B/S5YsIAJe2byXIcHpurd
CJfb5AF6KgArnjVr1oYNG5T8+9//ft68eR44qGXLlm3evJlfqoOOZzlFpRUr
VvzhD3+YM2eOSk+dOrV06dItW7Zs3LhRdd6dO3cux7h+/fpVq1a98847mkbH
Jk+eLDFlclactgxcigx+PXjwoJ84zD//+c9vvvlmu0KuXr36d7/7nXS/elD1
iRMnakhwTp06VUUcPgbybOvWrQPmtddegwTT3nrrLcBg8BZmws9hKsTzpk2b
cD7lYNrKlStxXkCBhKPDfPAk7t69WyKPByfpSMQlKWxKwxcvXoxj3CY+aFpP
DpOUYL18+XKRwisa6y/kM2fOfPvttzlkhQM/e/ZsDhlDwGt3wimBv5UItupw
g8QB06gEsj/96U98dc0WD7QF67TIw/Tp0ymMutSidn1mLh2LxFz+X7u0RQbP
mKlM/FcFkLRCUWBH2QSm9l5KKpJfw2FTsiZ4S2ZsHzduHMyYP378+HaRAbx2
7VpSFpjUi5naS8NJzVvCqKphhlxkgY0haJ2/ZEHltAJUGZRclymwKlCjaCDb
oSc0c//+/f6VX3TGAcBIlqp4XdthnjFjBh1QhRrDIni89dvf/pagyaJuplbD
jOGkA4yqmSpNoyeKVfu0adOURs1Gs/Uxeuw0XBxk7ORLiNS4+9exOPg0kJjF
D4gUohVnrtNisEBknhkmM+QqPYtEfBcnzK/yhPXrfKCwwofwDLyBUNWqwhYz
Z7kS9XXZbO3220kXl2NUtYo4Z4VzaCIp65bCIdRjAa+rFxLAVCEw8TBCgGxe
98zved2DVvjLBaVvz2tt3bqVlwBGega5evUy+PVARdrF33J3yueQUyOXK+5s
375dsdym5vDt7a1QIIfm9SAPZomePShcLQrMgI774q+4XKFQNNEBqMvhujEB
i/CQi/OKMjHB34QbYU4rCEI5Sk6wwGoVeQsPNard27eTVmAjmaqFWFM4SHiI
1TCL13BqiAwqogm42l4Cy9VAeOQxwJFBKwCDRATXXpzRE6ijpxrx9mhF+EZS
/sVVCAUXYPSLiNKvKsJhkLSCwvDthCgE7KsIo5RJuPIrVn5Vt48N/apMnMEB
5WtOht6aiY16O1HCTGXUJFHhKiJx2SDRBBiAxIHokmdapPCIANtVLVpF/6NI
dXvJAnvVjjlK8y6WapqcSvAg0TPe+lcrNDZtiRKSHRbJIKcXGZqq2wFTSz0Q
VWumd1WdaRnvailRHqoo/c8xGiwNFwdHprE4OEaNqKerfwJligUiad+uRhWc
W6Z8M+3WXzmDIrCHm5x8rCSk1jOuokD7KKmDHqFidBclJTOWHSPlwdLjsIUx
ekgSBH/5y1/u6SLdG4P6DRs26FZ1//rMM8+sXLmyO32Mxuh/JBmZZnxqbOWv
EZC/D1Mg+zJKNWitU9rXUfRRIDv1bp49xGzhNORpWlRg9IFhjMboZ0qC4MKF
C3/qIh1pI/o//OEPX375ZfevxoN6Wd3pYzRG//Pom2++uXDhwieffCI60Pz9
+/evX7/+zTffPHTo0Oeff37w4MHMpB09evT9998X4IyA5BEor127ZijqLYkf
ffSRGMrijE/ffffdvXv3vvbaa5l/RgZQSvtTRX4SxWQ+ffr0rVu3Up2cZ86c
yYPQdvPmzVOnTslw+fJlif5eunQJNulff/31n//8ZyXcuXNH1Z6VcO/ePSDf
fvttb7FrAA4cOHD79m3B3YPXIc+aRuO4r776SspgeT5GY/QkSRDsOS/KcJiV
ISGz6v51bF50jP73IfHi+vXrP/zwg2Axb948AVGUEUGEwsOHDy9dulQI8zdj
KNHtr3/967KK/CtULV++fPLkyaKkB/nXViTiTJ069eLFi6mCJYpub7311h//
+Mff//73fvKwYcMG+f31r4c33nhjzpw5q1atEtGmT58OyZUrVySqesmSJbD5
m+W7GzduVJpgt2XLFrFv8eLFYp+/WaWjKDEaPKETJGHXK8eOHWPUCxYsELh/
/PHHI0eODJbnYzRGT5KG+z6oW6jjqhPbc25/LA6O0f8+JAJ+8MEHooOBkgfD
vS+//NJoS0DUS/zss88+/PBD4ePvf/+74Zvn7AT5+OOPDSRlFhb9Kz+Tke3T
Tz/11gcVtXcylSMeKVkGw0ymlzIFWfExnymz4SIrMP0LmIfsOvnnP/8pXmf7
iUolZvuGArObQE6vqyJ7Ijwrv343Wx6yPBhsmQfI8DEaoydMgqDO6q2GNHPm
zDNnzjR96/ERo+ZVBo1iCMETB/iU0BiLRqWnk0UGek8Pl55OFj09/Lk1xqIC
egpZJAi+9NJLV7voypUrBw8efPvtty9dutT968SJEw8cONCd3l3IqVOnjhw5
cvLkycsVKU1i+7MMerzJfPHiRemeszgcjVpFaPfu3QsXLhw12/nz54E5fPiw
hxoA8hBIyqkrhfn48eN+zTLswPPQkyHdNHv27LRLXWpU1IULF1JIOKDh3dy4
VJG3jh07tnXr1nAjie058zeJhSzas2dPN4u8fqwivZr22s+ePQt2mNMutYDX
kG3btuHP1UpSdYs6sAX8CDRnzpx2EcOgzFMVBUxPRqEaVZ7zK8A4JnN7FRoS
iUe10rr2lrbT3r17FyxY0JHoxSMVaXXNlqNHj0KeEmoOtKMqFMqoNHfu3FEN
DTAShM3fIGkHFgbijGxJ7FD7mhslsPft2zd//vyrFQ+p9OnTp8OZdtFI3LVr
VxLrKtpNO/C8SIuiwLU4asxIOXViO+wOSK+//vr+/ftTCA7Eus9VJDONqp1Y
bX3tutRUIqOS6ubNm9fNotrJSKfqO3fufBwsSr3dLIJqOMDhEmelNCXH+vCQ
x6idQI2tNvCr9z2kZ1ohM4YXekhgQCpnae23ueJ2EwNVjVfvW3TECklJbOog
QbDnvOiPP/5448YNnrP9VIeaCudFf/rpJ7z63e9+t379ekz+85///Kc//YkO
ZFd1NlvhyY4dO3744QeCyJK8mzdvSvntb3+7cuXKnluMu+mdd9556623Rs6j
is2bN8MTeW3ZskUt5KgzsLqi77//nmZKr8vURk34y1/+Aolfgcn+phJI8GeZ
/WeffYbDiuU88UFRmzZt0skXBYj1m2++wYGNGzcCRpRbKyJQ6UuWLPn73/+e
PfJYlzBNZGArAVf/8Ic/AFwCplXtGlZIRyIpr1mzZt26dYAB8+abb2Jjckq8
ffv2e++9R1IQegBMpFA7DpAUx/vVV1+tWrXKK9K9Dsz27dvJ8fe//z14GjXy
enV56k1/iFykZGefwoHBMf1GJkPhP/nkE7WkUwFY1pOQHabJyRP+85//5DTq
L26tatMEeHHLuqCQ4xiZyqNReNixp4CgFdsB8u2KNGrDhg1+xShIlCAckCl4
GCidK9CW7Kl/hJ8McBLykfOwUHaKG1SLXLI70lv4T2SQf/vttxCCfefOHZIl
L14FSMg1RyIuUS1aN6q5UQPcblU7I5Sputdeey0LeEiNmHQPMHbWrFn0FpOh
4kb2VMtZSYf2eksJpPbll1/ScBqizGg4SW2rSH6v50yDHIukfH9zsEOH1N54
440PP/zQg9qpn1fYMu1V4K1qmhoYkiJcDJGofG2HDSRm+NOj3sWgTM0Ji7Ca
1ukSZwd9O4tmzpw5Kou4x7AoZUofjkXxLVhE5//2t791nFFD7SnqcIAphsJT
L4TMTcn37t3jtdauXRuL+3NFcsZBMU+to2ksUXVvVUSOhR4SGJDKWUqIJOsV
8LIWOhrOhTL8r7/+GhLw/EQ38A17ywsPDfd9kMpRb1VrafevhXEQW4iGKCkh
17Fo0SKmSmQ83tKlS2kpjtEKUuBDGCOH41lj/fWvv4Ubf0riIBZhJpeodsqD
b3SJ8uAqbXz11VeFLdg0OaFfOMhBZLRCe3PuinebxkGMiiEoVkeROdCuL774
AisoGBFnHb4UvOJsCZFwvZVeJZ4sW7YMQgzMonqsYyarKpJS2FXoGQexl/LD
o7r0PVSEmfrVYKRjqTopTECQ0m0AhnnCybdIZ4ncaQ4b4Wf8qi3KhE3+9l3n
3dQRB1kccfD8FCArJykMbwkSzrAdkFQqnQnw/BRe7FtREQ7LqSGQ1JX+4x//
gI2fUaZwQLIZXvHecTXtpwq0homDWJGNDAQBRvZ3UwMcYIyZiNBYQoQQN9rP
EHh4KomDAhlOanj8GA3PKUMCBHlRG4pHsnReD5NSCROaQ/fkjzem3nGho+Jp
j4MeGC+WKh8ApXGebBYAoYc0Gb7awcuCIhjIYvHixeQlHNB8YHJoTzxDJMUG
eR46lnjN/+A81Y1VAtl+JlKrLQ7mIBocECayh10KFVW7EghRLSRFcPLTarX0
PCPiIak9DuJJWMR7aBokIlQ3i3K2DxXFxppF5AWnqJQzE3qySDaMZbwamNOB
WtXoI0fb1ZBGjoNqB0yByidf/Mw3LzjVi41+jT3CQ3moekwMb3MSXYYVZNoq
85BN4yA3hVcazgvRhDAKQq5Gw3MiBHhYygnk7Kaew7cRaLg4mJOXhNqe/aXy
8aDeQlag/VStP8+BhDmDUaiV7lfPWEdwTEYe+sOgRqi9m0riYBqVA8QwNkdT
EiI8HiR6SL2Ro54nGwQmaP0qM09SaDt1HNSuvN6qPLNnbfyp2pmSupgGVBlv
5pBGODHHr37K8gyJMOewR3mkZA2GbIUs6hkHw+rwWUWewxyUkzADQ0URJQHl
nM+cvogVaUVEmWUesCkw8EaOCB1xUOu8+4+KcvCmfyEMBvxRVxJTaWBn1Upe
rFHVZWYFiEblAUKlRQ+7z1DtGQdVca8iSDQ84sOEbyr6e0XhQI2qRByFVBIH
ocrqFwA0825FHsJDfIMWMHmII8osZ1QxDAlnSsJ3HQexJQeWqouZcIMRpZIp
idJSkTz4lkSZPcfuspgnzFRvnVgbRavqiicxv8aC1NthgHUcDKR4m1h6tMLf
v1UUPuQs2RjXIx8MttriYDeLuO7hWATbcCzy78gs0px2FrUqR9fePR45Drbu
9y68HsxRmxiav+1KVTuo1n0PWfsND4UesmkcrM087jphQmLkWNsgGGC3+/By
+p9xnkxhHGxK3WZSbjh1HByOyK52PukDpPCOjS1JoQO1ZGmm7mV7Bq/LkJBN
LkrOK+19wp5xcDiib3H+fGxdC7WP+tUgC0sbjjri4MCpZxwcjsKidBvaudEu
te7EdCEInWiy3FS6QoYz25I4+CSpjoPt9FO1/7Fnfo3NMPORKExPquNgT0o3
Ep9jCyNLp+MvEmjqI1hzplAk1fP1UB0H2yks6smBJ8CiUeNg39Sfh2waB58A
jcXBx0Qjx0HacvXqVZjTTT1z5owxPid54cKFnTt3UpLDhw8b/h87duzSpUus
mPPJafl79uwRznL88tq1azdv3ux1EerGjRsMLd3Offv2Kf/69euZyw2Vx0Ee
Y9OmTadPn85n6G3btm3fvv3s2bM5NRoAlp7PTDA8DIt+vnEQizZu3HjixIm9
e/cyagzPrBEp5HurdoVFWZixatWqbFEX8i5fvpwey+7du2XmqEl2OD78LOLg
cKTXFL0V8SkqpTp37twjd/Ujx0F8zmeFqDSJrF69GiQSkZKlNX5duXKlByBZ
5fr168l0fUUEOnfu3B07drAFMXHDhg3GO/mooSiJzEpRlCGHqbaGiYPDUc0i
JhwWMbRHzqLHFwf7o7E4+Jjo5xgHhTxsPH78OANkofLnyBHu8dVXX82yIvYl
ruUofi6XiYkdjGXRokW7du3KnmumlHthWtWiDj+dP3++df/7Zl1jeRw00lGv
oiA8cuSIqkHiAaQsWbJE8D169Ojrr7/OFTzkbuufdRzkJImAOe/fv9/f+fPn
85ZYxK3ppRAf/4lFWXRNTJhPUuKg/kmr+mrsRRl0fm7duvU/Mg4a6ch84MAB
3TyMpeeCyBOOg/qQCxcupL26HDQZPyHRMyEy3ZjcSwKkf/mQBQsWyMwGBTgp
M2bMILuZM2fqwwh2rEzE1OfxOuFmcZFGKQGG+gzbRnEQi+ChCVkYxhvk3PtH
wJc2GouDo9JYHHxMNGoczBbsO3fuZOrbc04kTmeVqty7d+/zzz//6quvjCOS
M/Pz2Rxd/6oof1lfvolkts2IQznty8aazosqPN9Pgw2w+sMKPKm96SR8B/18
42CrYhGJYEI+WKDMv0Uo+WgSFiUxU6BGDWrJ7YG4ms+7ucivZy0/6zgYvc1X
LXrbsXjjUdHIcVA3g2jyBS1fkYKHVmfpQsQnsZ5BBTtXCuYrHtie80XVc8ww
3yayONND+6fGRnHwybBoLA6OSmNx8DHRqN8Hh6MsWWnaJ+z+QNNRQqM4+GTo
Zx0H+6bu70QjyPpnFwdzHI1o0t9STK/XL+Zb6qiGMHIcTJn5jNuqFpakc5iV
M30gHJVGjYNhkdqbssiLuYu5KaSxODgqjcXBx0R9x8HHRGNxcFR6MnGwEf28
4iBHvW/fvsOHD2eP8K6KTpw4cfLkyWxpYacesqMzC/X9K4rlwNXz589LXLx4
8c2bN3UFL168mF29Sti9e7cMwlmCbHulo8ZBJahRHDTayk43sfWTTz65cePG
I+NLG40aB40BV6xYsXnz5m3bth04cABPdu7cmYuD8XbLli1bt27dtGmTxFu3
bq1fv37NmjVHjx6VDQNnzJjRB+yxODgqjcXBx0RjcXBUGouDo9LPLg7y3tz1
pUuXRDTyPXjwIK3bu3evKJaL4zn/5cuXMw1BkI2IYlevXpUzH8h4SE0WFIwE
xcFly5ZJkS3bD7NT+7PPPmsfSY0aBw2gFN6qvISqZ82alQlS0fYRcqamUeOg
2sHYuHEjF3rs2DHsEvoFekzAopx2rgTPoqTAl3U4svk7Z86ctKURjcXBUWks
Dj4mGouDo9JYHByVfl5xsFVNZn5aUbZz3r59+9tvvzWCu3fv3p07d/KVLVuE
DNM+qyjf3bKpM5/z8pnMv5xMdjgqx7/13pP2rY6jxkH5r1+/nunE7IEVTHM+
+SPiyhAaNQ4Cjz/GtjUTgPEvYNlMnRXamJCvzPnibxSJCZ77mM4di4Oj0lgc
fEw0FgdHpbE4OCr97OLgqCQe8eeP8CCXUeNgq9c32eF28z08layT0fxsmOo+
FqBVBcpHeCRRaywOFtBYHHxMNBYHR6WxODgq/XzjoEBz6tSpHBJoUHPkyJE1
a9YQtyHhihUrHqHcS+Lgk6RR46DAZ7i3devWo0ePXrx4cenSpTdv3jQSzGnV
x48fv3r1Kr4dPHjQgDrHpdJMo9e9e/fi4dmzZ3MSYw75LIE0FgdHpbE4+Jho
LA6OSmNxcFT6+cZBI509FeWYSg2ZM2dO1rp45u0f1ZDwZxcHv/322+zrR4TL
l54/f17s83D48GF/9R8WLlyoHP2H5cuXL1q0iHM7ceKE2Ddx4sQdO3bMmjUr
h5wXHr88FgdHpbE4+JhoLA6OSmNxcFT6WcfBHEr52Wefff3117kjOMe6Evon
n3xS6MNHpZ9dHPzxxx/JFENytmq+D+azKc7kiFQPOVw3Fy5nI+qhQ4dyRH++
nJYfvzwWB0clQXDSpEkfNqQZM2bkxPinhA4cOLBgwYJBoxhCM2fOzInxTwkd
PHhw/vz5g0YxhHRr9XIHjeIB8TPz5s0bNIoh9Nprrxk6DRrFAzJgef311weN
YgjNnj372LFjg0bxgI4cOTJ37tzHUbJOiAjSx4tG4kePHn3kePomYEAaNIoh
JAi+8sorN4aha9eu9UyfPHkypzHcW8MVdf36dQ/+1sXWiSPUVUK7du1iDu0p
1yvqyCbl6tWr+akdQ/dze2J3Qzoy6xKwxI7qpkyZUsiidjCB17MV3dxrRLt3
7+ZUG72iohpPO5I68WFEhqZOnSo6j5qtnQOqvtHFhA4J1g/dCjAy7dmzR2gu
zNxTn0cA0x+vpk2bpo9XAibl12Lq1pP63zpPH6j27t1bwqJ2NW7XlnaJtOv8
wzBq+vTp+/fvL8nZoc/RpRttbuHGUA/QYYyFtG/fPn3gpm/dGMYP5JbY2mX1
gQflgLhGr/SUYM20GlUfYBAw2QhZU0+5d5hSO0NuDJVauwp1F9Ih2dOnTwvE
HeAFwZ7zokbc77777saNG3uOIpvOi3777bf8cI4OY9fbt2/3rHyehyf84Ycf
PO/YsaOPoxJCHfOi//rXv86cOZNjNmv6+9//rmoDEBiwAp7Lly9/+eWXEnOZ
o+7Wzp07//rXv37++ef5tJFLoHLcWc6ElwLn3bt30xAvasibb77JP3R87yic
F1WyGKpeHHj//fc96E9mykiNGCURhly/6+HKlSu5X7vparem86KA4Q88f/nL
X8hFA3OzXq5iz1GZuh/37t1rBKOdSuZFCWjz5s2YTCi5KxYYHQ/eJkeqfvfd
d+fOnQMPJDoJUpbcSyHBRvDK50VVSgq3bt3K+XVE8+mnn7aqKS9cIjVgYPaQ
i2ACRlvKwYRGnReNSigfABp4vCIwahblFoPcQis/MPh5+/Zt4jtQUcedrSNT
ybwoU2JfURKiwSji+OSTTxiLnmHO4lP7li1bcn0VU/UTF3Hz5k1carqdoXBe
lE0xIuVjF17RJZLKOhMcwxxDLQy8cOGCn6BilRL7mJRudK5aTZCQEUWiNpiD
IVhH1TkxWoQnYPsVY/tY5tp0XpRzwxOWzgXhA6nlEGPGhYcSYYOq709jHfOi
ufNdge3WSjfIgg5LpKJhAmC0ZevWrXfu3KmlRnPOnj0rp1873LVnmLkOebSC
KmIvG4+XaIc03PdBlrJkyZJnnnmm53aVpnGQgjGfXLO+adOm5557Diep/bJl
y15++WUNXLRokYd8NdC0kitB26kjDlKVHGGRC24YLwACwYQJE6go3T58+LA+
m+eLFy+uWbNGgCAI7dUu8PBKyrhx4wCDRzjAQNhaVXRYvny5ouIz169fTwTv
VtSx1Lk8DnJiRuXqVYtR7fz589N8av/qq6/m9PuFCxeOHz8+l5PyXZjpxXxw
KWRR0ziY7zurV6/GDVY5efJkldLJ559/3gMfQpS8NKtvVdFKY5ta6KhxUBtJ
hyAYI+9kJLJy5Uqaibd4hWO52w6jQMoxnosXL84mLDm9SEwy5PDVUfGUx0Fa
QS76VB7goTbMM+l0Zs6cOTkeltRyLdqqVateeOEFXVDWTRvLP42NGgcVqDo6
SSvYlCH/66+/rtKwiKPIN6alS5f++7//O86sW7eOIsnMGAl3xYoVUJWzqCQO
aq96WR/O6PZDwnuzOGJi77EjNc6bNy/HrorLkMBGdnDyUTBTp8JuQ2EczIm+
pEZAHCmmEUoMjb+FjcLQN2aCgdRSIgXTEGzREI63BEyrSRzUTBzIN8HUgj/8
iX/JjkxlUC+Tx1LI6T+Tyc2wbL/c3JrGQVGDyPhkFsE1qZSS6LdwTYrKFlHs
yvdNzG+6pbEjDioQExSeuwtVmkCWRVbqIq8XX3yRn8QQ1dFhv+ohRGpqlwGX
gid3lyc8KU1FnJUa6e2GDRv0D5UvXnTY4HBxUDYGuG3btvo+kXZqGgdJlukJ
KHo4GkvH0k/Oxcfq0jr6n3szOb2mPeeOOIgbqtAjBR6X2GA28OYuIWBYmapz
81cS/UoWukDg8S2gEn028uTE6fRV/NXxwNiUJtoOF7IL42AkS/kznIHEWC8y
kmJsqCHRDfxRF4HiD1vLjRUZE5VQH+tk8MdbP1WXYGqp9kLL2fL/+ViPFcmg
CdSycBV3TaPGwdyimHFNbpqO5uC/5wzBMrIACbswXLj0l3T4edlwUgZsLDm+
uDwO0itlYoUHFWFO/GQ6sf4FhsMHhhGpOpM5OZ+ZNpbPe4waBzNvkw9kaqc8
+r01ixJ0alvOydJ6NZQ8vo4V5B7MQhaVxEH855eUrAowYOPhVYEtlCS6jV30
mRpDSHyQ1LpNCholZ6HrLl8nw/AZdYIL5tSGhjnQ4gn+sETPHiRCFTByYnJJ
Fa2G40Eqge3prteKxCg8gPpTdbN8jB03JN6obqMgBR34cnNrGgdVqu1aHX3G
K8YeAyQXAJheeJ4piKaXv3fEQeagOVqXOwXitymqMSCHLNGzxDBEvEjoqaWG
Y1QoF2PV7jrXf3iXtmOsYkkW1OFCtiC4YMGCHxqSbhsYTd8KYV3Hw8MTc+PB
ymsfteqHx6ZrR1XKIZVTf9hYEA/Wx4uPCkA36U2xiMeEoQ+QbCrd3YdB0rPe
vjlmUMAN9vduSaVNgelwijtPDx6U89b6QtSj3ofXbRFT7+VhMAwHo29sOpwC
et9gHh5ABwED0sOX/AgjiCD4b//2b283pF//+tdr1qxp+tbjIx7ewHlQtRuw
6Nz625747LPPrl69elCQukk/Yfz48YNGMYSee+65VatWDRrFAzJeftpY9Jvf
/OZpY9ELL7wwaBRDCItWrlw5aBQP6K233ho3btygUQyh559/fsWKFYNG8YCA
AWlQtfd014Jgz3lRA0kjCIPQnl8Nms6LGvXnS80P1RSN/puUr7/+Wt8pe2dS
1w/9binq/j748ccft99CmxbpWqvI8NlQ2iv37t1T9QcVqToTDrk8Dhg4c/9R
jmDKLIT8MPubiXH5s2TCoLu/74Otaq41c+x4ot5PP/00M/+ZlsyEmzyZAlVL
vj01ZVHTedEfqk9d2PXFF19ob5YPAYarWcmAUXjYdEqknUrWyfxQdbBpzjff
fEOFaB1BaD4mSGndZwjJ4h6QMoeTWOrfRpu1G30fVGM2cOEA0WR6POoNT06D
xB8N/KGa9s8yjHIwoZL9g2Ao/6uKNAEHcmuk5/pqBrzKHbi15oddmdUpx1My
LxrNiTlTHlUQGRXyLm7EjqT7F+uSOTCyVq38k3eocF403xwxISeaEgcBBUwM
DRj/SoQHA2mazI0WEYX6WydDjdXoXYoESVbNScQxD1EnePpbltZ0XjT3ceQT
JHeUB24TKjDq574Pf+uYF011CQp1YmSh7fliRWnz+S9cirtWzt27d70lJZNv
rfs30OVvHXeyZzNL/vbv33/69OkO8COsk+HJBe6eatlHHOSE85VHwJo4caLA
AQwzf/XVV+mnuqQnBFDCpl+auuPgiRMntm/fnmcF+psQxtHhajqQGzduxD0p
L7/8MhadPHly+vTphw4dws9Lly4tXLgQ2vjhy5cv52uUQmAGmAgUooQs6Dpw
4EDH55XCOMhpz5s3T2ZKrpfy2muv1UtPPUiXwi6ozcyZM3MHDZC5CP6HoQcO
j0xN46CScylAlhrOnTtXG8nl+vXryvFrjsziFdMr6KMPM2ocVCYxTZo06cqV
KxcvXsT5yZMnUzxgwrFWFbyMmNavXy/Dhg0buKAzZ858WO28Q1m9UxiAyuOg
AtVFSTAEniVLlkDYqj6sqHTGjBkM0/OOHTuOHj2K8xCuW7fu2rVrtTaW1NIq
iIOYv2jRomXLllFRjoJZqSgnV+fYllbVY2HIEyZMoGzkRXmIlWtlgNjFtZaj
KomDimIUUPFRWMowo7e4AVLsiLzmzJmTifra1iABftu2bZCU63Z5HORs1ZvP
XgcPHgQmi1fpGFUkNWhxSR5g9uzZI5E3aASm1SQO5st7euM/VF8uErDyOSzH
xVy9ejU6YPwCDxvM/aSNzK1pHKSxgoJW5PYrqu4BQ9S+dOnSLJLBroSGPtx1
Rxz0ugZyg9JrVcwC2pyrw8FiQpalwSYnUTJzGDhJNp44Qjnh9BZbEL9alXXk
EhN9m5zhw0AwlsQ7vtEPFwfZFCOiEvnU3kFN4yBLxFU+geIJN1Q3NztTe6j0
A0+dOoXbOX5wy5YtPSsdgTriIHYRmRT9liy1ytjhRrXXD5937969efPmLAyW
k2OXgcotXrxY7VlZsXr16joOUoZ6VUbWvwG/du1aJWeE0m0mhXGQOLJejlgv
XLiQ2BoZeZ3sIKFvNIHQ1c7f8jCYplLIGXUhi/pYJ0MKFAa7MA1CWoQb2k76
kFAPvOLcskZLTGzaPyyJg/SWwzx27FjWw2zdupVMqQo8uYCGINasWSMFuzCH
ZImVFayoKDca+LVkaUp5HOS+AMhmjXPnztEE3YNWNbIgQYqnXVSd1HJfOT2H
Iet7PfRce9aTRo2DWKQWYLSa9/A3H8u4AhWFRayPF+Uo8Ap/sPHw4cMQ0nYy
zRYPmRMURqaSOKiNyicU3ACDIVAk6qcujIol0qvcOVjbGofAigVBikS3ZUjX
YlQqXyeT6EYTqIpaGFqaTC6kJuThAzcFeQBjGhHTas3p2IQ1AjWKg0STaziy
+prmxJ8wK2g5Rj2cqDHlxBP4/crqBcpyc2saB0UNPTdVU1TRR3OISaWsj9Q8
v11tAKRCmCmx6cFZHXEwixWJgKqzF/zHlqzNA0PijWr7MwFhCDwYwhuzOAhZ
FiGSZr1eFKO460QQ5ago63z4apkzO9HNuuHioMyYMJz3aBoH1ZvSstA9/XPW
6jmh3685fT0Dt4cfDypNmf+qKCW32gZQHupfM2rOi6rWd80mlLS9Y160bkgy
j+A6yudFazCZcKgHLx5q5OoNr8KfjD39Le8W9hEH625nBBRgas+6rCQmg78l
qw07qGReNKLMt2wciBRqjiVPBNEu9DxLj+DyMCqe8jgYtVFFHiKaDjC5VadO
bAomVDIvGp2MDtfDupoV7YDjAZKeh9oKClGVxEElZ2o6HIiSeAagZkiNuba1
ZPachpTrdnkcrC+7V3L7dfAeagl+V1HfYFoPsX8wi9vDqzCqTsyC0hpPloiU
F97HuWq186ntvd071erUn7vunhdVcu3fUm97UOjwOXVUqt117cOHc9dh6Qju
WhAcN27c+Yb0yiuvCNBN33p8ZEg1bdq0QaMYQhMmTNi1a9egUTygMRaNSgZK
U6dOHTSKIWQQl8vKnxLS+Z8yZcqgUQyhHD09aBQPyJB28uTJg0YxhCZNmmTo
PWgUDwgYkAaNYggJgtOnT/+0FxnO6P7dvn27+6c5c+ZkqrCQjFLzYdpzFhJI
yWdQtaQuz8aY5WW2k5HvkiVLutPVZcTRnpLPrGlXKr1dUc7uk0H+4Vrtp6xj
SX6vf1id22mo1Z157ty5Fy5cGBU5PmS9jcLDkBqwupIuj3RtCX75pYzOlKF0
4sSJxYsXl+ePyNqBRVJQ1eILE5oiqen111+ngaPC0N4IS3WYUHOs1pacECg9
S7ACKQsMespxODp58uSiRYtKcgZDAOS5lkhPMLWmlYMJzZs379y5cyPnUWy+
gIRF2ZRX8y0ZovMA12xJhihVOZ06dUrPeeQ80ZxYSof4gq3GnOcaUh6aOoH5
8+efPXt21Gy12tSMCsJP7xtapFbzpD/+oNOnTy9cuLDpW58OY1l1YhxXf+a2
YMGCM2fOlOevHVFEWUsnTjJXGNfc64OAAak9pQ4KHTBqy5IhilE7wFqFRpBU
z7hDW1h6hzEKgj3nRTOzum/fvp5jyabzopn1xcl79+6tXbs2W34Y+KpVq/70
pz998cUXf/7znw0w+7hqOdTzvgmD4v379/P/7YnalbloDNFzU/vhw4eBWbZs
2Z49e7IOUHclCwxyR/adO3fyLVhc0znP2WJ79+41fLh69aoXb9y40Q2pcF5U
ydeuXct6m6+//hoGqDIJo64//vGP169fB4P/wUAZwPbwBNaLZmNvVneoHZJN
mzblypg333zz8uXLWflAan2v8i3ZR097cVI22iu/SmFYWVE+hX/22WeAkQVb
WL9+PXgecnoS6Zd886qp0blqxte0jlaQ/tKlS7Myk25g2htvvEFnyDRrw6iQ
YplS01OSWmXfB4lg9erV6T7RTEzAIvXiW1jErNgaMDJoYza5+wkPQU2eQiqZ
F8Uc5gMSvaV1fMWdivJlJ99G7969y714BgkGNugtgmN6x44dK8fTanKuGk0m
tbhBjK0XDXKPVIXd5bOynzyAwaUQcSMwrYbzopmUzjxeVvF9WB1DHfdCYf5Y
EakdOXIEx/iEJ3OuGoYwK95G7TSZw8ETwHhsnOQQeKqmMGrqPleNaKS0r/BP
LZSWknCkYOS0GVpELv/4xz8SoXKVSaRGl7KPnnbFQ+Y7vlCV4xmxlAJTGCZQ
uE6G9QmRKupphk3joEoVRQOzLsWgmHvXOnI3bkpdETf3Sz9zGkA59YyDWUnC
k+NeluKk7TeqE5UlwmNIQrV4KiLmN/AQnw0t+flWZa2Ge5xGPnZIxEPWrcxD
hw7xfowX83sueyj/PkigGzZsyCU1rI+3j/fGorervTaEqF55iJU/wfwcMcHl
Fn4ZafX1fTCLOrQXi5ZVhIEYMm3aNDJiJqyV1DCHE8acR36ejOoE/WeffZZV
yonnnDBU+gyAcZ7Z6kKLaLs+ycWLF7dXxGTmzJmDabQ0J5mUfE8pj4OarDsH
D9F45Ze//CVDTjo+G3dDhSG7du3CJcKaNWtWTIkeAvMIz5NRFHVVOJXOMmnl
x/yfeeYZ6hS3SU/4Ab4F08gxnSuMIkodexpYyKKSOKh2glALd0d7//3f/z2H
zvnLmUdJ1J7jy0jttddeo0UkBQObwrfYWuHZnuXfB1VKbbKVgxprSCxXdRyj
psmQWU0Z+BP6maWShJvzA0uo0blqGbBQ0R+q8yTJUY+ldi/SqfGiRYskEh+9
gjlbAPDt8Z0nQx94y+XLlwtMHvSXsh4P085X58nwnMqke3SGWJtudemIgwrJ
SIRn5voorTAhumnvb37zGz+Rzrhx4/zV8CT6lezmz5+P25HalClTqFDW7Olz
JjwpjQXBTMnZKcZ65mZ50Q7ujbBOJnMpPa2jaRzULqaXjTmUX4DI93GeJ2dZ
15sKf6jOrGg6MBxuPKgJXGJOq0t3olWtMFR+tsKxoHwlhyQbBvkxnMxyI2z0
Uz5eZ4U8i/Avb5bzfEaAVB4HVZGOEAFpiKrjuyT6l45RS44lm1+YBnh+ylip
Y4/kCNRHHEzYbVV2oXbAsgkru8AwAbxk0H/AyUd+vmir6haqOufaZfuSFBgk
RkmiqCh7vuSBNl4l20JzgPOjPV80xwOm/DxnGWQsOpoMKjBgZ6tpELbrYQmV
rJMhguwsy26vBNkcqFvPG1At8sIrOekwtZEh+pNVCtJLxvUlcTCby7L1WC2U
JLvwYKuH58CIdGpXaeYkcw5wDsHOSX2FW1PL42B6ra2KG9m5HI3Flqg0tIoK
AJjxJHtmMwdYUkWr33Uy2WSazW61e6kdo8Rgjr37K/3xnS+arcGsKRstAahX
sMcTqj2H5cZhRvnLqTsOJtZ8X5GSs0yIgeNDNpV4JbqqLtgkeqAthNguNdik
Z11Nq1LFxJ1s7MXe4UxPEJwxY8bnDckgjho3fevxUXqSg0YxhHR3daIGjeIB
6dcZOAwaxRCaN2+e+D5oFA/IIFdvc9AohpAe74ULFwaN4gHp/BueDBrFEFqw
YIFO/qBRPCBjJU510CiG0MKFC40oB43iAQED0qBRDCFB0JDzXEN6+eWXd+3a
1fStx0ebNm2aNm3aoGo/fvz4oUOH6H974iuvvPJUsWjz5s1Tp04dNIohNGHC
hJ07dw4axQPasmXLlClTBo1iCL366qs7duwYNIoHhEWTJ08eNIohNHHixO3b
tw8axQPaunXrpEmTBo1iCGHRtm3bBo3iAQED0qBqP3HixMGDBzvctSDYc17U
iDJXNvRcktHHvKhgYWif2+KOHj2qWKNsiUYExr/ZGdp0nrmm7vsHr169mvNG
2ltkTJS7AHJfgG7Al19+uXfvXhhyPBc8ivKrFIzKxpOcl5Khup+A//rrryXq
GytQQ9asWXP48OGOaaXCeVFvGd0fO3ZMZs1XKeSZxDPYh1YtqsO0bCOVhxzL
r5moqY91MpgA2GefffbRRx+FdfkcgEt37tzJuq+ea4QKqWRelG5oOM0BQ3Xw
EMHly5fDsVY1+339+nWQMgcinRzzOThH0JfjafR9UOE4kOtCqERuSPEv/fGv
eqGFHKOyeKaPFRetsvsmZCAaykwV6QlTyt2RWBH20rELFWW+KKgy9+jFR36u
WmrPFSowEA1x5CqHXGGZPAzw9u3bxMoAo/NZS9N0p1v5OhkOIcf75DQSwDJL
BmcuRgQSgKgNgWIOlWgEptXvvGir2ua/f/9+Mrp16xZsuV4BTw4cOJCDDTEz
17s0LbmPe5cMsaNIYOQCDhhwjyVmaR/m1Kf2NaXu82TwWeHtn8M0U4iRqF62
o+05xDK3cuTkgUjNA7Sev/rqqw53nfsTc2IP0/BiFmpiaccE6XDfB3O0HZ3v
ucitaRykhOJUzusDQ/A9ffo0Y1m+fPn48eNVkbNTgMQTrr7ppuzuffTKNwLK
mUhcRE4Jmz59uvEvyeqQGK/l7p6NGzfmfBtuGT8N2KkBhczNVjnaiM3miyHu
xTVRSDV690xF5+9fKFNTYRxU15IlS2bOnLlnzx46D3POU2pVQuQicpoQHVi1
ahWh0z0dTpE3x2yWf0htGgdzsI/xiFGteqlZ7kMxqJw1a1YWHBIlRqUV+T5V
Xn6r7P5BHH755ZezVOlcdfsnMMRn+K/2nDFFHHPmzPEXuzzgPLHmBkmKQWTd
n8V7UnkcVClg8CiWJ1+2bJnn1v1TInP/IFuDMMtXaFqOCysHEyq8f5A90pNc
VUOFeIbFixdTqt27d+cYRlbGviikX2k+55BLP4mS4MpRFZ6rxk8uWLCAcAFQ
rwjIglhfvV5UukETVQdpw4YNhPX5/bsI169fDzNUhX2Y8vsHlamunA/MP1Ds
Oihnslc5U6ZMwTfMyY3bnAC25HiTEjCthutkxD66miUHmPOb3/xG1RwLhZ83
bx6BshHyogPMX2dbY9OZaWRuTeNgOvn8EnEbuHk911VAmK/bugpZ3tmfu+5e
L8qZaG/OLI279pdZEQfHy5Ref/31pUuXYpTImItQIzV6m6+HsOV7JfdO2er7
B1k08DJ4oF1C4dmKCuNgq3ILHUOqmprGwRxuxlRBFTL4Ky3CQF4iK5HgzIo7
Gehn+fKPUPe5aliRtY50ODeveVAyA8RhykbD+S7AoMoBWXoamabzK/XLBcc/
VHdE0sOMVf3NiV7yA6+04bYwlO+bIFnAsFqxLIjPTBwkU6EnY1LDrlxMnzu7
44G9KEYXsqiP80VzfzdTVRfPqcmASYEWQ3CYQmb9GHj+feTnquWLPMnmtjWt
julhAklFSchI1SBxGljkAdsz/5Cb/liK6PBoz1XDCr2RXLnOY6g0Z49zUOrN
CmT6nIPviNiDTgWomEkbyzdQlNxHD4AGXqmIn8QN5fsLRuzXv56BhCqan8sB
xQIqQYHLWVR4rlru/iYRg1AP5EJYMFCeLJXh3LIqEkOoFv4wzyzk9opGkV2O
qhuVytfJaCkHnmNJtL2efcq927rlAAdkTt7mFjBKZi4iC8hLqNG5ahmE/rMi
ToxF5BgxMEDNPZJ0ICv0SJCL8BbDxLTHt15UVCKRTEDp6OoPsCnP+nW5e5QO
0OecwM8HNtp60+p1rprwpMk8M24oWV04w+pxUiKeaHu2DUqRkyhrqSmBnmfk
nuEbJf+8WmSVi6czB5hrJoabchwhDo5ATeNgO/Uxrh+Veq4XLay9PeURYitf
L9qU+gPZx3rR4Sp6VFwqmRdtBOAhRVkeBwvp4RlVsl50uIoeh6GVxMHh6DFJ
rTwONqX+GNj3vOioVfct0D7OVXsk9Q5HHXHwiQEYoRxB8Fe/+tX+hvTss89m
TuwpIe7rpZdeGiAAnY2OlOeee27NmjUDAdOTBMEXX3xx0CiGEBYZXA8axQPK
/YODRjGEcv/goFE8IL3NF154YdAohtDzzz//VLFoxYoVTxuLxo0bt3LlykGj
eEDAgDSQqnPbYHe6IDhv3rzvu8iw9OOKcjpuBy1ZskRM704fjr799ttMueci
Lc/ZJqOQO3fuSDS6VJds5WW209WrV7OhO2S0rhZD4/Y8akwtht45uejTTz+t
E2HI8WWG0jLohMsjsaOi/JSvxt7SkEyFnTt3riPz0qVLcyneCPTll18qJBP+
isIQiV999ZUqMgFeS0EGOLHLrzAbRvm3G94IlBMbSnKmfBXl+p5cEFmDyU0K
uRQs64UwihDLkdS0bNmyetNQTwqTs+4Fz7Eol8d98cUX4VvQSseNiDIsypV8
2WNbjuf69esGFyU521mUzVw5WRqpMbvhgMwWabLrQ16h//qv/8rhEiOQxuIA
XaK6alQ7eCTiIRoFW7jhX9k8QN4fqhs3bhiijpwnzKEVHnK+XFamASkxUgMg
FwxlbUBgwOnFprq0fPnyd999d9RscTK5DyuiASxtB0Y6ztRgsl8vX0MagUE3
b9783e9+1/St7ysnqcb42xyB8n3lIsJAapZz1cLARvTb3/72nXfeKc9f21og
xctBEu3KNkzUFEZNwIDUkRhPEvfSnkgfJIKUCVLCkiGb0D3UitRdmhejb3Wg
0aI9e/bgbTckQbDnvKhX/LRw4cKek3tN50UB1k0Chl7pUr722msXL148efLk
m2++OXv2bGgXLFiQq6bKy2yn7vWiYtPu3bvb8zDJ1AKGRm3dujULxsRQHMBJ
KfWhN6dPnzbGxMD6ZtXPqx21fpIn5zQa7m3atOnKlSsecp9Le3Wjzotmf65a
ElaMjLI/FG8NTDIb9ml1wmQwq0Vm4cxbgj6+Nb1TrHBelFZs2LABW3Ksh+d8
r8QB8po1axZneP78eQAuXbr0448/5mNQOZKaSs6TwRawc9BEvkgSgYbnbKWg
vXDhgviFV2vXrsUiyJmtv17MMs5CarReFFuInqYRB1ecj1n5EjdlyhQZtmzZ
ooEA55u4h5EPXuhJo86LqkjJdJJ86TC9pScJQLmKsXX/Tu0coebXgwcP0lt5
qLp3G53dVLheVMl4kruAGT5ZfF+dE0W3822U+9q4cSOLY4DEp0eUi8xYTRSv
HFLhvGjWU2V1E2AnTpxYv37999UCj1zBhocMNv7Qw/bt29kdSE1PSWr0fZAO
53ZySA4cODBt2jQeUiSdP3++f/kfVkbTmB71ZmW7du16AutFKczhw4cJGh+8
a7itdkwjQdLESfLFtKYwauo5L5qT5fC8fXEI/zB37txt27ZldLBu3bpTp07x
k7l5LWHRc66aTX8mt2DjEpMkPgqGaTk+CGP5hJ5rKob7PqjhNJkhZwFAB/Vx
vqiG0z1yP3bsGClrIOHiMIem4eqiz1kZu2PHjvLTG0IdcTDOWZPpGOZkBR3P
wMriWOBhg/rqubpUM2HApVzOS/rEkdU1OZYQ8kCimdrOlJRGJfA5g77ucyxL
4qD2GlnjJL/NA2eFA0ZBLkb/VF3TjDMws/Qs49m3b5/Mwq7xJpMBu/usvJ5U
HgdhyESTdnHgao+r9C/rIDuoPEyfPj1LW0GikzgATw5FLKmlVRAHs+Mg1xxr
qUpzUyRx51j1VrUqg7ByMB0NB2nv3r3Ss3Hgp+q++EIWlcdBbdRk2kIWENKE
LPfiK3Dg2Wef5dWVRgfkgZOwmHC2vTRi0ahxkJkTFraoSGOxiLpmjwDljBa1
KgMhUJmpN37iUq4P9i9+lrOoJA4SBHuJF4WNPtPe7Pch8Zw9wlnxTmrPkW4C
B6USnfE/N1pyXFk4NyqVfx9MXzdnSeFGvZNlV0Wg0saYW1a6Qg4hMBSp/KLP
RutFsUXn5JuKYBg/fnzWywnHWCGRbvNsOWIFZ7JqncoJ3I9vnUxta9QYGH2n
yIJl0eqMMrA902LRpfLCW8PEQUYRb5NjqLOuTMn6SHQJV6V4JjXPdBtbch44
ADSndf84OIXkKigiY4DZeELnV65c+X016O65nG+4OEhVcuJlT243jYMMMPub
YMjEY/pC1CD3bfkpdaFsUSkvvNVr34RC1JgLB3mnLBK7V1F9+VqrWlkaYDmx
x3OuiqNvsOXWrRyynTERTsqTjSr+qmW47lnJOplc0poLGckrpQGWk73rhgRz
ruyUDokWJfJ6HgFDO5XHQWUGjOarNNPLrfvLvOsjGWXI7XUSI8eAKTfPknO2
s5pRqzNJG83JNFE44CeBJnnCou/vbx2qL5srZFF5HKxZlMKjKu0/RcHCDXiC
sA8WlayT0dLIKMoTpa35ljx4VV8fWfMzqHLLZCGqwn0T2QSR1e/R8BiOxAgi
mp8DKmuDCraIVc7C3kJ5HMwhe637F8HX7Y31xXnW5hbvFDCZ1y2povUQ62Sw
q96DkLn9VsWHaFcOogz38lHpse6biK0FUvxnwOSKwFq74lSbuuuecTAbSGOq
cdo5gTyhIU4vhzknMU67VqTW/etlc/Kbn6CNP49JjqxOguCECRPeaUhTpkwx
eGn61uMj4yPD50GjGEJTp07Vpxo0igeUvXWDRjGEpk2bZtg+aBQPyMB29uzZ
g0YxhAy6jYwGjeIBGXW+9tprg0YxhGbMmPFUschIc9asWYNGMYRmzpxpTDRo
FA8IGJAGjWIICYITJ058vxe9W1HPn5jniRMnev40HCkqF5DpddfFApDEEeoq
IeY5b9689pS/VNSNIbWotK66ztmeKFv368M15MyZMydPnkxiTczz+PHjI8P2
St3qukYP2Q4zQroXPXfUODIxz9dff70wc09hhT+pt+ZVHt6pJiuaEls4duzY
qEjS6jS5XXPaWdQt1j5YxDz1pgoz1yzKc53eoU5J7ANMiEc9evToqEhqxWhv
fv38/vBa1NToRBy9qVGz1dJRRS2mdpFlb3KNuVuU5SQu65OX5OxgVLuB11Jr
R97OwHLStdObavpWqK693TtFi8Kx/pwkPPrkjV6pGVJ7gA4dfhh3DQyptaf0
lHtdY4ddd4eP+IeedXW7shyt1pFfEOw5L5ovHevWrev5cb+P74NKu337trHq
jh071qxZ8/HHH1+7dk3itm3bUtfGjRv73pP4Ttc6mZyP1J7HOHpjRQbXDGf9
+vUYYkRPKBcuXGhV98IYEXA7cMKzYcOGTORmcV0OlIA/V7dkV352bf/+97/3
8P3QQxVKvg9++OGHmu9FMtq9e7dorvwrV66oPftDjeWh8u/du3ezkTYnuW3d
ulUEKb++p9VkXvS7777buXPnBx98oHbRU6XvV+uXcAAYKvHJJ5/gEj7kbLE/
/elPOfqpHEyo5DwZLSUyEsEQIj5//jyREd/27dvzPT2HhpEmFnFBMtcsyqFM
5Xga3T+IRe9Xt18RYr5atu4v0AIgH3+zKzz3wlCzx3H/YI47AIZomKom56JD
f/EkSwKgPXv2LC1iaPgmPRcHSIz6leMpvH9Qt1DJucYi13pqRUSZCcZ8U8bA
HO2Sj0F4tXnz5qabAcvPVcu3ZrVcv35djfXRAQSEJxJztgDkmXiPuTUC02o4
L5ppxlal6swfr6juxYsX9+7dy6ZyphOmxVdnc9aTWScDDGsilGw/J77PP/88
J37kzs0sx2qKJNTz/kGOpX2TO1kQkH4Xl8imNm3alANGLl26hCFZusAF4ZJE
2fIBN9+PanftL43io3K1a84vUrWSO9R+uO+D0Y1x48b1PMqyaRxUKd3IUaIw
vPDCC57fq64KFYh5sByfxdfxcpjc9CKPd7q+D4qDDA2LyDTL1bhcAxD9EAqP
Fbq1Kg0PMZksGBS1X7RoEXGsWrXqpZde8ko4TxlyZkLWc0IYn5kLrW7dupU7
m9ohlXwfzFoFzc/RNMuXL1d1Lo+LkydQsta0fC4BWEXMeerUqTykeCRzfWbj
yFQeB4mAktM6TY7OZDkorubyViwlTQNwz8CzTdmyuBqryz8WjBoHcxenVnML
bMdfTjiXR3s3y2BURxaGupwhoZNvloSFRQBjkX9LTtFs9H1w7dq1AGg+Vvzq
V7/KyS3pgBEfVDScQHldnJ80aRLt6oNFJd8HoyTZlaDt+pnMh14ZBeRctWiO
n7KglGeQBz/nz58/YcKEXENWyKLCOMiQs/AvNp77o7OxLr6O1XBK1IxB1Yew
LV26dNmyZfQNG7OtqYRFje4f5NOyuAJjp0yZEj/Dt+NDrIxF02rp+gwQwgxM
7jQvqaLVcJ1M7knPd+1p06bRamoDAOvDE5wUB1955RVWkHWPbL9VLWIE6fF9
H9SnmjFjRo4H1BYY9OISQXLqC+3KEXB0hjPMvVrl1BEH002iMIr6vrr+O4es
EkqOdINn7ty5ETT/PH78eBwgSiyChPfjn/Wyfqwo9w/G9yrNW7RRjfSWmdB/
mqacDp85XBzE9gzDH8k6GYami5irAGm49mo77gkxWpQ7B1HWD+e4s/LCW73W
i+YkWB4gfbzvKrpcETDYwkHh1ff3zwTO7hUMxyXPYuX71Tlm+WLb/tmaimZL
lxdzdnFPSCXjwRwky13khGStUB0brJVcOplyGloBf8ShxksVZfuM1pX41Ubr
RfGBOuVmPbXXep59QxkEaXvt2KluDrwFpnx8UXKuGm3hGbCI/9TkKIlEIktX
IWL1UzYLeM4FZDWLiKyQRY3Wi2KRVn9f7fAyPo17j+LloGYICZeBR1W0IocD
N2JR4ToZyHPgtu5xen3ETUAJJcSnJ0OOUS1IMCoHBlLmLLooZFFJHFSaKvCh
Ph06W/MAozBRbA/yZE+xhygbe8G05JFSeNZQeRxk+BnCZ9aFvQcMJcErgOFk
bp5zBzqTzDV//FV5HGk0HqzXdXhga2rMkfL4EF9NsnxRDl4j08gIiyQ+vvWi
2eIXr6iiaA7R066sRoaQzmMjPH5ttDup1RUHv692N2N7FqDGb6slDlbV1Nhz
ZudILSdyc565lTV9TqzLSqe467gs7+qXvlPtnaRRoA43hhUEhdpvG5K3AGj6
1uMjfGAOg0YxhPRb6O2gUTwgQYFTHTSKIbR48eJ3qts9nhJia0LzoFEMIUMk
7nHQKB4QZ6KDN2gUQ8gQMlOaTwlx6YYJg0YxhOCBatAoHhB5kdqgUQwhQfCZ
Z5453JAMijdu3Nj0rcdHK1asMIgeVO26SXv37j106FB74vPPP28YPihI3bRy
5cpXXnll0CiG0Lhx49avXz9oFA9o1apVL7/88qBRDKEXXnhh3bp1g0bxgFav
Xv3SSy8NGsUQGj9+/Nq1aweN4gGtWbPmxRdfHDSKIQRP7oZ7Soi8SG1Qtfd0
14Jgx7xoLmrJpEQGpN23PzSdF81h8obz+Zqjc5I5PYX/9a9/zVnrOgndu9EL
qfv7YN2EmjLLhzwYO3slW+SgMuTPHiLAcg0KtJlqy2YWfzMLkQuwMmwPZn2J
nTt3nj59uo/vg1988YWKMheqp/3hhx8qNiuIMjOcm7nybQLaYIbfW+9UNwqV
s6jpOduQvP/++5B8/fXXKtVq/MwnQlVnwhnmvkXWKjtnO5LKiQeqI9bsSiPH
SCRfKPJlQWZ5sgctM+2PaZ1MvmJnrxOG4FK+NGVCKZqM4ZiWr/YXLlzAzEY3
/YVK7puQIXbETi9evAiPRCzCivoAhGh+TjwLi4Chb7lGpxxPybyoWrKQDxPI
ix2BRDSYEBVqVZOHmelqtzX/Yl3TMzQK50XDKOVrO5WOuUWF8I2kctwWMOGJ
PCSYawsaUaN50ZoycRfvBCeGcA54FW9AhYCUoenNDqGm86KZY8/xgIyCUgFD
OjHATCwTXx/6HOq+f5BiJCjUiQkKmQxJGMomWXhi7BQmNyTmIJqoTe2u440x
E+ZshJRHFd7atWtXLrNrh9T9fVAhp06d2rZtW5aO8PCMsaMhTeMge9y9e/eW
LVtYh4C1devWkydP+isQGyCDx//49dy5c7mLpOkNPt1xUBNy2A4uJZxhI/00
bDx79qwmL1682AM+S8nVh/n2mquOpCuQCOJm5cxJDvnwSjk1xAhr06ZNftq3
b5+GNF0v2qruN1Ga9uqfvP322/gMpJJxI+d05QIavyo8H4WxiErAafCS74lp
3agsahoHKY+RyNSpU6mNB5qDY8xBRw68nHnIJcYwcelxrBfFmXnz5i1dupQL
3VcRFuW8QaJMjZiAFYbe8atESdMY2syKiKCcRY3WyWzcuJF/UCy1IZcsV8Of
HNbtJxaEP8QnA6tXci6NKgQTKrmHN9dWYlHuqaEb9BYSqnXs2LFW1ZudNm3a
jBkzqBajmD9//vLly6PYlKoRqpI4+G11VzXr4C0VrvMfh4YJpJMPNGSkHIrd
bmv6DMDzA9lTXxigC+MgXWKSmJB1gwYF/k1vk8l7njJlCp+5tiJhEScxivga
gWk1PFctJ75mUJCzd9gpbJiT9UI524qkjF+o2Zw5c/KtsJG5NY2DnA/FyFm7
DJzq+hvtev7558lUCo3Kbc59uOvuOKiZ2dWVZV3pyBEWE2bXdImMVq9enduc
ActwgEfKdvv9+/djWqv63povm+33D+ZYVLpHtYQznlZpo64XZSDK9BYZHTly
JEv0OxrSNA6eOXNm0aJFuW4sy6c1nNYBtmPHDokCSjZWZKlwgk45vdN1/2Ca
gG+5+jBrJzRH1VLwjefMLd5+zZJd1pELVcmCW0skyrDIc3qGcS+CLEFsqmi4
qxJL1snwALKREfy5gVexhF6bNjnyGAwTfi0KZjVurigHLEh8tOeqhWgUJtA9
QuFjCSVnqAKj1VnOB+f58+fpIVFi6SO/fxDzKW1WecEfFmXFRc3eXK7qJ2xh
MrxHdnOQKcnmcN1CFjW6fxAfcm0l3aZU4LUqeR0/fnzNmjVsR+8OeP/m6DBq
n9U+wHxbfDhJyToZdakoLitXMUrJHoT6tDdocYNZERx4/Cq+ZfdQTueDqmRo
XxIHsZHrBkMzWQ2rz8oKrAApbaf59Jk7qm2NFvlLfDkxTIuyNnJUKoyD+MOU
NJOBaz4kEEYr8I22ZOOJDFTdA5FhDpDpi9LzEjCthnGQ/jD5nDCca6azcQ/T
aJf0nIOqgbTdQ+4fxDGsKze3pnGQnuR28qzbhCEn7eAMM+dURYS5c+cKATJQ
7KYXzHXfP5hm5hIEuspkcnG8RAAoKnnJkwX2/E+OC+OusQIGQYTglIMncdcZ
HspGXXMlfXagDDeg7rlelN6y6OxtyUNHhqZxEDx6WF8vWx8allFtaqwHqjlp
rbzwVq/7B9ubkALrE9JaVQ+ku+qsVo12ZXCdovKQv17JyWYdmLupZDwYVuQU
IA/1MW41tvybhgRzYNRVp3UlLGoaB2tI9XMgBXPw1Bmy4K288FDJvGh7q+vq
ar4lT4cE+2ZReRwMQ6JXtYBaQxlVg4meNwUTKomD9SxQeJXnWv+Tp/63nS21
JpejKomDgVFbX7vF1UoShxB4ta11JBauhyxfL1qrbrtut6e32tSm3UWUg2n1
Oy/arkjhQ2pMYqvNbbaam1sf9w9mIWvqqiXYrue1l+7DXXfEwbrt3SUnsa66
XbVq/9Ntg61e7rqdgd0kCD733HOnGtKLL76YjvdTQrpzkydPHjSKIYRF27Zt
GzSKB6RnNWnSpEGjGEIvvfSSzuSgUTwgXcqJEycOGsUQevnll/VjB43iAelR
P20seuWVVwwWBo3iARmtvPrqq4NGMYQmTJjwVLEIGJAGjWIICYKvvfba3aFk
IGP8mJ0suqO52qyd5s+ff+3atbvFpBx9AMNtRWUb4xdffHHnzh19p1SUa7/K
C+ygM2fOLF++vGcTalL1rYoynfh+dRNZe2Ju+PJXZu8GZEdFMGNIzoPN9nl5
sPH06dMdmRcsWJCFCiMQGKnauzmxITjrKhCmQeLfQP28IswEtc5TQmfPnjWK
L8kZMOFDbvRL0wKsZqB0edoZWA4mtHDhwitXroycJwzHhFyol3vZSCcXigUV
jZKhRpsL5kCS3gjVuXPnli1bVp5f4WqMdKLMgUH3ojxRe7wqL7ODdFMvX748
MgYtVXU4kzsxwyIYao2KjHK7QVh0d3glH4HOnz+/dOnSkfNgRa42Uy+GRArh
Ve1MetpavE0jPGjRokWXLl0aNVs7o4Kwdji5l1DVd++bWy27IGxEFy5cyOEY
jajmD2ykA0O8Ze1kHkaXFi9efPHixZKcKu32SHfvO/DcvlQ7geQh6KZ4gAGp
/jcm3CH6yChKUnubu13+MLXnasLuitrddR13+OqTJ092qJkg2DEvaix59OjR
XOOiagPY7r2HTedF4Txw4ICerbcyA3/jxo0TJ07s2rVr7dq133333bFjx/bs
2VNeYAd1n6umCfv372/PkxPAWLGqd1SU08By7kcO3lHIihUr8JYmex0wY2qc
j/q1qtUjCsl2ciMsHZubN2+++eabO3fu7OP+QXJZtWpV7iDDh/feey/f2nID
Wqv6HElhAFOvNjJ5eUDlsUFtP4ZoVCqfF4VHtz+fkHRujWpz7lx4pbGxyjVr
1hw5ciTHmr3xxhuNwIRGnRfNPUEkQpm//fbbgwcP5tMbFfIu8WUSyQMkWMdq
AKbnuKexhFi4FztUPi8aIhQ6wBaYVT7o5L4zrAYPGKgUiGN9r6wrOVcNbMNq
1kRzxHEP1AmjAgyLiEY6JY/DxyI9N9FHCsyNTscq3EcPQyRFiwgrPIEn3wrl
6WlrDG3lypVNz9AoP1eNBWVhGw3hebKgqFVtSwcADxk1c8MTkpWipatXr246
4d9oXjRTf7lLAkOIiRBxifegSzmBQTo1zo1dYDcCEyqcF6UqwGtyVmN6qBnL
9Agrx0bhGzZSyxwkVXg9Vjt1n6vGi9LG9o93APA20ZB87j98+LA4IhtnS3C4
xMpygse+ffuwLt4g7jruSDYalTv+sopARUyST+tw193fBwmF/XIjuX3j9ddf
73YmTePg9evXKRh/lZtniZjzZAvESuKaLGxJz51H2tvUqXbHwboJWWGCIVkx
m6PgRR9xkF75laaJL7jHn2iXchjv3LlzcydarsBTQpbufFttbdb/TEOoiqax
91wC0g6pMA6qmtSIMt9z4SGvX//61zxYq7JQHRU6w/8Q4gsvvJDeAmPRUclZ
N91rn3pSoziYBVqCnVdEoiyU0kxuOZ4KMH4DJFzFQEooRXqjg0ZL7uGl9pqv
1fohx48f98pXX33FlREQQ4jmY0UuQOTBSIdEsHH79u1knTmBQhY1jYOcGDER
EL+qOiCzx5yCcc6smHxxzDOQbP/MmTNNL3Ut+T7IhebMW0bEyigSs1Wp+JLe
bO65ztkXPAYW8V2e582bp/z0qAtZVBIHeQZVUA+sYEp0AzZthycdzlbF6trW
eJjYGvJiFg3K3/NEx24q/z6Yy3+jpTyhFwOGUGgyPr9fHUlN36gle4GWtpMd
Z5Vz80qov3PVoFIdbxBd+m1FJMsA4SFQzNm9ezfHlb1UesKP/DyZxEEqlKuy
vEW9U4vXf18RtpAatlByXR0pwiIW0XaiLMTTfZ6Md+lDtvZQ2pwOKlvOv6Wi
WyoCb/78+TiDaYKIQtJJoGP/8R//kQNn6LYAnfCkNJm5CyUwbYC5bs6h2133
jIOZPAGAnuD53a4bq5vGQSNTDFQsnESfczt5OQqcha+ZX8qXdB616a607jhY
NwEpOV9Ls4/pp+rqwAwx/Ko6tXtFYwELhkyr5vt4brKLe/dMFpqQKrIsvyek
kjiIsYwdmLAiO7/gzHlTaQhsORU5q4vTW/Y33XiM6j7atCc1uo8+M5A/VJcz
AhMPmU15fso9cR6ArBkIQ1pR3n8uWSejpcr8W0WZD6lvL63XzGQeMhuv8JOI
ySuzXlnXXciipnEwq7spQ7ZmwHC32pGq6jANfzQwyqwh9UFe5VQSBzU2/cbI
IvsgMjOc8U4gZX9czaI6MWfwFgqucDxITzQ8e3K9kvusM30dv9puax4iTYky
372/K7Pb7fSk8jiYHaatqn+VWbh6NQWmZelFPtBAC4znWH09viih/tbJBEO0
hdpkAjnn4ynw2+ouS82M+d+tPqmU61J5HFRpZpyy97OWVzQ5B5fFN2YMG53P
7qFyFnWfL/pRRfHSfs2CFjBy5aKS421qrysbi5MzSoI/2XydbRdej9HVrcg4
URXDKbkgOHXq1I8bkj5wguxTQkZ/mUt8ekjHUp920CgekMHCwoULB41iCGFR
5jCfEjLsNW4aNIohNGfOnFOnTg0axQMyJNchHzSKITR37lzDlkGjeEAnTpww
0B40iiFkxA3VoFE8IPICadAohpAg+OKLL14engwkuxNfffVVo9cR3hq5nPq5
Z2IfZPicHZflMHpiaAom2YhVIO54ZeLEifv27SspZITqclh0CeBRafv27TNm
zGj6VjuA4X4aIc/INGnSpL179/aHoSPlkWjUjh07pk+f3uiVkamn+BrR5MmT
9+zZ06ii9sSe//YtL7Rz585p06aV4BkORk88o2YegaZMmbJ79+7CzCVtf0iR
7dq1i1Pt48UODKMKtJxyGkYfGHr+2yGvPlCRF6mNUNcIlQ7nrktgJI+O5eHD
hzvyC4Ld86IXL168cuVKTtcxjnjnnXc6RpF9zIuq/dy5c8a5eiZgZI3QwYMH
JeaEHIlN7++oqXte9MKFCx37cI2yVXHo0KHMUB04cOD99983gpZt//79hvy5
UtDD999/73WZMw/QPi+aC7kyLWn4kIsGVK20js0pJfsHW9WcQCa0b968mU/P
GJW1BOCpIhuxVeRB7TiJaeUbsWtq9H1QdeSrFhqba8ha1ZywZy3V/PerK1nl
+eabb0iQr2565nyr7L4JklVppozUSHkyuZclOq1qSsQzLYWKKGXW0uzMzYH5
5XjK50VrFrERCI1q6481cOqV5VMLXmWSDbD+pFayTubGjRsKZ8u0mv5knQwF
lph3c8ALokjaKD3zXZBT8kZreErmRakEzlPXnLyHUZmGBalmVL5rQ0616A89
T+bcl9Fo9rh8ncz169eV7y+2qF33NW3nGeh5bgOBFhgpycwvNZ3K7vtcNYIj
vqyejW/J/LC+x3fffcfPEFYulGxK5fOitDeWFUdNjplI9KAjfevWLVw6f/68
PLm1B6SsxWqEp/s8Gd6PX83n2lC8DTHxeHSJZ6a0BJQDQvMtyVgsi583b94M
YT0vmqn+VqX5WIp1OZEgK09Wrlyp+93hroc7Vy1fP7kUMj1z5kxHQ5rGQX5s
3bp1+tvMkB2BnasVM58Jm/aqqP5s8ZDfB9OEDRs2ZB9lPkfevXt3xYoV48aN
y1r9NWvW5CPs+9WV1lmsMn/+fGByeuS8efPAjhOr18nIL8DlmmNhRRX4f7Wi
Dn9SGAfzsRK32Saxzpo1C4Z8+8sJGMrnQNauXUt8tAXyXKuX1bzli+vK46CG
5HgNWkc5MVa/qHX/eC6UtQ3Lli3zKw4zW/DysXWEGfhuGjUO4gPRLF++nJ7A
j6UvvfRSelASE52BgRBgPlYGekXBiMx43AMW5UKfkkUFjc5VI7J4dQCyIqtV
rYvWqF/96lfkEhaxuFwURay5g6kRi0rOVSMmpoQ/LH3mzJlZ2Jb1tBs3boyT
qVk0Z84cxusnUlu4cCFp3q2OqPp4+C/d7VQSB+kzn0klaKnys1CBgaiaTcW0
YeYNcNsDP79q1So+UKSWZ/HixThG2Qp7xYVxMIbGYHlOIqM/r7zyShyv5mNF
Lu2CZPXq1dByINBiZr6SF36sbDVcJ8PJpzNJYVQ3ffp0YSV38pJmFs+MHz+e
QEEVC3AsV82C9Mi/DyJqkPU5TA+SJUuWpPNGglu3bsUZ/+r05uJpovTMUfxU
nVpZzqLu9aKYoPm5VS3XGlIAw9gZM2aQBSTUSfMJmoZLx2RVT5o0iRmy8Zxh
mK/MhhXpf7aqT+dkQf/lxzpmoigZ+IdRzxeVIeuKtVQwzVrTjoY0jYPqZYaY
iY08lahHxHgOsETK4FeiT5SXKKW88Favc9XSBALVCr4oXlpAITUi1iKdDX6P
dlF4zznJlpnwJ2AAySpzvmhWsmW8Q9Z4nmOBOWcvDndlcGEcbFUrKBhgzgHW
Y4G8PgCB1IhSFTimi6hSbN+yZUsuIpSzfBlbeRzENBxTtQcRUDNzSFFGXhBi
Ak9CXjl6Lsf3hTkiY3kfpmQ8mNE6SREKz6DGdM+oZXomqsvR8TmIW+YszKgT
dWygerTrRTMtAE/OXacSWSRAWDl4FlqiCYty5yAwWVfciEWF60V10eNM0j/P
hXrsKOz1bw7VhwQeqGALcp4hR1xCVTJ2LomD/BiHmcXPgJFI1qSx9PQ8WxWr
4cnp1kJPfaMcBUsfTytyVN2o1Gi9KH2mVKTAwDmN9I54G3zAmahNDJ92AZOD
wSGPqpdQo3PVcCObszA/jihr9iiMlBzqKARkAx2OcRQ5j7HR2uPy8SC5ZHdb
rvmrb6X0Oo7xe5wk9YYEr3IpPJxeNKgv30DREQdxAIe5uNxTqfOv8HgblDWW
mZZMZykzh7wNN5XBO9Zluqxj3wRB627l2kE5VTFc52q4e3hHpqZx8HFT97lq
A6fyOPhkqOm5ak+AStaLPklqul70CVBJHHySVBIHnzCVx8Gams7jNaL+5kUf
K/VxrtpjpY44+DSQIPjLX/5yT0N65pln9AqavvX4iC1kb91ASAdGr6Mj8T/+
4z+eKhZRvAGyqCf9+te/XrFixaBRPCDua9y4cYNGMYSeffZZHbxBo3hAguDz
zz8/aBRD6LnnntPBGzSKB6Qr9Zvf/GbQKIYQFkE1aBQPCBiQBlV7T3ctCHZ/
H8wxVq1qykVfq3ss2XQ8aJCb822MW424c+dg9uJlR1hOGGt0FVo7dX8f1ISO
/SzZpWKMZjhvdK9n62/7vpL6PKhWNYVSD1XaD27N3rqcgvtxdYaVZ4P3Cxcu
9HH/YGpRVDZwBU/OCMq0fL3hSwbD/2yiaVVf9gu/edXU6PugduXr27179+od
cNnIk20+ORcL6zxn4XEfR6aUjAfBkCetxpns88rBU/mKWm8+yidgqGQOqqxR
KcfT6PtgWOQhx0xluq+dRVlNRFLZ4RiE5WBCJfcP1ocE1mcfZeoPi2otyiWb
OBYtCqqRN8D2pJLxYC4piG6oItsVCQV7I75WpVfZIhdOZv9prkd8TOfJ4AlI
cTjZblZ/Ysv6EMaYtQTAZEtmDmF7Mutkah+ICbl8DZ6oOkblSJPs7GtacqvJ
eFClcSxZflBfv0h82pVvQ55xLxn6g9R9znaO1Gv3/5nnj7tm137NNvlwKTPJ
udPTWzlgrb4UoDXUXXNf2YidKo4ePVqv/6mp5z7648ePi5iKUvWaNWt27tzZ
0ZA+7h/ct2/fxo0bcWDVqlWbN2/OIsP9+/dT4/rQsHjFSKG88Fav9aKaUMNO
vMg9QTNmzLhy5QqL2LJlSxaMXb9+fd68eTlfFEioWIqQITGHruP2jRs3cr8S
lioku/41JJfQbdq0KRfftEMq2Uefe/TyhWtP1dmO9ak9i13JOoeT3K2O/czC
VPByQBxzrs/zH5Ua7aNfv349AFnsodI0BNOmTp26bt26u9WZkDREByD3xWhF
eh2NQnPheTKy4T+GL1u2LCtS1q5du2DBAlqUDbxsasqUKQAbXeIkhBR+bkXR
0kJU5XEQi3LjIb/hFajiirOUCAAyAobF+ctXrF69Gktz4EYjFpXEwXwyPn36
NJ2fPXt2vvRRV2qTU4n8S/qKyjmfIFHXLABbvHhxfF0hqpI4yJwhoTbpRBHW
1atXr127xmmwlHyF9DB//nxIYGBEnAzm52Cx3OpY7gQK42B6I6SWRQLemjlz
ZvpXly5dwje+6ONqZ3R2/2HL3r17MfOn+1QCptXw+2AWqebEEhYNBmtSL3gH
Dx7EBA6TY+QE9lSnFdGo9ls8Cqn8+yBOki8ZEfSSJUvobRqOb2SaM5z5PV40
q/jY5rFjx5qyqHu9qHpZdFS9/mg7Z84c/ufmzZtUiC3TGVHMv7k0k/fLOa6E
hV1ZPJODm+TJkgaulXkqnB6CrYTz58/zG3uqK+TaIXXHQUURAdOmzwrcvn27
9nY0pGkcJFy15KguOq9dDPPUqVNZg8ReWLEa8eGR3D9YNyGXXNf3Dwoiucg1
5259XREYObnIWxiVC3nJHWNly3WlDCeMzQou3QkNwVgNSeekeyRbEgcxgfLL
xjZ5g1yDuHLlStpVm7YwTflh84Az2pWjTWfNmiWzZy8+2vsHKZimcZV07K2K
OPxWtdYdMP/mwJ+cSicg8qXYhZMYC0z5eZWF54tiiOhGyVkon5AFHqSQrgJ7
xBMKSYLbtm2jUZBj6ZsVUSSSKmRReRzEInrLSWYpiPJrFlEwLGKMFAwetgOD
zISbk65lfuT3D6pImTBoMvsiOKFHjXQ73okh5whWyoxFfH5uRcxhuWHRo7p/
kKR4qhwCSSjZi6SKEydOCHwJPTkiTKX0HGBQcUnPKvPktB3CR3v/YKvqjauC
fuaeQZS+qzjIO5ERn5Ybk2k1zJqQq2Yf0/2DudQvLp0QMUTVwGAylc6NkFwN
nhBfzsTL5bzysIhHfv9gVuDoiuCD6rzFO4VFPKeqc6Enw58wYQLkgYSlkNAu
Tr4QT/c6Ge/yTliX+wdxg6VEFmohiEx9SxcpsjSUrZEaPfc6k8+Ji7mHl7vO
UaU5CjL3zCbuZAjZvWqu574JYFJm4kj3fE7TOAgqvjGBuguULo1aMsfoIUfo
IFrx8PfR103I+T+5RStdr1algXGMMsgWv5QzuFJCVmmmU5orrgJJevIHZyYP
e1LJvGjuoc4uxUTqHO+GV7Wk6lvb8C0taofn34AZlUXlcTAnXKX8zMfWnU91
1bILA+kGDQmwcjChknlRzVd4NFCNUZKcFpsM7WKNdCKvLDmL4ApRlcfBmkXt
vMpPNYtgDvIArgfvjVhUEgdrWUR5iKxd/5OnvgCxtuha8xuxqCQOZiIrapOr
9FqVaNRb21eYkzvjIqn2xOB8tPfRt+7fb9i6bz7tTiYa1a42P1XX0OdXsEvW
G4f6XieTE9VidHgV5rRbYhJbFYcb7SwrnxeNR6rPUYy5te77ydSeQ+eysbqG
1IhF3ePBNDNsj7uuHexP1fWCMuRsyTpSxNhzeb1f6+sL2911NCr567jTE5Ig
+OKLL15pSBMnTkyH7SmhHKo8aBRDaNKkSblT+ykh3baZM2cOGsUQmjx5sv7k
oFE8IN3OTJs/PYRFe/fuHTSKB2RwN3369EGjGEJTpkwxUhg0igdkqDtt2rRB
oxhCU6dOhWrQKB4QMCANGsUQEgQp0kdD6cOK8ix265F2ZBB0jD0/KqZ8pk85
StZlSnqdKIOKygvsoMOHDwvo3enZ2tadmLrAMARIBs95gEdibq/rIBnyYt0c
f1V98+bN7sy5hmBk2EqoW90OQLF1HunJk/QAaxdQIR05cmThwoUlOYcTVtLD
HJA8PKTsZs+eferUqZHzpKI0tlbFDhbV3AjCsKiWcjkdPXp0wYIFhZlrMPhT
V/pRm7zaWVQnNqU5c+acPHlyVCQ91bhGFbZEju3pfbDo2LFj8+fPHzWbKtol
0oEt5DnMqTmZhjSFNHfu3BMnTpTkrNveruEfDVWbmH8Msw8w6Pjx4/PmzWv6
1kdDba1mTp3YgbkRvf7661CV5Gz3SJ5rebWzqKdHakTkldMeanq/oo5stb9t
l0WttH6t1X4Ep63Y2meminPnzrGpjsyCYPf3QQ4hp/p8/vnnb775ZvcFKE3n
RT/99NODBw/qBty5c8fYbevWrVBdunQp9wD+4x//OH/+/MqVKxtdhdZOPfcP
5mY6nrY98ZNPPlm7dq3M8F+7di0H8ty+fVvtEg2cZdi4cWPeMjA3rM79BTmr
LR8v/LqnujTq6tWrS5cu7bmZveT7ILnkI8X169fDinv37uESFuVAJ+N6Ulux
YsUXX3xhXLBq1SphFxgjTbAbsah8XlRdpL9t2zbC0kZg0sC//e1v+VqBdfiG
YxQSQtxYt25doxPMQqPOi2I1DufOerLI5yTswnyosqCiljIk+/fvB5jJE2K+
FdYL3kqofF40X7Fz5AKGbNq0KUvpvvvuO5q8evVqrKtZBLlOI0GXH7hRU8m5
atRYY5l2rACX8sWQuHNxJOvD6hwdBrOfgMSZlRU1uuOsZF40u9Q1X3tV6iHr
e9VFgWPj2AXejRs3styCtrMv2AzJOYrHca4aq1E4/mg7/uTDVibTuOUsp8+R
U4cOHQJSS6VknUw5mFbDedF6RZAaCQ48TMBAjKLeuQENJFoEpF85gT42Pzba
R0+ZCYWx0xOWlZ9EDVX710+UOSdF0Ex84yua4uk+T4aZ04d2a8UEjjptp9iE
xfXl6Bh2zcDhYa08Zy21fFeiWln40aqWtuZcI6XlRapCYRhvyf2DeK6lcq5f
v378+PHe6mhI0zioLSyRUnkAnsSNlQDjuJYsWUJzFi1a9PzzzwscNJPxNj1o
tGcc1BA2pQk8ZNYz5GMTQU+cODFrcnIsDz+vC2cE91lFgOFeq7LW+FgvUhLC
Ij4asmbNGl0FmLk4mHseKVMSBz+uLiHliMQ1RopFUHF98fM5bkLTjOOITwzS
iQKM2uAkoWSiXqAsWZBfHgezWoDiUX5Or90c/CTkRUYy5NY2Y6gXX3yRs81Z
keWfCUq+D8Y/UHvF0nbePt++sQiwfPbNGlG1g03iVJekBCP5tTosKvnYVB4H
lUYQOWURJHXl7EH6AIlC7lb3kmMRZaNyMufosKYsKvk+WLMIEoM15kyHWahn
XMp5YnwI58zQmLaf8IclUieDKeWXs6gkDvJmOcMKJFVoglEkbtCT2bNnZ1sE
7X355Zdzy+3OivLxjkwBg5l/KzyGojAO4hJ9Y0p6SrkpGB/yXZLCCNzMmR+Y
OnUqRsURQUV/fqqOkC0/zaDROpncrn6vosWLF/NChCj+TpgwQbsIbtasWfhG
OvjpQcm5qQrUx3GeDJPXsef3wJg+fTr1iK7qay1btgyXBAW9l0y+6b3gYc5V
w6hyFnXEQayWovlKVr4C9SfJiw+cNGkSTYBBCFO+WtKbygpkbpBPa5darosV
IqM8SqtvAqWTvD0vmsscO7jXc72o6uhtPn2qsdtZNY2D2Cua8DMK9FcTIKSN
MPspQVyN+TgusemelOHGgxh7+fLlrK/wkOsIAcgeGdV5SGdMTvzMvjMAsksi
n1az2iHnnqUzycvlWOMRIJXEQeLIsXLg4XOuycMQANITgJwaAJYVd7mnEkiJ
8ueGO9r4aOOgdmVwoVL6qaJ6fSOoubWNShAijcoZiTQtX9WBKd8EWhIHFYsh
kZHCtSJ+oGZRLrP2E7Q5IjIXt0nUhKyIKGRReRyESkXK9yA05PC0VjVk5mD9
hGM1i7g4yg+wJkgH5tHGwezXS7yDJKfHe0vt9XV74UZgc6pZD0nnI+VyFpXE
QfqACfFpUWb2gjOwRXytyvX5N6P7axVJyT7HrHMAbGT7qql8/6DCVUSBsYVW
e6s+9BtbKE92UeEVJOFhwGh1+dlQjcaD6chlWsOLudQbDM2njVn9mNPImT/w
gZH1nOUDw/I4iOc8EhapGn/gCYuyCFMhVKj2SP4azkT3MuVYiKc7Dipf6xhI
Tr+sz5TLtZi1YiRnphHIyysAR5citSykyVq1VmWPSotF0L3EnZ6QBEHjoLsN
SVdTmU3fenxERtnb8vSQzhtbGzSKB0S99V4GjWII6ZzHST4lJEDo9A4axRBi
nlz0oFE8IP1A44VBoxhCxnGC+KBRPCCON/vanh4y1NJTHTSKBwQMSINGMYQE
weeee+5kQxo/fnw+STwltHbt2smTJw+q9iNHjuS+m/bEF1980Vh+UJC6ad26
dZMmTRo0iiH00ksv5TSDp4TWr18/ceLEQaMYQi+//PLmzZsHjeIBbdiw4dVX
Xx00iiGERblH4CmhjRs3TpgwYdAohtArr7zyVLEIGJAGVXtPdy0Idu8fNPZ8
7733POTWwu6r5fo4T0afLZMwhgA63rkIwDhOotHr0aNHjZ4e1blqOXYgx4zX
iaqGQVckG2l123KroDG1xAy9ActJQXJqeL1RxXC73n51+vTpnLUuT6ZJaf6x
Y8f6u3cpUx+Ztf70008BqGf+s7QpEyCKkicPmJa5iEYsKp8X1SJyx5ZM+mlj
vulA5V8wpH/wwQew5dMS2cn8OM5Vwxw1ai8mZJ94tsH6V2K+qpMI8UXWGEis
hJtEAmq0zarReTKpKFPEeFJ/0abVOWEDPHlyktjt27cLP+N2UMl5MjWLVI0P
mWP85JNPcCCTkJgQFuEhBkKSMwxv3LiRjy/leErmRXOTICIFus2OVEdPALhy
/74bGhUY8sgpHQx+JvcXlONpNTlPhglkTphQiIbU4nCCjUqrGveiNrBlJvCJ
naumLlVzjJh2/PhxyowndClz/vEGcctNCy+fF1Vp1IaA4rGjQtyO2jGwZlEu
bM3tsU3xdJ+zTfRa2r6jU9vZOzHlHhmhinrH2wDwQ0X1DH8NqXbX9a5GUs7u
wnwRUJqOZfe1mz330VOALELIGsV9+/Z1NKSPOLhz505l5vQkA6WsKNOoJUuW
EPHq1au5oI+qW05yikt54a1ecVCTcxxZdlnmFraVK1fq0OJY1sFmD7uOgees
fpkzZw7Pk8nkFStW5EpHTJYn58n4SbFwakgWCuKVDsbJ6oKkdkiFcZCkcGP6
9OnGa4QuNOhMZnu+FHhSzrJly3K+TS49EdHoCYdT7jQaxcEcgpevlphTn3cE
CUj+lTh79mxS41IiO/zJpvJHuI9eUSSIyfn2jUt0RkVkdPDgQc/5Oqld48aN
I9Z58+ZhFFnQeYM7qsvVZzXRI99HD1Uu8aFLKs3KTOack6ixbuHChXT7/2Pv
zr+sKLJ9gf+/d6232ndfq+0ANoMyD4IsoLhoe9tuEQQEUQSUUWRUEBkcr92N
XAYHEFAUu+95n5XfZXDqFFRFZlFVvrfYP9TKyhOZ8c09RmRG7E3DhSQN8vUh
LKpf4VBTf9BtscIje/AFCxYsX76cYvMPSdnXa0JzWKQN/wMJ5tBqM7usF60X
XGUcPHDgAGuirqSzceNGV7GRXbt2UeakitKGN8jyUT+BgWMeJKkFe82XnUrd
royDWMFr4c/OnTsdG81u3769DG5h07Xz/BJeZWXRypUrly5dyq6hrR9Qtcqr
JtzQH/fHqGeeecazsFMRgU2RKQbGuJxkjwsXLtQgaRNa1XSu30fPq0dtyAKj
uKa4NWAY/tDQUAragpQ1mTH8XiPQehYNxEFM4L1ZjYPirlMxMO+LTN8IZd++
ffE2EOqUjs2dO5cQcSNSS24EJg9hPi6Tb9LU6FEXuduhhgaGf3etP6jHLG/j
f7jE8dfhdQc8TC14AREeDyJ4JQtW6v057zHpJAMZZ141psQFCXn8kh6pUJa7
uDO++ZVeReWyPgqMJFgDDEj66cFT/gw3WBlDTlZe6spejjarFrMQ91512Cvj
IIln+wbBuflbb71VKos5cH8OH3iCW7VqlUdIQcxUgAWV869kUX0cFPtwj9w9
MnWlCXkQrolz4P+d596jVNgLG9nhauq43ce8ar0m8W+2iggH5JjaZHii9+zm
oM/A4FtKW2qTD/2kk30olKqktRyd6uMg6RulCM1FbeJnUgie8wTAeWCONmUc
ARMKv20ImPueV40mpPQhReK+Msmi4dS717CIjHADEkEnyUgTPR1TYAKF6n7l
VcNGugpG3LtnZ0TcBYmktHqvyRboGCrGJdzARsnjHpkD3U5h+hoW1e+bcM8M
GJJ/OGvheo33gDa1/zhDOJMAH3OAYfVJpF8DptcyDiajGgHRz7fffpsUUuOb
56f25MilY04mg351EniP4OC+51WLL8JPKseIOEaGljhovowbfHVYxAUlI7cn
zZ4XNlifem5kXrUMYrPm3CAt6WW2N5T1MGwNB+JtnKS0ejd8wpwitWSPj7t2
K+zVTFxIjUItPcK9NlKNWX/wrqPEcdYfLPfsP+gw3y9UWX9wzF7Gg2GA6usP
jsKEu+LpBvK+1B/sRzjyoC21rT/Y39GYxx00qlv9wVE6Gr86ta0/WIPkXsc1
NJ76gzW63YFa1R+sl1RneJ3zqvXGcoydId2X+oP30TdW1h8sz35fmDD6tYLg
73//+4PDaW9DKT4uEBsGDDQwhzXWPfibISMlo8qpRjGMDG+MW6YaxR0yEibr
qUYxjB6wqJCpiumAKUm/xRmNz58/3yC2NPDrlMArBMyKFSumFsMAPffcc6Yn
U43iDj1g0ZgEDEhTjWIYCYJLliy52UemkLt27dqxY4eZ6c6dO81rzpw5c3M4
cRfmFzcf0AN6QPeDmNimTZtEurNnz65fv37Dhg2mFQYJGzduzMk1a9aIj9eu
XZtqpA/oAf1/SILgXesPrlu37tatW6zPBNY4eWAWOc73og/oAT2gfnr//fdX
r1596tSpEydOCIh//etfkzpDEBQK33vvPVOMtWvXJnn+yEVZD+gBPaDx0F3z
ySSLiDj47bffnjt3LrXp++lBHHxAD+g+UlLisKlk0ksaja+//vrjjz/+7rvv
Uo45ZUZ//PHHsvvgAT2gB3RfSBB8+OGHDw2ndxtycODAgb179/o70ODxxx83
STz0m6E9e/Zs27ZtzGYe5ODBgw4MsPft25dn3L9/f06ig82HGL86Lg3SBrWC
tHXrVndodcnB5oNscBael5NQ5aNtq3sWqmTRAJ7ACLvSNTBhRU6GV92oFYsg
ea+hgmQAQ2HavZR2THLVeFiELUHiIKjwyj3bak4/1bNIL1lkmOMilwEWpUG/
nrciXVQafpFUONOvujnTDyONu0GCp62h6b3YVBFfEI4HSaieRSPpYLM2owhx
pPV1I3jcttUlxVUWe+9X5oKtG1WyqHjgguFQn+zKv9F2jcfjlwTBxYsXX++j
7PV76623vv/+++PHj2/cuJFzuD6cnnvuOSPY62PR+fPnN23atH37dkNZfvjY
sWNGvLt27cKHL7744siRI/56KLPODz744O233/7HP/7htu+88w5gJ06c8DjZ
z37t2rXROzp58uQLL7wwehuj6/Xr17ub6e2rr7768ssvQ+XCF198cfXq1Zcu
XdLm1KlTfoLwypUr/voJ4J07d/7pT386ffr0mM/bTwYYn3zySX371LxIiQQ8
8Tiff/55doFB4gCG1157zUErGIU+/PDD559/vr59lijjRpKNr1mzBjxcAsMx
NhLihg0btmzZcrUputqBVq5cmYSKoxM9NANavnw5bfnqq68wIaiuNx+ygaGi
WTBMvtqQqTNJcN0KD+mvXbu2vn1YhAnAAPYf//EfNOry5cus4y9/+Qtlpr34
o8GYCnwvWrVq1blz58ZsBkC2UHEFNITeFsayZSLDHFaGdRpgC2VmmH5qiyep
lWta/u1vf+ND6AwnwKOCxJlcb9wLqEuWLMETUnvppZd4hgsXLvhLP5MXvRUx
3rNnz9a3B2NoaChF5x0vXbqUsaeECgaS2rJlyyiSM22RhPCWTta3J47k2b7e
rO3PSi3Cyt5q3Pv73/9On8muGx7keZO0uZKYObl4EHKhvYTIe/BmPDm/lOJB
//mf/9lBWCFgQBq9DaGICNmsffToUfJ6//33XUj9GGncNRj+Ze+gkhoJugoP
sxWulfkLgveqN3G7If4ku5D6qea9KHaJbm+++SZlE9rIdMaMGVhH8Twg/8AS
OXwAmAzNyS5pT7po0SI8dzlW68jxmGtla/ZN/PLLL56F96ZjMHAO2KsXTnXm
zJnXm8zeSZ+Y5CR4ywtlDzvpYy/OsLjK9L/1+yZCeD537txnn302FTGEP/Ga
LTz99NPiBRE4cJKfJxQeu21Jjrb7JvAc53Hpxo0bnh0rSPDWrVtECQlXtnnz
Zr6Lov7000+UoaTkrafKfRM//PDDunXrfv/735NXtprSiuxS5BygYhfUhu+i
tB4TfwBOHh7DqpHaey9qu28iLMoADGdoTpJLC45xHf/85z+pukDWa7KXd2BR
/b4JYsINOgMAPaHDsRqQsGvFihXAkJ0xbfTHSUPNsKh+a0b9vokM4bLNWZjO
pjDneSry+rd/+zdQ+2u78PbZtX2zKe9Vn+Wm1b4JRDoGKpwet+Pa//W//pfL
M+Z33gGjS02oMOpqy2pZbfdNEBz+s6BkvGFTSeuB1aQGJO5x+NQsX6xoaSs8
vfb7JlLbxViXBwMmczfnBWhcSn0T5wHjVDuwqGbfRL8H5rQ9PsYahpGRQVR2
bb/YEMPn0s1PsZ2xUydtGGD21FfuzLrr90GsTgWBVMQYGYZq4uDNJhsJJMm9
z1PxDCY7CSUiF0PwpAwWG/3qGVMJgnkKTwZIbGf37t01rqMmDialW3KVYxcY
dB63+YFsuuw15UXYILTAO07Q8SucSZCVxmPi6bWPg9jOHJJbnrIlwxI1w3+d
JgU9R9q5JEfbOJj8/KSDS/lMnMogKb4JD1UEI6MCwzP3n6A4WIpNpNpFCnOk
L+qUJPzJOQ8DYP2VAkiw/kN22zgIA/xhEWHRWx41+9mj9tnVm295SRwxcXGw
FE+hP4wXhvTFuDI3DIuIjF3TqNTRbltMoT4Oel7jltRwyRQj5/Xo39TW6a/t
QpRxbm1LcrSNg6nKkdKZkZq/uJQKFLwELQIbPA3iJepv3msfB/+nKUE4oM+p
BpJhlZO4FOGm5nUrPL32cTDmFu/ncVIJotfEr6SxEiK5RJoWFiXvYj3VxMHi
gXX3YUPM3zGexMx7vxYKYeA5H8ClDkWqQVWa/2+23gTrIAIPVdP4Qb2JMelB
vYkx6UG9iTHpQb2JMelBvYkx6f+JehNHjhzZunVrykm89dZbr7766o4dOwZS
do9eb8Iketu2bW+88YbL803chNp8f8OGDfv27Tt8+HC2LmblQ45dot+ccZD9
wlmuk/UGrholhXhNvQn30eydd95xAInn0h08efee+4Pq3507d8KT/VxOQl6O
66ltvQnPmE+x4G3ZsgU8Z3DeJC61mP3qGJhWMAq1rTdBCtu3b4ck4sh3Xscg
QYJRUK1bt87xQOb2eqqvN3GwSUFJXrt27VrfEAEFJEYRDaY5ANIBhBoTYls8
betNJOdVWARbUr86zzRoVBq4ZwckherrTVBsstjTEPWme5ELYM7DmVfZAUPt
8aoDsPp6EzSERHgS/cJAVQ42aXijyebdcMb6yNRPsIGUNq2obb0J2pJX6Poi
KbwCr5zEtGSVjIJ1oPHUm9A7DhPW0Sap5ssvv+yAPuMeZnY2tA71Jg41a7Tw
IYtVBswfx7ohCdXUmwAAK2gFi6bMRFN0G1uiJ1gEYRL0aQykg927d2szMmaN
TnetNxEfaKqulyVLluQFfj+N/l7UJFqDF154gQl4hBdffNEs2DBp4cKFyfro
2EnsNePzpP7F2K+++srDMpCvv/7ak2pmJMy6o6KjT28rvw/yuqZFN27coFcv
vfSSWbORiQdcvHjxzSa19Z///GcDFbNLjXHgaLNRKwtpgEy5zMpXW23fi966
dYvr0Ffyq+Ne6uGa50KS0g8lqy14E1dvIpSa4DQKB7jiZcuWkdH169dFCtwj
jqyfoW95sVOf7bBQ5XtRAKiBIP7FF19cu3aNcnI12UBHmgsWLADj3LlzrICv
yDorcxYiw6V6efW6fh8MiwiIxPOW2Ems9ivtMs5MUfhuLKp8L/rDDz+wYvxk
CAa3+f4eFoH33HPPHWqS+XMRhIgtJKj9sWPHWql0r817UWqsrywiYstCQ5jz
888//+1vfwP1ypUr/hKTafhPP/3kb76Jg9RqV0jb96LXm6UytCVFJVasWEHu
+T4IrV/95anykraDobV9L4ohea+uI4b/7LPPMrfrTQJbIZ4QIcFJnjPC6qBF
HfKqJcX3/PnzhR66xPy5aziZPy9dslh3y3JW817Ug3O5JvuEy7dT3STINff3
b97T+ldIxShIBAui/Pbbb7kIMVHcaaXb98qznfTdvBxuGDcOXDV6HHQh+yU7
aOFxKzfxUETMpWfQxb3nbXzSgIuGqfuwdOlS3sPlMLBuMZGjc6vRH6cmDgKT
NXLgJW2sjrgsePSb1MccSMYSbIT06Z6r/CsQG3vAoIHoMAZPG2obB/FTFxBe
unSJG9ejZ2enGT/no63jfCwDvnK5TqEO3wezChcM4xl4aJeuuR3hJqsIjOST
t5b9At/WQivjIEdBN5ikqAeVjsrSlzNnzhi3UJ4sbHNgnBDDMWLU2NCClCvx
dPg+mBIhXLrowyiC0N+8XxWdiZL4ksGYS2nLoso4iEXUlYwMnPTOIZQMyQ5w
hrvQhvVhESFCkikzPIyrPol0fRykIeIve+HGyeLpp592ptwk+aIBgE0bOh85
5mM0TatPRd42DrKgjMBTlAcfsvLE8Ik2CkDwzJ07l0alFkwrK+61j4N6Ef1x
CUP4MeqUJSg8//Tp07MWJSvYIResGWMrPL1OcZBiMH/q50KDqJg/ocT8jTZp
EXmlOEhbqomDUZvMgLi7VPZxnoZn4VmvMVgqxEuLfaaNRIlLHB09J8Rka6+s
RHDXukueUahN0b18DB24avQ46MJSEgg/3cG/buKvGJSqfw7yKdyxBvkq7WQu
zCWupVSeKJO1UagmDgYVykEeMCnfSzECPWZ1Smmc0WkpBaVl5WC1bRzEljBH
1zcaAqac7DXjk3hRkLCrrUftMB+MIMINB4GRk8l8W/imTduycb02ebajkwFA
bfpHoViRrjVILQMNHKeNn+pTr3SYDxYWxVIAKOYTAf3UUK8ri+rXyWSlpU71
wpkXDkSdMnQv+l/0vNeSRfVxMMtjYkGxpmI4RZMLjJgYyoqRAr6G2sbB3q8q
VBhSVCUHUIVL3QxtPHm2AyNqHKMLjKI5PzfU9p4d4mDUOP3ey/w1aLvuK1QT
B6MbARDdTl8ev3Tq+HpTYyJKHutLcCnWV6nbguATTzxxajidbMiBgeKJEydO
jaAZM2YYPo08P37SnU7bXmXAYL4wZjMPVW5eOuo/2f+8DsIEfzugmjlzpgje
6pL+XtJ1/8kTDXVgTihVDltdoq8CI0zoPwivSoMONGvWLAPdmpb9IsjisfJT
P39GV9oxycDSRKDVJYVF6bRoVAEwgLYtzZ4924i3snHhwIAi9Z8vaLsJzkh7
zpw59XhG6nP/T0VS49GlViwaAFYc3b1OdqC33nrrmWee6Xx5cUcDTng8WmQy
vmPHjnHCOHX/fBEwII3Z7K7q2o/nXrrdAZsgyPYv9pFZDJ9J4TMhFbj5h4vD
afHixTq9WEfG/GbQe/fuXbduHYTHjh179913DQncIethPv744wMHDuzevdsZ
QymdOtB75f2RSfGqVatGb6NHE2dz/PPnz7/++uvmj2fPnnXSLMlcO21Onz4N
gBBv4g8GwGaarlqzZs0HH3xQjwctWbIk5ZIryfx9c0PG/0eOHHnuueccQAve
pk2b4CEFc8x6tg+QW61cubK+Pf5nGUP2sZqYEJaBN25g3fvvvw9klhZQmG6Q
li5dWsNVA2y9G/afOXMmQiwKyQGSF6aZylHaVCylYHm53RbP4cOHDQvr22NR
VoNk90Q27+MGZSaprDwHj+a3RVLo2WefxeoxmwHAYD1+aohDgif0/GIj92yF
BgbfwqIU5KVUbfEQ+ooVK2panjt3Djd0TWSknMz8FxszzPIqU0sMB4y5wbN8
+XJ67te2kJYtW3b8+PFWj/DCCy9QXXplGBaR8ULmuZiDJ0RG2TobGmNhvN2u
TfFZqAiUP6RFKdKKe6yv2z0R3jKK+vaZ9ZMazgCzZcsWB2SUd+9+pWywtXWJ
hYABafQ2NCEWrbu888w2LqIhIIy62Lh9CgYSvwSS83TM7IPP5Bla+SVBcOR7
UaJk3b/88ksyP6xevXpgFtkqv6j7ZNmMvvgNDMxiIdqLG4IgibNK7kJczrZN
j99q207lOhl3TvoaSCJHJ1mfx8wrkWvXrvEV7DQfW1lr9jrxKtlHLzbdq/Du
ALV9L0oW+uW9k7Pld7/73eXLlwHmVAno5s2bGE7oeb9EN1oVpO51ei/KJ5DL
jz/+iLcwpPq8YErTCOvnn3/mwfCw1xQ+pqVtP5rXfx/MWt8sGzarzRqYXpP3
ALCFCxfeuHEDrxgLeYHNWLIIhAhGZse9F3V4L0rx9EUWFIPqYktqzhqVGQVR
7NR8pznUpgOLKt+LenxMoHKiXuoRY1HWEty+fZtSGR5rk6FdtstpHDxYdK/i
pCOp/r1oKtGLMnQGV//P//k/eOW8Tp966ilM4+jESjqAUVnbQ9k87K1btwii
fqlM2/eiQh5eJWEFh0O3KZgeIXn88cch4RCmTZtGsfNdZsyPMgPU9r2o+xMB
q9cd92guCQlIWMH3JtUzp5SN4XxC2xrlvfbvRelM5iz01siK3/jpp5/0i1dZ
PwkGPHn96HkdtMJT815Ujx5cgKA/2lNXvZAX2fHeccJwwpPdpp988okREaYB
yQxpqZPcS6X533UfvTtzvwzKs4sCIz1/qzgIj6infRLjZEPExw2ZceiCF2W5
2SmJ+RirfSveVq6T0Qv1ZmgM0LCQNJ1MJeXYHYbzn4xdVMJhjTEBHshxmNMA
r/J7Tds4mKLYBl1RudRS56DgpA+6BqmUF3eyMhwX6rBOBiQapSOMwjow6AYx
JdNdttDmawVH5PwE7aPXkdBGFthCXoTl8fP+n8IQzdcN8RWOqY2/nCohYhpN
dlCJp8M6mZQOp8AEZ+QchjimwPgGjIOkdqE2HVhUGQfdFovIiMoRFg5EWPkJ
E/AQr5LciUrzLXv27KHtKW5en6KkPg6CnZXhRJYshWWpM1Ee/TU1EBiJNUBi
1M2m7huTzDeyGmobB4HBBE8dPyD0JLMW02Zf4PGofs2XOJpWP44KtY2DxKQj
Lj3fK8mOfWXzOJyJkjjGGDM0LatE6qltHNQpL534EhYRFgAGVE6CkdVovSYS
EWVbFtXEQT166qT2SlpONn612SpOUnE7WCcy5ktiXtVqDBipJf2LX11bA0kQ
FHNv34MioJFktJnUGb8RIizmeV9uda9HbktDQ0NkMf773C88Rh3M877c6n5B
SkLO8XR6v5CEOEDmeR9vOH5au3at0NP2qvvLln7KXHuCbt6NDDiTSGQ81M+x
cXJPvDB6GSee8cPopyQrvl93Gz8BA9KYzVqZ/DglKAg+9NBDe4aTiYnxm4Pd
u3cbA/g70ODhhx9+9dVX99w/SuXfdG3UOrLH0UkQnDZtWk0vKfad4/TSf7L/
X3hMK3KyMKSeHnnkkQ0bNtS3D6vTtX71mJMG1eVkWwz9ZKbz5JNPtrokmzdz
3C+gqAQqPOxGjz766Pr162tapvfwoSDZM1w/dzWUk92AmS93ZpHucCadOlnE
d1fzqac//OEPbVkED50JgD2N2vg3IP3qOPxx0EGdsOiJJ56oaXlXfS7nw5bA
SJuoegdeYVHZZF1DYUKE1Q8sjBpA24Fefvnlxx9/vNu1wRZhYU5gDAi0Az32
2GPr1q1rdUmxoMKNAqNfgt3wAAPSmM2KBy4GFf6Urot95WA8RicIDrwXvXXr
ltkoH262a0aMIQcOHBiYRbatP2jyyILM2lyVl5NXrlxx0iTXRNs03Mnjx4/3
mgx7GzdubLstpTK/6Pbt202LklPRgMQs28O+/vrrxidp45GFVHfLS5utW7de
v3790KFDILVdm932vaiO4gpggPONN94wnXSS6B1fu3YtNTLawijU4b3o6dOn
adQvv/xy5swZXRPfDz/8gG84ln1eHSTVT5XvRX/88cfkirl06VIEferUqbxg
JKMMDy5evKiNB8Q9zTRum/Ow1+m9KBYRGRZhCG+sd2NLkYuluxv1jm/vsPc5
VPleFIvIwlNfbNa5MViqmzXn+OOhTHVpO9ZlVy/9j0Nr+72y/r1o9n9RXQfA
EI25ZK8xcDNKGs7qt23bhmlffvll1Hvv3r35ptmK2r4XxaJ33313y5YthJWS
x0le7eDDDz8kR+oNXn3u8QEaT35RHHMt9cYQKkRelNnTcdRmB902KfTavxdl
5vij3+tNCQxdJ08vvqXUC+eGRW0/CxaqfC8aD0xMMGCFqOE4e5nz0ZZnxiUa
DipnQn/4czzUeN++fa10e+T3wew3pxWeF9r33ntvJOZWcZAT8DhDQ0PPPvss
lzVnzhyalo3zy5Ytw2EPlQ3s+E8BPFHbzPyt6k3owtP9+7//O31zMmmC0p0G
5pWwYTjv4V+NJ6feBJXDEIz1LLqmh8eOHaMMTq5cuTJFH2bPni0Y3W4yLUxm
vQnKD5jLCSjFFLAOYM/IuWk5ofUmPC8TSM0g1ocb+BOHyQrYxapVq1KkY+bM
mXhOb9euXZsPBJNfbwKLFi9e/Nxzzx1tspDtGV9Jjso4GBbRmZg/VyAEl9Tx
4l3CENPjZiG5Pbwkx4TWmzDiXb16NUvPBnDqRIWytC9L6MEWO+bOncvPcGgT
XW8i+bLy4W/FihVLly5lTSnWQ5+xIiM9DLw9dfUmKO3ShsiIzhgM8zy9JoJM
cr0JFlHqTYiD2ELDU5KDPk9cvQkD7HjgBMQFCxaIHc4TFj8QOxKnqBZ5TUS9
iaQTNwXI93QH46xHT50I0TgQKmEISFM/rKO9Jp5uzodgKX7yYFkq02rBWK96
PghGEuDnM3QqfRvSuzwj9tvNdzTMxFh+LPneL1++nKz4E1pvAhgui0XcbgoW
gIEtqengZApPpIxC+DkJ9SayHeD6rxUAsUXXRBNv7yRJpWYBnkxcvYlUbcAQ
YxJOAxL/pq8knNd7lvwlJ7+T2bEyyfUmHERA7gNtlmWWkhzdWFQZB/tZlKoE
Zed10u/7mxUgFDhfT0pJDspWz6JW9Sa4EZZFjakubBm5AeYkGA5wDzaeIeVU
Ym5UK8tUKiF1iIP6TeKOVAa52RBJCWERX5BoAN6U1Jvw+OESnH4qVUtSjrAV
nt59rTeRr2/9JTk6sKgyDsYD64UF6TEqjTllBS+fHHal3kS+pBeFj/lXTlsm
ud4EeJiQlT/3kR7UmxiTHtSbGJMe1JsYkx7UmxiTHtSbGJNO/VbrTRzro+Tu
Nrs0+U1Cb9PSY8Np2rRp27dvP9ae3DAfMZMk3AzXzR2krgTqcE9kgvz000+P
3iaf+VLsPvUmdLrn1wTmTmrz9ttvO965cydUqTHhpH/zFroVJCx6880369un
vPsbb7yBCfjv+ODBg/v27dO1k0UoTraCUWjz5s2zZ8+ub3+0qTayZcsWBwBg
y65du5xPMYVjDa/wsNUzDtD06dPduaYlqREHYeVLQZLJO598CH7Flmwex71S
TKEtHs81a9as+vb9LEqW++Tkj/iSG9kcPHzrRk899dS2bdtqWhYWFUUKi5LR
Ny//o+oO2F03FnnYShYRhC60p7rZ2qnTY40ZElN2gxb3ksapN9EW0h//+Ef3
r2+vU3qbd33ZGJ66NjkZmXZDEsr7+W7X5l06AI6pMWE5iEbR+W73RDNmzGjF
ouxPx6jYftjiJF7FY5MgdnVmkRuCNHqbUm/CAUVNhmdiAsx5PNGGJidldAq7
xNBi/m2NbmS9CVNLQ1DTq2+++UagNPwbuZO07TqZQgZLS5YscXl86Ysvvkjo
eavJrx4/frxbAvPO9SY8GkjZS6vrv/zlL1gKlcapfmIyTuK8HD63ql/Q9r0o
VnNlDPPy5cvwiFkmuRSAWMkie37/8z//czLrTZRiCjDgCXie/eOPPwbPr9Rv
8eLFIOWtzsTVm/jhhx/MHP/0pz+RMuk40PXtJm0g/gDANv/xj38sWLBg6dKl
58+fB88cIbo0afUmsrpJ4IMWJJxhtvhGDcSmvPtq9ao/VF9vAovw89NPP706
vN7Et99+Cwm3kPK7f/7zn7/77rtJqDfBoNw/W2MydMGNXrMUjQcgLOdBNQFn
gxcvXjQgx7S///3vE11vAiodmY9QpwwyKRUz52P5OvbF9Mg0uQUmud7EmTNn
Um/CGUMFoyC/mu1iTgq7TE69CZ3iAN3OFjy6lM8x5EgBYMPz+fPn42SvE4ta
1ZvI/mWGoDtGzcpcm2QCUePsJqbz4jIwTNhV+T4+nnoT+nWGFBzw5I5Hfpnt
HAcztsksjFs2SmS/165dozn+7bBaLNS53oTzxjnJdNFrcs5zZbxrqTfBw+Aw
zWTF4fYE1Zs4ceJEygToUfx1OemL2nBmqeTq1atFZK5j8utNMG3AMIGaUbC8
X6V19NBJbJnQehN8VMbtDEGY618MSXDkQkz5oA8PRtEujXn+JOg4NSn1JmgR
SzF2DYuSrYXTwJas9JuqehO6pi1Xm5UM3CxszoRFE1pvgtq4M42lqOTF6o2u
e417YapU0XMV96IxzjvvzETXmxBWUs4PsGQypEXJIphEUtxs0sFNbb0JMpo+
fTpucDgsjrw0mJx6EzwkAVEhVsZju5z+OJllk5SNnmM7B6VBBxa1qjfBuJJz
kmJzYqnNmi+S5dVHYFAzvpEPdxVHTbfHU28i2/NLvQOjtZHfrDvHQbdKDvBU
B3BzB6yA0CsX9tyV6utNJEd6SbzfG16/INUxMororzfRXz5ggupNJHd6UAEZ
npdM7/1Cmfx6E8CU8gSRWsalJQv9RNebuP1rwvnbfQU4eo04Ck+iURkEliIp
k1ZvQtelykMRXz/fpqrehL/Ffm831Ux6v+r5hNabSAmJwodS1qHXqFDgFfcS
lc7Jia43EdMuwNJX0N7+taRC0P5G6k30+qqWTE69iahHXOWAvYdd+BNedWNR
q3oT/fWPBsoDlVoq/S69m27ftd7EmKn7J67eRDfqVm9iZHL+U7+mUj817gTm
HepNlNoE/QULRhZ66EbjqTfhr8HYSBjjhFRfb6JfD/uFiAArdShy3Dk//3jq
TZxqFKacTEqofr51o/HXmyhsOTW8hMFk1psY0BPHgRT+FJEVnK2obb2JMCTY
+jsdKKbQFkah+1VvYpz+p5/GWW+i3/TCrkmuN3HqHrUnIsr+487mP7LehGDN
OxllmY+XhPAD2blb1ZsodPbsWTPW3bt3u+0nn3xicm2S4uYHDhwwznRD09j3
33+/Q/2CzvUmjh8/bnyb8ZI2+/fvz4voVL5AZpqOtTFjbQWpbb0JY1pzfAHd
rCQvjSNZeEz/MWpdQ6b5rWAUGme9CQcgGeuWehN5N4Lz3fBcrK43YUK0adMm
k0d6gjk6LUygPPAkEwJhOUjBSlDZWltFGk+9CXry/PPPMxnHeAXVp59+euTI
kdR66FySo0O9CRLBK/3i28XG6HCDcz5z5kwqKSR/5qTVm8ATf0FyrfMkCOp/
/Md/MCvAUsklVRVSpKMtpLb1JvT72muvYQWElESn7J3oGRrFpj+iKnvPhpcO
dF/qTXBH+fadhKJUCDO73fPiOOpNOEh6iozrsIj3BskNQUoe5g50rK7eRCmP
kvVmlDauOxanDblTrawwSaGi1BC5L/UmzCV5Eo98tSmonYTwA7PIDu9Fw14I
KZibM88FCxZw/kKqRwPeCGH16tVDQ0Ntd6P0OtWb8FyEi58k/uijj3pYk26s
WLt2LX5evnyZCAwSNPjuu++2NDSh9SaYjyktALhEptQ+K6bYVIqPYFqKMk9y
vYlUuDAMoL1Yl3oTzAHfHG/evBlbJrTeBAAUY+HChXT7559/BokKpS/HqVpC
nWbMmIFRYBgtiOB4mITz9cUUxlNvgtVQXXegvY8//jjmgHT79m2MSh3tSas3
4dkXLVqEJ9GQpCRyHwD4rscee4yHuTqJ9SauXbtGcE899RQV6jVMS+WCH3/8
kc5va8hJrsBoJy+3J7TexD//+c9jzapRBx48NUqMZ7J6Byexyz2p9BTWmyC7
xEHqBF4Wy6XQw8WWCwN646g3wXwSXwxBDVQoVSBhETXgHyah3gRlIBfqmooD
4gVVj26nSogxjBBZzP9+1ZtILh03708IP3BVhzhI0NSeT0hap6iik56OMznd
UJ60/mtFoc71JijhqSYneRwUNmqDvRpnfz179Cu0Wck2cfUmoIJE7w7MBFNx
I5U4UoRC17iX7ymTVm+CAeYLvtADQ1aGHGvqTVxsJlBZVIYnp37NdVZP9fvo
ySsvCuKyKEn6cibywjSoUh8kBRyTT2Zy6k1gEYY44BnCotSbSEmOfM6Y6HoT
WUzLKlMjhrzKzutjzX72OBazM/wcqDdRz6Ju9SZYUA7y08VmApst/ESWKEaU
cSkTXW8iA7ykoRAHY9cpQnGqSWgmABlO8H63m2IKbTMHjr/eRNKMZA8OJ4At
zsTQJrneBCn4m+Ig9BkeLIpvJDg8vD3B9SaiNnm1Qm3oMAXmAfKRVAMRmW5r
Q8n7601ErKfa1JtYtmzZzy3J+NyztL1q4oiBZ/z/2yGzAyKYahR3iPnQvalG
MYzWrFnDE041ijvExDjVqUYxjAw4ReepRnGHkmpvqlEMIxMlo5GpRnGHOO0U
EPztUOr5TjWKO5SPCFONYhgJgv/7f//vvX20e/fuV199dePGjQ6yCdffvcPp
kUce0WBvSzLQ2rp165tvvpndvskNbh63ZcuW/Fv+tiXD+OnTp4/exsgB5qSU
z5cLeDxavrv5dW+zxH39+vX+7tq1y0G2eLgk3GgF6dFHH03q4ErKXnXA9Igh
SYWqa/zftm2bk8DkZDcyGZw2bVp9ez2+/vrr4cCOHTtwo8DAumShz0FnSFiU
7bqjEFlg/p4m3T0M4Q9gqTgfnBpkjyceYlfOZzd0K3VKvYn69v0siqUAkK6z
KyGfoYO//rb9lHoTYzbz7HrRlx6jMw7SafYgaxD9x5PUWci28bZ4dPHEE0/U
tEy/NDmpg7OTJT/FuBwU9xL8HawMPfbYYzUs6gcGD0XSVzE0OlMMrZzsRpxJ
JYtGUpIh0CjYHESro06wdYb0+OOPe7r69lGPlG/AivjnsIjOxBJpAmDd8LgP
SGM2oxiYsLfxjZs3b069ieyjLwalQSp0OJ82cAIff15PguDAe1HBMZ/wvv76
a3Ph5GAZmEV2eC/6yy+/uBu0Jq0e8Pz58zj8r3/961iTsCUZzs1z8blDGvOa
96Km8HTJRFtfJo8rVqzI+z2z6RRc1kbvq1atws+bN2+a77snMJcuXdKg7VfL
tu9FscUlmfJnu2iKmJMRETiGx8lWGPqpw/dBs+xkD9i3bx+2vPTSS9hCW1au
XElDkq68MtvqXWnM96JJlWmQc+vWrcOHDyexD7WEhPgOHjyYV7L4wzTM5ogP
D7O9KEtrWu1I7fB90CxbR1QLKsbIYLHI2BLfnLly5QqBOtktO0SvZX5RFnTy
5MnojOOfm3dH8Jh3ExZtXL58OTk6CKNOnz49cfUm8nqTvV+8eNElPGfMgSiT
bB/TinuhRUwS31KTohW1fS/KydDhZEdn+6TDuK5evXrgwIHs0Xv//fc5irYw
CrV9L8q+ypYfgiMg5n+7qWMIJxVifQ5o5qTVm0jyEACyiRg3KFhYJIT5lZj4
xs473Wrei+oOBqqbjK9EQ59PNYu6dZ0v2qlBzzFiIKlhEcP3U4pEtII08vsg
kxkaGqLAkFD7NxsauKpDHISZT8BG3GOknNiiRYsYqZPwf/vttyLUwoULO9hm
ry4O0rTk27naFKBhCBjYa/bRp8hyr4mDbJYT43x4WnFH0ASYOKg3raCTZdP9
6NQ2Durl3XffxR+Rl89nSg7whKCTJ8Hf1FnwICJC2wDU4fsgrfMUSUgCj95B
woqs2HR+7dq1kRfhAn/f99G7M7bzDPlEYuCU2kbEJ0AkDvrJv0xGS+YJHmvF
eQ/7zDPPaMwuyLFm716H74P4gAnJCUxhCC6pXUDCmWQlihrA1oFF9fsHaTV/
le/dAGBCvg8yZ+GPgIwomG14riU9Tw6EfICuxFMfB+kbGMYGXBNfyvT87TXr
hcjx97//PbkU90I6RvIckTGnBslfUQmpQxzEVfoMmJEwhywgkiNDC9MwJMvD
oEpJr/qb99rHQR3pQryjTjE0gz3Y2D6cpJZsTjQKNjxMfbpW1KHuEvOhrhmT
6x0eSkKRUuuBTpp2OejGopo4mAHwrFmzSIf2susUfRA7nE+YIylBJCkRKFv0
37HGCeJ8e+Xn1JFx0FDErbhZBx7fwchv1h3iIJZ6kCy64MwdMwQneSpdRCc5
jQ6LZHrV60X1mGVgeJtScb1mrV3xTgH2Y0MeUHs/0QrmicO8btK51EBqGwf1
gg/AZHRa+A9GmOYvbNkK7Sl+brmdtsN8MNLPHl6sCAf4VazLrnBs0Sbf91Pp
oBWkmnUyOtVL1qzCkPRT/kZ5gvO7hrKpNge9ZkwLZ3JBOKgZS3eYDxYDycKh
rDqmXamhkOOwhdp0YFF9HEy2h14zEYMEH9IXbBFT1AbCuK/oea8JlPVLIuvj
oHtS3ViZfqMzBSqmpWhjFIyYtAkM5yvlFWobB6MPuFQM7ecmsxm0MESdYn0x
uraGNp599Doll+xbdwBPhBXr6zXOqm2hmV6n9aLx1WBQj7BIv2FRr1Gqstm/
A4tq4mDv10w7cdd0OPv6AYjPSRsSTNWzuOtMrjWOowC+ckAlCM6YMePzljRn
zhyhtu1Vo9OnDXW79p133lm6dOn9xTNOmjt3rgnLVKO4Q7t3716yZMlUoxhG
8+bNM+acahR3yJRk8eLFU41iGM2fP98kZapR3CETFiPwqUYxjBYsWGCSMtUo
7lD2rUw1imG0cOFCqKYaxR0iL5CmGsUwEgRnzpz5RR+ZSJpgmjucOnUqHwoP
HTr0xXDi5EeevCudOHFi/fr1Gn/00UeOTfocnD17Voxg4O+///4HH3xw9OhR
k27nnTTV9esbb7zhGJKaLhAn/+yzz47ext2SW/7jjz/evHmzYa0ujhw5YiLp
vJPa6Dp7w9HQ0BA+uMq8O7tUKsGEOHk3qW+PD+vWrdu5cycurV279pVXXgmX
YDO8/OSTT/Aku+y7ESefsp6V9Hkzuti0aZO5dl5oYxQuOUg28hQMzR72bpA4
eQ84OgY81K/H1yOdfO2110hk165dqRP6RcO31atXwxm9BQls6pSXqBS4Hg8n
b6hQ3/7zZnQRFoFHUmSERQ6wiFZT+yy7qr/nAGERjR2zGf5s376dntCf48eP
01iPb1T5RSN3YGDwbxbJOJma3cTaFg93aqhQ0zLvQiOXt99+O2k8nSeaLVu2
PP/88/gDADmCxPZfbshVbSGJg0mwUEkMecOGDfREXw4whyJhCO3auHEjkFSO
06t3PgPkocTBbtdCkvopfC/tBfLDDz+kVGvWrMH5bvdEgk4rWbMa3KDSNHzH
jh10yQFfnXVWjimbk53xkBdIo7chCGaOG/Q28Ygh0G0YeOPYNd2mP0yMq6Tz
9IrU6JXGVK4VJEFw5DqZZPU3AyUCDfiHgVlk5XtRM1OSpRXUHhuxjogJFG8Z
pjunxlC2K5IUh5alF9yRlvXbUmrei5pfJ7e8ebRHzkj7yy+/pGwPP/xwXjiT
76xZs/Dw/PnzuOqeV65cSTBirXkJUDnRbvteFEPoBm54fMdQkU7y3NKHbF2k
hEnAWN4K1tPn7d+LugQH8l70QEOefc6cOXBSSMrpgCYkoV95EVdPNe9FcQMn
3R8TiMAI4R//+AcMTia9AyWhVynhTWd4aT/BSZ2AJ2uMwq4Jei8aruYVMekA
cOvWLSZJtxkpG8liUS27sajyvWheAYk1//Vf/4UhBic0Oa/9BUcOf9myZfn8
BKHz2MgEUkAkKZQr8dS/F4WHmdPn7P9KSZdeY4Z4lc/fKUVBl1iKcSOTTCnV
fI+ohNT2vSgYxk6wMW1+xpBerOE/sfrRRx8lMipNfEDG0NpmhW37XhR/KHlU
VFxOvQn/8jnw8PAZURBu3hB2SDPS9r3oL7/8Akk+/Ys4jp0RDgBja9mWC17x
RW1ZVPNeFBupKEvHHCIWNVJCBUPKGjC2xldnGvXUU0+BlDfe/HzWFtLtynf+
d603QY5ik5vEkLOepJ8q4yC0Bqi0zt1oO4cAoZAnbPEVIs7Fixc14FF1oUEW
cns6l3B6n1fX766Jg3xjir9glNDGryYTQqalsTvKn4pXhO6vn/KVtuzddmbi
1smAZ8zDgYRXFIymYRcM9BAeSpiX4aQ/0etkMMSglAHmCz4YyV7Leeo9lcTx
UJj2K0dnSDMR62S+aJaKpTaB7rLDGhi88kS95osJDNSGurIv2Gim24pojmFm
GtRv4tbJMBAsynSV4LCIVeISOULrhvxYMs/QugldJxM15tUzYc/3ONobG8SB
1P3keCkznjjpEbTk6yrx1MfBpLqiz+wOJIpUstYIW2bNus7eihQ0JyxMyxdM
2OoX+nbIs20ERSt0wRtQKgpDWCyONJNtAHIyTWatlPippw7rRUv+atcSUJSc
dOIMaXWmQknRkPRErahtHCSO1GfEAd1xiYICb+C5nBSMUjZIMx4+WTdb4amJ
g3jikXl1vYgOVCWPAEYJPbQ9i3m0SVlbcuSLQErOCmg7r5Opoc71JkLw81Q8
W+f15ANUEwfvRffC0H++A862cbAG0niobRycBKqvNxG6l0TK8Tj51jYO3ovu
o/jq4+AodFc83UDWx8FJo7Zx8F50v6Q2znoThcbpf/qpbRycaKpcJ9NPrTjQ
gV2C4EMPPbSnj0RVEzQTNwcpPp4Nlf308MMPm9DtuRsZQRnOjbyk3FyDu/6U
LZDZ/9uW2Oa0adNGb5PnCjCDQHMrxznp37TJ84JhRAFJtvxrZiZe2lTSI488
smHDhvr22AIS1oXtenewp9nFn43G+T6Ykx2Ih3/yySdbXaLrcKCoxJ5mw3j2
IIct9xJ0DT366KOmA2M2S+95fx7BEVD/T0Cm8mx2bXcGln30rS4pLEqRSmoD
0taGHEMLSUHbgbKPvqZl9CejYpCKqhQW7WnUPlvF89GnG4ueeOKJmpYeP+YW
U4pZ7RnuXoplBXNyXLQlLHrllVfq2+dtrccPx+Lf+iXVb30dyID88ccf73Zt
zByFaeFSsI3H0B577LF169bVt4/s4vFwI8ocvsUXRcGc7IYHGJBGb6OXeOBk
Eoi8IjIY0gbCiC/mH50vPrwVJEFw+fLlt/voxo0b5sIGoqYzPHlyYt8eTqtX
rzYGuz2CzOKDef/+/Z988glI8CSZPKaZ6ZtQc8jmqkn/q0Feam3atMlVBw4c
WLFiBVSnT5/++OOPPa+7nT9/3mPu27fPVHdkjyE3FArv9Wt5LhP8kydP6pqu
pgqAkwK67tImH2H9mxTTq1atMhoHI1rh6Ubvop+GhoYMe+rbf/fdd8l0kY3h
oJ45cybvxvPVCXJzTBOo+nv2E34apta3//nnn0+cOAHGjz/++N5776UuQIqo
0k9gKEAqsHfDg1KsfMxmyWdITEePHv3v//7vKH8qoFEVN8lmxhQMxTFtslG0
LR4a6w717bEo324gxBmao+vvv/9+5cqVtAuSK1eu5JNKWySF1q5dm09mo9PN
mzdTF4BQsnAIN6KujIvsTp06RdXxxE8//fQTticxSFs87IJC1rRkZdSYaLKl
MRsqbw93L8yKf+AcQN3TuN+2eBCjMJGvb8+COBMCIp2UleGgLl68yIVGav5m
OVYHMLeb/e+err49cWRTsOPDhw/zG8ePH6dF4dKlS5f4UmrpWLNukGjm559/
Xt9e75jAHLAo+W1IMAVrgKHqQw150m54gAFp9Db0hNtJwnPyxQH+/+uvv373
3XdFkKQ2zcCYmlFLEzru6OrVq8yN1VC8VpAEwYH3ogCIKUK2e3LFGbMNzCLv
9V6UNJP8KkvmBDXs4r7mzZtH4T07xQOSg81S1ezOZiPMk6Dddvbs2R7HUzt2
ufPMx02y//1es9qa96K8Fq/O1siRQHXBVzgp9KTWvDYiPueAsdeuXeMoFi1a
xFqTYogypNT4BOXZhoqmYVHezlE/XIJw7ty5+MDtC2RY90WTbTJfMOtv3uua
T8ZThBWAuVyn5EJAAICHjceOHUuxAJKdoDzbveaDBf5DwjapBHnl41cW09JV
x/iTGvR8WpKq5RMnjlXi6bBOhrcklGxTMmpKNnI8AQxDks7aPZPvBccmKM+2
3tkIleam+HOBT6dZ0EW9wyLjSax7+OGH2RGThDYfLrEoX1prqP69KC1lOLEs
7osPKTvg4l4oPI3a00ygUmohOUO4OL5uQvNsHzx4kCwcUBXAiCzJW4wZnMFz
J3ldYASmtkmk274XxRAi5k4xwaiSxSWvCGkKRjTf08UfakD/WWUrPL1O+WSI
ho3jBjBMj0rTH3yj7bR62bJl9CfzIyyqr1cSqvw+SD9pcmowZak/d4EPKUDf
a3Sb2uAYXRI06ZUGWJT3ivlWXplDfuT3QRrIpZCmA48Mw8idm/eKg7oWmgmO
HCNf3NMS1BQ84r5A1SDbe90cD5Nq3r8aZxF+uRw58CwObt97i31lXjXd6SI7
sh2nbrgnBSkOKuezyNDJRF5ezsmsqSsnx6S2cVCnkGSl3MWm6F5cvTOYA3yY
ebupTY+Bk1B3ifRdlY/4sHEIKZqjd/zxdGRt/Jz0Ah2+9tbHQWqfuK87neor
8oKNbmStb4IRDFpCm03rZedvDXWIg4VFunaAOdFwwsIibIEkALqxqH69qF5o
KSRZWQFY+upnUY6j29iYhViUrd7Vt4qDYOiIutKfYjX97oWTd8MksqDbyUuf
6erE1V3yyCWHBoZk+SV28Z/xA3QmXqKboY3n+2AxNAfhEm7EE2bhEJwdMhl2
iIPkQl2zuDev/jiouGss8hMWEVZY1LY0VU0cjBpTzttNXpe4a1pETLiRaUv0
mQQ1BkOzJGHQOGKtN39BcKAObw21qsOLaQSKb217qaeaOryTTG3r8E40ta3D
OwlUWYd30qhtHd5JoMo6vJNG9XV4J43a1uGdaBpPHd4JorZ1eCeaaurwTjIJ
gk888UR/hXquacuWLaac0B44cCDrYQaq2M+YMSObPUch98mXNZezZbcyrc7O
nbyXcGxWy7L27dtnNieWnWjIzJFHcuAM7+149I6QXubPnz8mnhSAMFnOy0/3
B8yMG4y0SYZPv2YH9ObNmzXYuXOnmdSYzztAM2fOdJ/69qn57kGyzQQMnEkt
ztwHA3HJr61gFHrjjTfmzZtX3x6X8jbYgCf7GXfv3u1k0s7jD4Zk57iT3SDN
mjVr165dYzajCa+//rqZGrYQ0Lp163AJKj+RIJmGP+D5yQFg5FVz5wHymMyh
vn0/i7J711/H1Ib5gBq+jTSfepo9e7YuxmxGK1LTIQVDCQgroiphHRNL8W46
5iCJCGruPEAses6cOTUtGU5eWznAouQ3CNRNmzZBiFcYRaVj7+ZQybTfFlIl
iwqxI8D0xb9hTpiWHf1bt26FCpIYflskIVr6zDPPdLsWe8OobFqHDUj/wgZz
Z0N7+umnmW19exqS95B6BAmXHCT3gmOQSBCXittsS8CANHqbhCEdpegAPAQX
H14MirzoNhhxEf7V2M2TcKMVuwTBkflFnX/hhRdMgU2yTCI45IFZZM2+ibNn
z6Zmcb5cgOehTGkXLVrEDE1X/eoR/CX0p556KksBtXn++efd/7PPPvM3aQHG
/KpSuY+eX8LJa9euLViwwAO6ykmdet60MdF+raHM3KdPn64NJYSTHt5uFgKN
8nq2n9q+F/3pp59oWvaA461RbqqUgsEq871ArE8KxB9//LHtTrQO70U9e546
Kb5Fn19++eVik9L23LlzmBk2Jodn/QedQpXvRbNXFxOydIo5UIy8q8cTA0tO
PtvtRTEShDljhp9//rleXr2u++hZ6O1mzYzHwRw9EhPOkJ0wDSHH6BG6sajy
vag7cxrZMo8DPJXxSV4t7m2qksFw5syZlPIhOxxj13TsdrNOoz4nQ/170VgW
X+Qgi0/y9vLLL79MxGH1cfuM68qVKw7g1BKv8n67ElLb96K8GemYsl29ejX5
o5gbnCT12GOPAfBSQ6kU3MHQ2r4Xxf/Ucc4uXUzg0rlNHAsD88FUrIcn741b
4el12kdPT5ibHk+fPs0fYkJ2N4sIoGZ/bt69d2BRzXtRGGgsV/PNN98wTL4r
JaTpTMk0bugLBs5QaRGEepMpeNloDFu9+Y/8PsjTpvaQg+R74QYHrqqJg0lH
kxQWWZmcYuvu6d8kTxPmgCfrFHfISt1UB+Nh8ErXNTtqK/fRZ5EtvfLXA+Je
FtploVqvWWsRcTu/p1li7SqAhQC+haICrM2YeHqd9tFnhTBRMlXw8pkJGDBg
NgXj85NvFp6LLfeudthHb5SVFZhMW2TBJV1nC60zGecnJwlpEvR930dfiC7x
lrebVa+enRTiumHg/2H4/vvv+XaOnRUY0muDXYBlyFqJp8M++rCIUCAUs1go
N4UtUGG4qAEVzmhJ2WjUBO2jz9iV+fBa+qIzZfd30uLBwJ9Axeh4XWzPIkC+
gmQZYCWe+jh448YNM5pI6mLz5SLPTpNJh4FDSG3whFvIXmkjqySXznrgSkht
4+Ann3yCD/oCYO3atbwNDWd0OINRGUX4lfFyVk623QXcNg7iD6VNInQBIoZG
Rq83lNzRSRNBWBQMu1rh6XXaRy8K40ZyVqS+g9CMGziTb4JJrkLbw6tWeGri
YEweB4iJb4cBY+PD+cOYP0j7GqLbqacJJx+FXSkK4KePPvqoBtLIOOjyLCX9
n4ZyMHBV5T76DIOTficLPMr9/9VQTjpD1jmZX/3r+JeGakaGNXEwvQRDAZaT
5aP8wPl03c8El1cu+WsbBwtbes1YKJD8S+I52Q8pTKu/ea/TPnq9pMewZQBb
8OSkv209fK9NHAyGgU57w5lW+NNNXr1O++gLi/q1q5zMTHk8LGpVb6I8df8j
D8iuH2FpUM+i+jjYz5AivlDpPfwpIiuNWzGqwzqZqFBxO0XDC5LCnA6GNp51
Mv3C+mdDBUZp0KEKYds4eFdl7jXDraLMBUYHFtXEwaISA9GhPygU/en16Xa/
/tSbvyD46KOPHh1OZmHGbw78NT7JcT89+eSThgFH7yvlM0G3a408n3766TGb
eZB04QF1Z2qT4/5+Sxt/8+Calcb1NG3aNMOn+vbpJV3rF6pgCP/zawcYhcy7
Z8+e3eoSvZtVDWBzph9bZzxo+vTpSak3JuFAAPQjCeULckCOR15Hm89Vs2bN
anXJXVmU40MNYVEadKOnnnrKKLemZTotZlse30ERUxLIB3Y3FhmNz5w5sx7P
gM6E7upeysm2hEX5rldP+opQiqEdHe5/uiEJmWzOmDGj27WxKdiKvR8dzslu
9Mc//rEti4oKDdh7EVa/QNsSMCCN2ayIqV9dy8mjDWcCIyzqP26r24LgokWL
rvWReah5pemMsZ8GGzZsYInXhtPy5cs//vjja/cg4T4bJcxVP/zwQ5NTCLXf
02Twy3sYc3/TXv8mI4cnTTJzfNavazU4e/asq4Dx7/nz5+/VHfrggw+yjWsU
ykcKT2SaprEx2xdNOQzjyaGhoeQY1PXKlSvff//9K1eubN++Pbs4Hbhw165d
eY1fSc8999y5c+fq2yezN27jf7bTmuTu3r172bJlGAXYs88+69fg7ECe1Cy+
vr2HJTUSzIL8LC2ALds8jx07dvr0aYFjpG7U04oVK4h4zGYXL140cySLTz/9
1OSIK6Yq33zzjZ9MBDAqm7zefvvtNWvWgE1S5EVqreSFsl+pvn12LeGM3ik5
XgFGzcy7AcA0A6EU520Fo58MU8+cOTNms5JsPJtKUi4hP9GcdevWpd4ENmLX
559/furUKVB37NjRFg/LdYealqZFOtU1APrCEDpz7R7uhVZTdXOEbHhpRQyW
Kta3ByP7KzGKt3ScaiaQZB89tV+9ejWta4skhLcub3XJ1YYccIYkDgBh8bHx
BnjiIPtnu9GqVat42vr2xME9uuSrr77SNSEyjXx34MOxiAQJC8hueNw53xlH
Ib0wZFbv8T37+vXrsQVv464TDpgY6UObMsp5icrwaZdLWpm/IDjwXvTHH3/k
8diUX8062dfI1w6jvxd1IVSCmlgAksfxN5VNPIVovmTJEviXLl0auc+ZM8d5
jPWA2mhsQIVRYHhwjbmC0dcYVNbh9Syk+cMPPzBAXovy4xsOG1Jmv4kG5nF4
SMTijmNRwJ0ZaVaMiMuVeXc77B+MVV5r3LvHzwYiXXNfzMT4gfEmLwTDb5t2
vsM6Gf6BR71x4wZIevdEpECaJk2gZl8/J589aCkA3QpS5XvRFMUWc40HcEmP
1C9fjemPgSU7ZRGU7ZFHHiGvpLPzsC701PVS6LBOhp6ERXQmqwiEJOrkPlTX
rzt37uRdsw/LvxO0j/7mzZvUVWNi8tScmICV90W8AW6kpDiQ2OWG/AYeGu9l
qU99ltf696KeN/We3Bye5OPq3cO9ECv5pg578nLXL91p+16U/+GdjE9wBitY
HGuiSHw7XxTT+8Mf/pAthImw9TfvjW8ffYa+mEOLqJP7uBvbp/lZkAaeM63w
9Nq/F8X81DVjO8Bs27bNeE/XnGeWqDkDW/aDZ5zWCk/Ne1F64s7CBJ5kzbxR
pekJv02HsytQG2oPZAaiIDmm24TLFsLPyjzYI78PsilPzYodUFSa3/b7IHg0
mW/M6PRUU8cwuaccu6drKZghKxvJpA9gbbJWOXtaPQ5T0oAP1H70V9A1cfCn
n35yT51C4qH0y+iyXxXU3F8bwIgpm9lNM/OV34VZHDVxcZBkdZ39xfiGGxwC
+cKZtANO6j0roOCZ6DjIYzNPEtGRZ9djtq8Cg9vYAo9oiFeJgx2cfGUc1Cm2
4AOHgCERUPoCw/msKAaSqjhjJAltZApqvZPvsE4mLLrWzA2pLueZyAIkdwEJ
OQYAtaHVExQHdaprAPCH2Zr7l1XW0V4YcAY3kp8hZdoK2omIgxebLas0Nvvi
MSSZKO7qXjDQ8AZO9uj8hMZBfUVnUhCKgPRIWHqHM7XVKFKqq0xCHMz3rHzS
osPwZNc8bQn3ivUlcVNlgpR+ahsH9W4CGDP/oikZyRdxUPjm6XCGsMiIQMOi
ytQihSrzyWAFAeFARm4EEbaUcHCtWRTHzWpMpQOYCSRvZ4aplU5YEFy8ePH3
LcnYG562V00cMXxxZ6pRDCNjEmo81SjuUDLaTTWKYUT3UnPnN0JM2wBvqlEM
I+PhDNh+IyR+mUBNNYphlHR2U43iDvHYQ0NDU41iGCU75VSjuEPAgDTVKIaR
IPjII48c7qODBw9u3rzZ9NPE/K233lq/fn3q5PbTE088YWp8+B7kDqkEumfP
HmM/M9YDBw7kW6fjLCHISS2z8NXxxo0bdZTPxP46ma/Yjvfv35/lK/eiVDMc
pUFQZSF3HtDkKN05+dprr2W5hQPzSm2czz56jfN9cOfOnaPff4CefPJJTKhv
7xmz9NeT+hv2Jje7Y78CvGnTpnwx70Aec+bMmfXtMSSZ27PeAyuiBjt27Eje
SARPvu12IyzaunXrmM3ymZI49u7dSy75KBl5OYM/URJtIi8IN2zYQGpt8WDR
jBkz6tv3s+idd96hOf51HBbBtmvXLkhSc7MbTZs2rYZF2d8EQGqCRGfCIn+B
gSQsIjIsoszawNkWj8srWeTxswFKd9iyZcuW4El9ZKyOZWU7P/yQu3kcRSua
Pn26m9e33717Nz7kEwm7dqzTKBK9cpzC9J0NjRL+8Y9/7Hat3jEh7yFTTNaZ
cAnOMLADPfXUU9SjFYx8XIheJdNIvg2F1diFdVlh2IHcE6TR28RLx6IThgBw
nBIhCQf56ECN48Y1zsISjdvqtiA4ch+9eG16ZT6e+shEMzCLHP29qDnpCy+8
YDaEaVTrz3/+80svvWRYC2qCIxE7Y2pMsiYpZpdEn1oPsd8XX3zRVZ4uVRJo
7Ohp4iq/D7q5mWOqH3o0U1rz6GPHjhl1Z3eqBsm/bWqQbOFffvklzMaczmcV
buUi4bbvRW/dukXZPKy5/wcffACJvrgvKpf3h3gOT1La1sMo1OH7IOazPvpg
vE0NaOPNmzfnzJkDhkcj3CwCyWrzDsu5K9+LYogeKUyWWi1durTk2fYT0Xzf
JBg8fvw47iXh/JIlS8g3q7vrGdXh+yAVyodjKs0Gk/IXi5hnSmNAG83pxqLK
96LuTyL8wKkmnQ4u6TSpBmjyokWLcAyr3e2ZZ55hLGSXcFCWo1fiqX8vmt3f
mPPDDz+Y9bPuiIxXIXfW6gDTzC4p9vnz5+fNm8e/ZZfchO6bYO/Uw3wEYykM
o8gqHYbGF2EjPFkw0+tkaG3fiyZ1Z/a7MbFly5bhGxgklY3hNIonxKuo0CTs
m0j1Abp96dIlrEhVoKNHj3ICy5cvZ26ALVy4MElrO7Co5r0otlBdYtILWWRz
7smTJykzPFku4nyKnVEA57EO4GvXrlGkwq5KbCO/D+K8uEBvs1Qy88GBq0aP
gxhFo1JLCz/5FjcRgFiQgP7RRx+xgnUN8fz4TJN1RyE9bMaQQ0NDyUyV9zBj
ppSpiYN8JvEZQuAwG+SjiFtYSaLyrLsg+tTspsxZv6oB26fYHD4MeD5B++gv
XrzIWek0H1D0yDqIHg/5q2vNOjd4SHxy9tF7WFrHZeV9Oym4nPp5LqJxJqmo
6OFE76PP91DKjwNGCBmuxxCoaN4/00YWild0jwQpA6WFhwOZ0H30TDWZlwze
9J4N4M5gEZ5QYEiSjmNC99H3mvUw9DZ1zFlQCmY5j3UxZ//iDFtj4ISVmkdi
0wTto2dKxrdvv/02hrD9KFKvSWdBq6m052JlGQyzR8BSCm2i99GfaopA8Ujw
4BVG8R4QEl/qO4DH0PKlfhL20euF/nhq6iTcsCm9x/M7ZiBkxGvx8JO2j/7G
jRusjGJABQwWkSZvAA/pp0KcMA3bxO2jp6XcoB7zkT2Z7jgxFgpbxni8Md0m
ROOoDGlwiRUnJQt+jmcfPVPNK9PsUtTjyNzvo8dBAG40lL2NOXaSxFM3ykkH
TmIjhU/5LQcZF6UlAMmLldH+6E9RmVdNj7l/Hq3XTBLdv6QqgsS/2acZYEnO
UxI9TVxetdtN2S9I0jVWZPqZ4hc5CIw0mIS8ah4/8uo1Dx6/mgT44WH5dULz
qkFCauk0qlXkFaYBRmSGCvBkJ3I/7PoVFx3mg4VFAZZOC4ugivh6XVlUHweJ
Ix0FSf9Tx75yPrYcYDluxaJW9SZIJHzoV6R+TY75R6W1yfFE51UrKpSDTMQG
DC0n/2dS8qoNYCsKkyVDgVE0Z3LyqsW007vu+lmU3uNL85ZjgvKqJQzFA8cf
ZnKX8jdp43wWz5Tz4VV8eK+NbguC06ZNO92SZs6cmWq5vxFKrsupRjGMZs2a
Zfg91SjukDHS/PnzpxrFMJo9e7YR3VSjuEOmkPPmzZtqFMPo6aefNqWaahR3
yBRy7ty5U41iGJmYJKHcb4TMlebMmTPVKIYRPFBNNYo7RF6kNtUohpEgiEsX
hpMhjZDtwHDdCNDfgQaLFi0yG70wAaTfrHVvddXBgwcF9P4zhogG0iNvnucy
jy7PVU66xIwgVzkz8vILDUNSVS3tc4wVx48fH8C8ePFiE/lK/OWeKbnY/xSg
BjBs2gR5Trai9957b8WKFfV40kVeXuVklAGM8w0VBgZbB0hYhG+jt0lZuiKp
9BIkmFOARYL9be6qAKPToUOHnnvuucrG/WCK+Pr7dRJb8tN/NdRWq9GSJUuy
jWt0JDoKN/Cqv/fCAefTAOZ+XpXjSjp8+PDy5cvHbFZgRH/y4OXkheEG2A+p
eJ56Wrp0aRbPj0n9upQNCOW4n4E56PcGrejIkSPLli1re9WFRpHSI+rHE5wo
1es63PnZZ5+FqqZlkUWUtnRXAsGAMhcH1YryqXHk+X5DLtSvpUU6pWXEdFed
wcbSOM+i2bvvvpvNFAMkCI6sw3vy5Mm8P0/WayPSgVlkZX7RkKk0J/zyyy9n
THLixAkB4tKlS8KHMyky+9FHH7F389yvv/46nyYrbx4aeC9qTp3MP/1tkov1
r3/9K+aYqb3yyisHDhzQ+xtvvLFt2zb9pmDH559/biqdqj251XfffWeinTfS
/maxipOucq27vfDCC6YSAxPwyvei2ROUb0w3btzI+rr8lILd586dww0HJGji
z1en/FDbz+X170X18vrrr9Oumzdvesa//OUvMPSaHT1Etm7dunzKxCIwrl69
SkP27t07Ee9Ff/nlF72AHd3YsmULXpGIk46zksG/UP3pT3/6n6bq7osvvpgt
ciBRs1Z46t+L5hMtlpKCv2vXro16RPGS6z51sbP3PzWPOlRQHfO9aL48Jskh
K0jFGep69uxZLGLIQYsVlJ+wskKMSTLAmEPlfthQzXvRbAakycm0rwtWn6wy
2JtdhDwS28crVpOcPKm2AFKrN3i96veiHpk4aC9GERl3kVoYveYzE2Aff/xx
kmxndYqTyc/TCkyv5XvRspaD+dAoctQ1r5uFhXjFjTiPpQIZTnLFbRel9Krf
i7ozE6A2hHLlyhWqWzJaH25WU/vp+yYjeqID4kXPnDnTFs9d34uSRdI79J/M
Yqp8pc0CdQfiRfL/MHM6jyeE1Wv0PDt5834bMK5SG/6Bx3BMxENDQxg7EtLI
74Mcju7wPAlwTCJGan6rOOgBOXkA3A2eZJmIQroPVKnNNGPGjGReSlaoVn5+
IA7mizMZ4VicADWj5PqdPXu2xvyDMRvJ6j3egGngW9bcpshIFlpko6i4GXfB
mmAGj7Z7EIzyUJ4u9WL6IVXGQdzGit///veenUMwLDElycvt7du3J1kK8c2b
N49xsXfST6E9suZpDXIqWVQfBzENT1Lpw1DhmWeeKYW3CH3z5s2YQI0FQYrB
cObPn88XQcJsk3mgEtKYcTAd0U+GkBwXdIYczZL0CGFi36pVq373u99lBPXY
Y4+xC4LjTLjifAiDquarbn0cdLcsrWd0mPDQQw9l9VSceSoxJVlKHpDh0z1n
MpaoZ1HN98FkaKGfR5sKsNjFiGLFGU/qFCTmgBUciwb+cmgcLHNIOpdKFtXE
QYLQJrUSshrcmMQxPLNmzcqea4NMJp/9/iyR1HCSPrAask5wrzGfXnUcpAn4
s2jRImYlBK9cuZKssxon65Dj8bKnA0NSeoa2A8NB1X+CrI+DtCXV3vVLUosX
LyZuroldwwNexr2pqkmXuGJ3znL3VjkZ6uMgKyYXYDI452qiFXwmUQKgjQeM
PWLj9OnTM4bRoJ5Fd42DXCjX+m//9m80hFw4beYfx57ai0SGP1w0JYQkOqNr
mpano9L8FSlnlUUSCRIl6xDTV69e7ZhSZcg6QHeNg3xyyWfibiPXbrWKg7kn
UV5oNv5TMDfHamhpO0Nw7IyAcqHJkEMTPGmrb68j54Nu64a3GhLI9EWgeSuS
uOwSaubkZw2lsh5sxJH8aSjrH75vcj1B3mtWUpEIiWsvsmDOvbxH/TqZIMSE
kq2lVAeIdumC2meimgwz8GfwVr9qtD4OwkMc6S5vY8pCKSCzWDqJL5JYKXzI
mgcPUl/vb8w46Bnx0LN7asJyc4+cPQJJL5M215rsqT835DzfAhVItMsZInPh
yLVeI6k+DhYWuW10+/smvU9RvOgb2WX0Tl5BGxbd3ziorxTLY+B4lWxI2FXS
blBdziGZlCDBK39hYGU4Sdk0qGRRTRwkLA4E/3GJXwXJszvGLsYVSE6C4dd/
NcUlcQy7HBBf2mhcOVGtjIPumcWEWfiBG66KoTmfPFGZ7DjGqJxMFql8GqgB
0+s6H/QXHqioKw4kyRWeAIyTEVzWRfeateV3TfN1L6qPg56a+01lLpEo5tZr
5vhElggCSXLsxHkm0U0rFt01DkaBaQUBxdipqC5oQhLFpFAX7cIrnofROQle
Ulr1GqtMaqD4bY/AV2fNpwtL0rC7kiCYnSCtyBDOndteNXF0/PhxoXmqUQyj
5cuXc5VTjeIO0eqkof7tkJkCbZ9qFHfInMhgeKpRDCPjXjFiqlHcIW4qW7p+
O8SDcYlTjeIOiSOrVq2aahTDyExKRJhqFHcok7upRjGMBMFHH330WB8dbcqY
moqmYK5Z+a5du44Np2nTpm3fvv3Yb4ZSr3mqUQyjHTt2YOBUo7hDD1g0JiXR
ypR0rd/169czNBhSXCDpMjj5pJ5w8uWXX55ydk0hi+5FtAiqqUZxhx6waExK
0qepRjGMBMGB96L/asoiL1269Pz58y+99BJ7HOf3wQf0gB7Q6MSaklXMhGvr
1q2vvPLKZ599ltxWmzdvzpd6cfDWrVupTzrVeB/QA/r/iu71fZDRffXVV6l2
kYIp/fQgDj6gB3S/SGgz6Vu9evWpU6cMQQVE88ErV6688847yXiZ5TeffPJJ
r1lFvHHjxg6bqR/QA3pA96KR9SauNZVPk6iN0Yl3V69eHcjO/VurN/GAHtD/
08TcLly4IPZdayrVZj0n62OJ3zXbdrI4wQFjvHz5co4f0AN6QPeFRtabOHTo
0NatW5Pe00xw/fr1I2s9jF5votD+/fs1M9ZNXQl/3Xx/Q+7p/v6WUhRO+rUU
mDjQUP4dsyPDZgF99DZ3rTeRfRwlOb/7rFu3LnnLk1ivc72JpUuXtsp5HraH
q3v37s3HoOzjSP55eAilQ0L+kJskLXY9nlJMwbXYla8M2QWGbylC0aFmQaHk
7q5pSWr6xY3UAcGfAjLFFJxxHtMcYKMDJ9viKeXjK6mfRcmU6y8WZaV3KqeU
Oh3dqJJF/fUm+hXpcMO6ZFtN1usUesCllHdpi8f9jYFrWpZ6E1lmoLs9e/YE
ajQ55u+AWDkHChZzawtp2bJlrWqLlHoTKWQAWIrgpI5JnENOtkUSohLLly/v
dm22W0JFkXDGMabRZLo9nsIu8LS6/F71JhwUFqVORzc8NSzSSzxwCvHE6otb
Tkgqlh5IqaWSuhhty4WMrDfxr3/968svv2SAZoLGomvWrMmWgX6qeS96+/Zt
Y9d85c++BtplKPv888+n0DxufP75557x+vXrqVn/8ccff/rpp9kaduLECSEp
JZnG3CnTud7EmTNn1q5dm62jvWYPS5wq8CdPnly9evU333wzOfUmvvjii5Ur
V0KV3et//OMfb9y4kf28+AYwo6CEZXf/ZNabwJA//elP5IhL//jHP8TBv/3t
bx999JFBFK2b6HoTP/zwA87QCo/w008/pff8REYLFy5kKamnXJIAu/PhphDG
pNWbuHXrlk5N5SAheqw+f/786dOnsYgEw6K2aRh7nepN4BJ2EVwenPIcOXKE
weIPR+FfJsarUOnUo5/oehOmtJwJxmavq8fRezwAYPPmzTt+/Di+Qajxt99+
O2n1JlxFeTgZvdNwA1fKTH+IzHF20HcwtPHUm+DrskWOFrkPjYLn66+/FhmF
yF7jnKeq3sS1a9cy2kxBIvfMpq0OLKqvN0FLKTYMtA4eJz/44APqnZCELQkW
2eUtkGEXj61xds6Op95ENp7TWz5KsDNCHlkBuSYOwg8n1w1/qrMtWrQoYY4q
MoSU1jK85H+wZWhoSGOP4wCjOBZ2LQrX1IOurzdh/tJfb0Lg4zDZQvZIZu8z
tUy2c/zHz9g+TcBVo+sJqjeRqhYYq0cRZ/r06S4nCAMn/oRwaaCxGeuY/HoT
OiUsIqPzTAMPHRhC0FJ+daLrTYh9NIEsjh49SjT0h8jSl1hMe1MXjObwqNnS
S9/IVxshcqLrTRB0XlrSVaOsVHwgqXPnzmERfyskaTlp9SZiTUZ3WU5DLqyM
VlMnzg2vWC7+4GcpyTGh9Saiukwsmf+pN4ZQGzZOvYVI4xZi5ROcvDCJ9SZY
EItwzCkRHIY4xkbcc96TTn69CQ8SQ8u+uaSN4uc5YcrvePLrTaQIYOpN8EUp
gcdFY2D2gE9CvYlMmmgLXTp06BANTFYilg5Pqsw4T3w4eaGpnJU8A+OpN9Gf
cV2kKDnG+6kmDvanc899HDvwNzslS1ZzBykokMT43zcFJlIdhjLUPEVNHCx4
+utNlCoPaZP86r3h2c4np95Er3H4JeV+0rnrjoMND/vzz3fI8d5hPljqgwCG
G6VCR+FA5NWb4HoTvWaAmgIcyQ/TX4+gYMim2l5f0ZBeG3n1Os0HC4sCTNel
2EoQjpNFHepN9PoUqferOYcbKaHS+7XeRKmOMdH1JkoBjvyU/c6BB5Jf4wom
ud5ExFfqmBRHN05DG0+9iX5DS12e3q/pwjIwmLR6E9hSaoKEG8UX9RckmoR6
E8nzUAq4fN9XfqiUluh311hUXHq9+d+13sSphhwIpsaKI7Nzd6g34Va5Z317
VNm4st5E/z2ByXE5KOeDs58JA21qqG29ibC6dF3YXrpOg7YwCnWoN1FE1t/1
wMlWMh2g+noTYUjEN9BpEVM5fy+lHZM615vo16WCbTycKdSq3kRgDLCoX3YD
CtZBl1rVm+hX3QGR9at3mn3YUAdIbetN9PNnpDKPB0lonPUmBnzU6fthaN3q
TfRLrV+dxq/YlfUm+l3xgMIUMCPPd3PXI+tNGH/yTikob7L5yiuv+HcgO/fo
9SaMq82a8yEeznxONas1RTLFO93Yo8m+Wf+ZM2eOHTsWKRtqmgib+Dvwk67z
EsCvzgNzr+4u3K3exEhyW8/iVh7QVNqMW+/JK+s4ieVBNbw8evRoXp5s2LAh
70yMgcX90e8/QK3qTVxoXoFu2rRJR8lHAZIZHDzOgO04ixwctIJRqFW9iQtN
kvaspsAZsn711VeTx8+MyViOaAgoWSu75cC/UFdv4kIjONMicjndvPkECU+S
xwkG5/397LPPssaAvI4cOQIYw2+Lp1W9iUKRUWoTYw48lCfv/wFue7cBqqk3
caEpE5As8brO7nvqGrm4HDYDxcKiTz75hKatXr26sgZBPx2uqzdxoZEaC9KF
AwBwI90xOvAIyPl9+/bRJQhB2rZtG/+Q7IutqL7eRIgye3xTNkhYGWDOxPo4
PYLDJUhaGW8/da43caGpp0BAwsSFxmAxihkebjLWYmZnQ6uvN1GIY2Ty7M6F
fG8WbySpcsy/G5LQvepN9BP1yPI8EskyKnyAihfCihSYSMZvUQYwGg5b0m5r
zApalXcZWW/CNNMdaJeb00+soCcDs8jR34uan7on5wCVlrTCU3sK43/wnKH5
ztDDS5cuDQ0NkXg+8fP/2ujXQR7Ek1JUSvtdk9byXlRZhzeLnb799ltPTbL5
mpP1HnkJIFKsWbMmpc/FR4wljqtXr25pKDnrar5X9tq/F8V2Kkfi7p+E8582
hF1PPvkkBTBicTLZI//+97/Xf0AJdXgvqnecJ00GiBXC4s2bN00HFi5cyEv8
/PPPJrwsote8zC/ZLOup8r2ojkgtqb9xSbQqS6cwhz9/7bXXkkSdW7t+/Tpl
YKo0B56LFy/W1y5p+140xEbozMyZM4lmwYIFVIvHoFcwYCAM33zzTduPuYUq
34veuHFD11SOlemUZyDrvALNOyisC4uYyffff2+stbUhutSKRfXvRUmKXLK+
QuicP38+wfWaZMjG1SAlwzYJiuCk6TFFIph/+umn/pS2Y1Lb96LuTGmp7tdf
f22YQZ9xAx8ON2tck/va6C4fJqBqa2ht34uSC9u5fPlyvtXSH09EKGvXrv3d
736XksqA0edek9e3Q9WStu9Fe80bxe3bt0+fPh2jAGBlWOGATJ2MJXrSbvtY
a96L6svAkuZgRQrKZJmcqEFq3zfpfAHIagGNqb2YAiQN50VpqZNZ6lkDaeT3
wdRdosBciuc1OKGxA1eNGQchSb5o1yYZFI+XSj3inQdkC0l5TSf14q+W1ADb
PS+5C1I0EBNE5JEABqhynUzmm0mS7JjC8wDO4HPsjkEBg6XUD3thcBXbd4zn
fJrGlUbXNg5mKUW+XKQK1bWG9Ei4t2/fdkAoFCClatqWpuqwTgYfiElHpuSM
AtPAEAGZJN+eNVoxBIqNV21XslXGQR2JNRhCGbImpyxgdjl54Rv/wKtnIc2x
JpFUiiJBXvmJudc1DpIRnpBRFpjBEMFhXcqmUM76hSgDVBkH9SL40goModVg
EFa+2jgWFiHh9sMiOkaHccnzUuksMa3EUx8HGS9jZ1nJQ67fOHBc8q/eSYpN
EV96N9aKMjjPD9R/S+3wfRCv8jWQ0kaZe82aq4Q8DEzUYGhid36tp7ZxkJjy
iTZF1eGJY8cQ8sr3uGRu7zWlMTrUOeoQB5MxPuITSrhuNpjSG0mFjfbv3594
1JZq4qA7xzMzJUHB1CA72d9vKF+0Y+lJAJ7zWWfLEJKHXCAbM3aEBMEU+mlF
JnGp8jbRxHg9F6MYvVleSU0CnnoyR0hZit8I0RYebKpRDCOjKRYx1SjuEBtn
nlONYhiZFGRy9BshMV3cmWoUw8iAk9ObahR3SFg3eplqFMPIgFM4mGoUdwgY
kKYaxTASBB966KHdfWQcm22Sb7/99ptvvvnKK6+YC+weTg8//HAK4dWQG77x
xhs7d+50N39HaanH9evXC/GVdy5kADZt2rTR22QvtmdxkI2ZOoLHg2zZsiVt
IHQe2jT2r5MuyQb8VpCwyK1aXZJXVdgFjwNnDMPAAzJCAcOZVvcsJAg++eST
rS55/fXXX3vttYiPGiTDnjMggZFNrNne3g3SI488UsOiyCLr/B1nIXc63bZt
W/Y3+ZdMN23a9E5DGkR2rchQ6oknnmh1CRYFTCwFnt19LMpxTnajRx991G1r
WmJOvgPu/lWRyvnILiyKJuebeATaiv76178+/vjjNS0ZV/YJZg9LYUikg2+7
G/XOd2eQsrexrZWhP/zhD56lvj1gMfnYPh3GNDJyE4CjYEnO0BZJCIsee+yx
btfu/lVhYCO1OGH+JxvYO98THo9Z3z5yoTmElX30uxrCLtwrAaIzi4AZk0Xx
0jpyEIPSteNkoS8+h9oQX5Q82U4cd8AmCA68FzX5NepbuXLl5cuXv/32W8q5
e3z5Rd3Qg1M8HZnXZ+9SdoV4ogMHDpjNpbZ7vlz79dChQ79UfyDo1b0XNZXW
i05Nonk8wv3qq690TW8XLVqUr34arF69Ovt3qF8+jF68eDFfVerx9Nq/F00t
ddqeXUJ6d2Canx3Z3zXFU1atWmV20ApGoQ7fB8+ePUsPCSLbLenbzZs3zZiy
xOLSpUv79u1zskOB7FD9Pvp1DZk8Hj58GBP0npd+MGBUXt0nPpqDm9atWLGi
bTH6Xqd9E/RHp6mdl3FjCqIxEHcjLFJ799132yIpVPle9NatW8Y5tDTLvVxF
kyMX2r6tocIisye+QpsPP/ywrezq34uyl/fee49Hyt6uBQsW5AUjrfYvXjng
xMDIC7dktKBprfD02r8XPXHiRNIysCl+g1G4nKM7evQoHbt69So3Rccq36eN
pA7vRYkv+ziIb82aNZiTxALcI+7t378fHsLtsIM+1Pa9KDwEx2OktjXPnHeh
sUGQwqL61+kDVPl9kPtNJgGyEP5SozbLAKJLAJjHHTt2jF/yE+PlxqlQ9oG2
gnTX74PuyY1Dm3U4SWXQT63iIAayHZGaiMV0mr9w4cK9e/fCPzQ0dKFZhAa5
v55LeMpOyVbfv2riYLZj85mYdvLkSToGALU3cibTLCoQAekw0ZOC89wFFwch
nFhBD/m0Sum3jYOnm3wIHDj+8/Ng3GyIJgiLFBIGjkLvGrCUth6jw/fBqAGN
wqgkHBMTDzfJvlKAGH8SyPCf1CZoH72OjF6yxgn/6Q9ZR17ZYsxeshiYsVBa
J+fOnZt1TTgpVFXi6bCPntTCIjKCBBOomfED8eFeCqC7Z74SigsTtI8eN/TI
avBHv5DQpeycwuFk56PAHAgWpdYzQ8BSeIAEuBJPfRzETBj0wmVxIMb/EYQe
gaSKhjfAJKuhYybpYQ35mCS9inxrqG0cJCmK56obN26wUOOoMAqXsEXvhnlk
mtLSTlaWAy40nnUyNJlxMXOxhtHhEn3mKgF2zPoMXUauWhyT2sbBDL/ZESfD
rLhN/TqZRb+0PSwygMliubYsqvw+iAN6JKOMl1zF3Nh1iQ4Qzp8/nxb1Gv9J
r1JKWKDJ6hTOqjLtycg4SByEwvE6SM7tkTrZdj7obm7CIpJGuD+JNzUg38sN
UTwnjWDxv1Vxmcq8aslg7M6Q5IAcHZQHZI9g+BtIfsoef7LIzmj8r1w/1mEf
vQdPVXp/cSYF1h0k14S/2AhYSnjX730OdZgPZhWosKtr7rTAcD77nQmxVDwn
uAlaL5pOiSP1qVM3PH2RozvoWhvHycqFokW9ZiFrUk/UUIf5YGHRd00J77CI
dKAlqTTIq4ZuLKrfR+8xcSarKaJIZT4IYZZDh0UQft9k9o7at2JRfRx0T0Et
FhSXEmyRVIqtA+CgmFtKjSfdU/2AoW0cjMlHdQmu2D4+JA1XUpkVQ2u7JHI8
++h7zbIrADChMAQAx9Hn75s6CG3v2SGvGrmk98ywknik+KJxsqhyPpgk83px
kEiRUBL/k2bw5E1dkrT0Gh+uMXZFlJW6LQjOmjXry5Y0b948A4O2V00c7dmz
Z9myZVONYhgZqGSV6W+EjCoNNacaxTBasGCBCdRUo7hD+/bty3ah3w4tXLjQ
LHKqUdyh/fv3L1myZKpRDCMzbvOCqUZxhw4cOLB48eKpRjGM4DFXmmoUdwgY
UptqFMNIEJwxY8ZnffTpp5/Sq6z6TmrQkydPfjacnnnmGW0+q6aPPvqIepi6
mqWePXv2zJkzenF/x07q5ejRo+xdy+PHj7/55psa1N88eyd5sNHb6Fq4/OCD
Dxy7/65du/QOA6HABoPzZuJuBYNHTnmFrNjfuXPn+++/3wrSnDlz3Lm+PUhJ
8A4Sb1PS9ezevTswBDLHMLeCUYgcebD69tmQjjMOMA1bsqM2K53AOHHihGOC
64YHzZ071/1rWuoLQwjl1KlTBIdLUH3W6BUMOOY8eWF4EiF6WFJri8dz8Rj1
7cMiwnIQjYreZntaclxAYjjUFkkhA073H7NZdFtfGKL3txty0k8wOCYmXIKK
FjnvZDdd0gsPVtMSEl2QiO5wKdgC1XjDffAKKkxjWRiYAgFt8SADzhoWFfrw
ww8LMEoSQ3Oy6FVqFrR1QYVw2Oil27VYhFEGhzH8t956KzkZPOB4DM2AMxvZ
6okdYVGkFjHBg2PZ2taZOSFgQBq9TfQE0VsMAYCMHDuDG3HXMf/sJSFH5zUI
WlbQCpIgeK96Exea3AhJCD8wi2xbh/d0k3hfgCPWtWvXvv766zSQv3rppZfo
nqk35Hjea16nvPzyy233in7Wpt6EWTzPMHv27K+++goMdk3fMqc2AX/ttddi
VqlD8c0332SlkPN5D1D5tbrte9Fbt27pN1ncly9fzpSyHZtZudX58+ensN4E
JmBR1slgS5YWYCbdc5xP/JNTb4LgdJqPO73mQ8aqVau+//57eOjkpk2bkvmQ
4LJQpFV+/vtSbwKLDIFeeeUVcnSMb+vXr5/oehP4AAZrIjLWxBVQ13xZSPkS
OlzqTXjM7777TuOvv/6617KEQav3oqk3ke9fa9asycY3umTISr3BeOONN5wn
OABSnqnXcHXy600Y6f35z3+eOXNm9gvTt9xzkutN6D3pUOj8l029iW+//TY7
x3nItvpcqMP+QZDILgs5YBD+mD+oAg2Gp3RIB+aEWtWboP9kJDqkREJ/vYl4
BlBZH7HSzKtXr2LU0NAQpWrlrkepN+FhS0L4gavarpPJilZXcVBPP/00/cde
QTbBwkMBL5BduXLFv04y5Pv+fbDUm+AnDfnAoGCcgws9bL768VoMBP+J3iBE
+1RiEoBST2Hi6k1wm4Y63JQDcifTpFBzEve4rMmvN4EPLFHXSVuHIfSNSqSY
Ai+XVb7YMmn1JvSe3RzZZ01MK1asAIbzBw/3+DQOlhzpm0eY/HoT0ApefAie
8KUUZuvWrRNdb4LJZykdb6AvsiihgcIEw4Vf601gEeM1nsk2/4muN8HciCDr
/XqNyDDZTSBMyMji8N1NeTtmOMn1JtiaCZeBQQrY8UV0LAsjJ63ehLFBvnFz
ufiQRdqpN5E1yRw7/Z+0ehO9RqPMU+j2l836QAbFOWMOH45pWVMBZ9tsHqFW
9Sbwn8lTYLo9UG9C76kIz42YOxBWckRQsJTquF/1Jnq/JoQfuKpVHEzC8HwW
F7CwNIlB/JusDklv7jjZ1Pt7r6SaONhfbyKQspLBQUle4WGTz/yXJiF/zjtO
kqXeRNabKJUv+ktL5GTmqk5mtcPk15tIXvf0XmqIRGolN/5E15uICCLEskYo
Y+lSuwSGZMifwnoTvSZwJz1+Ut+Ph0WVcRAS0ik1HaJF+cmxGB0Mpd5E+Ba7
nrh6E5495lbqBeSnot6lLkbMsJR+mPx6ExiSg34Nn/x6E2FaxFHqTfQaNY7g
JqfeRO9XjUpfkVRmo9SmVJrQoNtWjlb1Jnq/mn/qBPXXm4gax107X4qbdCgP
JAg++eSTHw2nknq9P89/P82YMcO4ZeT5qSIjgfnz54/ZrCTkH6hfUI77z9+1
cT3NnDkzb9frqbB9oPdyUI47kMlCDYv6qb/HfrbcL0izZs0yX6hsfC+d7EfY
L9MOeLZv3z5v3rxWlwxwoxwEQA7Gw6LZs2fv2rWrsnH6GtnpQKmO8QAziJ07
d24rPCOP78q0fvG1oqefftrcv9UldwV2Vw3vQDt27JgzZ063awfkMk5hFXrm
mWfasuiuwrqXQNsSMCCN2eyuJn8v3S44u7lrQfCu9SaSYNwka82aNSNTr49e
b2IUOnLkyKZNm5g2n3P27Nn9+/enUobZ7okTJzrneG9Vb8LMyNMZs507dw7H
XnvttbVr1/r1QlP4eGho6Pjx4wZ169evN7l2cnLqTZjdb9y4MTvBjx496nEc
QGu4C4lfTVVgBrgVjELjqTdBUuvWrdu2bVupN+HRsBEebbrhuVBdbwKAJI6m
4WSh91JMIQmakmJ069atxEqdaG+HhPMX2tebcP99+/a9+uqrEBKQ3jGK5kDr
2N1ef/31lStXgtcKRj+Nv96EA1YMyWeTW28CK7Zs2bJhwwb96p1lOeO8fx2D
kQVyybo/mfUmPDWbSikZ5hbjSk4PJ8PJvEbuRuOpN0FAFIZXpFpTWG+CafN4
bJx98QCExdvz0hEoJ/BqQ0TZDU+rehPA4EDKAJ08eTLvtAG70Fdv4syZM87T
KzGLh3SVAXYrSKPUm4BER3QYnoFZZNt1MoX4PTFUjzBTPDbF85Cv6ONB6rc8
D1DNe9FSb8Ks+cCBAxjIAJ3M0tC8gnCGKqbwukjNyzmYnHoTUNFV3gk3CP2h
hx66fPkyJ7a4IRgonkFLcuNPcr2JGzdusE1Cv379OoVZuHAhRu3evducF6qy
jW6C9g/q1EwWP/GHg6KZZJd3IwRnUsmrEw11ZbM3b94UsgkO8mxBmrh6E573
s6a2BRbpy4jxyyYZO264j79cPXXiOqJF9GGC9g+OUm8CH/KVf5LrTaSUOavx
1Ab/ZJ0Pte6AOWyfK/DrU089ZVScUuyTU29CfMErDPm/7N35sxRVtgf6P/hG
3O6OHhSRQZlnOEAwia3d3uuAggzigEwyqMwIItj9tFtamRwQZBAl6n1efoOk
ThWcszMP55T3BeuHiqysXbm/e017yL3XIjsKnIA2bI3aJIhTnG2OPU5Mvgks
unjxYt6zk53a2cUA803cuXOHf8YHMLSFDjN/9SaGIYWZPHkyNWAvYVEd976Q
GuWbyDluMGAwtgQAZ9L70KXkm9D3cUR51cs/x+iI8lHlm9BSHu/LvlherftB
OI0r8MHz4dcuIr5y5QqzNYxvHaGrcJ9M8k1QbBzWroRkyRa7lMFY931iAmx0
z0V3vgkuZZzyTRC3qk9VgeW/rkaGPCeVg4GUoxU8SQ7XwzaR+SYy9GKkvFNS
KhAZ9QDDQBFbxjXfRJ1MAYy8KMeH+MlsSlR1pzIuziRg6oDzWFceIKvFPpma
RYSVPVQJtoDbLgxp6Bs365ratGBReb4JtTww3wQMOeLUk28iGV7GL98EKSQe
F3MzHiC1mBvtzWYPzpPdMf9Es8nkvVMNe8h0/PJNMLTYFIfA0cWUCI6DdZNe
YQhU6YAmJt9EAkSQxddVHlKWnnwTxu05PF4ndiHlCcg3kXEvbqQvwASSUnVY
lNw3JEjnXbvIxuNyKowngxXcCzA5esMZuumCUuWtX060AUbHkuKWTNO5RLeB
p7ElkH4L+Sa0DtrsbWhHj/NNjEqP802MSo/zTYxK/3icb2I0epxvYlT6v5Jv
YuPGjQl1XgeE74nO3SjfRE1ZeG+RCGBUapFvwvxx27ZtCaJeBzB3YXINYXe+
CcPa1157rT/pxsjUOt9Eqk7I9O58E60D8ofGkm8iqSWiBknJkZwgfm2Rs6Cm
wnwTAKgaH95555066H1+2rx5M2BJpoA/AdMu4PyuseWbSPKCHIN9raJB5ZtI
PoUkLtlVZUvJchY8UNXZMVy3sMQW+SaSSyJqvOtevolkToHN/RwNU5jptcg1
M5Z8EyqtE2HU2V7qbDtNkYTGkm+COmmLzzje2HuOoI5Fix5JvomwK3lMXI+F
RY3yTcDQo9tJYrLrnrvGJfddULMkp2iRS2WEfBPmoXVA+J5ZZIt1UY/9/vvv
Nc2kFWyz/hyC43w0MyetopMtNgaXrIvW+Sb0/nmXdObMGXXlGGP2KifOtjLd
+SZylH7Pnj2NILXON5ElUBMTd+p8E1n4ar0c3Rlbvgl6Qg0w6saNGwZOCS+Q
48YHDhxoh6dTvC5669Ytwk1dGOK6XgcjI0xLGmX6k6NVWWZvcbJpLPkmcAaS
S5cuQbhu3Tp6fvny5S8HkW/i8OHDq1evzlvLThU+WqPWrFnjK0YlJj9LpGns
rimedvkmTLRhy+qrqsFbuXIlIdIiZpLTHJQtJ4ibQmqXbyKM9QkhhUn+d+r0
ww8/YB2XeKrs3Fk/tVgXrfNN7N27F6QPP/wQQ06fPq1p1PjatWscJlfc+rXR
I8k3AdK+fftA8isvzQ+0S8LbaZhv4uLFi/ipa+Mrrl+/fujQofrdN2e4e/du
zKGWjI74QNJdAtlUfCPkmyBQHZNKH8k+mYROMjTl1bkONrJw4cJkqNHFsMpl
y5Zlz0951N+aSvrBOt/EL1V6X8LFTFaJsTDkbXjSQvHzdb4J/wISB3B7YvJN
0PykVOAl6nwTSepNvl9WWYknON/El1VgyYgmYkqG8UWLFiUdDOG2SKZQ2A8S
EytQmBliCObktHinkjvlSUQXworgdEaMAqSJzDeBM2vXrs3r3aNHj4J08uTJ
sAjbJzLfhMGAf9X9YLZd8aIUhv+n1fyqm9iVfTLjnW8Cc4gPvJgD02NuBORR
JLV8+fI0kLz4NIyasHwTGEJS5jiaf6pK0pFsL9RsaGjIMycm30TiQiffBFcT
Q0t+GZ2RQYtfDUTxUIEB5psAiQIbLbig3lOmTCE45oZFTWN6NMo3oRaFE3ks
A0v9XR2z3ewPSDpj8MAX4RVFMl1NfI9Hkm8iR93Hnm8iBDmNSrhyonedzA4q
0uQEvXczcRUaPblTHFetzqNBfNnjBJUG1gHMkw4jBzOzT+mX6vVlzYQJyDcB
mz+qMQecs+XplyoJYMBPfL4JokmUsE7FokeVTKGwH/TYpCAJQ7K/MXXVosGW
bKVz0R1wfrzzTcRN3arIheoSEj+aM5B8E8mnUKfkwI2AgRC3sSinj5PooTOe
+SZUF0X9pqJYUPYRRZOzVTKZFOpT2xOWbyLj4SDp3LO+pMMI9yY+30RtaEDi
XrJyJDBdZDRh+SZqX13nmyA+MDIHTDoMn+Oab6LuDmrdxorocEQW++opHB8e
ZWuab+KLhjR37lxdbdN/jR8l38SgUQyjefPmGaIMGsV9Sr6JQaMYRvPnz8/G
zt8IJd/EoFEMowULFhiWDxrFfcKiJUuWDBrFMFq4cKFZ8KBR3CcTusWLFw8a
xTBatGiRSe6gUdwnYEAaNIph1J9v4ty5c++8806ObJtgmkSYe/ZE526abyJk
Rp99F/rQTz75xOdnn31mvr9lyxYXHnjixIkkXGj65JJ8E2fOnHnttdeIwPPB
SAw6Srt27VoT7eQv2LFjh/taDYz727ZtS3B+3Gja3qb5JlS0adMmNUKyffv2
XBw6dCjvhXEmb51aR3pvkW8iOxzoA8Hl1bPr7Bo6fvx4XjwFZztIhfkmckbe
NISwsrSu3uRK8Jn78FBUP1Hajz/++OWXXybEpnh2Nc83gQlvvPEGtqjXEBcM
kNavXw/AqVOnEn8gCV7bUWG+CSyiM7T03Xffjc7gWPJNZEkNZ5TZunVrgGEO
vjHzprIrzzdBZ3CG/pyqotCQDrnkJzb+3HPPYRoYOUvIxICEDQMb4flH83wT
alcpYKdPn2bvmAaqm7SaBHOAAveawqhpLPkmVI0zmEydiIyMGH6ikXtsa0hN
800QGXnxzxQYo1wn1kG2DuJbIiE0zelQU0m+CY6O3yMUrEju3WQsyr6d9BG8
QfZW0Z+EREg2XjcbqcQ/HpRvwpTT/JfP/Pe//21SqY8gi55ZZIt1URNY09Wo
Ot378ssv1Wtii+d8qWksJmtjztI2enKn+Bx9AhFfu3ZN1cwnYyQMzGlxYJ5/
/nnw1qxZ89VXX7mfzBf4/OyzzybmrVYUwmu6LqpeTjjbiYle7UnIy3eBrV7M
oQyAJQ/mBKyL+guNUpEmU13Y1Dtp0qQEech+DI46kWPrnLzlVB5nmxLqNGmI
6+RVycIIJ29Ihj/UyQX/k5fp7hgzJOFs+TnoFuui/kJJcv6LxNV+69YtZus5
CUUOFaeaSJUtWFQeX5SG0Bl46AzPWadZVy8uJZa1X5ctW3bhwoUEF3KdZf/y
c9BfNNknQ0yU1sPZOBPL6iV4ups///nPCSga98JSKBLf+EV1AiIrcoWQmq6L
YoWKhoaGsoCWOO30ilcHJgcqaVrWRVsYWtN1UQK6fPlykt5yAgn3nbj6Tzzx
hO7ATcqMk3Uc5kZ4Os3XRYlAjYn/Q5OxRbdCTPiG2wBwC9OnT2eJ7VhUmG/C
mCTBiwAwrciGNKjobZigDzLky/Y5CKFiBcYMq1at4q+yRlpo/v3vB/2Rqqia
NjJqttwfqrRFP6jt5hdGgDkgaZDMgYBtnEPuHAhj0RG02DDWKesHE0+DT8BD
PaDejVvQzWmsAVhEyQSMXUlc2/kKzFQYtgSfSQBzQ+gSSE37QeqUTb9kaiTG
EgkRo3hCX8GgdZjGXggFG5uGlWjaDybSjoariGnjG4bQBM4Ni3JeO8m/OtXx
XnoyTvtksg+HvCBxjQ91jAh3WAfxkVdOVfjpH9X6gEG+woRbfu64aT+YfQth
EbkYJKs0KTkS1sn9HIRJcJ4WLCp/P8iUcIYH4zY5qwgrILmIREqn9ljkAjay
y2H/ZLsrxFPeD1IJ8mUv4QwxxRz0OFyZERTAtXsB6d2KFHafnY5fvgmOSEXc
ThJUJex/p+of3cGuJC5J0HvsaroJpEXeJa4p43DYstMJZ/TL7N3Fl1VuX7Pp
xLrhiBrh6TTvB7WdI9K/6HYxCovy9g03yDE7OWFLuPIWLCrpB1VHb9UCDF0i
smyQiA4nzALDz5Q54XcYGkh8OP2J+WtC4R6w/n4wNPLAtd0G/hGeSf2Im5W1
C2Be0g8Woqq/tt6lHGqxT2ZkGiOepv3gCLXneox4Ok3yTTStqx22pv3gBFB5
P1hCY9ft8n6wBbVD1bQffCSVjkBj2SfTeYiMxgiyRb6JB0J6VHhK+sHOGFjR
Ap5O8A9/+MPe4WQAYD5oJKCHzSHlngJ/+ctfTOL2FpAu20M8qqRw978a/YWH
nzZt2shlMrBJWwyGjRlSiwb6mjK7qnPieyrKsU0XPrdt26YVjZrwxBNPGFWW
l/d8tUACVd4Pguo6h/3BeLuippysyThh6tSpjf6iXm3PtYtwoGadX4OtHR70
5JNPvv766yOXwYS0elcV0CDV5XBxWBHO5GvUdVeVdf2dihqxC4umTJnSqAk1
iyI1n3srXkWLgqep5nTTpEmTNmzYMGqxMCH6082ovZW83E8UiFyEmS6CthG9
8sorTz/9dEnJQOoxt733zLDW5NokMa02w0b01FNPlbCopkhKXTHt8AGFaXEI
NdoWZPI7efLkdv+tmRM80aJu1WpH8Lz22muNYERh9t6TnTux96SOrTW8HR5g
SG3UYjlBv/eeQcVd10qV+yDFzN3vdtf5YznpBIeGhm530Y0bN8w0V69ebazu
gWvXroXh9nDyq2HP7QIyxl6zZk32vJ08efLo0aOff/65m6resmWLio4fP37o
0CG/5r25kmbZiaqaHbkl9Omnn/rLyGXMr/XdqjPjZjhBlZewOax3uwrsuW7d
OgWyiJST0bozk+4cui8nz9eo8vKqw1Wf3333HS6p2iQ3OQuoDVbgkjaeP3++
EYya4DcGKy+f9b1kJsUWExPYrl+/jj85KEfftPHIkSPt8CDPoQkjY6AtJiDE
8c0332RTiuucuU4GPfAOHz7sURcvXkw6DGI1QXAHVMjL8STXdnl58I4dOxYW
EVDeD7p/+vRpVRMfG8mQpvyZPeQ5JvKjFgMguW4/+ugjGNjRpk2bsmyVJWVf
4Vm5ciUwV69epUW4mr3ojejs2bNm8SUl1WKQA1XWRen2xx9/7D45UuMVK1bE
D6xatQq7+JydFTXFg5577jlNKy+fDQCan5OVgFGnGBcwbsJGzcqdTw8l80h5
eVp0o6LbVUyP5LuhwGYoVOuHH37ggsZi+Age3C4vr1L2Rdbxfjk/CJJeBhIS
NBxys6lLrAkYHnVUDPoyAsr7ZTXqLJi8ehldymC17o8Dp0gcFPHxAG4mRkSi
ExSSTrBnXfTnn3+mV1SFAVJgasYP98wiC9dFf/31V+MHhZctW7a3Gky++eab
kHMOcBpYJqURe0mcHEhyKlnz3WHRhTPcknXRO3fuqF0t+JMDznoZfiN7tPLK
ifGCql7MJ3peiK8gbmXA1hyAKWQJpKbrol999ZWuHzdUbSSQI+GJ0wXG5cuX
X66Ierjf/Y6skNrFk9EK/Q7ZzZw5E4yco6cbVNEDE0MsMed5vEceZxsGBah3
YrMAoEbNp+3cVyLG3K6cs6/sVOEE7lOYz+fQkh+EoEvScbaLJxMW3bx5E1t8
TbQiVslsqRBghJWY276OU5ztzr13Onk9ypcS2S9VKHI1cgs4lgTfFCzhyul8
YhHrhr4oi0XcaZiHlwvNq0lWtmDBgrzY8tXAnjqpnbA4gRznN8rSj/tX4rff
Lj6S1nRdFBhCwSI8ITJ6Qi7MnK9bvHhxIjkzNO6UzpBd08BETddF2RQRc6fx
ltSJEpIjGFjtaRiScXjeMrdIytN0XRTzs1808b74omS7oFTMXOfIckkt8a6T
Jr4RnpJ1Ue5l+fLlZrJYobNQo3/Fh3MCec9Ot8HAPSzCunnz5pEjFeIBmFs2
YRY2vP/9oLr+VZGLxBLpd7nl/WAMMNsqYNM6vOWaEv3GKIgOs1y/us80fGaf
pGvsfYT9IP6wYtXlEChvkAP1EKq0PpfNqRoKcmtfVBkJc6D+iyoMeKfqrQo7
oKb9IJ6ohcPPsfGcluU08AEejGIIuJcz/kpOQN4lQmF37NQ1FiWzkkbhGP6Q
ERjxEj6jeI0glfSDnswjUSFMwIFEd3ftZiRCglTUfWIFGLuSIN4dkBQGNQli
RsXToh+kG2ERcbiI9qo6YX8A4LWiXe1YVN4Pqi5h/zFBpYnF16l8RQSXHRcY
nqTeGKh8BFqeL6C8H7xdrQVFLrgUP9+pfELSDGVDpgI5ye4iiwPR+V/GLe8S
ScXkAYPKdbK9uyBHNz0tsKHS3qZJhcbyfjC6mpAR8ETbASCscAwnm25K6bSK
q8ZdxHxUp0XZRhj1js7EkWZfR9MIYIXvB5N/AZh/VGeUkt4iPrwe40W3Y+/p
L+Kxo/y0vbCP1gnOnTv3YkMycMogqh3hp7bEHB4JGUAa4z2qpz0SWrJkiRnB
oFHcJ6M7E6tBoxhGS5cuNaQcNIr7ZATOHAaNYhiZfZt6DxrFfTIvMIEaNIph
NDQ0dPTo0UGjuE/mRytWrBg0imFkYnXkyJFBo7hPwIA0aBTDSCdo7nmyi7im
hKPPpuIcBD45nKZPn/7++++f7COef/fu3W+//fZ7773nOfv379dD0VKfBw4c
0PyDBw/6Y/J/+fzggw9yc9++fQrv2rXr1VdfVdJf8nc/5ZTrhxX11xjaunWr
SfHDfg2pKOGygUx6ggMVaam5tuqUAQMACNW1YcOGTZs2QQKka38f+fk99Mwz
z+zYsaO8PCcM3rZt27Q3L3TcAXXz5s34iVcAm61A2AhGTZ5M1uXlVU2IOcKf
V9sJPJ5o/ESDh3hFQ9rhQc8++6wqRi1GNEmsmffyLog78nJhkus+MW3ZsgUD
s9s8EfKb4lHLnDlzysvXLAKGsFhKkqMlOwalBezll1/OSZymYEIzZswoYVHs
joZQDxeaTzR4crKSe1hEpQmOCgGGOQqUPLmHeIbZs2eXlCSIbIJybQyWs9gn
K6uHM6FQIcQ0mOkVnMqnTCOaOXMmeykvrzoVJRUj2bnOPoGsqMf7ER9RNkUS
YiazZs1q9986WQkYcOKSmwlX7rHtnongaWqnMah444RiAIBME4KghZi6CZhR
WZQ0zXGDGyqiwNQJTyImZeK9qTEFUwAw/0p0XwrfCJJOsGddNIsVZnzmxRTM
JKL/YMXD1kXNSXMONKfMFFu/fj1sBkj03H0sNRL49NNPr1y54oJ1aIj7Bplr
1qzRH7GyvEAkBf9dt27duXPnMN+dEU6ClKyLwsbRsbirV68uWLDgr3/9q7m/
h//973+fNGlSVjtN8OEHw2T/xRdf1N1jgpm1Mglkd/v27cIVm6brop7MM/iX
mTLvR9w4fPr06UWLFnHvP//8s/vYlbWsW7duNT2J1i4fPencuXMHB7COMty4
cWP+/PkLFy6kh5SQdHBSATwpf6FTU3mcbZqgXsrDOaidTtbJFIgmx+rPnj1r
apDcASRo9NKpuFryZjDULh99WERAZJeFI0heeOGFf/3rX2DUIfrbsahwXfSn
n34yuWZubMQ1D8/coqi7qqxkfAWEdCCbjniJ1atXJ/FoIxaVr4t6Mj92skp3
y5anTZsWc3Cf0BOTQZfN3jkxTIMNHjqfsMblC8hN10X5VUrL4TBt022Dw0T+
WbJkSV52exokybvdwtCarotmTwihJJCmXo/nTHDyp59+mtQYXeLewJM03I3w
dFqdm4CE2yEdJsbS6baeC0iPgsTTEhqi3TG3knVResL7ERO10UGolJgoCXHj
TN4K+cyYk0a5T8eYMC+aWF4Qluv2A8/R5xx3Vi/V0n/M9mH9ILVJcjqUA/66
FX83WXPBGP0rJzRZN4NKeik2m/0zhh9cXJI7ZG6IA9rOO/k6whuxkn7Q31Xn
ydeuXVNX9jslpwnFi9PgwYKcM8n+cy0iNWab/AXJOV7C2Kb9IFFmg/R3332X
uDqYz1QTwkjVXJBhWNQvKavKH95pdY7emIG6Xrp0iVJxmznem/1jec/rIptA
cJJrHadz9JQ5E2SzngRWIpf0KeROWCRlbKPHSfB5aqaDzr4dv7ooxNMi30QO
rWMRqWmOsSgHQvSJRISBSdqo5GeffUa+43SOPvENwiJ1YUWtHiSV88iujT8x
MJt2snfadVYYCvGU94NxpOyFiSVWEmHVDzE2VjVTIilsyd4YkMJJchy/c/R1
AMNEOQAyOwHMuThbsOm5AgkNRNOangIeSz+IcCOJZsDgz7NDAxuT7yaJ4Bvh
6bTqBykqw+HMKVKiVcT8aTgflR0CbrbIbtZpco7eUMrIFhJGTXVdg8Gm8tL2
H1UkTPYFDP9DmsSXzagUPmFPChMw9feDGXWkG9U7PLA/fVg/mC4YwZDXl9kA
ZpDDnOMEPNNNv/qqpM86KfCdivza/XfXuRhhiFjSD+aBKFXngR7e/eRAikKm
6tx0XYMvHAI17Qc9NtzodLEotdcvheuqk8ug/OGdVufoA0OluQiMiCk8zEWw
NfXwnSbn6Ou6IsS6rkxnoi3dCOvrXysqxNPiHH3NoihM5JJBe42q3q9Svvej
pvJ9MtHSWmNr9ahZ1H2/FmKnIYvK+8Fuc8t1rb3JmVLDC6ra52Srw/jNB7tV
qIcPtfjqmy0MbYzn6GslCZLaT9YSbGFoLfrBcKk2oiDpFlOnFXNCJf1gbdF1
RxB3XTvJTpe77ja0zj2l6jRhl07wySefPNJHul2fJiDGaT57fp0yZYo5VP+/
2tHHH3+slrE8wcjEFL6korQl7cpXFyY1KdDd3hSo/1iXKaSpU6dmRb2QaiS5
CAxfDSECw2eE0o6MsWfNmtXoL2pP1ZCoOmxxM8J6mG6U07Rp04wtS0qqveaD
6255uX+4opyCGQswg8+ZM2c2+ssDWdQtqUMVNUVS0/Tp001JCgvXGlsjCfka
kbmo0bZjkSH3jBkzCgvX5nakz/S6pVbfd7MFr5555hmTu0Z/qVWoW1K1F/qo
oqYwajJbefbZZ9v9FwZMqNW4n0vtCB6omiLpUeZuX1Q7qHZ4yIvURi1W63N3
B9Htro906XbtosPDpoqkE1y4cOH3XWRW7slLly5NstoNGzbw598Pp6GhoTNn
znw/Ihld654SHiHv8U1gjSfzZtxEwGzXvFVdfl25cuX+/fs/++yzs2fPKqmA
YZWLAwcOmNiafY9cl4bkDOAIZIL/6quv4pJpfoKomyIBCZ4hrpvKHDt2LFss
zHYhN2iB00R77dq1fhr5+T2U16Dl5Y1pswXl3LlzBiemt+fPnze7x2pcMilY
X9GobH8YHT16NCECCokakEiydRu/+W/CsZrnYnUCDJqtJGdoO0grVqw4ffr0
qMVUmj0D0Ra1Y87FKuBhJrkkSJeWLVumI4vgoGX4o6pND2kUQZeXxyL6yUAu
X76cjNLwqJRtAkBSbmLRBx980AhGN7EL+j9qMQC0F4uYT46H13qS17hcVt5a
JkMxDc/OB01ohCeH0EtKEgQxMUwM8S/mQMPdZ1A0B58h1KvmJJqfYCa+r7/+
uhEexFhIv7x88hSrDqOoE4bgTPK5kFRSnDN8XGqKJJQgJI3+8l1FLk5WYT2o
NIYAmaCse6sYNcaxrQ1t1apVnlxenoxMaXGV26HeSY6QxG18OM/sIhnV2+EB
BqSRy3DX7777LkGoRe3cDl3SfbBueu5XZbgFRsez5by/r1jEZeG/m40g6QR7
1kXZFH/7X//1X55JS6kKifTMIkvOD+oF/JFX5+70qomF5eHsiBli9ZIlS3Tc
aod/8uTJ7733nsb6ledPJ6IAHcjOkJHrKtwnw+I8kMpptaZxDhhI6/iQTPYT
CQTbb926lQTx9NCvTz31VNbnVVQY4Lrpuuj169f10Tkyz3f9z//8D/Mk93Q3
uL1gwQIMcTNB15uGnW+xT4bsVP3TTz/hRuIqZJ8MK6CTkPBmhJUDO3595Ofo
a0ocCbUQnxr1DnUOWfxhLPx5gl2wGhYBocbm/Fd5INwW+2TCIrILi6gHbsAQ
LYLNhM4zcaYdiwrXRQGgG/hp6PLzzz9jCCcWq+HwmbPR3dWrVw3/pk6dqpm+
8vaA5VBtOYvK10VpabZkk5G//OEPf6hfrHNiOTJv4MHSwfbYWbNmJfk4yTK9
8t0gTddFszNhzpw5/IBrUlPd9u3beWZIkqyEIvmVKI3Mc0y1nFqco6cwOV9J
PagxzQHMvFvTPI3mu8mf5ERqi2CqLfLwZgzDg2mL6Rs5egKd4fkpkgED5aH8
7VhUsi6qsbqAnGOiMMw5EcaM3wwVsj3g+Yp0fFin+9C/0DrSBDjBGXIgvQRS
//tBsqADGp683jnh1fOvkn4QMzEKqq8qMgbgB/ANb11zgEScnQ9chA5RRUTs
sUyYn08kMU8osYiSfhBj1Yu3eJggb4YBwHAdqstKeLIiJuEUYCw3+7XgdDMb
QgoZ27QfxHMjf4K7efOmVsOpXkwAI+dYVe2mXomsgW+alrppP0gNqCsRqChB
NsCgWtQeJDdxLxPeTpUABa/Grx/U6vBff6d2bcmyv3qxgnNQAH9guF0FxyPH
HFo3qi+M/9NptU8GqrBITx0WkQ7xAZCwb1jkKySgYt049YOeDwktpTBYcaRK
DJe6cIxlESUVwg0X7rNofMsZZDfLQ3mX94PMTb2arF78YVb1ngogM5g05MOf
xD3IHh7KD7/+cfz6QaYN1cUq8AjRMDp3aDjuJSQC1wd5ztSTYzaKl1PTfjBv
AOsAKZQwuxHoM2wYQoKERUZJSKFAIzyd5v0gz0ME8b14ggmEEtNLrAOGFgfF
bbZgUUk/WHvghDRRC/3he7lrVWfaQpEyZoATr5ShdUldFN3WhEIPoxM0krze
kAzIGVrTf40f0ZOM5X47hLExq98IURJd86BRDCMjcIo6aBT3ifmYOg0axTBa
vXo1VzBoFPeJazIGHjSKYZRwdoNGcZ946UQg/O1QVqEHjeI+AQPSoFEMI53g
n/70p4PDKQcnjYtyVjrn2btp0qRJJp4HH0J79+5NuoS33npr3759viaTuIt8
9eRc52YKvPHGGya2buZYfYq58JPrfgzd9Nprrz377LMjFMgzzaB37NiRSIZZ
GsqhYxNtdeWMf86G79mzR+FNmzapPVEFzLtHfn4PPfXUUyOwqJ9yhHbr1q3g
Jbfy3ir/hXlu1iU8za+NMHSTJj/zzDPl5dVIfDnkghvYAo/7ifvtTg5o41Vr
SJMnT8b5kpKkRhykk9M0MEReERMBhWkbN24kL8AwzdeUKSePmj59enl5z1d1
WAQbk8Ex1wCERdGu8K0dPf30055fUjIs8umaqsCQ+++++y4MgIGhQF6jkFr0
vCkef582bVpJydrcSCRnwzHk4D2m5Yj922+/nfgMMf/EI20KacqUKWRdXj6G
hkU5aBMBEV9tfbQo8JoiCWnF1KlT2/1XpWqPvRNZYPA8hIVp7Z6J4PHYRn/h
b5MOPnkuEuKDdBKKoakz7KGsz49cJoIgWRc0JGvs7tcW5xq27DZJqJPEkaBy
YDfVbZ1gz7qoKXC2PJlsfv/994Z//Wd5Rl4X/b7aJUK1cu6PJWKpiTbv9NFH
H+GntvjppZde8tUkBQBC14oXXnjBxaFDh16qSGMNhpVkQSMfVCmMs63qEydO
6P3/t6Ivv/zSSFJFM2bMyNQ+OSnA++c//2mEYNp7+fLlr7/+OobWqRYxCrcK
N10XBYBYifjf//43OSawDJvV9gRiPXz4MOakcIvtyi3eD2I+/U+6edPtrGV9
9dVXJimmutBqY86rlrOlmwrXRbXd6PFvf/vbF198QZ2yjeF6FdKQsEwqjxw5
klO3rr/99lsio3uKNQXW4v0gFvEMWERnsEKLWM358+exiE5eu3bNA7OQ3o5F
heuiBBQW/T8VqR1nUh0fwhj//ve/56zx3LlzFaBXTNi0JfvSy4E1ej/I6k2x
2RQmZO9Hp1oLnTdvHni8BO0aGhpiXLdv32aYQCYaZCNGNV0XVZG/LFiwIGEi
2BTLunr1KkPzlRni+eLFi1lfUyShFnl4r1fxadWlfyEsroZ3JSneALArV65w
obH9dlrU4twE1dWz4INOUNU8IV+d0NOkGZ1sd2iiU5yPnqRoNYlkdyXLYkpM
zH+zbI5pVB1UbjybDBPOOqfRO03Y1f9+kN7qUk1n6KR6cYBke/41cj8ICbR8
ET8JngudFKj6tfXr17NHRqFdbuasvcIsAntpIFX0F60jhRyCZq2j5uctfD/I
+mhackno6/FZY0lZ1XnxykUkJZkaKTOcOOBrFhZg4EDG6Rw9MAShybobAgVV
o9L34QnwhjpwEn2O9473OXqNzWozNWCMOOArLvkkMkygFVwHNuaQ+Pido9de
DEnUsiPVvnTMSULqjO2pfV7P4Q836yejQQOnHBIf13P0WW3OxlFdIWAEVLPI
fQqfLSvtWFTYD5ILC1IpZ0Vtsi8071CMHLDIr/pK19CSpmdqqaGCJui+x+Mc
veqSR4a5JTxgTjTr/sg9o1AcM9NhX3R+zZo1DJ89EpzC43eOPs+HLZsMiSz7
RXVAtIWD1Q3Fv+EqhE0TjjftBzFKTwcVWXz44Yf8GFQXL15MNAaSolqcMFcw
kefoDZCyh5ZRxEtDRXu5HcaVmD/k9X3DrDehkn5QJ6KlyYjHdkjkYpWpAZJl
y5blHP331Z7zvODWXyT2CxVNLsIxnqPvVMcPKWROKbKa+JxuGrkf9Ed+iUYl
nJQngJ3XwfWF52cjQcZCuOoi+w3CZNd+dYEhCaI1ApX0g6lULYGXisBLS1Mm
1WWQHGAJdoThweCzMFBP037Qk9VyvUru4Bq8nBsFL2dIr1dv84MNGycgrprm
k0JOQ7vIkDWCA4xwEwG+U+2JGlVG/VS+T+Z2lT4yG+pc1AHK3AnCXARhsKUA
VOU7LlrMB2sWRbsiKfxJeJBuvrVjUfk5+ppFnWrkEEPrVA4twKL2kZcC0bRO
QxaV94MPNLf8hCFRb2CUyXltuoRX2TFSgy+hpv2g6tQeRtWGFusLyPilTiXf
FoY2lnP0YVpqV3VkhF2wxfMnH0fTx7Y7R5+N4p17VhYliTeoC4xrXLXadtId
BIDPWnWzBStR+Oo5dXx4QJbrtk5w6tSpZ/ro008/zefp06f7f50xY4autv/+
WOiBFRWSIcrChQtHLfZpRWfutSvX9UVdpsYzMhNGppkzZxr/N/pLd43dMHrA
tyMDpAULFjT6S3eN3azrx9aOZs2aZUrSFEyPOB6IsEemhfTee++NkUX9N8fI
otmzZ5vEFSLp1p+enx4VMCyaP39+YeEH6syZAqY1ojlz5ph1NvpLXdfpis70
cW8shrZjx4558+a1+2+P6vZja0dz5859//33myIZP18EDEijFutudfdFt+r2
Q2rnrnWC3NH54ZQcPUZZBw8efPXVV6lZTwHu4ujRo+cfQmZnr7/+Ohe3f/9+
kHx6oMH2oUOHdA0+Qd23b5+bn3zySd74JKj4li1bsrCjjAJnqp3DBw4c8IRs
gH8YKZzAuSMQANqiRVn8NIzUlatr8+bN5tqGKIkr7r5ptdnT1q1b3Vcv28+L
zqS0KyT98pEjR8rLnzhxYuPGjW+++eZnn32mXuOl48ePf/jhh6p20zicfbmJ
J+XP7CY8XLFiRXl5jSWsN954I1u1wYga4APh+vXw4cMu3nrrrXZ40KJFizxk
1GL0kAjM97EoiZthSPDVHB4kKRqlwGuvvXamckQRYiN5IZq2fPny8vLdLKKB
AFDgSAq7QA2Ltm3b1ghGNy1evJgtjFrMHASLTEN4mISOx6v8BAyOUXIswqv/
/d//xSK/uvCXpniYz9DQUElJFpR1WsqDCapm4+7jFZDmuWfPngV1/fr1GsgM
t2/fnrcnTSEtWbIkTy5vAunwNierRNsqZeMUiQOJXoEHLXY1RRJis8uWLWv3
X0xYvXr1Bx98gGnZ+IEzTIw3Zr/tnomWLl1KEOXlVYpFPHxML4EOMJnOgETZ
sIuJ8e3t8AAD0shlcCAb3igSSa1duzbdojtJtK0MSNkSo8D/VES3YXNB7RuZ
v06wZ100x+d///vfm6HTEO3NK+NuGnld9Nq1a6RJpf2XSvAtCYriZjaC+kqy
bFy/o3aDXpYLPLVkO8zWZEph/l/bFWa2I2fDLFwXzSY6c3kTZ7Z58eJFE39d
LSR5H0HQzApss2n44xUBgxmwJO4sPDTadF00rwXJFCodhFEuYDSQ/mORShMG
Pyll//Of/zRdZGuxLoqrZKEizSejhPumEpr2yy+/UDN3CLRTJRG+WOUJbQSp
cF2UOpmDqJTDxBACwqis2OiDGBQbMaBy0ziHIXAgxmmQYxSulh9uapdvgurm
XRjrJiCKxDy59wsXLoRF3FrWk1uwqPz8oOdv2rQpCWS1nfamLsabHKM6IELE
GSqtcFKq5YB/+VueRvkm2G8OV7IjU6TsNEu+CUL0KNJMBjdM0wdhft6GJP9s
IaSm66IMgXSmTZsGRirFK3LEENxO7fpEet7O0Jqui/JsvAopqI6fT7oBIKdM
mZK4EDkYnlwY3377bXnS5JqarotiPgw6F+qh9uxRyU4wGk55oMIiw5iwqGlO
8JJ10doDZ9/gpEmT+EMqRJGwJVFEPMe1gcfly5fJUZl0BCyOlnoCiys0//73
g5igah4mMfwzOer518j9ILbQbZgxyqgvUz+CTrw4asZZ5aYC2QFr5OyOsYcm
qC77ZlmKdukrkwNlhFaU9IP02cMByD5YwHIuOxEgY3fwAAmetifUp3+xiMR5
U97NQo1q2g8SOreQA7wJLQgbOSYdQE62uhlHQSEL8yzX1GKfTLJvqIjW5dxK
7ILHoF2GiyZi8beY4+s4naP32Cwg0BwK7wKXIi+NIi8GwplQJMLFKMrgOofW
lazTHIxKLfbJ1CzSEMAS6CA5JvirsIg6hUVHjhwZp3P0nWp7m9rz/jS5QfNi
CwwsYq3J6YBFLoCJeQKGRTS8EE95P0gQhk80GUNUobrs7DKAockElC0xxu3E
B6QZKwbmJbhZdvlbsKb9oOcTBM1h2ombkShebsLpZtDScI6C2jftd5r2g9mG
kTfLtIiHYWKaD1i4pNPJGhrhZomsEZ5O836QFCgwMQGmOjLidpgebiTWVjeL
gPRTIzwl/WA8MKI/3KBJsX+5qTqcyStUyuw+S0+MFFC5BVZMkcgXPxlgf+f1
QNIJ6tnvNiQTNyJr+q/xIxad2cpvhwwVKPCgUdwnvi4Bvn47ZFjOyQ8axX3K
/HfQKIaRoQInP2gU94lX4eQHjWIYJdXjoFHcJ0MFTn7QKIaRoUK23P9GKNld
B41iGOkEf/e7373fkP74xz8mb/tvhHB18uTJg6rdeMmkoOfmn/70p98Ui9jm
AFn0QPrzn//8yiuvDBrFfeLhn3rqqUGjGEZ/+ctfXn755UGjuE/GCZMmTRo0
imH0xBNPGAMPGsV9Mtp88sknB41iGGERVINGcZ+AAWlQtT/QXesE+89N3Lx5
0+wym1H13f2hLEvii9akt/2+ij9/6dIlE1hTabPa+nRAnX0sG1zNtQtjinZT
z7qoZ3799dc9bxncPF/tbXBTvcmHCNuVK1cUznkEY+/snQY1kW+Dv3Pv0Chg
GJKkV+erLRyuP/jggxMnTvTsry5fF71z506eGW5fvnw5dV28eJEU4MlKtQm4
i/pmI/50mqyLprrsXScOzcwiVWLD+hoGgppXpWHm3eY7qEddF83CNTAqunHj
hmE/udytdrarsd5JrmmA5e0JVOGYAh7eaNN7+bponp/92yoFrPukRmwHJIPw
7C2/cOFC+FYOJjTqumg3i2DQfBrSw6JOtUoJjMLfffcdtH5VGN9qJS+kknXR
vGLT5GSNTHRcSLLhKkzwq+ucqsCZeBifnt80cG7Juqj2Zlpdsyjh0F3n9V/e
WvboNvD/qajwqFSo3bmJblvLZgB+CWBa5Dpn0CBpd16vfF0U87OKRWHUW/si
kDxB7eRFZ5RxgXXKNGJOqH9dVOvoQ7cPUS8xBUCtLQrkHYRKY+w0DYxo8t17
iT47Xe46thlOJsru/v37jx492qP2/e8Haeybb745bdq0HB7M5o2ehjTqB8E4
fPjw2rVrd+3atXPnzuQTP3DggE7ZcxJ2Y8uWLevXrwdVY5PLu5SnFfX0g4k6
ridKFJo0mYnlkH6i7DLnKPycOXM2btyoXsxZsGABYDri2bNnA+kmu/BHf8ka
uLawO23P29vNmzefPHly27Zte/bs6em7C/tBULFl5syZajl06BC/N2/evLx3
TtqRhAFPtIS8LdV9fPTRRzmGWd77lPeDIKnu008/ZZhLlizRNaS3cv/UqVPa
xRwoRmLNufbYFStW5BxWI6c6aj+IpcQEg1bjM+bMnTuXUajOdVb+fU0+heQe
WrVqVdIPkemGDRvSJRWiKu8HsSKbuNLfJcxCp3qxEtuhJ3SDP6T5aocHsOyT
acSiUftBSGDGIkZKVbI7FKSVK1fWLEpsEDqmMA9GkWgazuOba6IsR1XSD9Le
nAenG+xdvRlWUR43M2DYvn073T548GAyBdBnsiYytuAz5zELdbukH6QkinGY
rFt1msCE8cRNpt2pNI2CRbepfTbJZz8Pws9yFpX3gzkbmKPWsTWmpFLavmzZ
sgRMJsRFixaBTVIcNcHlhGwjLSrsBz05yTji+cmCMsetJQcf1vGHlJkB6oaS
SSSOMauLhXh6+kFMYLmsJsO2NA2YRBFRI23BhyNHjhA0D5C9K3w7r4tXyUkX
TfbfRAlLbggNYR2ZRCQe4/Hjxz2TcOszyKEHxpPBgSlTpmi7HuHtt982bexp
SKN+sFMNMxJYw7wpASEZLG688sorWsef0JyhoSHmA3B2BjYaZvT0g99XWcmw
K4dzeXUalQ2ZrpPqYt26dT61IkGfSBM83kOPnAhUzAQHSOHzzz/HvXTNaYge
00+JYJBJR/9Qv7AfpGZare9ThWdyAhF9GkXQvqoim6gJ103iIEeVlkdL6DTp
B6mlboUO4J4LMtInhqv4k4hYFIMQlaGNEBo/AM80GE75/rpR+0E6QHUp8L59
+1RKNJ7PWLI1lJlkyeLjjz92hygxh30dO3YM5xOvMkNK/+pR+wdSeT8YFiVY
Cv9JOukHa9tJEIz3q4CoENJn+skbYxcw5fvrSvpBwzDc+OCDD9jRmxVlO7Sb
cZuUlgfjZ6DSO1Ng2LIPIWFVwqKSrSkl/SCzWr58uX6ZyOi2cWZC+ujs6lhM
icvHt5DL1orwBD+zxYhu+zVaNyqN2g/iANirV6/GSc+sWYRdCaqWaTLfnvtA
JhwreWU3vgvqXciiRv1gwqZpO0UiL7aWPYTxLfwAGfEkzIQr8Cuj092weuIu
7wrL+8HkWmU+yQmLCfHDLtIL67UT5oXOZAiaDTxJ0lGIp6cfZCBaN3XqVA/E
Bw1PwBCVclmueRsK7CtzjrvO7I/m0zEFqJl/Zc8tJwBJNmX5iQXxDzQ/DkHV
D3TXD4wno4qs55B7Vpl6CjTtB1V9vcrRVg+BPDwRCZDn+9XF7Yr8msgA5c/v
XxdNCIuMKhNwoFPN5nKdWrJHy526OtdZs02Im4Sny8ptRjuBGlfvaSM4tPJ1
0VSXQA3dIRqyQhLmqzHc65YIqOWjhfJ+MMIKT1RRQ+rmamDEEoFJ4J1uVpdQ
yX7RRF+M6tbBPeqbnUpXIUm9tXwj1lxnAacEVXk/WLMoK0jdUks4lLCi1sDo
TLSoEYtK9ovW3IhB1XE/ahZ1o/KZiCWRZpSqHFVJP5goMVnFim7X6tqt2zVz
4gTuVsGdsgKTAoW6XTIfxJPa3sOiAAvIzr1ALj263a1F5SxqHU+mtrVol+YH
ZARa3+xUHC4Z19VUvi5aO8aEJ+p2jL767Da3ROYJkmx5LcTTvy4aNah5XmtO
dDjRxuoQQEEV79S555fik2t3ncJhWu0cRnDXOsGnn376VB9lG2qSOqGeX595
5hnDtv5/DYqMFpK5+7dDS5YsMcgZNIr79JhFo9KOHTtMCgZSdZZKcs30YnE+
Fy9ebGaUm7VJDpDMcM31Bo1iGCVJ+qBR3Cez2qGhoUGjGEbwQDVoFPeJvH5r
LNIJzpkz55suMosxzeQzXZgmr1u37vDhw98Mp0WLFpl7fvObIVDNLAaNYhjB
A9WgUdynxywalQbIoo8++ujVV1/VEev7Xn755Q0bNpw7d+7dd981s+DBjh07
ZvxsIpaV/AHSYy0alR6zaFT6DbJIJ9izLnr58uXnn3/+v//7v7///vvNmzdP
nTrVVKJnFtl0XfQxPabHNAIZcP71r389cuSIMeebb76ZrT4+E8jIfSPPuXPn
/vDDD7dv305MoUFDfkyP6f8/9MB4Mvrrbdu2Xbt27erVq4mn3fOvx/3gY3pM
j5DMB99///1//vOf2fZz4sSJ9HcffvjhV199ZUSqfzQrzHuuDz74oOnBosf0
mB7TCFSSb6I/tPh45JsYC33yySfGzKMWe2BKgp4G9t9vF++d4zp16lR5+Z6I
991x1LvDzjfC0E2FLOqB9EB25XrsYfDLWTRCpY8w38RYWHRmuCKNMXlB/Zea
RaM+ZGQW9YCZABb160zPTzXsB5YpJ3gKtehhwjoznL0PK1NIwDTVou6qu/nw
sCQLTamcRf1gzvTJa4xWf6aYRd2s6NbtHt/Yoz/tdFsnOHv27P8MpzrfxCuv
vGLqd/To0Z4CCxcu7L/ZTZ9//vlbb721ffv2s2fPHjx40FDWWHffvn2Gsp99
9hkm+HRfFcePH9+/f/8//vEPYBLE0q8HDhxI6L9EO9+8ebMCI1Sn/Jo1a0Yo
gOp8E1988cXGjRv/9re/GWzjmOe7/69//Ssnd5KqAKps0IVfK/7+978nOP/I
VXTT0qVLR2ZRDyWz+ZtvvpkLVZ88eRIMOHft2oV7ULlJvuXP7CYNX716dXl5
jU0yBTJSKU0gUDzEjeeff97Ttm7d6oE43w4PWrZsGVmPWoxoduzYkTdlycpB
H3ImCJ4XXngBBmVABdjsSYG1a9eaVTXFQx+ofXn5bhbV+SYgAY9GkSOp0SJl
miKpaWhoSFc4arGaRSaV0Z8eFrEsZXBm9+7dWLRp06Z2LGKSRs4lJelM0t2e
O3cuKQBiDjwDNabVnCGVZm6MDuacGmih3suXLy9h0fkq0wQZ4UN2/rO1L7/8
0k88Dy+XjDaERb1dvF9FqaLtjawe4erKlSubtiIEWGwfyNpgDx06RLI8Z1Mk
Na1YsSInRsuJk0yWEH9kpEmbQpc4AfyBsx2SkGeCNHKZOt8EudAQF9mxSWrr
1693UxkqlNQS0AKGbymMXVSrEbt0gg/LN3H16lXtZdqq6JlFjppvggfIMTfK
T5pz5swBVdvpladpi56RjV+6dElD5s2bl1QaulctpQM0UMP5JYXnV5QT8Q+j
RvkmfvzxR4rqmVQryam5hWxIrvNNXLhwIVG2OA1/WbRokSYnlsI45Zu4efMm
C9Kb8xsvvfSSXkbzMYqZ8w8//fQTCwUpIR2IeCLzTagdr3AAl3744QciA4Ok
gEyW6nHNN1EnU9BqtWzYsCHnef3kYsaMGX66e/eu0QKLcJ9q4RtZJy7QBOeb
YD6TJk1KChgiA89PkGARpZqAfBM3btyAhCJFQ/AEBj0gDDrBsM74CouILyk5
xiPfRHYXoByf1BDi61TbD5geh5D8UIsXL477Yr9AUqpxyjeRKNasEh7ehmiM
BBK7Ro0cQmL+GAixemUo9oIFC3QETVk0lnwT7MuAisPxFdQ//OEPfCn+gEe4
E5ZvolOdvEuWkJzphmHv3r1UiMNMWpCEVGq3Pt8o3wSrTLoZ3TEO5NRn1ANz
km5MYSpkXE2IvKg5iE4t0bfGkm9CA3OYkfP02Kb5JvwxOQfpvJEeBkKbHG0e
5T69VYA2EveeitTCxHTitIgh+8n4kH7yaUzDzCjnIh9GjfJNUDzTCvLVT2Gy
jr4+tp98E/ivsDJcGW5oqX8lws/45ZsgMpxRqeYb3ybUfNIrYAL1gxP+HP6a
4HwT/6nmSkZfieKVPAWUBDcmIN9Ep9IosrhbxdvHB1yKISQ3AXYlHAFe4R4w
5EUl7g4i3wRTZbAERHbJ2JLD7BOWbyKKxGRGZRHXERaNR74JVehqNVkPwq6N
UhKJIuM9SHJi3QV1cvOjinK8cTzyTeQ0/TvvvMOTQEJAHEu2GzEuDgcTsIi2
UDAwkvUmWUvoG5CFeMaSb0JdSS6T2IaJc8WNkBq0dycq30Sn6oaS/xS7+B+j
ykRP0gtHWwjIsKpwUtBD5fkmkq9E1TgQX0FnatfnOXHXOkQllcc6+k/BMiz/
P51vInZKOcv/8jjfxKj0ON/EqPQ438So9DjfxKj0ON/EqPSbzTexczgZ4m7Y
sMGFedzrr79ugNRT4E9/+lPiSvXQ+++/nyhJxg9ZF0VGgx6yY8eO/vIllFeE
nuniYWUo3tNPPz3ycwAwyTXwCyQNzCKtiae2BJ7hovuuFXitIqzQlhRuBPvP
f/5zohQWUmrUTHwzkMYx7YUnYfHcNDgcCxu5r8mTJzf6C7Zv2rRJ1eESPuys
wsNmZRJDXORmO/rLX/5SwiIACE5JLIqAMKT+FVtqmSrmwlecTBTBRqQTfOqp
p5r+C6QIbuc9wwG4++ZYCIteeeWVQhiq1moS8ZfNmzfHABN1LdyoWRSTHMGg
HkaGUoUsqs0tFyDVqlK7F6hiWSmDWqj3E0888fLLL5eXT+10u9/Q4ujcxL2m
MGoyIJ80aVLrv2dJv7Z3F/EMYzG0J598EqpGf+mWWnZQBAyHEA/ZGszOikUg
jQogYTBdxOcQXPojX6PbKUNYQVs7K+xq6q77802YpO/du3f+/Pl37txRhY67
f9nkYeuiZtPayJ9kKYYo8dBMdvXq1Vph3uo663tGuTCbxylmCpwu6fvvv6eQ
u3btOnHixMGDB815NdCs3N891t8fNqstWReFjV/65JNPzDf1mxhryp98sqw7
IXp81TQzcRNtGKgBSNkQAn+jlztN10UTNhbDE3p97dq1ZtxHjhzR8OXLl5vm
68hI6kzfGZZCavF+MMEYf/nll0uXLhEEGf36668GlljkE9o1a9Zg493mmSZC
heui5PVKRXQGQwiLOBIiycAST7J4Qn9WrVp1t3qFEdNoiqfpumhI7YFEjSk2
w6Fp169fp97ssenTeqhwXZT20n8sOn/+PKuhewcOHKgzO7Ap3MAiEsSuu1WO
FeVHfuf+QCpfF8UEUqCu3AjdS2SAznD3wrLoOcFRMI81Ji9cxeqmpnl42bW6
qErSW1Bmf+dkMGTp0qXgEShGNYVR0xjz8K5fv54D5F05dgzEkB9//JHz4eRb
Q2qxLtotNSq0b98+wqJCHsXq+czWYDrF7wfVQv95YEiYEncU6fAbefeNLQlw
ykbwnJ90we78iy00OmPb/36QdWj+73//e8rpaWwcB3r+9bB+EE7AaFESVaxb
t46W6r8WLFjAGP3kWnUcjpIeQuLwa6+mzZkz5+TJk/jDZole7StWrNBp0tLF
ixeDsbMKLv3AVpT0g2rUL3u4zo6jUG86Vn6DaaSP0/Zly5YRk695h5jMApCz
VrXrnYEvYWzTfpDHwBkuggt1TZSGH5cvXyYCtZO7fge2ZHravXt30xzQLd4P
njp1StX0kID4KNzIy+ts9qNv2ojt2JLXvk0Pdxf2g0Rg9EIT9u/fTytYBOZk
3OLOvHnzsAiroTJVIVzPpGx8CDyspo7tPCq16wcNUYyWs7eKzjMcd+DUJ2aX
RTZIN31sqLAfpB4AUGn+SleYzavxFeRCdgAwWHhMVfLemW3m/WA2bxfiKe8H
Dee4EYqqO1adaUVe+XW7F/YINg/vJ9ZNvcmR62Ck5dvAmvaDxgC6GIpNVTQ8
KSfcpFc6Zcr28ccfJzkFbYe/ae6bFvtktJrO5M3ykiVLiIYQWWtSzNArMGJo
7K48nHVNLfrBTrWjKVKjJFx6EtVxgBDqHN03O2uaJCtU0g+aieAGF4E5PLCL
5KN3E3/yXpLmMFjqhIdMfmho6Ntvv2XFhJs9YDx84YvdB8bZpgxq92nU7aLO
YlbTw/pBVZMaz5m4phcr8pBvqtg+VyvKRafaUebhuJ1alKGZPv0leaP4t6Qs
dNNn3hg+sBUl/WB2vETfAHAdX5q9TykDCXEHXuLNdqpw6AmE3qmMyNfRmPr/
UdN+UNuT8AvbtTop0sLDBChWdZ0iJzfLH95pNR8koGxMpV3YAkD2zgWb+9gS
hcQTZcZpv2janiZjSFSi/lW92csXPQEMpFpp6Ux5rsZ2/WAgRRy14cS5hTk+
W8y8QuX7ZDQzZkIW2dUccdAoTwiAsIgQ6Xmy/iXVQvluh/J+EBOyDZL4kluz
+6dwqbYskOAMZveTu7AQUtN+EBioaG+3MrsZBctWEPDY/t1qv3H5jp1Q6zjb
IcpMpaPz4V62ykSNiax8/3NN7frBWmrJjZjQ1jG3eCFiapF8sFM8H6Q/qou2
UFdgQHKTxtZ5E5KqL2Ot5AP1GS/aqZxDofnrBJMgrBHNnz/fSLvpvxoRi+OX
cKyksGmUyeO44mlKpsBGI4NGcZ9MT5YvXz5oFMNo4cKFxt6DRnGfTKMMKQeN
YhgtWrQo+6t/I2QCnkWJ3w4tXrz4ww8/HDSK+3TgwIGlS5cOGsUwMoPLYe3f
CGVSOWgUw0gnOH369HPDCc4kKXv33XeNkE0/ewrMmjWL0zg3GnnC22+/vWfP
npyG0y9Qkk8//dTc1tdsXVYXF61XTXatIxWp0XVS4paQGTpzGLnM6dOnX3vt
tRzkV961St1ULyQpk3COO3bs8FPCHZ88eTLHb0EtBBOaPXt2CYtq0iPk9b0a
33jjDTVmwer111/Hw1OnTvkVtqNHjzaCUZNGcarl5c+ePZvX4jBgCzV46623
3MQ68BTYtWuXCea2bdvcbAdpzpw5xFGI5NVXX81xAEhIJz8l3+vu3bv99Nxz
z+WFFF7luFNTPGrRNZeXD7CNGzdi0fHjx80Cjh07dq7SxrCIXoFNk5siqWnu
3LklDYFk586dYdGZKmszYeUn97HIT+6D6msNjGE2xePvhSyivdm6cKpK5BFF
Olf5BN6ASrvO+q1PYmWPIGFjU0jz5s0raUgOcKkFH1g0DWFrrv2UY/X0mQ1G
i/gozkqZnJhoRJ5jDNz0X6EEqaDPuMcDY2C8ZXY6tXsmMm3xzEZ/4RiJDAc4
YTYOFSYDk7PttQG2I2BAGhUAQcQDMyiVJrhK9sxAcq4yNN6ALvmazTwK1D68
ESSdYM+6qGkvi37iiSeyXUQtrLtnFlkYX9TcGSfXrVun1VwWMzQMoOrUb/Xq
1R7rpgky48qmGg3x+Y9//IPH1q9xkiVT2k7xOfr0s+b43MsLL7wAhps5j5Yy
ZtmYnIShysBw6dIl0/AcYO9Uq0+F6yRN10WzRwhCs2BMc4E5WIR1xPrll1++
9NJLbCFn0K5evdp0RaLFumheT6sITwho5cqVP//8s5s5XAAMl5jwAknZNk7r
otevX+dY8DNn4gj6iy++qJ9Ae+l89hVo4MWLF1mZ0R13lEWS8jdNLc7RJ0gR
tuASMDEKNymMXykPW4akcy/j3jido9dMssAimsy+6G227neqpX4AdHy+chG8
GR4qiW+u797LjViIp3xdVGPVy5d6OPOMInUqphnL5W37ihUr1q5dqx/8/PPP
sVHhnOljoeWbr8rXRdkjuRAEn5a4EHkD4gl025j/woUL0aIs0mppXg7yhOUs
arou6slXrlzJSx+cyeCBGvv0HBqVvQE04e69ZJflDw+1O0ePJ8YYnKEhAVQ6
oLypz6twYIipXbz3knVRdSXxPVkkBpFPN3V5y5Yty2qnnpH+cNRUmo4NDQ0p
zKUkqEWnsotCwfW/H6QnhnAA8Myu2U5/0IDCftAfqRzW0THPyUbcHAyPN/MQ
g8O83Oe+mLDxBlvmeKmEYVthWImSfpD+5AAC5rACFXHpbpIvg42RwklAANND
pmq8QR8oNveYTQVAFh46btoParsRIH+lRiATZCCvqiGE+d2KmAyh6DEhLH94
p3k/SMNBwlUwKCQ5Ekde5eMGs6UkWBQHqwAhjtM+GTqQQala6CSPWu/JyQDV
r0zSJ75ln0zys9+t0mQbWBbiadoPwkBXsYgsvv32W+xNMIGwiKTwhBq4yfkb
czbKIR4q7AexiHSwwmwLEsIynoxKq5EXTYJp+qwMX0rDXZj+QOuP5Uezy/tB
7eUl2AsTY+951x+o2MJTcWU5oI1drrMr/vuKArIQUmE/qKWYQy5cDYvGIjDC
IuNhNfqqW4wWuWC8ClOesAjHCvE07QfznjS5ZXUQlCROIFElSRPPQYqh4dgI
2+YfRi36wRyTZ+B5P8V7JxIXbnPj/BKNMoMoD7PTTSX9IA+TACzq0h2waIxl
U/jD+6V3031AyCGz+tyHx6gYyAguoS1KID1wn8yo9FvLN1HSD/bQqCPzpkP3
HmraD5bUPhZITfvB8cbTaRJPZoS66vtjBNNpu09mXKl8n0ynIQfasau8H2wB
ox2kpvtkHljXI9SiMe6T6UbyqFC12yfTeaRs6aaSfvBhlfYozKNCqBP84x//
uK+PdK89F9305JNPmqT0329Bnq/f775oQTrB6dOnl9TV065UWtfbjaEu3A4Y
Fm3atKnRX9RS11jjfODNFmRAPm3atEZ/6WdX/82xQJo0aZJpS2Hhmg/1xcOA
RV4tgBlzTp06tem/9j1ERmPR55qeeuopw++SknWre1Q68Hpwdt9sRCbjU6ZM
KSz8MNV9IIzW7Jo8ebLZZUnJB5pV/VM3vJ6LRmTyUs6iB4LsRzhGRXr66aeh
aoHkgQDGrtXkBdKoxbr1p98t94DpZlcLv6QTXLZs2c3hlOX6n3766eOPP962
bdvhw4d7CqxatcrI8GYB5TCXB166dCm5MLKEe/bs2c8++8w01kzfjFvJhMH/
uqJdu3bVgQdL6NSpUznyMwJdvXo1J/dTF1lkSzmO6dPNrN0/f/789u3bT5w4
YYSZ6CXffvut0Ytr8/RCMKHVq1ebX5SXV3VECSeGa/6NGzdwKXEkkpbOzUYY
uun06dMmF+Xls3q2Z8+e7EPesmULCV67dm1nFZEDTxI3UpnWkNasWWMiP2ox
enjkyBGVYhF5gURvs/JPaoBRpAsXLigA28WLF6lZ1uE1oREef8wR3ab/wocc
NEv0IeptUvDWW28laEPTB3bT2rVr2c6oxfBhW0UJmQsMSBTJT9988w01plE/
/vgjFYom4ySoR48ebYqH/T7//PMlJXP4GhLYsnshb9kI7vjx46RGqSJWMOgS
k6f8LppCWrduXYmjIIjsrKDDyUqQaL03q0jCWLd//36cUcAF1rVmEW3Mgd8W
dOXKla1bt2IdLnGMuOQOXcLGOMl29Nxzz/Ekjf6CAySSl0f4Q20iweShaCGm
bsqa+agANDnrogcOHEhSEmzhA7PYrgxtB4yMsoycdVEcyzuURpB0gg/LN0GB
ExC+f7GocF3UXFUTlixZkgQ98+bNg1BnxxCGhoZ4Zs2hdRh7586dW7du6Xyp
qNbNnTt3wYIFPF7hbLdRvgmGYHL0xBNP4JWbJ0+exMC8uMFP7suvdb4JPk1X
iCGJsz1++SZ4UXyA5Oeff84bUjwh8WwZck3cCd4y8fkmQOJtjA04CqJMJCLY
ZsyYYbai5LjmmyCvBJw/dOjQw/JN8LR5iXCuOuHLatzJTpXxyzcRokWY88wz
zxgbUNrZs2e7A8zy5ct9EhbbbHoWu6bCdVECyjA7YWT4hGQH6FRbBQjLcxIh
hL1Hh2kaPc8RuXHNN0EchIKx2WAGHqHzCcDoL3TQnInr6dOnezKTmfh8E4bB
8VEEN3Xq1Oy2Cot4laYsGku+CXKEEJM1n43ncEHO1McZDiTfBA+JOTNnzsQE
8JKFZ8LyTfBCtJe3oUvuLKkor4/7801k2kWXeIC7Vcz5Meab2LhxI1bUAeF7
/lXYDzK9HElgnjpuXGWSpJzt93HmnJtpmn4HZjeNgrSFFSvGlT3CfTLq4isM
idmj6jJu71RvyWte8YQ6yozAk2+CcrJNvP13Fe6Y2Y5TvolEnEsicoqHJ6Ts
Cdk1ipMGD0ZoOUw6Yfkm8qY+e1nDDRzAIh1ikin4Ot75JjzWnGtftZkKBgPm
nnwTphXsAiq6RLj4c+rUqQSqGtd8EyHKE62AAYBkUqDMAMN5t4pwXm9Ibkrl
+2S4CLpNYcKu+vgwvQUJ32gOnMm3Ql7Yda7KGwLbOOWb4LiI5mY1RaJI9Vn+
LAElnQ0ueSaR6bvhBNt95j+R+SbIXe10BlTAXIORDIBhEXssZ9FY4qrRHIwi
PrrEoMIQOkznk28FJyc+3wTBJVVleufMUmFmehOWb4K8ICEgUtuxY0fCViTf
BDfVnW+Cs9JpZhicvLclkCYs30Q2XmpU07pK6NzjfBOj0eN8E6PS43wTo9Lj
fBOj0uN8E6PS/7l8E0k0YCrXU+Bh+SZGIM/cvn27zwcmAqgTVRiwNXpsqFG+
iUQpTy4JX1955ZU6gLmLnGGso523DmDeOt9EcNapJQyq3QTVr6D2y6KQxpJv
ItH486Yy2RzcGXsY/MJ8Ezu7kikk4HytJAEDQx1w3kWyGLQA1iLfBNH0syh8
C+z6ZjtqkW8iAOocMTWLsE6BoM1J//48MqNSeb6JZNxI2oukd6lVt8e9QJjC
rluYf3m+CUxg2ml+txZliRiYbhittWgs+SaoEyRxAqAmAQcxuem6zuDTlFrk
m1BXjrHjVcQU1YoWDSrfxM5KiL6mDIQRXI/5P6p8Eya8CZvvaboYdfXMIluc
mzAfWbNmTYKom765SDQkUjZ7/eCDD16uyNcWa86N8k2YRDNnvPr666/NuM1t
CT3rbGZw71eUVUqqaDKewLx79+5tBKl1vonE2cZ2HFa7SRPh3rp1y01tbH0W
Yyz5JujJ7t27qQHW0RY3sy7Ks+FSOzyd4nVRbYc8yRRu3ryJCfVSIUkRHxvB
FsBcZ8PM6tWryfpuw3XaFufoE7wFi3bt2hUW5ahvctC7mVAq7V6jdJrkm6hZ
hAOUhzfI69qwiLZjXVKrZIMT5gPf9JVu+brojz/+ePDgwexGU5eLvCSt3Qum
0SKWhW83btxgiTms2ghPp+G6aLJ7YwVe1UuFer34n59++unUqVMa+O233xIc
f8Uem2rRWNZFORkS//jjj/kcOrxq1SoCvXjxInj0ufXRgBbroiydyNjURx99
RCi6PzqT19DLli1rEeO0m1rnm1Cvi+ydUCbd08mTJ3EJVL0S5X+E+SYSNp8C
A8CI+rOQtOgHjx8/TmO5TZbIZn3Onj0bt13rMjTEp5vZp9royZ3ifBMZMDC6
EydOuD58+DAR647ZaSplm5w8JUxAM2A4WFZmEMJY7lbnsscp3wQpJ98EuWMU
tjBGTFu6dCmLIFPKw8PHajjYick3oRXwvFcR/8C5LVmyxHP8RAH0j9TybrVc
Nn75Jngtis237N+/n5hcE1y8UwyB2pARLmUtWhcANvkm4Pz45ZuAgfdOSg56
FRaxUMwBJi/xeQ9a5KaH07RxOkd/syvfBLewfPnyFStWxFcAgEWAURioOHZC
pORuMsa88B2PfBNKcuPZ70cuqktYqm73QqVJMOlsmPDOKqEMXzce+SYSH0nX
xuSTeY1uRIsy09EuZWiLfhkMfKNFuunEjijPdzaWfBM5R5/hLqhr1651x/3s
0AZvwvJN8IRarcuj4YklxcBpDtmZylHmicw3wZaTb4IE8WTevHkJAG5uRVi6
RT9hV3ql5JvgsQnXiKJ/c8sDaYR8E1gBDHXtN94W/WCi7hM6PeThM9nxcCaZ
F9Y0wa+sYJzmg5qTV+Ral/wFKrpZbSxPNPVO5dmyMSyx6BPsKFkwskNpXPNN
8HgYkv1y2TiX+9kSkx34NbYJyDeR2Cw3q1AkOJCG40/izGcbT26Oa76JTqU8
Kr1dkUrrum5W+/MhScKCZMSgRdl53hnnfBP9LEpdKnUz2TFqJO1Y1CjfhLqy
vYR36meRC/2F6+QKqQU6Tvkm1Ki6bIPEJfXWdl27F/ddxLJILeD9mk6hEFJ5
P6iZ5KKi5DKgLekHo1QZCWcfWvCEb51K58tZNJZz9Eka4vNulW8ivjdqFqgT
lm8inhC5SLqZaFTSiGDgBOebiOA6lVyShqNTcSOeOeavsIuc88r6Xrn5J9/E
vxqSHtloqum/+onO8M8+x/icPXv2GAOPHc8jpPnz5xuNDBrFfTLTHBoaGjSK
YbRgwQKDzEGjuE+G4sk++duhhQsXmkUOGsV9Mt9cunTpoFEMo0WLFh08eHDQ
KO7T/v37lyxZMmgUw2jx4sUHDhwYNIr7BAxIg0YxjPrzTRw9etRcxvzXjDgB
vftjdxfmm6jpzJkzJrAbN27EgWPHjvF+5oA+s/Her4w94cTNZ7MdIqHgC6lR
vgkXW7duTXzvnnwTMJhX6jJ68k2YSe3atascz7nm+SaOHz+uus2bN7tI3klg
XGezQTJ3gNEiIH+oXb6JJFOAJC/Kk5nXNbYkimYyLLSjwnwTNGHLli1JIZGk
CXUGh7xBgAqeTZs24ZULxSCkEk3xjDHfRJb+IMQoymOgaHiGRdC2TslRmG/i
008/ValpyDvvvENY3ckUaLKvOfbyxhtv0PkchwHMzabAdjbPN5F3EMlckJ9c
JJ0NlQYjxh6mtcjv0CLfRLKWZNEMkRot4nwGnm+CPmdjFXWiV5wASNgF9kDy
TeASz4wbnCRVTyDWicw3oeEJOs246An+YIu+KfkmfL700kt8SPKtQHvuXg6a
R5Jvgh9mU//+9791iJSE0vbMIhuti2bN8/PPP3/xxRcxMC+bXOCzlgKvG+Ki
PVPHoYxpy7p168oD7XYa5pvITF+nkwzLdb4Js/5Vq1atWbOGWdX5JnKiFlSy
UGD88k3cvn2bzmu4eb2JP/kSRM5VEVAOda5YscLc+e4E5pvIu60rV66QFE0j
lFgHhv/00085+Nxpm0yh/P0gtvAtLJE2Ekq27neqxRMi++GHHwDIGCartTyw
0UunScD5zqPIN6FqGpXQPefPnwcDKvdvVTR++SaSNJloyIWSs6M6Z7fm8wk5
D5J8E3nNvXLlSpNfejV++SYoDEiUuc5c0OlKZ6NeXcaKijCNYrvAtAnIN6HV
HHt9sJT4Vq9e/d133zH2weabgI1X5zqyoq5pqgYm22471cuRick3oSKO8dln
n1VvQqBkP9jE55vAHDqj+2NrdIYCc91Zu9afmm68++673Ai/bXaW3MHZGNwo
3Uz/+8GEU9NVAaD/NWbrPwXcqB/UIsLFT31QTmQDqQpmgqvYm8E88Bn569AZ
bKOwCY3yTeAV1dIR511Sd76JRFhK3JJMS8k6eRhzJnr88k0QJRikzCq5Pjwh
R25hV0UEyrFzcZBPfL6JOHMio1QZyeTNfgbMd8c530R2qWl7nUwhJtmpgvAk
tjw8a9euJSbyoldumiTeHUS+CZLiBrM9EmCw+f+71RHX8cs30an6FxVhi66q
O5kC06DzbKo73wS2K0OT6dh455sgEZ/4kGxZ3els9F+sTMeh00yoDd3BBOSb
AIkvrdPZsKlkmUksrzrfBIFOfL4J2htTwq5s6I31ZQA/YfkmMpyLRGgyJ0mC
xgYexXtPZL4JzMlBfpBoLL8aH96p8k3kAE7CTtI3CM9Vy4MJ67FvbPkmRo3j
3WKfzLjmd2iRb2JUGGOMhN8i38TI8dXHGFB9jPkmxoMeSb6JR0jjkW9ijLAb
5Zt4WKX9GFqjap1voiR3QDtI7fJNPIx+O/kmHiG1yzcxfhZX0g+OBUCLP/bn
m0gip8ShNT3Rt/bH7m6Rb8KjDAu7H5VDkT3Ry/fco0YPL8k3oeodO3bAkKq1
S9W+vlNRHdjcfeON7sI+caMppKb5JjwfjEQbzlHfRFnvv9kIRk0t8k2oV6X7
qljuiVytdhcgud5Znf0HqR2efU3yTUASAEHia+7njHbYQl4R3MOUdlRqkW+i
n0X77omS2oRFGeG3o8J8E9Hbuq4cDc5PNRjXWBTWuQltbjai8nwTYUhgBF4t
kVqTuyXlZi3WRlSeb0J7cSBmVWOroQYGDFHvXDS1+n1jyzcRhQmYnMTZN1yC
7ahdvomdVcSDWjrx3nmrNZYsM/uK801EXvu6hBJ/2K3bCXHfbf5x103Z1Z9v
wuBK54hvSbVg6tefaqE830Qo8d+MJH2abpva+/uFCxfMCM6fP2+2q0XHjx83
9088B51so5DmJfkmfvjhBy7l2LFjnqzfXLNmDTBqVzUYqQ4z169fbyp99epV
vRicbhrgKZ9kpuXUNN+EYT/x6Rfw36xk5cqVGJU8vLqwixcvrl27dt26dSUJ
Gh5ILfJN4A88ZHfp0iVswSuasHz5cni++eabc+fOvfXWWwq0TqlQmG+CaBiO
ttPtDz/8kKBzqvFmlf5g+/btJEVRMRxIE0zXdSLvRtQ034SGZzdIWJRjsDQH
n5lPEj2wlP50LeVUmG8iUSjZzsGDB6kKASVX6c0qJj/u4ZIyyarw008/cWWY
v3Xr1qayK883keOlbPnKlSsnTpwYGhoCzH2fXEqso3Yv169fjx9rBCZUnm8i
R/UJ6OOPP968eTO2xLPFuEiQ8gCWtAXYrgyTbIqnab6JvPLLK0jmkMhRmTFx
AmDkcL2vOfzSglrkmyA1ssONBK1lFzQnbhyS1l4odK4g3wQRYAVjJ6M3K0qI
UdzI3gllEp2MC+KiQY0BEh/ddr+Rbvfnm8j7QXVRVNXxe/1LoI3WRX/++eeP
PvooHiOh+JEu/scff6QwlBPPXWiyvoDEPRzbG0VwLVkXvXPnDsVWrw5RdVqN
se4nyVGWgnNeG2N/+eWXvB/MaSYOJPFJPvnkk8KlvKbrogYGLDp5jsh65syZ
DApUrCNiCkBS7AID8RMzmx4jarFPBoAI4mbVZ6n69u3bxgbsNCHQ8SebDahf
3qQ0glSej157lyxZwq9iKUHTyZvV628gyeVf1QEcnhZ/kh+ECuFn4r2Urwi1
2CeDJwQdFvGlOEZ8s2bNwuqTJ0/iefqCX3/9FbC8six/fqfh+cGMHhnv3Llz
aUveDzIuSkWrYUj0QkJUklLpLvEWi3CvEE/5uihJ4QxPZSyHq7/73e9yFF13
s2LFCsKiObV7gY0xcgt0O+96yo/Hlp8fVIyM+NUsB1G/HC7jMMHABAowf/58
fp4+GzDTeT14DKGcRU3XRbUXsOywUhdsGEWdXDz77LPZ1a+N5EVYNOpc2cHw
bmqxLkp5eEXcYO/Gn5Dwmbdu3TLmBIaJxasXHqbuoZJ1UepBSUz2cYbKvVsR
VSE1njlnUSnwgQMHGDvBxfxxkvfGKz4KP41sC9fM+98PquLLirCCs/Wo/tQG
jfpBtk+vtMtziBITeA+O3cNJHE4dDV9B8SDXIpbr10bbogrjquWsYk5osugI
Ue210XFoBmAsJQFAlFGY5Xp+ztoDn7D5o1LTflCTdSW4ocYkYcy+UHhyrNhP
wIMac2i6baxFPwhSHLu6XGCaqsHAFhYBUjyYwiTr/jjtF/XYZIoklORKqM/G
YhFGKRClhUEZTEuaS/cTmqAQT4t+kGh6WOQmSLjNlWGLi+z4asei8n6QRNLS
oEp07k7VD1KhmB7BwYNFOqAYWvZilUczK+8H1ajfjxtJWpyYW7cm1+4loVSU
SfABF+Xbocv7wcSJSlpGfNDqiCORDGNlOcsMsE/YmEBTFo3l/WCMjqSSWy21
03Zsj7270yKyYrtz9Opinumd/1MR6fBROmJggDxX5ThrCqZT/H6QpDhemoD5
5GW4QlUAoLp1uhmqQplj/nER/LMCOfVfbv46QZ3+5Ya0dOlSSt70Xw8j3kMr
fLZ+ggGkkd6jwvNIyIDcpGnQKO6TcZ1h0qBRDCNDOJOmQaO4T4cPH161atWg
UQwj8xRTkkGjuE8m5jzGoFEMI7PL48ePDxrFfTp69KiJyaBRDCN4zDIGjeI+
AUNqg0YxjHSCTz311PEuyjnEhN/csWNHNqYeH07Tpk177733jo9IGptY5Z5j
Bp3UbG7mZOjBgwd9TTK7nKzft2+fMr6q1MX+/fuTfiLHyUemLVu2zJ07d+Qy
6kpQX7a8bdu2119/Peflc5EydNiEOintkv9CAfPxpEUYFUY3TZ8+fVQWdVNe
H2MXDpjvm91jwr5qf4ub+GM29+abb8LTCEZN2jJnzpzy8oSi4Zs3b3aRMztJ
a043sDHHXhKZvx0e9Mwzz6hi1GKEkhjyOf6GS8Tnpp/ef/99X99++238yant
AMM0WtQUj8fOnj27vHw0PCyizCoF43hlQYRFfLt27cq7OQWaggk9++yzJRyO
uhJNdnyl0rCIOiV/iq+JrxvJJs1KU2BYNGvWrJKSzJZEoMIHn8THoo/fkyZ1
IikwQMVDIM3EcbKFes+YMYMClJfHnySSgCQxB3DveOVDIinwcpK9Hfn7zJkz
2/2X5pARtoDB9hM3I1rksa21CIs0rdFf8ARDIrVat6NCOXLSDkkIGJBGLkMT
6EMsWttxIHuWXGCLm8pQ5kTMIEf36b+LGELt0gtJJ9ifj/7vFZmN5iU7PvTM
IkvWRc1VgTRzNKBNAJDEw9c090HVTLPaBJT2NeE4ND9hT7744gtTKlMGd0ad
1RbGF6XeqjCpX7NmjQFADhAlwGnKELrOIpFtSIommJvjswHV+vXrkzC68AhY
i/iivLoaL168yCfgfw557avORLt+4YUX3M9Sye3bt5u+aWqxLko6DOHOnTsE
lKw0WJd4zubvuATYwoULFcDGFlFhy/NNkBGtoDkEpEaztrwfxK7FixcnSV/i
HrhIchDK9nNF5ZnNW6yLUrywiERIPEFQAdB/ucYxaN2nM+1YVLguerfKmY4/
SSqdZD1ZWiR0RkSLcvpVL5B4ldlcl4iR5SwqXxe9fv16ehz4YWBE/HmgurNk
yRKugIyIVRngtTQH2BXAw/IF5KbnJpg2hWHddA/HpkyZ8v333589exYkSNSe
ADidSr4tDK3pumjWh3/88UcVRZ8xCiROErac+qRFXC4tulNRIzydVuuixMfz
c4ZGlTConYxYokfNmzePOrVjTqhkXZROnjp1iuPlRdW+YMECRn2z2syGM1mP
xShu2U+QJL8qd518E0FYbv4PPEefvhgAHQcM/cdsS/pByklF2QL1ztZfbpOr
4VG1jvcwUHS9du1amqMJjOLkyZMUgDZmXO3viWYwKrdL+sHEQkmM9MwHtctN
1akl2sUcdJHGY9qO25gAD3jZGQJGUjKNXFGoaT+ogyYI7GIRGd5zF6dPn95W
kZuE4qZnUgZ3uNnyh3da5ZuICLgmvY+ux3CI+hkTqp0cATDRyBYj7peIx+kc
fU5AUw9OmBRUyl3klS7d0EUaLQBDRjog1mp4g1E5tO6z/AR0i3wTfCYWqZSe
kDjmkI7BqlEWtaHhIIEHiSYkkUH58zsNz9F7frLVUKR9987RA0PtWZ+fIMGu
BLfJRjWy21elqCjEU94PMhNmzl6+++479SbbWqcyQ5CynxYG2GjOtWvX8CqD
wOwPfOTn6GvCqGSs03xIuPrzFbF3zhnTaDs1SOQoJZu+j2vRDyaON3UiCAqj
Uj0j3Tav9FN2GJpKJPNFwvI0onbn6IFJ5gsS0d3wBm7SLm6EwtNzsivcLNFD
Jf2ghtNMVVAJbceB41WiDW6wTjEPG0XKRImrzD40HWIdi0DXWRgjor8fZBoU
IGNXnwlD1POvkn6wnj3lM8kC4LxcvavSusQRcrP711Sa3SAu3CkZ/5T0gxln
Js+Xh2fMmVFNbqZYPYRIsKwMmOsCrsdpPqjSsD1sCf8ji7yqzs1gBmO854Od
qrGpPRfhRj8PO5WsWwxTy8/RRxade0P0WiHDq/CnLpOb4U+2HBTiaXGOvmZR
dLgbZPJcR707bVlU3g+qKxXVipT73SoUy4oK1TxsxKLyftAza43tVpXgydeU
CaOiYCkQTSuE1LQfjKSiHt2TGiADIFzKzRaGNsZ9MrXC1PPiHi0qn7zX1KIf
7J5M1brdbX0p0O6oe0k/2K0S0Z9aTHWluZ9rIGuRtTB/neCkSZOODadDFR2t
KBc9BaZOnWpideyRkoqMdtr912jTuG7UYkYOdVtSXU8D87W+Vr6+2c+EkWna
tGlZ5y+k7loAS9XHutjiJ8PX1iwy2J49e3ajv3TDqFlXw8hFU7Z00/Tp081T
SkqqvW57j7xqDIcr6inciMwiZ82a1fRf3ZCOVJQLGGpdak3PPPOMyVQ5DG3v
r7rbluv7kWBTPNu2bTNJKSxc64yLUaUW8E3xoGeffTbv9copXDo23KZqhDWk
dtSIRT0U2aX2WpfGbmgzZszI68WmYGo+1GDqrqE1mGPVG1iQRi1Wuz6f0duw
ogaQr8fuOc+6TAuEOsEFCxZ820XmlStWrHj11VeN1T/99FMd965du74dTsuW
LcuG554/bty40Uz2s88+A2/37t15Benv+/fv9+vrr7/upsGbuYkLk9aE7uQM
syHE35NCJXsMTpw4oRbF/P3s2bNr167lzPvBIPJat25d//1uMjtTBWAXLlxI
AHyQTCQJxSwgISKzT0YXr0wSmF6uTrJ7OJxXrlwZuYpuGhoaMlUvL48VenPT
/7wzXbNmzcmTJz/88ENT7+SZNQ7HnyQCa0F0CQPLy2ts3kpfunTJEBcMUssZ
bbrhDpwu9B3t8KDly5efOnVq1GI5PGuMnXP0kOQg/7eVymEOSVEPTIPn3Llz
eLh69WrtbYqH9LG96b9obCBRMJrMJ+fkOB2D+XKVFq01scRPPvlk1GI54kpD
aJHyFCmRBPz0/vvvb9iwIS/Bma2f3CfK9evXY2ZTPDwG3paU5D1efvllUmDO
FA8elea+azKiyTt37vzrX/+KV6537Njhfna8N6KVK1eylPLyfAt50RZzW1Jj
75SZEBk7MEHlmkY1RRLi8VatWtXoL1cqckF5cq45AuVz3Mw7aIJrhwd5JiY3
+kvEx+9xrZzPCy+8sGfPnvPnz3NrWEemrcEgYEAauQxrigdWe1IgJckFd018
cYPHqxw9iYANmN4heyrIEbsamZ5OsGdd9Nq1ax988AGdpCcK5FVazyzygeui
5IVFMPCfJox4qBVgs2VPYI/aQtCg5v34kiVLkqNk4cKF/qUYe/EETTAM5pFe
fPHF41VCdt4SKl22Z/q1f6WicJ8MRmnad999p9KEruXk/bHeVKDb1TTGzsFy
GuZ0P/74I0igaoIpdn0cbFRqEWebH8trC6KcPHky4fL8YCTjm9lThKIhjLTp
CdYW+2RoHf3/6aefbt++zft5AikApuvRxSd+MhllrRuwcTpH36l0Mm8KGGPi
CeT9UR1VO0m19IM4Q1soLT3JcbDygOTt4otGRoFEo+h2Fs/13b52qjNfLaI7
hgrXRSlD9gvlZTqv/tFHH2X5SIs4EMbFlpkbFfJA/fWUKVN0jgrDVv6uuXxd
lJYmzxr9gYdoeLNOpedmcNqF25jGTLgI+A2o6GciEpw5c+aRnx+sCRjmbAxG
n2fPno1pBg9ZqYu9x/3yEjkiV57HOdTiHL3+JUdxz1X50YgsiWb4HBiuXr1K
l7LbCvcUboSn02pdFB9Ih5c2WKI2pm8J2AVJwo8TEG95szgNRzeVrIveunXL
82Fgv/QTT7Kty3BOV5LVTuwynDOw4ZOj29jIbRIuN451ZFF48LP//SARUIzs
IWEyHtvvzx/YDypmtoVFVIgm68LA4Li4UCaQrO5u5uD8iYr8xU9JJqU5RK8P
0ijeTElGpzBBJOU3m/q2mjf120hJP4ixnqldGsgEVAQnpSJZmLPoDVISVibP
ETwKw2DACQMpKFkYQKBpP4hXSaSlRg13AYP2qhpzonWueRXXGsI6yh/eabVP
BiQcUBGjIIX0dPiPS25SThexLy11f/z6wRyfz1FohkDcMQT1wkBAmIY5WOTC
MxP2J/FeyuNUt+sHa0g///yz6qgxw8n7+rykA69wb1U/le8XxZ9j1RmxZIOq
HRQ/wMQ8BA/xh2FiEYT4BnNGO+X9SHk/CEBM+2YVLizZHDpV/8iI1A5PzD8J
ICg/rU6QMeOHRx5PpiZWD0zO7MfPUG+dEc/AL2Wba/KGMDQ4mwZuatoPkl39
GouwYMNkVZOUAQyvFW+Z+Eg+63RR5dSiH8wYABjswijMIcpouGvMcQ1eiyRQ
nbJ+MBJJaB2+K/PZ/LcONaYAd50gA5SKCwKVPWaUnkBAhcMGnaDpxo2G5F9s
raQkybJBY6qmVTSiZMUa1yqa0qpVqxID4TdCdIZTHTSKYWSAxKgHjeI+MR9d
86BRDKPEFx00ivuU+KKDRjGM1q1bxzkPGsV94ntNEwaNYhjBA9WgUdwn8kqG
2d8O6QT/+Mc/7u+i3bt3v/LKKzldvq8Kn26qvn84Pfnkk5s3b97/EPKv7JSu
46XnUb7WYcDdTJDwnI/uvrmvigCfsPCes3XrVp++Pqw6BPAzzzwzQgHkaTm0
60Kj1Jt8f24md4YyZtyvvvpq6nrnnXfeeOMNFzlH7+vIz++hSZMmJTZsIeWs
+s6dO9Xuj1CBt337djOUt956a1+VgC8vWBvBqEkTpk+fXl5ejeoNZ6BKRuzg
xO2E6M955HZ40FNPPZUjgSMThihmvq+uKIyLyItuRFd9dU1e4OUgbZJ9NMLj
ydOmTWvaCsqJt/6LSxhi0g0kYQGWIP9NH9hNkydP3rhxY0lJiq06nw9jUVTd
05I1QBnIm+JRxdSpU0tKdpvbaxVFdaGiVFEbXMK6JDUgu/icppCefvrp2Omo
pL1J3pEQEDgTFjE0X5POAAZl4oXwqqnVI0+YMmVK03/VhDkMDZIkXnfha63k
7Z4Jj783+gsObNmyJWfK4gCT3xk81629UAiHSW3kMhqeyBjpBZKYJiEF3Kxd
dDyzrxsrUjhK1VRwOsGeddHLly8b8tFbM+Jjx44tXLgwBze6aeRzE6aivIF5
tE88zMuaBLnVItNbaFkrlpp6z5w5M0d6E9ybBzPPjUWbwvhcv369P468OlEY
Z5vmm1+bnAKmfAIJHjp0yPOzDnP16tU1a9aYZZtcK2PC8uuvv+ID5rOdUabW
w6lFPvockdNSc0njE8xJcknSv3jxIkHkPGMjGDW1i7NNFfHNeCm9XlIAz5s3
D39IbWhoSDfd7ixtp3hdNLEWs9MDc3ADH7I2funSpRxNJUqoaNf169fdTBKf
ppu6262LJgEueNSG+F588cUcgktskInJP3jz5k1mkvgGeW8LT1jEnONJsBq2
+fPn4xU95+U42KbwytdFWRYMTDiJ3ZlbVqhoC3ZRpwRizUAIpAxHWwSRLo8v
qhYmwNCSNQyqOs52PAw3EnfKWCBfsmRJfwiRUalFHt4km0hYhpUrVxIWqYFH
pTGEw8QiXrS1LrU7R0+jli1bpgsAIBvAaLVHkV1JbJMRqDAfPV9t2kguDDNh
MUwkly9fzu1kaZSlYwtj/+WXXzgHrhvCCxcu0G0ibgSp//3gjep1f3J/8MOL
Fi3ChJ5/jdwPgpe4UsDT/0wnmZ4LPNQWItbxUWD8nDFjBp3kfxLJ3F/OnDnD
QypAPVTtDr0auU8pfD+YuFIee/LkSbzSvxMxq0xCok7lNFasWMHYtQ4H5s6d
i+E5+4/bTBjUcTpHnzzmwICEP1jx+eef810HDhzAAcDwXBtZmYbQyfHOR5/k
GgSRt6hcK0/FbxiZmDThCU0jNR1lDon7Ok7n6DtVX8M5kBGR5ZB43ucmBAeE
nhP+YEs662+rQLtKjt85+lC0In7Gp/43B+IwKq2jbPurzCYtqLAf5NuNUjT/
4MGD2YxXn6MPi3AjKQxwCTPhTM6aJHooZ1Gj94NZ02BuIBm6pBY1JmKY+2TK
0Z0+fTphEJJ0jDQVvvGoz9Gnl1GduhKnArwb93Zb6X3oMHmZSlDp5JvQC2Ad
BrLB8lADTftBjMrORhVxfdkfmO0Q2VRJ1ZNqQRNyUqD84aF2/SBWaAjZUSoj
c/W6SfpYl9e+yW/SFEynrB9Mqh32mO0iCWjDJQLAb+RdM6dkqpI3vLobPxEu
R42HOVOvE6FdJZD6+0GKCgOPl/O2SXrV869Rz9EngVSONrvAwByPdU336ptJ
aZGS6r1aUQINuaAAyiifU/YjVFfSD+b5OOaxPl3nkD67q41OLfVXkBLkgcFC
GK/iujA6VtN+MKzA7dSYqrn0vKdO1bmJk9jS9Dhti/lgGp5YCjWMsDGHjgHO
TWXKHVdN5f1gTvJ2qkEazxDlDMjUG0XNfSyqNTbKU4inXT+oxgzmO13n/VN1
bgLQbltdp2G+CeIgl7AosWI6XSyK4KK97kSynYYsarRfNOHCYm5R3c49Sak9
90ENo65XlMP1sYJCSOX9YFqdE9lYUedKwAf3aXuwZSd2IIV1xFfOojHmo79R
7RSCEHNSaZBHmjC30KV2+ehVikvEgQ/EFLa4GdUKr5oOfUOFcdVqoXQLTu25
2am2kQOW5BfpUBTIzQiuXLd1gob3Z4fTZxXVF7nuplmzZhnUnX1E9MAqGpHx
0uLFi8srGqGBD7xugRCLsv+znPrhPexmCzI9MbVvh+fsQ1gxRkizZ882i2wK
pqfGRwhsx44dCxcubPqvs6MJbiw05/9l7z6frSqy//H/qd/nn6maqSmdYMBA
zpki3EJFgSHnpGQkg2AABIwD8iOpmEBl1Pt71X6Xzb7n3HvZ5xAu45z14Na+
fTq8e63Va3Xv3b16woR9+/Z1AeMRwTPZnjJlShd4BpVaffR1za6JEydaFzSH
1IJtmPTu8Fh0T548uYuCLQAeHEmhSZMmWZg/IJKHYoVCwIDUKYCS2JJnGLTN
iRNksS/VyIoy9xhaZK1YsWLx4sUnTpy4NJCMhZMnT15qo5ytPnLkyMaNG/M6
yNrWIjovFvxVeRLff//9vRUl/qH8EhXXFg97piLrcUUseFevXr1t2zbVtrcY
4nHmzp071K8hCyLY1Jljcaa1mgDGTCAfmOQB0jpOTv9yHBZQppo5MgPn8PW3
EIvazrdh6N133123bh0+kGBip+eNhImTf8+dOyfFaiWHjrsgXJ0zZ07z/DpO
OrnrWes4Ro6XqlPGOQSd46KsdHd4EL9MuPfNFlno/unTp2ls3tXkJ1qUGM5E
KV0eUA9W8SGxrlM8Cs6ePbvTUqdOndJcrk81asgLKnorcdOmTdGrrsnsroni
aYUTD4vAoDAUKTeyERNIpE98MkAog8wSt2/fTsod4dGvWbNmNckZ62FQn6+u
KsYN7eanXC2dd8iJtx9s8rAPHeG5VIXsVuF9s+lpbnKxpJU/7Xq+9LsWmUv7
NzvTGCI6lrgEneLRysyZMzstFcqHMNL5sAqoS0YUO3fibNmypbs6ETzDGM9B
iQ2kHglYTejUBsfy2g1bBjX+zQkYUrsvgGzxwoqcLcXYRDeFgYDkMfAJK+GO
t27dKp1tz1c2POxItznBlveiuWGBCIyjeDQMaVlFDvVe1Jqdi1TEYAGGf/GX
OU0ECTq2aNGiefPmYYIm5s+fP3bsWKz2k0SyllmKPBzf+eqTKIZTzjFjxphi
8UdDfSlu+F4Ux/TIYpn1zsFevEr8gayjLbH5U0tsUvCAOVbZsIGkSKL6NzxX
2+l70Rs3bmR/GpnStEDFOs6CMbx16xZVfP755xPtFvM7vQGzi/eiuEoiiRLZ
19d3qXpBJxG77t69iyHkkq0geJKTax1BavheVOWkn4AS2qVLZTfF999/b4US
XbW6pHusK6jMLAUjr5s3bzY/aNnde9ENGzbQZ7LTlr9///vfzaYksh5g0Cuy
axh7oZ2an6MPi8wrEuibxuYFGoNgTGXLSrZJczrGGl7lkvqOWNTRe9FcE2ZM
ZQt6PrFpTqf++te/5oMLmwAPFsnw3HPP5ZBarn9tCKn5e1HVYhE8GmVMsCgd
l8IjQ5Xbt3mNq1ev+klKbnmGufkpwk7fi9IQzeWiDTMxy1vFNUdYdOnD379a
4iEkTNOXbbei35e6iy+aKw9YPBIx2HOYmq3OhuEc6u/iCpX+Zu9Fy64YBifR
bLiVBBvBlpyOp+25P5fgcn+9wcIR8N2yqQFXG+p2+/dBymmKaxTnMnTW2N+W
UsP4QdMqkMD+sNo7gWiRzMaj0Sox10jp44GKsNdf3pyg2becnvAruy1RVfoS
78BtDfVRrOF9E2rWnRy6NLuACraEo8xnnWvXrhm8BruOmCWaz3sAJtiy1Y2e
N2Fsp37QbJkV1Ufw4METY+Hy5cu5lpFM2bGcq82Gt05Naxf7ZEBiMYw7I4Jf
ZqMkJlpLvuqyHrlvgnRge0T7ZFRLFmSXjY6UwVw9bZGFIQmSdIwiU9Y1UfuC
Fj/btXco6s4PMmK5sDIRMGIu9IuM4MxZfgOq02pDDf0gbmBCWARPZs4ZLLli
CSp6Ran85CEDzSjAItia79Js7gfjXGiyB9i0m51dBppKGPZ8/wpO6s1LevZA
lAo2/wrW0A/qKfnmopZE6jOlDIswLZuFGKjcjgpzIpsxLGHR+caREDr1gwk2
npDaeJLzYjm6noGfW/+y8SPBNJpXHuru+2CCluSDOwwJXi0lSwn/Wnl1Gs0j
1MQPqpnSasuI1mU8YU4TY4HelrAD1Fh6rg6JbhvvMlNpyGVuGHag3Q82oSb3
TTxOauIHHzN16gcfNXVx38Sjpub7ZB4PdecH6/SApyTaqfk+mcdDzf3gY6NO
48k8anrAfTKFHqIudecHHx018YNN6CGyiBP8y1/+sqtGFnSrVq3KGdhcGG1Z
tGsgPfXUU2Z0u4YgBTdv3pw4sUPlaSGrxVyi3TB/CxkLzz333PB5oMq7Wc/b
t2+35LfehFCiNSAAyZNvK8mc9JwnVaQjSE8//fQwLGqnwuqcrAzPoc2ZaM/+
5lL4jmAUonj3ZVELwRAOaBS2SBNzcrozPAy27uhvf/vbihUrmuTUVj6RQKLR
opDhT66TI69cvJ7j0hB2iof5evbZZzstRdUJOuMFu9I0DEVwD0J///vfTfDu
m02v9R2MXKqORVDlpzqLEgb/QVjECT7zzDNNckZStEVz0Znoz6DmReaEh+10
lKF//OMfJnhNchJHNCTtlqEEXo5LhEWRmme8yoGpjshU6p///GenpQoBk3gR
kARSi0C7ICyCqqMikVrhUkIf7KrUqQtj2ELAgDR8nroFzjOpxT4Xc50QFpER
LYqN6k63OcGW9aDFpuUeHch9tVxM+9Jy+PXg999/r6fvv//+nj17cr0m7uUM
GnhWu5arOcYrT849HThwIF9F9+3bp7mEo/Fr3o5a/A5/4WOT9eDPP/+sicRN
NZy1e+3aNcv8vr6+RYsW5ftgvhVaUyd6Ht9hxW1CDq1F932mFAOp0/VgPqMQ
5Y8//ohpBJrPWxhCrLq/YMECbCyx9TqlLr4Pnj17lhRyeoUaAOOBjHDpvffe
u3XrFjxY2h2e/sbrwZ9++om2a1fmvG3L6f7+6kJqnbJoMgmnsQaIPDdu3KAM
XZxs6m49aLwcOnRI6wR38eJFukSvjh07pqqFCxd2cedgnRquB8mIfHU/p57p
DI3NtxtKlej3OZhMLQkuLOriEtXm60HWA1voM0OBOVQlUccHNS/EarCD1DAq
cp2afx8EnrfFljt37tCoUorO4BI7g41MYl710yjiS2zwjqiL96LlqlO8Iilg
Esdj9uzZMB88eBASgLsOWNHFepBEKDCbk1C9RAYGvkl5kGgeoYbfBykM4VJX
1mbmzJmYwxQYWeW4N0OUEEAQzps3b/fu3dJzdUKnCAe9j54dxoRYzhycbCk1
vB9kqwmOOpEdvnE0Rp9BwURwgrkvW1+kQ+5hzpw5mtPlxYsX6wItmjJlSgIX
cFtz586FZPjjck38IB4affQci3IXhm6Ssr7gYU7HMLY50f/dd9/lsg82Lac1
z507l++DNPM+PK2oUz/IfGERVJAAhglcM0+EOQere1hoQi6meWzfB8+cOROz
CRIOAIMtuSAAwqtXrxIfjuXLy6P7PogPGtV3fNBrf3Ep24QMKJXAoHe5EIpx
Y+TJVwpghlLzj19dnx/MpvQEqKdOicOgqtwR4KcuzGmo+XvRhIghIIo6f/58
GpIhk0tzjI7bVWxt8LIrA4vy8Qu25h+/mvtB7iC7lTRHNLAlNstQ5gWYXdU9
AjoSg9YQUnM/SL7skr6rXCkw4lkSaoAq4lgW9TKYmY8dO9aM61F/H8QQTeOS
voM0derUTMtNZiZNmuQn3GAY6XxClD+e74NsOLWBxLi2BIDEQKNd4OW+CQOQ
vB7d98FigbMMeeaZZyCBKpejZTnAUGcTJsmaM+QcPT9It6UQnCINtwe0+0Hc
NooZXnIhI+u49it+hveD5jZKkWAOosoJHitBA5OYUPOawEZ/pbNv8uiydBz2
r5xYwQhT8gQPH6YXDeOqqTz6pkLPuVpdiuZSP7Tpb7Y6SMeN3JsTDI9uv2hY
rRXwMAQrYOAcc3VI7jaCJKHpH89+UesFzL9TkYdEaPFX65hJFQGOQvr76PaL
9ldGPneOFC6lLf8CQ4j4E0VKFIKiM49hv2h21uWi8Kh6DrMXGQHQxR6/UHM/
mB0m/VXsnaIz/TUWIQr5gCxq7gepBBjhBkjRmf6hzYu/8X3B+Sj2i8aYZHRr
N6zor/wgVc8RftjiEDPiII/ON2fRA34fhIREICHBCAhbMKQIt4tVfHf7RROj
LOfQv6wuSQwrgEnYkzx0Cqa/mR8sFpggIhfaYkAlMcMfZ8gxYQfiAXPqv67b
DV+gcYIt5web0FDnB0eKmpwffMzU6fnBR02dnh98DNTw/OBjo+7ODz5Sanh+
8LFR8/ODj40anh98bPQg5wcfEXVxfvCRUpPzg4+ZOMEXXnjhw4F0tiIP586d
y51lLRnGjh3L9Xz4CEhbuUmqI3rzzTcZ1ZZ62mGXxPSrnp6Hkjho8ZbMpZK8
OmjJj7H79+9vAr4OpqWS+r91iTSptoXeeustrrlh5nr36xjq6QXGoBrShMaP
H5/zNcMjqXd80EYHRTuMBIciLDLBa5i5rkstYmofO12zaMKECXv37r0vkna2
tGt4Pb1rVDt37pw8efJ9s7VIZ9DEOtRBOdmQJk6cuGfPnvtma4fRwqIWwdVx
doRn165dkyZN6qhIHUMRTTuA7gY+gmf37t1NcrYM8Hb70/LcHSRgSK296aHA
tCjGA5prKzjTuZb8nGDLe1Eryk2bNpkbW5l+9NFH/F17dPGOzk3cvXs3h5vU
Yxlr0frJJ58kOP+7776bd0qW2JyynNeuXdu+fXunu0Fa3otaJp8+fbolerA6
YWBVLO39mrEjZ0IQ5F4Jv+KPDIl1kxV3AqLmHZdFN1OARRIPVreTWHovW7ZM
bS07Ihq+F7V413FjJ5tAPJR3aABv27ZNu9riUk+dOpX3OYRIoB3xp7+T96Ja
zGmd/upA5ebNm/PCKh9KcugsDPTsp5zuaX95fl+673tRQnnnnXfw5OLFi9l8
kpNl1EmLYVTEKk+CWOLY9evXcwaNBDu6TLz5e1EsIvpc9ZtrQfKGjWJs3LiR
gEgKZnkMunzWScTp5mBC930vikWEovtgGJK5twWLLLQl5ls2JoRFxppsOTqX
z4WeO0LV5L1ovuxgQj5wbNmyhVxyyhJlHGG14WNdIEMZazdu3PDQaaDa+74X
zf6TjFAcyHnhn3/+2VAy8HMLhkaxcceOHfB89tlnb7/9dm7GBLKjS4H7u30v
SkkwTXN4BW3ipec2ZwaHaTpfBbUjuC4OCzR8LxpbRIWAwRYPtChmjWJTFRY1
X05zWpapxFV86xRS+3tRQylb8kqKvjMsmNBf7a2iGIniy47hA1RhCCQ4Ro5U
K2FpY65jsiiVnxJknkJmW0VuRmt5o9v+fTDfqcM6nd26dSt/0dKRjvyg3lHU
+fPnEzQzBUa23EO+cOFC+obnvMZLL72Ez9nMqemOeNviB5Wl7evWrWMl8ETr
/urXypUrn332WUaJnpvWJg4JYC+//LJfsdG6UuvGI3v4zDPP0Ao1cDqg5hQw
7i1evNgoJg55skPvYkUtXzQa+sFsCtUoGQEJEvmW+Mxz5swBBmDMwTf6oF2j
TO/kAan5tqjmfpC8sI6C4Yk+Pv300wkdoEXjQpdloFQW4PmgTxvVnGPRWN38
y859/aAKcdsy1sQshoJmEpNVUsLL9FfqSqyJvLF+/fpc/cZcT6qIatHhyPG+
eJr7QWC0lY0WPEui7gTMruqICgU29LgA0szJ8byUDouax0i/rx+kkFiRO7kw
xwD3L67SahpuhZvT2atWrcKiXOlrYmO8mLf4dcWKFR6Abyi4Jn5Qczq+du1a
ik00//znP42gEgkksxewGQHjnUrnLIZusvZUgseE2d+GIVyafB80iOhqwnoT
HHi67DnRrnJUnEGjxtIpkjph8zB69GjDLZeYNGRRcz+Ysc9KUGkP48aN0/1E
L8yNPFkgsM8mfmBPmTJFBolGPUjNLWTz74OaM+KoBOngTK496q/m/1xe9tIb
YviGXcbj7NmzZ82aRZ/JsfmHyxY/qCCG//Wvf83lGn7N7lkmaM2aNforXdOa
AI/LYK6xC0NmzpyZAH3jx4+n7QZ77r6BPO6pWFR5sNQYMWYpv160jMFB48lw
xKZMpENdS+yOOnV6jl5VRqhhSCGZUJaKtkjkjxIrMjeCAaynhicAHW04b/GD
+mjilLklCarcg77QMRqVD/GsKP57VpZ3NnNIHDksovNGgdnOLxXhf9lLQCt0
xE/yYFFCKwwKqaEfBFVt6klUBEyAMAwnfdrIOJOI+SEJ4phGJWYzpD56aMii
5n4wgUcoOaPNHDEamQOAyumHq6QPD4QEyq4mBAcWJRRGQ0hN1oOJ0EI0uQ9R
EznQQYVSlp5kE12uDiEdEgyjIISKyHSnyQf95n6wzqLMSzMhISn6nBtq/ARV
doPgWxKJGIua73Fqsh6kP9nGnC3HGtU0Bc5Xs/6KRYlDQoIJlJRtRQRHrxL5
rSGLmvjBzO2NLzUbO9QVDEygrixAFs5ZxiaUShlrlMpElMnKLtaGG7ObrAcB
sNYzxBK1EpLEidL9ooGXKwIj9xRTuUSoSyiesKiJbjf3g4DhuTqzySoRmA2o
rBeIzE/UiXGg2AmLilHZ+JrVYpNW+jtZDwJPBNlRnHDQsUWXqqiwsXvwRJnl
IeV4ZEJsvjG7xQ/qe3QGk/E8LwdibSxANERwUJEydul7jo9hCBjGvsEOGyRy
ZpOhgRD3XSwq2Pl6NdRrK05w3rx5vw4ktQ36XMg8AfL29IbUXuegrTQnImDk
m7c7VHP3zTBU/nYyVTCsmlTSsLkHZBETlDtzHwo9IJiQmafx1V2j91XRLsiM
iJF/wEoeLkhTBcP/4bb+IOzK64guCmZK2ZLy4HiQqUJcZ3eoBn0eKk8TYp8Z
+QfH057YNaNMFaB6QDDtvGqXaUPibUHqouAD0jBoOcG//OUvu2tkLrRq1arV
q1ebWm/dujXBKHYPpKefflr67ieGzCVYjJFGMYD4QSupkUZxj3osui9hkVX8
w63TILIAsRhJ1IuGpXZV8Vh2VwfHFG/51U+JTVGvsBR5pKTdh86iB6RBWTSC
1GPRfQkYkEYaxQAaNJ4MkAn4QKYLFy40hFtWkU9afNEe9ejJpDt37hj1a9eu
PXz48MmTJ9etW5fb4U+cOLFy5UrLq3PnzvG/b7/99rfffnv37t2caT1z5sz8
+fMvXLhw7dq1nRW9++67eYeWl5yK5F3re++9Z8r6wQcf5JD46dOnb926ldBS
R44c6e6a1B716H+NBo0nY5AuX77cyDJsLWA3bNjQUqrnB3vUoyaUr5lTpky5
evXqsmXLLMkNKG5r6dKlc+fOXbFixTvvvMPl5cvUV199deXKFY5M5r6+vnwb
euONN8xXOc3sqfBXem5d3F3tZzNrXbRokemr56NHj6p82rRpMhi2DxjVrUc9
+h+hQePJJDRHPvF7bt8K0vODPepRE8rljImSZG2YkZXYSrn26+uvv86OwXqp
X6udhDIrEvdXH4MJx6QGbi6BmDwnbIvn7HtRuQXmQ7//okc9+kMSJ/jnP/95
Z4f01FNP5d7kJ4SsW82fR6p1M/MdO3a0JJrkJ9j+E0Ijy6JBKTF7RxrFPVq/
fr2F1UijGEA9Ft2XFi5cmAsInhDCIpBGGsUAetJYBMxIsejNitrTOcGW9eDP
P//82WefJcSfGebnn3/efhi50/WgOeqlS5e+/PJLdSaOaI46aihRK/NGqOvX
OO3nB82lW86zZHduWvGTfn3//fdJzP3X169f//TTT7P5NqcYSm3lL+Zk+64Z
uzyXL1/2nM3q3Z0f7K+2tafOxC8t5+hzg3YOh+YuY2gTtrGLWyc6Oj9YovZh
Y0699Vd9l55Lir/55pucfJEnIQebn4krdN9zE1EMADSESx5yPJaMgjDZaFe2
hRNB8vxaxRtsfod4qKPzgwUAtmg93S+K58EaDYv8m+gH4VtHePobnJvQUzqj
IRqScIv+zSsd3ckQ8O+VinJ1SPbo4meGQ0ffEJucm0h/AdAcVGGURO1K/LXa
7U9/6HzOIlHmqAH8HjoN3dw8vigwctKWBA0u8UU96Fe+zwKQgRbxdRSHIdR1
fNEE0U3wgeABQ20SE84XA7u76KH5+UGtUIlfq9PomiuRPKUnxnLkCF6u5c1r
h07xDBVfNB6hnpJb7xPxFaTYw/7qIF6iWECotjij3wZSXo94UFC1X1VkzTLo
nSbt70UpQGL4a2Lr1q1c3uLFi1tKdeoHMXDPnj1mtjCvWrUqR3h44X379uXS
nIkTJ5pHRcrY2+n7nPZ4MkePHuX3y7/91f4fQ2by5Mm5Ud1MW5Ecvl69ejXJ
btu2jXSOHDmSsPNq6K9sCHgXLlzAlv4qkIhK9N2A0pFcDrVp06a9e/e2HL9q
6AdpOCaMHz9eK3pBFvCk+3zrtGnTDh48yKBNmDCBLPBHi+XioY4Y1dwP6ggM
uV1CH6dOnfr222/3/z5BohtYQT14/9zvgKVQZTj82snVMPf1g1rkmGbOnEkc
nokppztxiaRKsJQ1a9ZgoAxkR5Fy6AlX9+/fn3oaomruB7VlTnvmzBlmgRqP
GTMmg0tDMFC8OEQPxJf7mDA/M5yOWNTED9JG+nzy5MlTp07NmDHDTJtFlbhu
3bqEVMpt77hNf+D0kNDNeIhdOYLaEFUTP8jrGTsGVywJSFSF4HgHjAoTMCej
JofZZ8+ejZOKWGyCmoPtDXW7oR8kBVo9d+5cunrgwAGoErnCTySoEkouzzvv
vIMtGCUReB3pCEx/h+cHCcLMJDHSZ82ahQPksnv3bniApNt9fX3GmsTt27cb
CDIETEda1Pz8IE6SL1mw2KRDycvtXSBNnz4dYMqsQhnefffdGKhOWTSoH6Q2
RPPyyy9nSpkOGpJGN03O3Tfo/Pnz3Bk+zJkzh7zoGHYxif2Vs4aNFZWeQE8s
BhEz7ECSJlVX26BXh7T7Qd7TmFKDAUimALdfvdepH+T15s2bR7JgQ8KMg3Ti
xAm2XUMZLzGqicKRg9vNqcUP5jAsy6MvFIz+51wzzWdY+Hf5iRUAdhiTWXst
4iHjCZKcMHDWHggFP42OGDq1mRUwODArpSOmu/K0r2Qb+kFNYC83p06owFMw
tTFimAa8evBHc7nqCDZ+QaP6yOY3ZFFzP4hp2qL51IngyLpM0qglc4G9RiXt
YisyuzBU6QObRpObr3qa+EHWUuV6apjAH2OVO1uPHz+eSwSAeeGFF7QuxcAk
ZQX5oNwJSFJQNTkB3dwPYhG9NfoMPdhGjx6d611wRutUERM0TVI5t2vo5VY7
QxiY5qHDmtw3wVqShTopAxbhjEbDlhzY12jsf1Zh8+fPz0CLcct1hH5tcrq/
iR+kLZrDfxIxuEAy0ICEJwFb+ivXYyLKkNIfxpb+w7Zjx47cy5xpTMPggQ39
ILt67tw5KodLtBoSgze6Su6khgPGF+uaQHDGi7GmF8Cwognw1YQ6iicT5ifc
x4qK9BqTKVWuf2J5qDEThCEwM0pK6UKGYUNIzf1gLtA0lvWX8SlTBSm0OuGJ
sPHYsWNaZ6AI2ggFyVQHVxviGdQPUgBa8dxzz5mEYIvu4wmJGGi0iIhzXbKO
J3YHnZGNGQSg3HoDA+YY7CCBx5ay9gwsq46N+pJXee2Q2v2gbCpkdnSZ0uah
pVSnflA9upmqMgXKFEJDmW+UxCxjO93v3f5eVFuGXg5O5hUf0kTEqjmtlOZi
l/K6L1eufF9RJjkqyd/+avkGc8k/TGzG5u9FVV6AJZpoYbjnzG00lHTw9CtT
Jj81v/ekuR/UU02EaXmjVX4CMk3nDa2/YWAkq2Ad/H2pyb1LOpj+puNpSKLW
i5LkpwhLhqg6lkYBmqNq7gcLi6LGecHe36Z4xbPknpr+anB1xKImflCdkVGQ
pNHc7poMsFHscEzORMDLDTXRuuYsauIHs7qJRDSUDw2RURFZog/FDcGQsRal
KiO04VeS5u9Fc4NYRAZMUexYp+h2kMMpZzS8v8OB1vV7Ua2EaQVPcEbNwsDw
BJiOrl1r/l5UtbHJdYudFmOf+2vKnLEfJB2xaKj3ohlWsdVqzoiOffYQ21vs
T7HPhRVlpRzDHgkWNg4PjxMcNWrU2Q5pzJgxmbA9IWSqOXXq1JFGMYDGjh1r
vj3SKO6RyfaUKVNGGsUAGjdunCXVSKO4Ryb/kydPHmkUAwiLrEpGGsU9siKY
NGnSSKMYQOPHj7eEHGkU98iiZuLEiSONYgBZOkE10ijuETAgjTSKAcQJUqQv
BtLly5fNjU1E830/l+rWidOxYP+iMaUeFXo2ecvHX5TE/FoydEEHDx7k0Osp
mjDraMn2eUXBU35NZ9NH2ILB35LY0hE1J10NeT516tTJkydbMk+bNk1iQ/yq
SnEVFibkYg5/68iT2AWjDh06NG/evE7xhDnB8EWNq/lWXvK0s7oJTZ8+Pa+m
h6G8nG9njtaDKsoTjaqra+FYczp8+PDcuXMbZi4squvzF79rSDIUSXUBJjRj
xozjx48Pn6cuC00XYRUWfVGTUclc51tzOnLkyJw5c+6brd50GJUBVXC26Ha4
NJS1GZ5mzpx57Nix4fOov/C/sEhK3eYMqttdCO7o0aOzZ8/uqEiojLU6H+ra
FYPTRc2zZs2CqknOwqi6xf5ioGgKo6JUncoLkRdI9ZRBbci/K/pi4FAqvikq
FOMwjCa3j9PTp08bUy2wOcH274Nr1qwxxUowYb472yTq1Ol70evXr6eqxI7e
unUrVB988MGOiizAedXVq1d3fSax5b2olfK7776rwvr2Kk1rd9u2bdmwumHD
hpy0WrVqlbXtTz/9JPPy5csvXLgg54oVK1jFvAGQbn1d9inJn2NfqU1Vr776
ql50t08m36bz1fL9999fu3btunXrUhV2LVu27OLFiwl2jW/YKBHI5uG1CzV/
L5oQKHQMT7ZVlI2X+VyIqznojYGk9p///IcvA7uju2lC930vqnL9JVkzig8/
/FArNJMIKOfGjRvzxfbatWvqkS13rJAOdZUINgHhanM8zd+L5it2op3TvZUr
V+btJW05c+aM0eEBD6UneH7hW3Mwofu+F8Ui3MAiUqC6GVDUtc4iYAwHVf1a
BQjFGf/mo7P1eEdv2Jq8FzWcWV3d//7773Vfu7ljXSLp5JsCkFFjqm6Nma1N
Rpx0fzvaBNIkzrYMhlUuwwqLjF/qRCg0ub8SqNks7crRy/Xr1xNZ7stAZQt3
E+rovWh5jwcbdTXGAaDt7A+QMcWe6Rg8uOehOZJCzb8PGgLUhlBu3LiReON5
E5s7qvLl3ajHE8NQHlztQqtb3ovigNFt1NTfhGfLmbFMw7GChmefPIbk8jWq
uHfvXj/luiKJ+SxIst9V1F9tLCdlIqaTMQg0gcIYvC32qv37oAFi0Up7s5mE
Wra/y+3UD+q4QQe2h1xXRNaAcUCLFi0yEjW6adMmTMaK99577wHvH8QlAtKQ
eqLheh1HgC3nzp1jJ/v6+vxlOqxtsRGvcOnFF180NCyTJ0+enPtWSMEgxeSM
F/XoO6kRivq14lf6wOC0DN6GfpCq0/Onn36aHSMjjWZTlp/gpHt+ZVqhonu6
qWmDBa/YDeCH9yN1au4HiYCykTs7YFVLE7JJAFTcyxVLukyXmAtW2hpq1KhR
OEDrsLr5Z4Im9y7RQPqpLcwkYnLREBZJt8LNpUIHDx7ENxJhK8wz8Qrr/MU6
vTYipDf52NTcD6oNKwDIWRJgGIf+ar5HPf7v//6P5TSrSSDQmN8FCxaQb+6e
aM6iJvcuGZ5YxO8wU1pU5ItqIQlV9vJR3YULF/75z39mIkzFo8DMF/zK5hR/
QxY18YO5kRMeD0T21FNP6bJ0WsS0ZpgYYjw1w06Nc6SLdtFwA01ibpdr+Hm9
yfdBHJg/fz6hAGD4YJEUXabAUvIRKgpDnQgReIJT7ayKPNDthizqaJ8MC5Pz
I6YKZaxlNzvDmN3I48aNYy2xdPHixQyOUuRbbu5oQs39IGXWLj3J5Lxcq0ph
GEzKAxKzQ98S+AgkKqEg09TkK22oxQ/mWqU//elPfIr6DaUcyrBqIxHPtCWL
DsM5l0/BqVGi1C603CWef1Edf5OZ2YzyxIAYibBhIHFTxUSoaOFeux9UleZ0
PHvtGOH26VCnfhBsomRncnGGyiE0+s5WF5P1V1va0krCJ3Z6bKfFD9JqPIQ8
n3Gzg4hH+6iizHbCEM80imTzldxDjvIZhnLmG2t2DWVLjOFAUXOFnAy5XW5Q
SM3Xg7lYVvdVDkw59mioYhSRBU8mzxI9w5/JW3MpdHQPL9al+3rKp0QcOICr
pJODPB4wMOcHaVq2VOlI80OgTc4PyqC/mlA5SDnQlNbLKjWbpROkxTN+Rqy6
nD0YUDU53tjRPbxhkQd2gJiyLzR+OQMZSOkAByGCMLs6H6If1CI1S0NYRFi5
Ji8syvsQeVhaCo8zYLPnCTsDf5SqOYua+MFs3DWU9DfXPEWlQSobZektzDyO
1nMheEZllCp2NTPP+1KT9WAZ74VFOY5KtXJcUToj76ei23qRCUxUq7lud7Qe
zJ6QrAp5h4w1TWNIbqvJ2zyiwUOyy3j3l64+9PsHc9iHemgLE8zMtZItMfSE
VudG2thG8jIAZQYmFzY1n5O3+MHEXCKg3I5HYbKPS6N4nlveNEp8+C/Rc5Z+
Gs2OJsoGajHX2X/bX4nVqkq2FIzfGRQSJ2gecqtDmjNnTqaUTwiRkZnJSKMY
QFZJtHqkUdwjamb2MtIoBtC8efPizp4QMqhz8eiTQ4Yn6zfSKO6RSaD1wkij
GEAWeqzlSKO4Rwyv1fdIoxhAVpecy0ijuEfAgDTSKAYQJ/iPf/zjeIf0/PPP
W6V2WurR0dq1a8eNGzdSrR86dGjfvn25+LXQqFGjrOVHClI7rVu3buzYsSON
YgC98MILW7ZsGWkU92j9+vVjxowZaRQD6MUXX9y8efNIo7hHGzZsGD169Eij
GEBYtGnTppFGcY9yGHykUQygl1566YliETAgjVTrg5prTrD9vahl79nqNuRb
1Ufb9hcmXcSTMWfLGwY1m3hbt1r+W8fl5ZIZgnnUUJcF35fa48lcvHixJUSP
5fN7FWnl008/1fSVK1csyXUEHkXy7ihRvMx7szzPuZUcbkolGJJDanokm8w0
P1Fo6s01fy969epVYHAjx2bLO2E4CSvfTK2+rf09X7t2TRcuX77cKYs6iiej
ibym/vbbb48ePVqOp8Hw+eefwxwGgpHvBXkv2imk+74X1eInn3xCOjiZt6+5
Al6pzG/7fxerPD9WRKWl3759W6I8HYUy6yieTFiUu87Pnz+fzw0UgybQcCLD
KOrkJ4qB+VSlCxY1iSdTWHSrWtJqMa+FPSceRWFRAkzhoV/zgiufDJrjafJe
VCvnKspLaTqccBY4YG2bYaJT8OQy8TLWvv76a4mdbrhq8n0wl3TkfKJGaWxC
z+VlaX/FIlKj6nDipMxGJfxyhp/N8XR3fjDvRYkDx0DK2zzaFS2SmI2O+RjX
aeUdvRcli1x9ol3dz3vRfEHOG9rzFeXLOF0Kzo7wtJ8fJPrDhw/Xj41nTxfd
zq8kEsWI1BIqECR5aFdUKIdDY67LcWyZc+4yXwRwkhc+ePBgi7lu/z6I4Sbq
bKYW1bBo0aL20+Jd+ME333zTElK/OCwP2VGm7wsXLsSWSZMmTZkyxfDMofJO
g1W2n6MnIK30/x4WIJ+xdErX6NjOnTtnzpyZHQX6MnnyZI3ipyIrV66USJOf
e+65fAckdGM5W+/w07iTQUdWrFihCxrSC+a35dtBcz9Iygnaoy0Ii/umafPn
zweeSTHpXbNmDeVMvCzGtr8yOM2NRkfn6Hn2DMnVq1fjQzoC6okTJ7Zv346Z
u3btmjt3LngA6LuaGZByDLYhpCbxZOSZOnWqZWN2qybWB23B3sTSiVifeeYZ
doz4rFaAxMPJFX1RRSaE6qGfozeaDL2E4CCaaCwBkQ7lSXxavKIeMifESoJ5
dsSiJvtk5MEiqrinIv9qyLAyoIgpQWzConwO27p1qyGAn4l+lvP1DVnU0A++
/fbbNEe7lthGnOGpIN6adSc+IdWCjRrXxxorofJ8TGwJ4DAMNfSDiSans7ur
q3IzyddcNsPHrqoq8VdXrVqVOYyVXfaLNmdRR3HViAM2HNPE+PHjATBOE95n
7969CZPLPpsGSyHlXOOeD81Nmgg1P0fPvABPN5jrAwcO5GNTfzVPIC/sIspR
o0YRbuK0sAAzZsxg+sqB+ibU4gcxgR7+85//9FDMNeYY77S6v/KDmk5UQAPf
8IcKQzTNPZH+hAkTMCf7ZPhu5jofl4tF1aIm8vbpSEUtc5t2P5g94VRFo5rQ
rppbOtKpH2QNAKZyeorD6lc5lhqSxC1RfxNOTeus2QPGVdP9/fv3U2ZarXIc
S1w1gnvrrbc8s3haxB/PrAFsslF72LCITOlANuKqKp+q8/meupIIZiaYVWJ+
DgqpeXxRI049mKwqvSjzIkygh/k8pAua0zr8amaBqQp+Poq4arrGmOt+NhVQ
j7hmrNi3b58hkP3wNIRx00fKkNBG4Hl4iHHVtKiPFMN8T385uGz0AkNDjEN/
5Qiy357U4OEFSAeSaBSWsiqxe/fF09wPhkUsapbwSmWalPUgMAAwC3AmHo75
JzCJ9AvMQ4yrVmcRRc2AAsNfDZkbJPxOUGUvE92mdSbzfX19ifxGt2V+WHHV
sHHBggUU1Zii1QYXSWECdmm6xAPxb+y5oZqxFvMoMxFLpHtNWNRkn0wiFgJv
NMETFuEYdkWL+qsBgl2ZBIKh9WKXaFFzFnXkB3U/oU50n6PRhOL6bkwx5poj
OBiyGMxCBnP0wsNDj6uW8wvhJ15hThS4vzKwBJrbovHHT9lLgzmK6Igx2Dz0
XIsfzFbG2bNnG0TkYu6UEFL4wNrkZgH56RJdNbpJ0PjCkCCM2WEeiSmR9uVX
VZYYsagqpP/QDnWQqt0Phoaf+Tzg/YOl8norXaz3C7X4waEaHbTd+wLrjjqK
q3bf5h4cT3M/2IQeHE9/s7hqQ7X1sDSnTs394DA0qDS7Rtgkrlp/gwH1sFjU
xA8OSsMo+QNiaxhXreumO4XXdVy1Qdt6KEJsvh4cBky7jjUxXIPSUHHVOqVO
zfUw2TjBp59++lAbcf0Hf6f2X5955hmzgvb0kSLzASv0kUYxgExvtm/fPtIo
7pFZ5ZPGojlz5owgiyg2JS8P/mKR4ZDEJsUzNIYaI81hDPMrFpnoDlOweesP
iDNkRo1FdQAjTnPnzh2KRSNCWDRv3ryRRjGAsMjSaaRR3CNgQBppFAOIE5w5
c+btGn3zzTcWm7kSxZp3586dFry3B5KxYPJ8u0c9euLpu+++O3LkyLFjx/y9
efPm+fPnz50799VXX1HgdevWXb9+3TN3HCW/evUqoypbzrLlcFAOuymVo0m3
q7ji/t21a5cUixGDhVPQUH7N13ALcBkuX74sZ4IUqUSdarOqOnz4sIKaXrFi
xQcffADG119/ffHixbSYer7//vuTJ0/u2bMnd28FT76S5MYEVZ04cULX5Mxr
vezyUr9G/U149jBBJe+9957Rnb5cu3atsAhIQ/79999PLEG/WtTkSwFsiXyo
8sT1er8izxs2bMjODZB0ULW51vNCRYo/Phn3qEcPRpxgy3tROv/CCy9Yt9L/
jz76yBo/sTLq9IDvRXvUo8dGv/7665IlS+i5FfqOHTtWr169uSI+YunSpfm2
zkdwNx54wIULF/KG3MqCBQuYel7mtdde49dGjx5dtm+VaHgq4VDWrFmTm7Dy
6507d2RetmxZ4jKZ/f7rX//iExctWuQ58eiA4WJ+/PHH8ePHc6O5W8c6wmAs
I0srcJo5W2KcOnUqd9MfPXpUdxQZNWqUobp///4EYuJPPeRKTf169dVX165d
W14E3b17VyWcHfekCZNbmMuvfJlhzkuqeezYsa+88gp4Bw4c8JBrHCdOnAg8
zuCe4lOnTtWLadOm+bt48WI9lQHOrKz7+vqGObDcox49gdT+fTAbD4wC0zxD
wPDJ3Wp16vnBHv23UHaSsMzHjx+30tlfUWI7Z+ckPc+2KEs2653sOfmiikzO
VeX8BVM/Z86cUmfCiirOCcqTcJTFD1p8cTScKd/Hfx2oSHP+GkrZLaZyeKw6
OVAulbvxNzdT3/o9YCO/LA9gClqa8TJnzpyBTVv8YG61ztavK1eu8Nc8qa6B
5C9HlstJQxaMiuzevTtLP+u+7JbJr4qYIahfhRaYfsqWJDkByKpTnScryna7
3HOtCenmDHGXYHDxetHpPrce9Whkaah9MsNTzw/26H+HclQqAbj+K+jbb7/l
x7s4rtijHv1vEif45z//eWeH9NRTT61YsaLTUo+O1q1b19fXN1Ktm5CbTrck
zp8/34x9RPAMSli0aNGikUYxgJ40FlnWPWksyrvZkUZxj7Bo4cKFI41iAPVY
dF+C54liETAjyKJBzTUn2LIezMFb88m7d+/+8MMP//73v9tvf+h0PXj79u1L
ly7lOKqCiXN7586dzz77TGLm29l40503bzk3kVZyhrqeeOXKlSQmPkMuDQdA
eq5WByPXHN+4cePq1avl2uXyF9QE4pZHKZ3ynB0ILcd5mp+bSOwR9YTbOajY
X11e8Omnn+YoDWABKTHHHjtlUfNzE2kuwRMsgsrKos5VAEAtl5tI7OiunFCT
ONtUMXs/aIsHcsmt6wXhTz/9hEuAJQgGTiYOg5pzbr05nubnJgqLCsKy+IpW
J0yQB3lyrUCLNjakJnG2A8AghUH3c/VJnUX91QBMIKBcJZBr6/GtPfD+8NTk
3ASJaDo113U79/qFCdHtXFWfmAP91TI2d+s0x9Pf7NwE/UnYathk1npCkXsu
un2lorpuA5/E5qHj+x/g3EQZa5qOtQSYYsfIQA7JUKeVh6fm5yYwXyu5Dl67
xRaBlEAHOdqfkZUh2RFzQu3nJvS6JS6NZ2IKALqUoRRtj0Qy2IlVWSMXqmhy
u7nO7RXF7xw+fPjUqVMtlqH9vajWJ06cuHbtWjwnmjVr1rz55pstHekinsye
PXvyRWPVqlX57r+z+hpipGtFR1jpHEZOMIHmlfe3+cFE0eGJEhwsXTbuVq9e
bSpy/vx5TDOcCRd7J02aJDH3qkydOhWXLl68OGHChG3btuG8cSHPhQsXEgcD
S427sFRH9Oj999/ftGnT3r17u7t/EFRMGD9+vFaOHz+u8ilTptz+/Y422nLo
0KEPP/zQJJMg+DKy4D7kLDeXNWRRR/cuae7s2bPkMnPmTKXSER0MV2kggWIm
CXrA+Xnz5sUndmRUm8ST4ZhgMIXLLo7JkycnwgbOEGh/dSsHbcQcQ2bz5s1W
B4qQVziWPA1RdXTvEp3BjVz30NfXl0PfFCbhJemJDNljRv2oHGD5atYRi+7r
ByEhICyiGOZjO6s7K+mntTZ2JSxVbmEbN25cjs9jy/Hqbl98k573vQ1RNfGD
mJBINQyIUa9dXYDBSJEYv2NwkeCRI0cwh3DlJ2sik9/fhMZqqNsN712Sjd02
mjQXFlFgGIimv9I08Oj21xXlBqgvqkt+UfS/IYu6O0dvHJWxBuHs2bOJHtP8
nT59Otjr1q0j05MnT+bUXkda1DyuGklhToLtsGl0OGaN9du6dSsdYw+ZI+Od
aZVH5hjGjmxRix/EBB7BqMm0raw+aCk90aKm8SFBL1kArEjUjv3794MkkSYn
MbGbDP+MNR2BMJf5MtcMda612rVr133vH9Q7OkNjFecRtm/fbnC1dKRTP8jF
YN2BAwcwLVfNGqEnTpzQwcSk8u/bb7+dS4gSWKZ55f1tfvBWFYVeQx4McyOL
RqmT5nvOjeFsF3HQOkobabK0c+fOxSsZsD337cKGCaxZfLTaFi9eTCLyy6AJ
meVpnxQ19IOJcsPtJtQhzgCQ2nQq+5Q0AbmfDGeJuyoicfx8FPFkqKWuGQW4
t6IiBr+/im5EVXLzJp5Q0d27dydyC9+NIZ4NnIcYT8YYxA0AsmvLM4YTJXgs
Ff1JFL5jx47RItzOjZlshWrXVkToiVL1cOPJ3K6uq0vIHfYTHtOG/mo6TTTP
PfdcTknsrghCUDGf+EwhcgF0QxY18YP4j0VUhTLoKQ3Hq1xYmflSznG88MIL
UMlAgWGjyX6VjWKHRQ8rnkyCyGkRDAbcHM/Iks7ZleAt9Mf0jwqRy5aK8ATr
POAY3aZ+Yel9qUk8GZAWLlxoHNFk/A+LPCcSflYZMPsJr1jRBCph4pZWRHDG
ZkMWdXT/oOYw/3Z1EidjTa9pO42KYQSPsYUcQ/wKmFIEzVo+9HgyCRLIMOo4
f8FiU6rYIg/GPjXmtQ23rFkS8MoMECSCZuQb4mnxg+o0lEaNGoXP+GDYSol9
05BnEuGDcEAGvM2JIY0mRlNiICuVZT4jwFwnrpqy1ANg4sNPeRIitd1cD7pP
5nZ1dileSSsPHmeb/hh3WdiqMw86krlQfzWc00rmSB29zuof7L3otxXlzWfe
TaVm9Ft1+7NfE0Y7dwtmMnO7ipKXxOREKsnf/uqFWI6J9VdvwNojrxbqKJ6M
eu5WlLeySVc/poUtMiSKbF0ioDaPANxRfFF9DE/yliaQ6lytw8irJHmkh2kN
ITWJJ5O4ZP+pKK/RSmKegyrtQluk5iEca46qo/iiYVHeQNal5qf8q9GwqI4w
6c1Z1CSeTGFRZgXx+HUWFVT+wkypMCpBpztlURM/SI01EbXJ6IvZyZ1xyVP0
p87ADK4S0L7hC7cm68H6eA+LMuhatKiu2xn1xWI0Z1HX70XLWIt2kWBdoCWx
vxJuR5ugmr8XVa2+5zVssdj9v9siHCgX/P1WxevL2/gMvea2qP29aNQgPC/m
OgKiD1ovipE5Q8Z4eaddIA1lrut+Z1BInCBHfKZDGj16NO/caalHRyaWliQj
jWIAjRkzxiRnpFHcI+v6yZMnjzSKATR27FiT/5FGcY927NgxadKkkUYxgMaN
G2eVNNIo7pFV3sSJE0caxQCy3rRYGGkU9+itt96aMGHCSKMYQPBANdIo7hF5
kdpIoxhAnCAuXRlIuU8hezPMtfJQp2nTpp06depKY1KhmWSp0JSpPTFvKbsj
q3IOvZ6iQhPplmyfV+RBo5rOVgp/k1jHI0UNg3bETykYzJ6x4uTJky1cmj59
eq52ui8lMOwXFZXK01bSA5hEPGezQcnTnA4fPjxv3ryGmfMB+srA/l6pcbXO
wIRz7xTPlYpF+DZ8nrzETsdxoDBK60VARax15PXEhnTkyJHcCtGESkOAFSQB
Fs7IAHAwDKVO96UZM2acOHFi+DwtsigCKspzpTa+gipfTGToFNXRo0fnzJkz
fJ4wITDq+lOwBU87c1qUrSHNnDnz+PHjw+fBjfoYD4wy7kp6jF59iGXctRvA
YejYsWOzZ8/uqAuhWN1E7ykAiuAir46QFJo1axZUTXLWGVWXV902Fp7UEzsi
8gKpnlKMcJ3KyAqq4c31oIO9xVzH75w+fRqAFticYMt70Xz7MAv1cOPGDWv8
bDaoU6fvRa9fv75//35zkps3b+aaBqg++OCDHRUluhTq+kxi+3tRnpHlr+f5
8ssv16xZIxv2WqmtXLny4MGD1vL5SmIFnY0WSmFLcgKmqq+//tq6O/tA/M13
Q4lbtmxJR1599VW96G6fTO4d09zFixeznyFvtvurr5xLly61lgcDGGizITD7
CjplUfP3onfu3MEHqp7T4jqS7amJu8JZSMdATEvcfr5s/fr15fR3c2py34Sp
o75rAlu0nqtDKKeHfLGNWDHq2rVr8iQOEr2lTkScS3waUvP3ovmKjaVY8f77
7wOZ9zAUY8mSJbn84sKFCySV4+qGHrXpgkVN7pvADSziLrWYAUVdjTLizoc5
TKBXWGR8nT9/XgZKnq+WBNfR/swm70W/+eYb+rlp06bcS0LKACgIA0jRJazb
vXs35BSgjDXwctdAczz9zb4PyrBu3bqffvqJttCi7du3G0oSNZ1PltTYrJXC
UCrYcI/I8pmVBDt6CdnRe9Gy2y3fSbVLSfAEc/bt2+enc+fOYQ7O5Kuc9C5C
Wzf/PmgIGFlMmXat/XNHSX+lQrCx4bkjCU8MAaYAf+TpdK94y3vR3HPBp9Tf
hEukRbkViyHNHg/aTkyGUq57M8aBNOhwRiKQSpEaFYpWF4sKdvE7FAar77tP
Js7RAKQPGzZseP7553MJVJ069YMZDsymB+NItSwbYGS9aNEiiea95pkGMlYY
vJ3unW6/h5fa0OqczsC63DijxbFjx8pMyc3Z8tnUKumZZ575siIDE0upIoRy
YiDOWzUz+3FPuKfvpKYgm2lw8eYEkc3qdUjN/SBOgkq1VE5GudWuvzK2Zk0G
heYmTZqUW+3effddAPyVB7ua3NcQ6mi/KPvAVNIojf7lL3/JxVvRTJqfzXWW
TiokKZkpId2jdZbGzT8T3NcPhiH0k95m/1gudbWQlG6qky84xPrSSy/pIIES
JSGyurMqMuvLFaJNPjZ1tF9UWwBwf7mqJubdX3zL1FEevkAH9cIkZ8GCBcYg
JeyIRU3uH2RSsMggZaYYJUVoFCUhoNw/iEUs/4svvmigAcPQyUDJsxkjX2Ea
sqiJHzQc5IHHg1H51FNPlT1gY8aMyWSALuXis/pYMwDB1l+Y+esmw6e/8X7R
+fPn54SU/OYnDIJE445RynAjKUjK1hSOgNQmT54sv1LZT96ERR3tkzF5A56V
ZsOnTZtGdoa2vvf19RlrOXUCTDals1RqzokP2Jp7n+Z+0HhhkA18mmN2x4hl
O3Fii4HHeI4fPx4MGOCUefHixZgmvfmtHy1+kFyYgj/96U/Ukn5yDTnpQBD0
BxNMazFBi+CRozFOdtR44cKF2e7IILDnfsUcgjNbiPIUi5p9sJwpVdRc+3Gh
dj+Yi4CN7nz69NBurDr1gxDqHTujU4YSBkJo9J09ezYHFbGRZPNxXEc6nRO2
rwe1lfiNudxKc2rOiwW/Yqwi+exLA3MdNuYk/rBnxXUws7V8hM2WGMMhF73l
kvE47kEhNfSDwKgt+/ey+ZBYIyPtkhoYmsAxgPVFi3kjnclbWTzel5r7Qa2Q
i/z6CFKZloAqMVxl1sjrdhWVnWTxLXtUzBmanydqcn5QT/U9N7/LnM2oHiCM
RQUyb7pyOgwSPAEGPByjwER25vdr0Ien5n6wsCgnEbAoGgtANFm7fiLZfM2/
WFGu2wPmIfrBwqJc50qR5M8tbAnK3T+QRZqOo8E9gksgUFJuyKImfpCwWDCK
qmbyojCGGCbgTG6F6690KefF6mNNNr7GAPSMtw03jTdZDxrvagaMblgFqzx8
oC1lke5X7MIiki330UdwOf/YULe7Ww/6qxcxfeAZ4+xADCPh5tUcYcXqwtbR
xfQd3UefhbBRA0wOXfZXL/T8q3VKQrJR5kSGj+bnlWNDPC1+ULsq0WXdzBxb
5cXaUKHcNpi1hkZliAnCmTLPlDkbsWKuMy8tFhUnqVn8zqCQOEHzkFsdkrVb
AuM/IWTFl6uTnxwyG88oe0KImpm9jDSKAWR+G3f2hJCxZno50igGkOF5prqI
+QkhDsISYKRRDCALBNZypFHcI5Mi65SRRjGAFixYwB2MNIp7BAxII41iAHGC
//jHP04MpBzIPXLkyL59+956661Dhw61ZBg1atT27dtPPDEEMJwjjWIA5SvM
SKO4R4OyaO/evUCavefmIClkTej1PH71U3tfqMeJ6tKfXbt2HT16tAmGRI2W
2UNuSB+eRbLt3r27qJ8iih+vaPgW/aqgbE1QFdLNN998c/g8atZfvfacG5EK
VOlpcfhOqSG9aAIJi9pHXwg3tm3bFgD37S+ZlpwB3x0BExZpvVP2FlJQJVSu
04IaVbBF9FKGYpGe+rVFn5vAI6Ai5fY6mb79+/cPVbyw6MmhYVg0IvQEsogT
bHkv+s0335gVG2IWmOvXr1+6dGk+D9WpF2f7j0EG9U8//ZTtKIZ/f7U5J5sr
CsmQc+sUg3FgIqybbt68SQesMeV/4403Nm/ebGX39ddf59qCbCvdunXriWqv
o1IJ+3D16tUVK1ao59NPP33ttddM42/fvs1rxJ63v5f77bffFFy9evXbb799
48YNzcn5yy+/QJigMZRQIjz5rL9u3TpItAIM1c0mqGwr+uqrrw4cOMAkWtFo
ERjPP/zwQ0JSDPXWKHtgDFv1f/TRRx7ypVudqXn58uWwXb9+/fLly/iAVzgz
d+5cizgt5gYHzTHg8GzatOn8+fNgZ89GYhHkLiR51CPbO++888knnyionvS3
fC9uIb1jkPOranPs+tq1a+rBBOk5k564UlqEX6MbNmwgI4DBULkuDBqqSyV4
qNeQeFAhtCBFlIr/61//4siU/eyzz7ZVlNhNkVq2wahco2G7SmSQQn8gJzJF
hlLL3H8RMdEiRTStBrKYMWNGvaEEK1CtFolSQwn9pLh/MSQzhHrluJGtMnKq
GetUi0sElJPa0seNG+cnXSMCCkMiVA5g3Ses3No8FPge/TdS+/dBSjhz5kxm
Kld/0jHjt6VUzw/+MSjBNJgLxm3jxo13797lmJjQeh6GYt68eYsXL2ZXFyxY
wCDMmjWLNaAD8Quvv/46W5dP53PmzFGnShjeJUuWjBkzhh3jRpmOOMdFixbl
LloV8sJ0bNq0aXLSN6X8VI9KARvdMyvLdlleVSlGWKlXXnmFjVKn1iHXnJ9U
4i8DmHdT2X/oX40yqgDDKV1HWLnp06cD7yed4oAwQRMt3ys5F15PW7lcSf26
zBQHlS7Pnz9f75hfXTNq+HdmNkdmVCWDFpNHWfXw6VykRiFPGBwTDK1jKb4Z
iYYbeKBmi6myfFC+lchf/7ivITAY/HwAlTO7Cnm6CRMmwCkF23GGsFSlZhwm
6IQWDHgNwczgJ8RZqfzkyZN6MXnyZPWQDhbpL8WAnJfP9kuuhCB0QYoM5XY2
9eAVueN8LjHEbdNpTkRVzz333JXqeiaMvVXFq9RWfaadyY9fKQ+e5PJHNQDg
78svv1y+Q1FX0yr9wn8/6ZFn/ExAwmeffTZTkezmKvXz3ZQEq3OPFc4ry+jl
ysX4xylTppjY4Kc6165dqy86qFS28WiOHHNAW9muoyL36Mmhdj+Yr6XZvmLq
VY/WW6jnB/8YlBVZdqAlQNytKq5UPQ9jwvUkUnG2XyZnwjuzsdl86G/itWYv
lgl8jv8kwDLblQ/ryaC4Sbt6tC7Rg38pHstZ3/MgRT05qXfnzp1ErtYWwJ7z
idyDIon9m3vkAUtg3iBXv5/AgFBVTGLimQdbDihlH1Rm+/W+J664UWAsJCyz
OnOaKUGAc8Yqn/I5lOwDSd9z4CXHwcBLhDfkQc7sysi/IKWb/upRGoIkJ6du
VRs5svOkvjCU81JFwCf6uuYgYcwtlsMQZROrKvctZqNO4icnOro8Vme8khlI
vXL91XdlFUmo59TmIRu3Ita0GJz1zT9aiVCyLTOx+vUop+E0rZKE1KYJ1ms5
AlMIZ6I86s8+0kSzxDfF66cYEhMbDyXmjJgUOdMQkDlcVo9Ln/1LV6rg3jw7
Lwlt2K4gJGkIhqiZzFrPVVbpUU6lJU5OQjd3PQB79IQQJzh+/PgvOqSpU6dm
xtuj/2rKGq2eEtM6Unh69ODULtMeDUXcWYnM0KP/ZeIER40adXYg5VN+br7O
xoaWDGPGjMk7/x79YciK4/Dhw1aIhw4dMkU/deqU2bIFmr8lz5kzZ/K1y6+e
5Tx27FjSFfT3vffeO3nypGeJnhMTjCJt27ZNTs/UJokyfFCRB0VkbkmsN5od
LGk0DUkHLJlzXL2lO/LIkKBJe/fupckeND2M3n7wO6WV0vECKVuGUrl5IEip
NkVKi0NBShE1lCZSeUrhDy7hQ0sv6q3ns92JKkA9rg7VERWSYFhamKB4XZRN
IBn47ZAKZRdTqb88FB6WxHqd9ZyRYF1Yw4umyKUoAAB161TaTf721vU3Ijs7
mKbVE7GX2niWf/v27dHzHv1RiRNseS968+bNadOmbdy48VZ13cArr7ySO2Xq
1Hsv+sejxG3Lwa5Vq1axAL/++msO9ZQ8Ul599dXz58+zw1evXl29erVs+bK2
fPnyXOyVTdqpZ9GiRR5k4Bf8lMgeciZKDx1buXLltWvXFi5cmOsJGJ9ly5bJ
UD87duXKlSlTpmgr2zZ4AaZJW/+q6Msvv8xdKvW+SMw1MTw1fc5XRa2rYf36
9eUFYMv+kw8//JDC8zU6pWZI4gJwY8OGDXfv3s1NHzlqvXnz5smTJ/PgmvAv
DBcuXFAqsWUgBKBeeW6zMrJULg/mbNq0ySBSRH+Z2W+//VaL0JYi6skOSb3D
bWY55+Lv3LkjZ2FRSy/A0wTOE+iOHTv0aO3atRrSNKj1bxwgrVu3TvqZKuQj
SDliH0g69c0333io70upN4SlZE0uZBpR6pFED/HCkJO7mi9fvqwh6R74FA8g
Rda4pEV/Nepv3nm2NJR7eWSmn8rKxvdBq6rZs2frVIFHduY5nB3pEMHSpUsp
DL3Sei7Q8dezFj/66CNdU6eH0lAUGxElZfBrot9jI7TtQ6ZHfxhq/z741Vdf
9fX1UaFPP/3U8DeO2nd29fzgH4+YTUbsp59+YqNee+21BNNjzep+kGXms9gW
eRJ9ji3KXVpLlizxTCti1WmRCrN1RA3sJFPGrvJETDR7yFixMxMmTGB8FGQw
L168yJBqmu7VN3Ay+IrkIK2G6KSq4qfkvHTpEp+o9boHyVlmJpELk4E+s+oJ
AWdely+YWfOWIqxo3EfOxRsUNJ8byo1+UN2qbmSLNdZx1pIHkbNAYmAVmThx
om4yzq+//nrxIP2Ve9JNBZllTe/Zs4cNB8BfrkRKLlLUzbJvNoF9NKovWUrn
grB4dvOBfMVTvCXwV+6rymYhv+IV8DxIdivVIelFbhrNTmBgEmopt0olLg0X
kFs4W66vygSGCGSYNWuW7iuFORIJ16+mTFSFaHQz24RIn+tMIDW+LJtt5MlW
olyqRR8YnPpHN4qkEty2xFYPVqg5W4DIqx5qTO/mzZs3Y8YMgsYrrdBAepXN
Th6oCs6AkUhW8tRvLpPoV9L0oBUdyQdlKSDl6gcPnd4K16Mnnwa9d+m7777L
Vi4DylhuP4Pf84N/PGJgc6s7q8jS5mqeBNMoeX6rLjTn46hEdCPPCQyVG1jY
Dc/sGC1STy5MkRJFSmJMylcVJWyRX3Prceqv711MWEhN5OoZvyquSK5Mzd4e
Ger3HiZCRbadSPcgT+4DkjNxhNjqlvB9AJRfFQ9gbXlIbEPNpaHU6d9cbxRI
2RijoVyr2gJJnWk9rJNT8dy0FW5ns4089U2h4Uz2k0QussmcfSMJymflUl9A
4ZLlDEuem4ZSZ1aRzSFJbIHExXz88ccte2lyPRkOJKeHnBxJEb8myk16EQkG
Uq58StjeXHaW4jlz0XKMRan0N3YpdwClzsir3qPvKsqFOxFHYVdeTUjMdUvp
e129JUYncylVFDWciUqDp1RvY8wfjzjBl1566UKHNG7cOPOxTkv16AmnnG4b
PqVHTz71pNajHnVEnODYsWM/r9Fnn312/Pjx/fv3WwscPXp0586dOQ5cp0mT
JsnzeY8eDeXT/6effnrkyJG9e/d+9NFH5vyHDx+u5yG7xC05d+7cu+++u3nz
5kyk2cCEAfevn2TzYO2TxFI8Ut60adPp06flSVTMhOCT80JlSxXPVUdS/KuU
qs6cOeO5JNbrBPjDimQrMNSgnhRvp5JT2SikzIlAm9bzq2yqKnUmG8z1xHrX
kijDhepDj5SCrZ6zTrqfplO5f5NovnfgwIF6TtWSTrBhbKSTK/By6ZJfFUwv
wsmWsgGvU2erIKWqCra0HtieCXfLli05WS9n6W9KZQOSh48qki5beFiqSo+k
nzp1auvWrfW+l/7mofTXYDf2S84IKH3RSj1nIEmhQh5KYi5Uqnc5GlX6G+1N
znrXAriluMQE6qmz63xFmlOzla9Ez8Wm1euUIV/36niMqe3bt0eBI6MUSTTR
IqC6RmEgWRQY+bX0oow1OckrQ/W9995TRGK9O7JpOuf9w1tFohWphJg++OCD
OocHVdcePVziBFvei169enX06NErVqzIa4cEdmhZRfbeiz5SYgB//PHHX375
hf2ZMWPGtWvX7ty5I7GeJyd/Fy9ezJfdvn170aJF3333nVIc4oIFC4wv1nvJ
kiX+vXz58syZM/1bP0WlQnJ/7bXXsvdAQ2vWrEng9z179jARr7/++oYNGxLI
Ze3atepUz7/+9a/du3evW7cuh9NlvvD7YcPffvuNnhjFs2bNMnihmj9/foz5
G2+8QZ1yYXpu2S4wjP1yV0IOvmVb46pVq958803pOrhx48b169dfunTJAxj5
bJ1E1mnhwoWvvPJKfRuD5wTnz8VeMmSvoMoxJJ/SciN5KeJfxravr+/YsWO6
sL6inBZXRDdLzps3b+oLJsjAmmEsDnz11VfTp0+XmQ3ERqwDyQDxnK9R5VUn
l4EtsOkazsipp0Q5d+5cOTOfOVsFwyFNHM7lEWpYunQp5udwfb79sbGYwwjr
HTGxriwn7qkzPNRxyHEVMHx49tlnyws9UsjJdCLDZ/LVImsgJ2FJL4ATWFv9
en3y5Mnly5erHxNg0EfswgQSpDDXr1/3IPO2bdsKb29V10koq2aYowllAx4B
yS8x33klqpzqFm5rHTB6rhI2R+uYwEDpFxHEWSueKM3yaAVXiUxOfxNVIJP2
UqdSEyZMMG8BQ53qoa4KYojKYcB2MsLPUgS7/KR3udMkH2o1rRW9qI81OQ8d
OpRdW5SK+OqfrbHFNGPcuHEErQiGgEd/VKLjevrDDz/4K8XYByn7fPqrV9BN
oqD3qGtq/z747bffUoZ88mY06EN7wISeH3ykxJzmFgALw9yJ5l+J9TxXrlwh
BVaRgAxtDqLEMMn2y9xAZ0gmikhCbBUDlT2Hb731FueY+FpsC1vEtDIpiUCi
QqM+QczmzJnDwmQ7JfNisGuIkpS7KdXMTso/atSo2DeQDHbtRp2YiBjV+qYO
ZtxMDEi2JTl1ll3KvWbSORpIEigMDHUCwAj7l5HxzP7IUN/SzI+A8dJLL+kI
DuiRDgKcrTX5aMXW1bU6GyNVqKBGFYRTL7LZUqniF5QlETYTBuzSNG54UFz3
JfJ9wCuVCQZ7W2+IAVQn68fceVDctCG7etST0xYAkIU5ieIEB5tKPHMH+qtm
eXI8XFsaxdXYzBzryFZSPjGcUa2G1DBt2rQyEeI4cCNeOIGC/UvQWlGV9GJ1
CSucSew72WgCbuujFuknrwSGBzCwOnOkomaMSeYkGiLQ9ILQl1YUbmS2wMVI
0VZdlDRBQemqhcFfs5RoqY7TYbLmRCgDsZoa6YuuqSSblwjdg8z1mbxRIEXT
2RCIP/ooc/wghESzoaL6tCH7Z3QWBrqqCd4qHpyeZKzBpr8WmxgoZ3YZ4Uz5
BJm7w3KHCO9Jqz0bZerBBDLKZl1Tslw5ijlkTfeyE7szI9KjTmjQfTIElz0P
aNCPwj0/+EiJCWWysrchK5eE76jnMTqyk8HUMdcs5tqRXDUlJVtEYtD8Lc+h
3AeUe77yawKNlnpyU1UuQMnejP9UxKpnZVeKlzpzZwoLEzyBIVGRaFEugKv3
gsVmVRiNtBiQqTzbUVh+a41sUShdy61GBWeYUOpUA1uaSydDyZ8NG/2VcW65
qScXACVne+Ut1ySlKi2WUtn+UUql7xLTen3hCVs2paQXhe2lX+F22N4uoDRU
xqaHgrNF6Fl6F/XIXpQirEH7m8rTUEt/5VFnwRbAhe0FUhpqsRhEHHdZtDTd
QfDU+xu+1TUqQyAiSKk6i0of81wWTcngpyKLOqQ6M/Orsp6jHoUhUbk6u9Lf
DAG/lsrrqltGZQZLqb8+RnK7XNHnUmfpY+qsc7i3HnzUxAk+++yzpzukF198
0dy101I96lGPetSjHj1pxAlOnjz5Ro3M3A4dOmR1bwFyorqz4+TJkzcG0syZ
Mz/44IMb//N0/fp1vLK48GABsnPnTonZPlHPdurUKSk4lvO/Z8+e9Refs53D
Esm/6sn5u/YmrIn8evHiRTnzQUei4tkKYr7tr8o/+eQT2WTIfZ2lho8//nj9
+vWKK5UPEx6+qK65R9kJo4aED833esUvVLdtepa5vePpxeeff654OuU5QU5U
ovJsqEj0/uxhKPV8Xu1VyO2xqSeXrma3QGDg2Lp16zA2RcIr1Wru008/zbaQ
hBjNbgcPR44ckS6x9GJQ5LLhwIXqrgr5d+zYkVdYqSdxL7OvA8KSmH07uTLD
Aha3VQ6Jh1wvm8rlPFtFR8muFfj1HbbsAEnIzYTokVlxOWXQd1IzytKQRrEo
XQ4Pc5reQ4sI1KmbcGaThgzHjx+nRVJUtXv3bulpKOfmStm6CHL9q9oSwBz+
pNDYKHY2wyQGbDvpwpo1azSnFwVw+quVfNzMe2z9ItNdu3bJkLu3VJ6Xycri
7bZt21oGTo969HiIE2x5L2rYvvDCC8uXL6fDy5Ytmz59+ooVK1pWkb33oqFf
f/312LFjCZOyYMGCKVOm3L1799tvv2VM6tm4p2kV4erChQsZgVdffTX7E7Zs
2bJ69Woc3rhx44wZM/LKJS9FS3GWc86cOTIomC8IucXeA+mYzKiNcTZ14YbG
jRvHLtWPiSX+PxMHrYkNs5Ov8Ozk+PHjc01PrvlbtWqVSnLT1htvvMFHKJVT
e/U3S7du3err62OcX3vtNX8nTpwo/63qRtQNGzaoCjAaQq9Y13wLYyHL+y6G
EeB8HMn1EEuWLMl9ATzU66+/nt04L7/8Mv1MEd3BOsj9mgPUZmJMK4bkgDa2
6AtZfPnll2pTLYQ3b97MObI6M1lagshtCPnS9PPPP5cD1NLzgS8I89WAs1Pb
W2+9pV2ZSS13rGs3F3SWF4nffPON/FOnToVBtly3xP7rmvpVriNaOV1d+a14
vnWqM/cMKm48eiYIDoVWkO//VxFI9deVmJkPeWrj+BSRweQBx5T94YcfZF65
cmWupCdQakZMpThxaF0HDfDcKEEtlcV5D5REpzyQPieoO5gMfI4Etrw1xWE5
6S3vRkbkQuiqpa66Rp00rQai4Yt1R79yzxdZh2OQ5EWuDCU4TI969Dip/fug
oUrnjRGzNXbGMx1uKdXzg6H4QZ6C7zt48CCjylDwCC1+kInAT7aF/cRPRp7h
MpGWmMCb/jIarBAP6Fcusv4pRwamTIazVShO1i8LwOwBkKIeBsfSIEER5ax/
hiuhrviFfOJnqXKd6PPPP8+FKc6oskusEGDZYB+fCA9LFSNZKoyGmNjrEXfA
0Ol79nMmxBnzzj6rFgyJescZ1YtDCDztklMlcgaGjnNPoKqfJ6oH7kjkFgQb
V8XSBjDkavvxxx8VBCkX3vE+egd81kH1r4fqwcBsuUyck4SUTEAtvlVxUxr1
64vKs1XVAwOezWNa1yMPmuC+ufVSP175Ndt+8MQDzmtIzf5q1BIpwWcUx2rF
tUh5IgIS5P21iC1ZZ2ECbHw3BajPJTxgbCKfnK4CYKrTuk9tciqr/uw1Mk4T
zEd6+dCZO5swM+4pu1CwTtNKUTOqohQ/nk2znrVCt0ugoUL+5cgoIf7oLN7m
2kT9zcxNQ6YBErlXuic/Zch8Aza908ez1eWVEhWpb7DsUY8eDw26T6a/FuJv
0DtAe34whDnZzFlPZH4Hvdu0Xqr9uTwkxMrDRjoIMUeMW0tMlXZxJ3BHe/qg
itH810EVbHitq5cavqH6vv1Or4fDlhyFGKb+h0UtlZM799HQEQzFw+ZNd8pP
qzbY6vtYGjbUKbYe9egx01B+cHjq+cFhyMBnexMGKtHDrIAkJlxVy+bDQnfv
3lUkAaMYQ9PmBAdTA1eVEFg5DpycCRSW4FH1l5ayZR+aUrndz6+JIpXny5cv
JxxZQqgl6NagvchVbtlwmBYTQk3NftIpq4/s+pOSCFcJmObf3DkOrXr8RFuC
KtG0EpLLgzrz6jKQStPWJjiQyGAllFbwJMjYt79TImWFRbIpZfVUYACfaGkp
a5WUN8aJgTbUfCOhtHLB3CeffJKgavn0mf4CE+R+Si/KklARiyzdyWa/fP7r
r1bBYVHCeUUWEiO+1BkmyCNxKPedoG2RfhQm+x4TMy37iv2VzfrLJC3bJlNE
5fInOlmBkUsJgwdD8tluKMUufAuLdF/r+dBc+JaOR0/qYb0TpDS6Yf2Yyw2j
PGk9IdEi4hKyL3VmZ6weKTUotmhmoqhZe165ciW7LovaX68o3EhiOBkRRM0i
xxs3buQwhZ9ySWX2iyabZxzWkf5q3mJiAG19QoInyZmxibdl7OeTR/qIG2oG
w7/wyBbOtHcNpBiTSLyMaBUSVj2GbX3se064e/+WAaIVCim908nMH556fvCh
E61buXJljv+wyTlVLXHZsmV9fX1nzpzp/32reb3U0aNHcxzJ6OBBdu7cSVdz
zHbJkiXqWbdu3YIFCzZt2uQn6XPmzDl48ODs2bNfffXVXbt2RbFzgXsOFG/d
ujVfefz9+OOPwVi8eLFxreD27dsNH3/9qs7EjTRC66MDjC1btsydO9dYU9WO
HTvGjRuXCM+a4x3yJc7fHFHXii5s3LgRYG2pja3bs2ePOrdt20ZhcuJ79+7d
/j137hybBrme6ppeYNHevXsLgP3790tUm86qLcchkdbXrl2bk4xQnT9/Hki/
rlq1KkfndH/SpEm6pi15YANSzerxd968eYrgPD5Lz7Gy2NjScc85JimDSp5/
/nkgdYdA16xZkxfI2KJHYBw5ckQ2LrJIEydHjx6NG8uXL8eu9evXK8586UVO
W2P4/Pnz/VUWfzzgrQlDPmvy4wlaDm1/5T1b4rsCoHKy0CPdASNhxgGmP/5O
nz7dPEovZsyYkUs3NEToAbx58+Z839QXMIx9rROoB2CYzX379iViQ7tKMMUU
OzGuPaQ75gYkq87cTvLaa6/JICcOqznTuRRnwMeMGUNJ/KrXZJRbJ2bOnJlP
pWDgPJ4nFsSsWbNoSz5Dawg2WpFvNNpqwca8qyfKsGjRIqoCYe4Nwa6c5ScR
aHPKVYacZ8Rn9ctDUor7l+YniohxMWXKlFy5AobBq2C+JmO+bBrK5/UiIy4S
bGhzktRfTRgRhCKROBLpnUrwpDnQSqBqy4UdPHWmiHXLwKfLSeWoLiGqBACs
wMAJEybUI0jAn7GfM8UEoTYZPKxevZpWGCYeyLoc2+nIsv2BqecHHzoZNYYV
vc1lAf4aQWwFJcygMBX0bCzUS7FmEg2HBP+XE4fZhHwpkzl3x/jpdHWhjJHF
m8Qy0/BiEyx5llUUi5o7bhKhJRFj+J18nTQkU9yChR1mhOuuGYyclWZYGEbF
X3zxRd48xjYTS7Y9uzTBZhUZGYNO5QyL57inaxUZniyYRJaBkVGh/nrQR4mB
AVJspr+spcpVm2ApmGl+q0K2jgU7e/YsbKwHY8hN5+tq7lRiChQEA99yTUM+
nrIhwMvGXeaDqUaZONag5ex2bkjPZEORmB3zh3zjU0qLuYmJKOMR6t8xVcjQ
5Qs7q4j5eci0xLP8WOSZ3wF4ZUWYSWS5w0iRnEzP97gsPULhjPwvv/yyroGR
8COJhOCvrrGBjGS+D+q1qrgDOXHYqg0ASDhoHZQ/lzr5CRP0SHqOkFs+ML+m
SXVTyX+trogKAR8WZXs5VsOJb37VfepEuGC0TPZorzz8C1T+6jJIuqMeIIEh
cV1QMN+p5Q88IwiT80mUULKPqz57oYRjx47VO2omv39lkC37iIjMAPQr5GSd
7/KnqxtM4EwgO4naImI5E5MHE3CV8hCKBzgTowBOpXJzFt2gbPUwCwnOA4Yu
ZNyRArZIpPZ4pSydx0wYTPZy81RmL+SLP9qqu3jFDXxczbYrdcKp/oT0qd+X
oR4DFsjc55IPr/LnU74RFwaqDesysjoxbH9k6vnBR0GGKg30l2JT6XyIyanh
/mo2y3q0HIzNYd44gl8rKqXyXB7osGFrbCallCqU9JZ6ZKvvsqg31F990yxf
xFrqyWnlxE789XcK4PaG6s/tie1dK7+29KIUZ0gZfE1L8ddzrF+psL96cTQM
jFTV0qNSXNnhZVFwlr9D9aIFfIv4Sp11GlRAhRsm7axufZNPf7Vc5TsSB6Bo
1KCA618AS531FltgtEgt75PbVaL0oom6thRvYWYTbO3M7K8iIVhi12sGNXGQ
Bq28fVzUwbeoaL2hltaHkumgylPnf0msqyinmQ1CmUBmUck1ty/T2tlS1P63
wcZ+C8j2xP4hvrb/zxIn+Le//e1IG+Xa8fpDnZ599lnTp/b0Lqi9oUFb7LS2
kaIuAByuqNOc9SKPqNcjzswHpAfHP1IceFjtdlrPY+5vi+Y/Cfp2XwyDZhim
VPPR3SmShpWknq5hPGDrw//6JEg8xAnOmDHj+xqZaO3fv3/Pnj35XmzxfvLk
ye8H0rx58z766KPvH5iy09tK5M0338yucq3nS30dDzAXL17M254cbYYtZ3VN
peo5E6xYtWaGR48ezZYJpXJ0XUP1w9o56ms5IEWdJmbZZJ6L7aRYfVy5cqXU
f+nSJWg/+OCD3OagoL83qqPEee2Wl4HAp7icistgzmBi79eAN3f1r2fA/Jrj
5y0iSFh7v5r552iz2eOOHTtOnDghAwBvvfVW9jmocN26daWGbHfUEU2rBGYN
qUfmxOf3nLP2UtTpQboW26XjJ9JPCGWAsQtgpQ4cOICN+pujB/igeKkc1Fyy
oHL6E8A56w224jmXnb0r7QQwvimu7M6dO2VWucQIS81EgCEgaQhjc/WhX5XK
IfoARn4lGgxRUJFEq2shvyZqxCeffJJj7LLlXH++LuVSgFyyEFWRgu2fV3cH
5DR6whHoe64qyL11LWQJk3slUvz06dPalZiealQ3o3L6lY96HsBrr6ooEjxU
XVlg9De3J/g3B/wT4mDXrl3AayhH2hUBT0o0Nkfmc0Ze0ytWrFC2NFR0RuVA
ynCzojAkTMivkUsytAMmI9VqCK+ggiFihe3gwYP6KDHv/C9VJLM6P6/uXAjO
dqn5Nad1VK5dxkEfE7IApIRl0GLdkshAAymVsVOklresuR8EEyi8nxLEAHNU
khgLpCanvyyM4VNnkQrxLS9McBKksEiKX2XWXLaWtZMMiSYBJ7QZlZ4xM18z
C/Lsb6FgMR00VmLMYE6JypCLKlJVAOd4VAIJ5tRPWKcIkDEyWsdDzxJ1PCNd
x2XOjiCJETGoRSE9+PXtt9/2V+u5ViY5z1YEz5o1azLSEy4Dhwk9sRoSIDeQ
wAsSrFYcjAwiKSy/tpIIkqqiSEAOys+uiRNseS+K+aNGjXrjjTc86ObMmTN5
vZZV5MN6L0o66vnPf/7DtCaQe391zrq+md9CPm/RJ06cmPNc+RCcAO+rVq3K
PZtE8MMPP8yZM0eGV155JZ7CyJKog2xOX19fTijLw87ouJT58+ezSAsWLFAq
sSy0Fdu4dOnS3bt3072CROKsihKTn1w8UwNV8Z6K68urr75KapR/2bJlBgjN
1BcAEutj+vTpcgJm2M6r6KeffjpQUf0lknoWLlwIZ/aQUGYI9TGhmH/55Rcq
9Nprr1G/HKAjo2yrCLsMVcwho2xF0OiGDRvYCpVAQqzqVI/OJu5xboggBSDr
b+HwcNy4cSwDfZZfcQ3RZIk6aJRhGlYAc6Q6TZ+9Fropp+ZoVz5MENDUqVNx
TAY9yoUL+Pbbb7/BUN8Y6RkelZMsK0eOEHLxKu+raN7vhIG4JLMixJQwzhoF
iTgA1hFgVEWaQGImZf6t2oLb8rov1wcwO4rjqqpwNXGPX3zxRYlgayJBwj3I
A1uuTsjdBBGWYZutKVHjbEqsq7EmNKQSOQEjlJ9//hkq3WFkEoGZHLGIfQBA
/bmvlkbV1YMaaCiXbhB07nHAjblz5xJErqGnUbrPDy5evFiLBlp2PdFP/Axm
tmXChAm4ql1tGRSjR4+ufypl9/Q994boqRrYHxpFDXAeYDjVQMRakVMi1t29
e7dFkTBcBt3M6VcWksrRN7zVCw8wU6rPq1vDSBAPIddNIOXBgRapkSPwtMJf
v5qMkZqhpDhB+FdD+gIzRZIOdhxrYo9rHdpILWG3s7GEyIwampkQ2bFIOAZ5
dpeRoHS9Lm8UCWjatGlYne/yZn35FIhFihj+iXeR76S5orque8wL/k+ePJlQ
jBpoCS6nfZ9//vkSBReLVBJbrS3sSp1UJYNauzobS6KPBE0W+gsV6SemK/BS
jMpIzdj0kI+MWh8zZgwkmJOo7AnRoCP5pEus2d9VvsniAKUdP348EeiFBwAU
oYo5zUqRJk2a5IGqsyFqBgBOrSR0Bm5EM+kDEUDup0ifMpAX7uWCGNn0CD+p
HP57xgEKRkwP607k9u+DsczGo1HMa8fgtJR6WH6QyuFDtl5jtVmB8Y6r9WPX
JGiEMtSYKcOeigxMwKg9GSXGReLTvlWRDEaiLiRqljEVDeECVDJlyhS+zygj
Yj/RDVXRhNPVTXyU39CTU80t25KZL+OCWJlBAlUhucupHphzlJhpIiP9gkET
ZjU6SLh+1UEKL92I0y6clAQ8KWqo20yl6JJeZ8aVuGoyaFGpTNg0lCmWlJwK
L2OTCum44mSkZg/ZKCInDad+uJ37JSVKASALOjpc351I+hkIKgcglw3httEH
UqKEZVTCuasieLJHRVk5sUtHAMbJ7P0jR3g0mvvHGZm6ItGEQxXpGpBKKRLd
UDwi85yVfrYJJV5ZhKXj2WaQoAEygweJvxrVWSzKHobSohSyI3o9ol25OIA6
GYOKUwatY6/Kc05kb0V6RAeYBQD0V3P+1RFNa8WzjsSD1xtiuzLe5aRFOU1P
HIpTp/QCtgRS0y+wCV1tUNXdCjB0OIqkYHbDKp5ICypMhIEEXqN4umYSHjXL
Zl3qoS2TEJV70H1CTH/r23LUSXzSqceF6o776IwUjRo4HrItB4DcQqLLMtTP
7PdXUwL8xxxFDK4MHIm5qCtB/HLxE5WIzsADVX5tl1p/tZMWhgjdXx4EWk1j
gs5ms1nuVCrxtMNqMICJQuo+PcETSEyowkM/yYxLkOTztKrwMGMt926UaUku
1FCEf4FQnUoVFhFlbgHLB27a0nJrjFbUmf1gCmpLJTqunsQZKDYw92AmHl1u
Ds0iC+cTqo58qQ1tV4lEQsEE1apcTlVhkYIZFzisQh2JWYjuIdoeK5e4mjL4
lY6BFH7W/Q7myAmw+uX3a15oSMyiQFkdhMq/6SBx7K/IXIXyh3UkmB2wEmUw
cKi3CQPVpSd5maN13c+rkgA2SD3QosEcS8c0/D6ZoT6kPiw/mENe5bttf2UJ
60fJHhaVJqgB/j+sWURHRLJG6FDnBx8uDSq44T+L0+pOj5x3Tb/9fi67JejZ
o26xv7LJLTtPCuFAXpQ1qfD76hXu97UrHVuaa2mI5fyioqFaH6ahFp15nIrU
BT0KRRpGav9F9Ch68dj2ujzqhopNyNeix7yHhxP8y1/+srtGWUHkVFGeMxOo
09NPP22du7tHPerR46IMxuEzZNg+Nkg96tEfgzjBefPm/Vqj76sT0GvXrrXi
y5so6+JfB1JfXx+v/WuPetSjYckSIO+gcsoslCg3BloiyYQ+/PDDvMHONpL3
338/R9Tz1SwbP/bs2ZNA7ufOnTt79qxlV6ITWJl++eWX77333pIlSwzbkeho
j3r0X0ycYMt7UQtSg27FihV37tx55ZVXjh496m/LKrJ3frBHPWpC/OCUKVNm
z569YcOG8k7s559/vnjx4pkzZ+r7wcw5J06cOHXq1P3797/44ouLFi3Kvguu
7fXXX79y5Qp/t3jxYhWePn161qxZc+bM4TpHjRplUmo8Ll++fMuWLS+//HJ2
D3766ae/9mJn9ahHzWjQ74O53o5DTBiiljvE+3t+sEc9akbfVxFvsve+fNHj
oRJVsv6dOocd/v3vf3/88cdc5KlTpxJLNpvhPVy4cOHgwYM58qNO3lAlVoVy
Ztko0cIzAXwSW3KEOt2jHv2XESf43HPPvdchvfTSS9lG2KMe9ahHPerRfzVx
ghMnTrxWo5wjyJVwaMeOHV988cW1gZRoeNcemC5dunTgwAFT5cOHD+d0Z+7v
fuedd3J4Iafdc8l1DmB+9tlnCpo2K1uvyqLVzNmkup5i/myS/O677+YAfg6Y
pyHPKt+3b18OdZYLx3M+OjlzLiN3lBcYmgjOnDkNGPk1Ib/ie/fulVkpS+mc
2c9pi5zOLqSe7BZW/Eh14XiO62bPM0jm+TLUi6R1HJMnR8v9K6c+5pB7rmIP
i9op569zfj/H87E0HIZcPSWnn3IEIOeaYdNQvlvl2HWO58vgGSuSCLyHHEjX
d51SRM7EGSj1h7E5GVHul886KOd/5aEAhw4dioYkZ+QbzmT3fjmRXX7duHEj
/rcoWLlcPkfCownr169Pj7Du2LFjyWmFVa8h7IpYsbRcth4N+bgixRNRIZvY
WzgftcnB8JxNjgSzHb0wRGIGo5wSyddqTuLFioBPL+oqFzbmTIfM5R75hBpI
4DUpVFE2BWVIL7QuPSfLctwyN2KE9MXA3759O6g5xp5D+jmho/jWrVtxqXSt
RaVLf/NNM0fRS4v1nGrWRPQniqTjiZvnp8DwnGGSQSRDQmckUECUX+8wEySc
wYe1a9caaDLQE/oQSJFLgmls2LAhH1uLeiS8Q85upPL6CI3U/Fo0v66lhXJk
I8M/GdSco+WleASks/nsG0p0CMpgsCuoj4k3rkg0v6WhaC8WparoZ4ZwTr7n
/L5SeUYJBKGPdf0p/VW2sCgkm6aL7qVFGSLWaEIqz7irm5cIpWDza4YVtteH
huJ79uwp0k/O2K6oLoYY/glUotHw0DNrHIMZzmT450jFtQejHH+urxD/85//
aPS111779ttvv/vuu0WLFrXEP+9/eO9F79y5M23atG3btsFgSOace85askjg
rV69evHixQsWLMDG5cuXL1myJEfOd1cnrepVYfj/+3//b82aNeWzyC+//DJ/
/nylNKE2laiWviUku37dunUrt47evXs3R8v5F+bo1VdflUGFidbrV5Bef/11
2CiGIitXrly6dGl570QuGAK8zAkOT4V+/PFHrW/ZsuXGjRt+AkOReuRAXDWE
E1FBQS4PH0gfhldeeSXHfqXX9w/fvHlT5YrMnTvXqM9xfokzZszIlbhMB5za
TezB7wfG5Ccy+VlOrcjGYuCt7ut7zE7uuPn666/1ffz48WBLl6KUXlA8XWBa
YQDVT9pVycyZM3PnBSOJb5hDbQzn3CasIUXwvwSE/Omnn9Qwa9YsIpBfKzKr
x4N/wyU+NGH8CVQ9ia78XnUVr+K4LUVOWqFmVeHG7du3VdtyeZ9qc4uHB3zL
1e0BQLvAw3bIcy8t/GPHji014AP+YCxxUBtF5syZgzNJAU+jJoRmWZhDgTVk
1JSDxsaRwR6GG7wrVqwAgGLQIr1QVT1nbkOgCRITF50EMxzIRYp6Fi5cyMgk
7KexSSf1ffLkyf9/e3fe7NlRHHj/5c4bmLAd4QGEFrS0urV2CEkjgWz0YCE7
PGySEEgIkJElswhjlscL2MbzBOEZ/MzjAam7b997n0+cb/wySufeFtiD3e0Z
nz9unHt+VVm5VdY5lZWZMCECo+NeAe/kCyVGCVja22stQWCglrhhLKwgxNtv
v52SD7soA7mjqIzQeulCnfQ19f7H//gf2GXpxze8qkj9hDh5SNBEYyKzaVS0
iFqUFr2+psXWEg6AQwPrUPfGVleimF80+mshKxmCmQtVs2xXkqNTQ6YYlGJX
AqI2cEAFPaSizz77LObQouRbiagur1vg0F7A0Qh5mPeTeTdSg1vpbjAcwpWB
7qRTYbAMskmEaQBWb6LSFZ/cLphUbwJWRoEGbpRnBmnAQg83TBwrI/yNiC5Y
6ULoo5BohEAJJXRPtTAZkhqX7gAJr2yZzCFvOFhZhsDBQM/HZEE460HTKlkC
MeaIfAuB9xeTy+hCr7IPoMGT8n9nO5FVzpBhJnmBCZruRcQX4YvA2267bW1p
glPC1tNMPSRRoaV5jaWwwmeqVeZzDCmrfEVzDGEgeo6xPSSO0/+161z/YNHQ
J1ulLeNS5l2DX9c6yHZhLCOTsqG97GpYWklrq17lsKsD7urwKsup1woK08ri
Pk8qJaAvgZrUhiiklLj/83alcmXp15JBAN+ghZYTTSk+TJw+zQrvJazLly/r
OEsMpa3Mil7YQqBlUmqao8Vz6kpkqzLQeaqrpQUi9euNzjTRqywZNG1XX4x2
ocLkqpIF6fx0i1I3zYv8RWxLvLmwmuXTTfmbOBobwrygddCIq1g9NeBwJlNv
NsGqDCrVUq9kvPlO9y5cuNCLQWYHmXAuFhtd5dXHLvyE4WDi5rPb1Ql//Cfi
QneBxaWiekkEnNbTkv+XxQU+zJ15pGNVPDzUvjIB3o7WwLrkjuo+nSp8gzot
/VSqOhCQBgKUUP3TQ/EI+g/DP9wuUwDPiQOB8AETwhhVFLnu+pZzYFx+WWMt
8QFvC5z/zlaVngRRt74UQd5DwOkPccATGr1slEcIV6vFUDw4I8xG4Rvasbca
B2aQd2xPqBzgeiGzOlMVq2K3dSFEOGMmTOgPCQ4aVCiFN1CVQbALMoAbBW4e
liQQ35AGzphWE1Cz1ghWC69AprHQ9jztqqUuGAUTo2TloITD6KVCkPccwnhr
Na8gUVUhQAafeuirAXox59PbRbdJpNofHmY0PIxeqqWxJ+Q7CXNOtuIO4DAF
mEkiMBmzdrKV9khq/iIcyW6qSwUNwCumyYgxmDhZPrdk0X4IHWvGNUfaICIg
/9aycjDxDZ5Io+opebpn9LFpDA6UqmBipQjyK1vkfvTSwxQbYshEkRnqzZzs
LDdrrCsy6TPNNxA4gOC2eQGy5wg0LrlXL8B9fufKVZQmSzOYjHXCLhqFCsyE
lS7Ib9+DWI2+Fo40OtwQSEMKpW/6a6wX2wUfnIE59QBK47S9UiwA4kzTvyeA
/C+eCjt3HVzTpB+fSWl++ms9J3O8JId/n5oIaxL4FcNfCvz4TD75/7llzuwg
0DS40bX+2j0xVUvi3IF2Sd3Pdp8u65OTMzURdg9vNNAAPPuw4ra77itpkxV/
FcHabEfRils1Lyqzu4JaiT0Xz7NonMvkcwXXc/a2DfAp3nEWz3WgXVmEgbMb
6EZ8WGk/K9+117mlB87VrnPn1I7Ju5ZnSTu35dkuJ4se7lBaG5zVybMiOMu3
s9p1Fo0bKcCN5LsT5bnyPfvwXJ05y5kb0Xsj5VlFNkiepehces+Vy/tQcSO2
nxX6DNR1VkCn28t5xazZgWJwzvJ/KLpR6ZBfRUDnMnO9bjQvdo1X0nZM+KW4
nZyZTf/U66bXXUJFaXWxi8iqML428GLzna2uaK49f73tEGvlU5lEL40VaC6Z
7fG2H1i5cw99p1i2zqrTDgdvYr7FSuSYk/F0s/YVYQ9m1eF7eHW72jo+2SqW
egduHa8Y9HoUsPL0HlYxvArguldj/WRLeum9vWiyaspUKBPyuKFXyWD9Wt1t
v4Lg82GXKvP4cBCxOtTh6QacKCpB1uAJwizooVH7X2xXDIyxfirVQ2hUcLxS
3TO6BoQVQ/ykwSpKvUpGvQo6OFGUP0LfmDP05jaqlnrVvUv84mVmFasR20mr
eH0t59e2Vb3xev7X2wUH4vYc5HxPySK+xf9SHM8H5smWEFVf7UvlF43riMm6
KL+Ky7+zXRqAU4bwitrnuNFFM12mey1XscIN8uv3Y/mKzYXqjzfiqqVegRL0
fD8eL4dUPcdttM/DZNFuwKjuqhIVTwdTF/deIz00HMQq474KmrJVNp0pxnOY
A+VveK6khSqqk294mozNJvB9mxRdspLZFIMYNNJ2V7nfm25RlA7vktuMIulC
n32A/HQpH9lGCpyBGoQhmT2plHwTebpAI6dYOfmTi1EI2v3KGUzIke2nKnhq
oGWJ4ndb+gZt+ifBlHNlcvAzDuuk0z6Rea47/ONV8p3E3eD7d9DTvUzskPG8
Yme6l/f+/92uDjCcu+iAg7SUR19yAX9QuvWPLt/0dRDffGt/85vfxGdgfQV/
5StfWRsQt7HYn0cffZTelk729ttvL5ViRaJ9qvuK192/tKvNLjM0Xyc977Wk
+XgWBw+ffvppX/r33XdfCQPbRPrEJz4BmWeffdbfT3/604888kj5Zj1v96lt
cApTtl7K9vWvfx0+lUof+L76Mfny5cv5v/J1mraPP/543ZlWz41oVvaZz+Bg
iBHhjF4t9f3GN75R5mTIIO3ll19eM1iebkV4IaaBN8BqlP/e7/0e5ZxC3phj
aHMEHKz+yEc+MuWAc8aVVbsMhI899phebfu3YXj33XcDBTFot1G/xtTQ+Y99
7GOlRSoj8bqjDn51MUy0BA29StMipwMV5cd+Zct46R4T4I+fFy9e9C8cdPRT
m43QW9fZfA1mH7BGr+jw/Mrs0IS26fATnxEFW8A7YkE67Yq7+Z3f+R2oIo3K
vf7668gZPQH8oYceevDBB2mIXzEZo/IEQQmv/FoF4XxSYBoLP+ktNfBT+1Gt
xX5Fgoc5a9gcygam6dCKHIEs5C6lcDm9oUpe7RIjRC9TyUMsqngrnpOgX42I
PyWUppwgP/fcc8wakeEqbNspJZT7778fYo1idHzI7Vv2SzR6CD4OYBrELly4
0I7u4EZjc/qYudBrM5MmYFfZm8cqEofRQa4GbtMWaSTiBhwtDc3aEyV627p8
9dVXATFH4IN2vfxK7nmRIG9EEgEhueDM+KZzYRCH520C4/bI93RLLX7PPffk
scprrzvkUYQ/OStxWK+hgmohDShzyhSGJDWADw5funSJUHrPofbEQeHLMz/H
A1q1YcuIrdbJ6wHqSApvAceHMbkWQdBgBQ1ammmqHLaJmekziagfhlSPPjtg
+qAdjXDDHIyaBR1MrPOcWPVFqUHLTI4JdIDpMw1RhJxe2Na30Mk3Dm18IyBo
wJCegADg3ubeYtdNXwdpCBFTztzf7XufzS9Khcpw6y9WE3dVVzCcxvo3zS9b
L6mVyHeFUCGeczMfmh31NTt8abopgXY+LH8ptid33nlnY0GYPjMjBmJUO5La
mRM32ud7Gvj5YqotVZpfqlJxcPbH9Mnv3KFBDxlb3VsozSMThI4Zq/L0kGTZ
mDVo4MZKJob4iTKXt79t/3w9nTuyklJveGYzq3Q/3aH0ie3y1pffDXzUAehf
c7yMyoCjOrfOuj8MJYbOrCFK1qAiPvOrluwhc8estSC6xygYenlgyqwXundi
DbbuOyKCIXDGtzx95WQ2tCHWiDyso5YkBSaG67WOPldHoDMRLjjgqr5laM80
Qa/c1AEc62QUDeBWum9s0RJ/PPQvrNyTjodWSWCzP2YKmNnwfNwa0NL8dyX3
nrL12mO1vh2zWZ136wVzK0geulS3POHYctdddyEHAnn68vxSG4RUoR7aJOUv
PsAtWZQf3v2HPvSh9fuoo2IdAKOoYFYyCd+ATU8YakJcbXi51rOoEADW6Fq6
waixn9aCXIeGpgOAQANM3U2HnBc5kvJn5dnMZQkONKCEikpQ5etPPTrzRi65
9mZlt3gZrpNX6SFQ6wwyNQydkzFfmKuH1XYHvDIuc3rQEoA/xFfVCdOnwmQw
pw/WGnj2AUum3vdK3q4Bwwu4aQVy5e1WHpoFpv+3tisnu2b9RO2N5QkmMFNV
q0csVpjOJJsm0CVzqpcBgjOzUKFLaYhYM/o2w/UaXDUQvyIHD+GW37wj5aSD
mdW7MWJFNOaqCkDNEIgnZIEJmLwamVvzuunrYPtCrnbbjpf60bvLT+2KnG76
3GvJdBk4PexmN9D7fJ7Xpa3mgTMj+vXHh2LoPZxx56adpbX7ivl61XLoPbf7
oORiz82FVvBpGZzdQOcif5YzU+48kncsWtHo324G/g7mSuavgtsq6NDoZieC
eTgNzlJxVoKrXG7kNRgOz0CrKIdvQ85OCadZDeZ+4Azbg7nitvL/XJVb+fY+
jo+Vw4NGBoqWMlBnubFiuHZfFbjogPUtdFWJQXidL+fO2ZWxI+h1/q6ErFq6
G2hH5q7lqpA7irQcJ9ROE86q3FkdPjkcVxg4Z+fs9Fony67lWe/YqMS0XBF+
f31eWTddhhurlHc8HHtVywTNpOxkscp3boYhw+rTbelfP6J3otyhcVbot+B1
09dB5r1da0xuy/poc7jgc9vy3oK8SiVQzdrb9PZSuMrRVrMgh0txfImgh6fb
e45eObzYBw9X54sn4DMdhNVBaN1rtgs6uL55K/KIAdWv4+9rJ3y8V3XXxZNc
HpWLbWvLB1rV94KTPg+odcT8UC4YeqtMIX++XbvJW8ier8gIhMOKZ2Vwd/ZN
S0PHz6E9xxYIx5vnyLi7InqlGMrzqGWLaWSujF1H93bd8eN5mAQrrld5uEE4
vwbasai5Ni2z817UtcTM3FI5W3OTrXiGUgTmBwlyA/XwePM/jrDmxk84mbAM
1HclMvOquEkTdq8QI+tUOrG6LxZ1WuZ5jPlpb2ozKAHiu8NreaL0VzNSYLh2
HI4J4BROO1Mj1+SQhuSmWNOkm+vbq51RdmtEAmoOpkj+ElBdhqv5x/Oytem3
064QhthMh6ODq0v3XFo7HqZyI4tMgTY9NGt85tQlz6P764dMrdnwfKOnh9Ih
P15qSEHVFBhnopajCWkpxKjWzn1Zy4Q+c8SFZCq9egnzqieCGJ5JieqYMCoX
k68vvrmmv2Z6FcY4KofPq8oNnqMzO87HW3/BaY6sQh92jSWZow4tWFjk8/zc
QioBb0c0OFmkxlp3wAb48baFm+06C/DWuW7uOni8FY2FQJVwC8LyGc7SPvDA
AzQNb++///4ciFXBeP7559966632WO69997Pf/7znj/33HPmBRNdWV6gXn31
1WeffdbneSeTga1krWudHRpUVbbdm3Z73nzzzWeeeQYO6yaqh77xP/nJT8IE
nk8//TSAH//4xzv8zNbp7jngGnzsYx8D0MyFnodVAdOFGT/e9tY8p3tt9SBK
r9///d/X68tf/vLYJavAf/pP/wkTchTCrSpveAXUWiAYyY8//nhZKFFtFJAp
s6EHE0iuun20xazhGErzTqKl49/5sDDQiPfcc89aMc1Ueuihh4CCMJa2KVev
1157bfUVVr7WcwibldAzy7797W+H0iuvvALP6iN4DyFiSKIC8z03oi44QwSm
Ui1feOGFttABYUmMDo1iyd23vTmjV5AOqgYy4gSmYTLSCplEOPzN3yeeeAKS
WPTyyy/Dsxrujz32GENKWJDRC/I6ak8HDOTXIqpmRAjT5CrqgmwsEv/hD38I
4bx40xK72rIzEPQKCLUeDUok/uEPf9gocCuExz1tIfT1nQQTimnFBNT51VhW
ijTBPfQKDcPGJ598EpOLUPO3sFNC1H39lCsUnXIW8aoBJbHCmmhlh8NMhAP+
+nblB/cvzNdNNjCR/OCDD1ZnHBo4jJz0CuRHH30UD+EMn+liIpNje7wQ86+x
qnQMgrHuuOOOqaFJ6BZZVNCxPBGA5xxHOJGVl3VQYt5xuFhOCFMJLYsGRRQW
JX1mZH0xgB5saSwy88ubVpijsbnZanW6mX0PjVjF6krZGgUCVXV0b/T+xRMj
kv54LdGe15hoes/UDEwcKygVVma9GeGmgxBEYzXUBW5r6WRgO2DgJYTRyPPS
pjE26oWfqCCO9ngJgmThY5ZV/5cIbr/9dgrZq+POZQmOxtAgO5jA0wQxHO0i
gpXbsAUcsSCj7mxyzlvquunroPmCY/6SAqHTGfPLKwTemg4YTqnIFM8J9MUX
XyxUjQKQF5l+YbuyADmUcwBVbZnNqRnIYJILIOsrqMaFFH33u981YjG5rHFu
nRXVzpzkwSRZwHXJ5ujFjJsv/n1juzTofE5b969s1cwLICo6RoNiwOFMb/2K
CRcvXjT0Oqif8vsYujW9gaCxhj9bnnL3sMYmoJlodpiwHZ9gFtginOkM3vQq
hBzOxTQZAkro0gVLYYIhBA3DmQteDLSszHHxkuUdArxTSQPcPIpLgGtgFsfk
UMJk3Cjph5UOkJZRnNHFC4B5NHGjOONXQi8cTGM8RIsba6LFnYFaT1+cbl4e
o9x2223me+c0zNZXtlq9hUeRWgdLQIA8i2qO40DSZB5z/HnY207xfYWbAd7L
GPJHlyDf0SBLEjidYUBd8XTrEQikwRycbE5uVpwPJdzWawydn0iWcWMeW03W
T8KUtjBbepL1S0uh4R4O5b0pv0GH0OBJHBhYeOyPtxKxAcy5Y67R4RzZGlAq
07PMSxcuXCj1QQwhzbLZkCZmDm5Hm3OzF5WcfVVthlhhcSZFgfxz0Ov65rkr
Rq9EN+7xjb4VUWvKm7/FveaGq1ZscswDjtu9fpSsYA3yLWlGPlDjxvbiT00W
EoGqLjg8b78nWwhhJ7I8rxZw1a+gAZmpF+8CwZNOf3V+AJ7mO+A5ajNueI46
Gru+jXdOD5dyZaLaoF7M3EQ1LuVIhUB1vekwlfi/tmvNDJCrlwllUvSlIZBJ
K8DRi1D8C1sqil1eLUgwL161g+HAJoBpLM3WSQ0mZfYr+ODQB0OgqJMGeDWK
RC5gMrweVjQcYjel6uuveN30fdF2h+bylptBc99Z3za32wfwaze17Kd52Ann
NrF7CA5jQhthy1KZYrvv/br3dd/+QHAaem3ZiOPE6Z5elY5mukdF3deH3bfz
4CYyhzQPaY7pvBYgGPR2TIjM3abcIK9ZA60tB+EVeJjseDj38XDHh3WgEVYj
nt33WEe/EUrjPmsnNs639dRA7XLXcn0YJoCQL8uzC+f0nDFkBGozIx5tx8gb
KJgjrNPDjmXCGkxGWDEk7RqlPcuZhhixxsMdcxq0lsOEHUorGsPknRdplGqm
Ty3Dc+CsCI98w3CHWwDb519HrJe5U/7D6wfH7qrnOys3v64cHqGv+Kyj7+by
inkAexhuozPj2BqEa7kjbZXLqpDDhGvbtfM4hNKINZzbLp45qIuFw/xti3uQ
X72WQ/vIZZ3m3sc6ZTqKNKIctAdUeM50OFclhjMrvTub4wXV8tRYq+XsifeW
+WLdCehcJT/XUKym7/QWvm76OpgHJM9+6ftyTNOodMmv7Uhrk9cmxu4cUhrk
HcN58p2i9kVvnWz1wXfBiYm1DXyj+3ybddCLYsKl3uOlglsNZnu/fftVxDkF
2uof4MdbTGIv3oUg1cWNt7vQyFN2tLmw20NoM3/1GAa/sxAFdo321tJNEVt1
H4fFWbbne83XE87ZltBeBy1ULY9kXpJahnAejeDs4OcHCY3sQ91jrPZxxnuv
d4moIIJMQS6kcbEh6qxffhhiyWtK5ijcHUs4i1s0Dm6xaJjg36mIVETVeDbH
AVeN+FVLLcd5Q3qlyYAMFbnSdqLM4xwcA/lUWd+CRtvp7fjFRtArHBAKoU2R
hooO6ueuiv+G6wN8NwVG90yc8n4M344OIZB1n2m1UtEUG0E3VQsJXPk2bG9S
J6nOUraYGnrmWp61kek64rA95IeHOejzbOaS62EDjcU4d15MEGUZcesyij1W
aDRzx4Q86SZmoS7riEm5vH9D2i9dFCBTdmUzggkaFo01m5bR28MxRy3Tg8no
yTgEaxk38LxZ7Asx+Y7OHB8iheGfqz0mlMIx7ZrRh7FpVMbkLGk9T21W05Eo
b5Yb8eaug7jnY/+pp57ypV/RmU9+8pNYBLgvbp/VnvgMb//QK9N9993HLuG2
D/ZPfOITr7322oAyofzqiZs2ylyYXGbRjovr0gGVuuC5Xxl5H/tU7gMf+IBR
SIdNe/rpp1mh9mra96YtqC6K9nOf+xyYrJMnEC4iL5iUFj8fffTR3//93y9t
kQZZ8oLjPv/5zz/55JMF2JZQ7voWJFUmQ/Qi86WXXoJkx5jRsn7sWCLvvffe
F154wUClISr108c//nHImMX08zOf+Yzu4OgOZiY0uzFwMAoJjz32WDtR6A1m
uUM71lJLKD300EMlKC7sgrDcY5q+r7zyir4NtB4b+OM//mPcfvPNN3GPBLUB
8ytf+cozzzxDdp5rAE/iMMfBNAVw+IMf/KBPbJwnelztTD4ZPfjgg6+++uq5
KkRYDz/8cGFW0IDbmryOYX92u9YpWdamvDCYlvenwMwvfvGLZiUMO6POLMCE
gCDczhueg9au19/93d+hWgM3cHjxxRdJqkA2ykxPkIDPpUjFWLjNCzZr8Ad/
8AdFp2LCAw88oMH8ml/y/vvvL1V1/C+ROAbCec4kEBNU77777rKmF4YGk9df
fx1KutA9AiXoCj/lYxpWIO1T21WeW8zPM1V+NheYxKdX8R1U1+vc+h1UEApU
i3JN0JS54AUE6uKh0dsx7jQXhS8fZqlHi44svy6B5qjCH0IhUwxcZaqxBvkB
cRgChfOQWludHgLl1zlRgDlFdGILPSmoZ/Y/j7YwyTZvoWf+Ri/EaJ3uuhAT
LS3fIMUujnKEBVvGx4i4l3eykEPIwyq3BeDXtvgsaLz11lunh62wc7Uau7Jg
JnhuvjxxOExdV1e4xTdzlzu4oCpGpuMEOs5nGuHiOeoQiwpMQBG7d9ddd2E7
VQcZeqTW7jEgRIaTePhbv/Vb5EumAELJuq87OWJXee3YEMO1p8rywAHzdymg
u+gkbnS0AB/KdpvnMZmey5B/6eumfw9i9aVLl0q9SN8IqKMmNI31K4+lv/jP
sJAyKXTqw7Wug6ZkvgPTHIdNZEiaaLSOaLA91SKjq+/NP1m2W8ABNE3KZt92
N7OW497cLIctXSpQlOzY2AwvVRkzW/yyh1TCc8rATnqpK/aq8g3l8wSnTNcF
/RXObPaVgtiKBtu8devuhOdaZkwMkbOGxkJe46oVFO0FOLAa9DoKzvoWiiGe
5J/KLMAESp38Wb84SueIUWxCPhcKA2ZuWWgUtA6NNSa3YHbYznLMFhFQ62ze
pSIZ3bMYpG/CaqZjR00ANwRGGVRLsj73w7Y4rCLmctxMmJX22V6WZAxp5zHA
tOwiKu9hulE8e+9g2pjsvdXAB/Di/ZkjACFZhHIJwzUoD6qXNKoCoMYUScsC
sZmIzMh4ha5u2Uf9WshqBK4vEnQPGtQGOQC6yay1Zq2vRvAkffMCEzqnARMq
l9Q6qIDDHpbfwBwZdcWi8jkjn4ZHXZ4pME1ANIJJW8BnctFC9wZP3SPwt3/7
tz0vcyYm5C4EAZzcxFhUBCjMMYFmssm4Cj41ZhvxrdzOZayFZP64UmSs5hGZ
YF6+fNnQuIHzJh1Bt/oTHzT86/Wvg1jwLwNAgjMvesVaXSS0CLvgzDK/tF3o
LWa/Ewu65NP3t6NE6zoILIqqleynXgagMTmHqRYeorE1FF29YyP8rEqfbksk
duFMb1NYaly49Vaw5uhoesIQozJHECj0tWM/07IUx3TYXxiWsRYTWu866VeC
39z3HcnQBjcuXrxYOuISh9IEalNaj4IK3SAHdVoyIy3Hu42LUdfMXXVzKElJ
ADrmtC7x/5rXTf8exH+z1UdBOwl9obcD3150f1u82o6b0IazLrz2RVevUDsk
7RoFc7f/38O204PZTZv5de/htJyHfd2vC+t4VXrZq0vb7+0DhEabNu0r+usF
gAZGWg/bJzyLcCOOHyHSBqUJBGhPqRH1YhV3WZuuLddsh2pDOdd379PFjdg1
KDXEoHT1vanAgtkeSyjNbuo8rEF41j0JtuHcw9lDu9FW0uzQJved52VEsLpT
G7qNpu6jcd1NmoehMVJrZywkR0CjCaO6dW9bLxqvnXE6t4+0iu+soycWxf+4
cbblcHsQbpR5ONvXIbl294Q1866ythz+rxNwVd11dM2orsV6J+jxkQ3Mle3j
NYiiOLPOtVGDa2ecmKnESHxk0cOVRfPw5BDNNMB36rqiNFo09mS4kdqfq+21
XFWiltmB2L7O09P3/R6MmcPAsWbDw1WLZnrOTBz33Kr2o0iD0krR/DoDZY7a
GG/QeDhTYMdtLx40gT233DMj73NA9NriOx52Bfz4JkUa3vTvwSZIsh79x6XJ
JZg7KZGNlGuZx2R0jCB8W/VkUiZmAUYJ43nxVuP2PetSn7k5ilezVOtvtquJ
NkUuxoaHiU+Jd95bZWk2+c8ak5JeWq2OtlyX3szTw2ps1WCXq9Ao1cIrhkhL
qxiYPkO0BJ82linx3M+o9YKYta+4vHWZO/umUWiSn366lXdcF6+d39+nR96N
GBi9WX5PDFeNoTGeLY5IaBVu9s0C1IyrBuXOCHioZawb5MvHuJrc0232te7s
yCeaVAhFLVvr4njlcOBqt2L20F9kouVoS3cwlmHe3AZP7IWqv+9uYYw7HDws
b/m8AY4p270I+beMH6t5rGUdS+yZu2eYEPLdXD2Elw5MkwUJ60tUPiCrG4Sz
rnOIoiuv0KyeVw4htKPkFKBXr+k+K92NFDJF2r31QaOUwinP+hK1c5MZsdR5
OOAD8PiQEL6Ws36NyuX82pE27x6zWnXhZ+GW2YFZDuZlY1qu03/e21OPuqOo
ST2KlMYSwckhwWyzKbnciIdj0M5l5hixlZnFgZbhdqTG0vrenKX/yuEk0mjC
+nI1oHKdT4junP/ZLdN+ZYLMETdZpCIrqXoVsqqPuXtL/9e/bvo6SHsfe+wx
3/Xf+c53nnrqKZ/GL774YmW83n77bXx+/vnny9HU1ofP+R/+8Ifa+zB/bbva
uiTiApTI0dtIDhHAfYB//etfL+uR+w6Kl3aM4Hz4v/zyy5/61KfWtxd6YlAt
AcQco2tj6PLmVUI0Zx8FMKKB6FKOg1I16vLhD394zdP4mc98BsKeeP3O07Sm
BqXwqCsp3O/93u+98MILRbHlXkEFDC9cuFAkfkY+QwelYi7eeOONJ554AuZG
+eIXv4hk1gBzOrF//L5ZekpLqOXXvva1WEQWbRL66cpSJq9CPxQ4N0qlXsq2
Si6z7pPaW2+99fDDD1dOEQlgVpKpMnAGevTRRw1Ki3THENIxKfwK5yoJ6ogP
aNcs1ycZPffcc2tQJ5QefPDBV155hbgxkCZghYHKqNku8ce2C5eMm095tZ/Y
SBD4aRm6dOlSYXePP/542e3ahKzETzEyGNupe/pQISoce/bZZ3H7ox/9KAGV
YRJDVvmWYOpHWwVn+BcCuUqBuO+44w5cxbHqHH33u9+ldUV8rNas6ELt33zz
TT9pTJ8rOfQnf/InIGBI8B944AHolbWMCAqlCfjqHTjeqvkQJVaU3s09UT7z
zDMoqrRN3jrvfvl9SgNYelXs0p7ulYcwVpML/hganPJ5FrPg1xyULSK771/i
+w//4T+sAQX0Ob85vlGhivRB3nCGXrN1VVbJX4pH/Sgng9w8zYtdclfIB7MM
fhb6AnlMwMuXL5O4OVWEgkHXIm5A3XXXXeAUdldit8oXGnRebDAzCd52220m
L72FNp3BnN/6rd+CA7lUwe14q+EIPffNF2AJBbaEhYcYAjJ26UItE0ExNVgK
n4KAQJjPz1WjWInf/M3fxId58TvaCmMV1VXQFjaWG9wTEw3wyoCye8inw+BX
nK7QoQFOz++//35DQ8OvuaSLn0L1uqEEt7jEPhuloBI6U0AQmNXYulluwblu
+jroheeRRx6xMAFoHcRbBo1QKhro18KoqQpu5/Wm/5ka06qY30IOPa9aIuHm
W6HJgGhJCiwtndcd8/PWUc7i9ElnXSbKLM2MkymbUwZg4jPxKY+JQAOr3ekN
p2ULqJA30SobZx1fs0wXrUMlissrSHx+Lc+zCQIfP1FXL07V3so/aBbce++9
pZepVC7SzOWKt9JtfDAoLtGugoPMKRwr17T5vpaKW6+rWzh/cd9GycVjaPxx
g5zVYhNTMW4YWPxXJxl6V9m5t1CE1YwzXsGKAc8//ifbpS/qPCwvcW53aBTG
WN4D7GIAKUBFTkuqCYd5/TbHsZ04rIMF/mfk8zqhAv6tiU1Yo+yyGV/dinow
GgWslQjaklQd1d4KiN4961TYIMytQWCSYJ4mDISzhdLzfHDwx5kZpcTRjAxb
YcT2IVcpAIUQC2svUTG5ZX0XEoJXzFfHj/NpgpbrDQOpSv4ss6mUmLgHk0SA
IboUgLlygP6XToGKVkSVguXlbNWgmVUAzKpDqQqzYQgHU8MoxA0NUsME6tG5
r7iHJ+VOh1vOO/e7KCGTtINq86QgOC09x5+iR4mg3KqrL4nCI7ysFAiBD0YV
4JYDXUesIDswe8er4iG2eGHQxftDeaWQ+ZGPfGT1wZ1uAfXYosF6hsS8K9P1
NDPFyAJbQDMuPCssbpJ6AibCM0R6AVJKENajMNWq2CONPliayaX3ihFBk0jj
gn/L7k6XEEtzdh/IsG09nYfkgnbMbIolNaPDE5Ie9qJLRuW57bzQ72zXmuq2
EtU0QRc4sBs5ea0LHd6elvSnMt90psQIeuFGWZrTWBy70Vftv9p109fBjs7O
RlDHetu7aBtkDmO34TBnsNu17ij+bHsOqHcO0RbtJJwe3Aqdlq+lgSrAejao
sIGoDbOpzdFW8456mLkzUDsJndZu43T3cLfX2qHiTn3vqgJ1FH+O5XdTl17n
Qn63/VKSq4mbaLi1+9Ulrnnn0VgRK0XSej4839YuMmWoaL+lfZW24M4e5o8J
c7K6A+RzTLrNpXcPBWLauL5+SNvVDvkcWY+ZjbgbKOCzmTPn4bt/93A8OwGF
xlmPTJnNcuWAQ9wldtbyze0alav77J4NzAhJZ8YrtFvpEnE7aUzcbm8w0q4e
YjGSdZjvEG6gVckba1oGqp29cR8M8sONHQ8bfbqMLJJaZ+yT6eAWH4bwq4eQ
opiQkrfVNt1j1Gx3/9Id+6ND3rm2Fofw6N29113ZDt7H4bEJo3t1yYk2VKRm
IV+Xlg8zfcf2Wr57SMU2Z7DPBkGs039kMd1HrONnadARwWooeth8mTCH4eE6
Hd5ngu+uq4f43CH8XNzGrsauX7y3usSESAwThsYr5wUHxa604ngL/p0d3aTw
q2D+L3rd9HXw5EyA+TDKq9G6NTFO85NDDHX3VqvyTa2b23OuYLrPSY91G/zk
EEI4aFw7xGFdfW+AahK/vkQNj6vi6EyUtJc9b5V+sm5W8PdoiWQfKlDnLevd
86Js1ktjr1W6FyZ29RCdmn/w+JA+d7x1Q9rYnJUJvXNeO6SIPDmE5e5a0lgv
85ULbKDmrDfMHqLRm+SVM+GNA3ME1JTfMXP8+CPW40Nw/ckW7IkzTRA8pGwn
h+DoWnqNrCzC6t4d8a3nK64eItZ/uS6euTDBB3WO12HXaMJKTm6skuKOU+/6
IQ4aEOy6tkSI153etok0juzRrhR7yg3PQB72hjYnOk4OuW1H6NcO55fOKmdO
Z8hcf28Ciq61ZQ125xaOtgi7ulOkcbxmRY8PUedzxOX6IfvBtfdGxx9vUZbv
HuLsri75K3YID7ePtwBhnxvrW+vVLTHm9S0LaPj0BniW8LMDjcEZDRlm0r0+
S2c2raByb+U5nZM/Y7v8NS+OljQIR+9NmDCXgVgJ/Lz+3mweO1mcbJGbvZzQ
MUw4OuTh3+EWi1xwm3Mv6wRfZ9D0ArxzdL/YyjXCpxc5D9dQ07hRVOPRVjMR
E3JA6+ITb0fdcHs400NWZbfFcStcN30d7Jx5fq4SRfpC//a3v/3CCy/ce++9
69ZHSYra7/r85z/vRrMiBN966y28zcnVLiUMX3vttakgQwptHoLvw/yZZ54x
1le/+lVzp4iegjJ8uX/ve9/rlPJaWuV02xiplhnb9fTTT3/5y1+u4NcnPvEJ
jdcdHoK+5557DERJKhRl9NIMwtCE9dNTTz2lGcVrV+T0fcth6JI35Pnnn2fE
nnvuuaqJhTwgr776KvtQCBgWFVRVJkk4r0kpTfA777wTlwpGa2cGY5GAPyu9
47KEJzhakkt+FsizhJcuXXrwwQfXg9lsAshtXZaQCsw///M/J4vdPqHuTzzx
RAezgTU6oZS0MLmgzsNCOEtp9c4WhPXYY49VGgYaL7/88skWLNN2WfnKQMDP
t99+m1zA/MEPfgANo4DZqc4bfYOY+GV+Xhsgp7PiABYmSSHxvICU2cEjAkhe
vnzZKO2matneLEF01PyRRx7B8Hbs3eQqohVFMRTvoGUZBUH4f7YLyatQ2J9H
H320KnjVlmoWpBIIh0Y19Ui/mAUDjdFzo+/dd9/9rW9962tf+xrc8nfPbJq1
AxNoxa5ynKmqWXk7KVWea7SXrtOsgQ+YRV8ih8TBNFvL8VuNJ30rkp7P1+il
VSwMtuxe83LFbIKGpfhDt6kczo8+I4fyFLfy4x//+OGHH8bYyo9qFpKDvOcF
W8G5oNfCXnJe41WxtNhCHNCAJPUDBCjthzOmAyYYFLZlztS4OlYl+MX5aoma
npD3sF30ssMNPte3FKwXLlygUYSCXaU+zvmIaSM1+JRzD7swxwQv9V9+eTgP
bkdbLUuMTQ/Bx5Cy1AJLHEXQJKzBhIweeOABHKY/5iD4HdrBz2Kfr2zlD9x4
ZyP9u+66CzM1Lv7LoMSNe2u5z5IlwqTzAyhCI+AemghwO3cO3sTrpq+DDDLZ
sagFc5Vvs6p/pvxa35PFtjLSARagnNiVMs/dVmQ3Dud+1ZcNXG0aMXlI3ywl
jHChaqUSZRk8ZN49IW5TslzTs7qB0278xYsXtQTnm9/85pVDomOgVodLBWE7
5MMCa4NXRZXSMc/zpzBQFLuKYOa7KaDNuZsbJ1vWpnJOpswMAjSwDs5umKzq
sVJI0uw4SnkdzZTVbR3t5YAqDIp+QkDLvrmmZRVpIclulJ+c8pfoFcmYWRDl
WuPPQB4y0eWxpP/eQyi/OYJF6zporNtvvx0oaOO5icmAmDL6Fq1W0Vh0lcvL
vYFI1oidRGKagt+LU+dw8uoC2HJgFPzsPAABvbslYF9n63p1wpblHPvDUsXJ
4s5Yzg5p5JyidbNCnWzlFXAeiyAD27I4klQ5IUuAiV43tIhoOpnAQKGoaKzO
eDDpqGBmsYuYgFodLmyOlgCWQjzNr/ylm1JAE2U1dktt2pGMuneKg/oxYsW/
V3dVy10ZPiOWVZ7sRifL4l56B8sBJYdk8XrlpY9eD8ml4owIpEKlMqAJz2wX
3PQqUz3kqxtoYvZCi9tzepBQoGG+5ztrhq77J1ROg3zHeWBLzumCwCprnM8t
iMM0h0oUO+8vrQDkAx/4QG/RRu88FZV7/PHHoceqzAeaFQRk+OADda12qoeA
g1bhqkqRmmv6si0YgpPkqP0wE4dNvRJQs3WkWaZQfyv8t07/0jgUp98ZHiTn
sCbEwc0NAlFBMwGspna6Rz3yXJf0e5yJvfDghjYwpEjlhaAenuRchgyeUA8W
T0eCK/MtMst1Uw2C9cwnlcaQjli4wZP0tmra5Wo4dxrerOumr4PtabQXnRuo
rfVORa7rAgXu4Mf1Q/WQdjj/cbvanKl6iF5Td6kL280j3XPN1LJ9g0bvnae6
Kt3v/BfBnJZ9OAzyu73HXp/aG69uS/6Udvv/53a1zz/VZ47emwRpd40/JXrn
uDIq2pkJZlsllQfqZOlZR+SUqfr5VtHm+FAnaLcEByfS8i61JThCyXmxO/KX
XPIyBDN/SnKZlqYM+2xZzzMyLUcuM3qyThy5JDo3HmOvHoIHd4wdmMRtJvbR
enKmiPYvvUCLmcOuttzj4e5YwuhMtNey7uH5zpJyahAOz/b32rCKilpWcGoG
isOzD1nLkUsq9/NDYZ1fHMo/rRQNZ1Ld0dK1DNDacuXYkJYU0sPcf3Ufek8O
9YwSVpxpxJliE9syjH13yXc3aARz131VuZIcXj1krpuWO+W8eqjedXyoGZQH
s0EZB28Cbe4l3xXPnUs6gzPzN3/oTOSkFhVWFgu3d7As28+XOlPDzDZOp7LY
ubK4figkFz/HvXgWt3bITxe7OvReOySpy7M/vTJoqUooJYX8IO++t5zZZDss
RqbN3rPT4XgroZVVz++ZqjTQTT8Vc/a6FdbBlrOTQznL2VqfbXBms6+VeXh8
yCJ7ckife/bhdL+2FNO89t6ikJ5Qfi+3KxptoF07pJO9dqjKOgO9z0XuPg36
O8OdbGF9kXD9UBDz9ODxzKNx7UxQ7bWtrpxX9+P31hi9fl7xUAY/x0HXAD8+
XEc3KM7bdbyUHz09uCSyljBvuTwroOvvLRI6DSBTpqyVnGyLn+ZY0fQ9OlR0
Xb17LfRFHgX82lKQ9+xBcdZG45YJN95+cyN6Ne3txYu3z4fdwn3tvUV+d7q3
tuzX0Y0d8lDNETwtRyHHDW3dX9/N1mu6zHCVOi3ecDiz2tLpgqs+PbItg9uA
6smqwyeHOJquVYvOYp5BOzpzuGg3rY6WKrSrmvkX/89Gh41yrio0eJ5tGe1A
FWS3Q2O1Aw3d/fWlXvPAmS7nPhx6Z1auLLq+hR5PwOCOXWPErh9K0M5W/Ax0
fF4x4lXzxxzNr+nzTJCxdSzMLNyr/VztyRi9cZvmjpkRVwbOMaRz1X5VieND
6efVoob8z372M/+6GQU4Wmpe7wzXrXPd9HwyX//61319f+5zn/OJ/elPf9q3
/He+85033njDB35VXTzxZd2B7Tnw/Id/+Ic+KNp1KUOdN7ovfOELHSP/3ve+
18YIu6fll7aLFQLk9ddfH6fh6bbLcccdd4Cjy2c/+1nvhG+//fZbb71VjrWi
w8qxVoEzcEas51LEGELmG9/4RqXZoPGZz3zGFK5MG9146aWXfJ6AbFKjJcdc
uzqry8n1rW9967bbbvM+CSX8ye1SPrQ333zz3SU1FgUu2VRhF8WJlJ/w1Vdf
/eZ2GZdyFvn11a9+lZlFGu5997vfRZexMGpgMgW0AltodV4V3dlbNy+//DJ8
ML+967wb+AMyzhPBk08+iaKcNVOYBpKvvPJKh7G1x5NSdCbB6tEk8S9/+cva
PPXUU1VOvPfee4v/MlyCRkV7jGtB7d40MNDQ7RIbq0AAfWFbObaHHnpofb/F
LkO3EaevZsgh909s13oe3nqErtKplVG20lTwr9BPB9p7dWlfjib4q3GuVX/v
uusuC9ZZ5WFk7rvvvnvuuWc+yd202WuUSuHAjf6T/uOPP05p2Ss0tlvIrD3/
/PPdGIUarNm68ue2o4gzJggCC/rDUlKbljAnAmOZX0V0ki+EL168SL6rZuJM
zikowbASfgb96nZVYKv6XEdbTRZcWunFbXIBAfCGgHae5XbPpuWPfvSj8hOW
wqvAyeEeOJP+Cy05cw0KSEEWJJITvPyiUMUEDYraawvaVW1ToMwypN1///20
qDDP0gDO9wt9e/TRRyvQhq78DojV5sXtsmDBAWnM4yQBNhkrgdrePpjZhGD6
1b+pE1B33nmnLus7JDVmb+GAM3nqIdl2/WOPPYbq1LWyhv7FigRNE5CQdSVo
KgolalbqRV1wg1kLppeuTl+sCe0JPfcoxADBOtSZIzpmOopVqcwTIJcvX4ZA
sbReQSlSGVZL82h0HGv7/VZbDW/69yB+PvDAA2VqJVk6wAiTMo7ll+lMQrlk
80kVkGtGUEXaq0EOEe310qV4JVaCbvhbrktqT0y7A3iWpLLwdRiDrAld+/JM
kuzz2+Wn1BueFNi0Wo8frNfxFpUMPWaw7MoXLlyg6lA1zemDjgw7TMy+HGe0
qNR8Bl3Px1bfkHUyzekSHCgtmLqsjg+6CuCr21XKU/xsK740thUvg5IR3WhA
S1H34IMP4uTVLZzN7FjjZGkppaXSOEPVQehUQ+bUGhqfIdxanycIFW5++7d/
uyyF0B6H+MmWiLJEzcX0lYA6i+qJ0ekh0iiAJ/AkU38ZJebFXO6doRLARiz/
5yBMpmQHSUaYJuhYBtHPbVcWhiwow7oOIhzYS5cuda6mCBrtiyBeq8t5odIM
eyGcBxaeHrbMeQ8BKgeuG8xJ90g5/9Fnt4tcaE51eHcHAvVal/XT7VUEGtQG
5tV1BaEKyx5W39DKTugFhdGN/LO7I0mlDIVwUY3Vj+us1y41OuCkhlfERNDF
2FLdPOlTc/Z081AAojH5Vlr3P/7H/1i1zTxWBRVilIGajOuRFYwtuQHt6jUV
68ys5hr+zwwtuykFoOH4Q3lWNCw6KLJm4V76ZlBwCr1HAg0v725VF8uQWWL5
opJRoYHJUuFRPKlkLSYUUVU47ZqR29whUJwxELTLHN7bBTgd+jLlSY28sAJM
7EKsG9PNMppKjB7SB7jhIVZQDygR7vqCp3uuZ1hBCUMMVPYJBiSZgmAG/cZv
/EYJddFYxCii/ApDCoCNBTb6SzNL4moa6lKp1mJXV3+06YBew1nUkEwlUAGT
vjIqj4hkcsfS0pb2vq1XlTSrONn7ki7sDJi5p2+p3dGb/j3o7YJJaU/v/9uu
PsPZge7xjRTaM69B21AeztZ6LSue0n5ae/Kn28mlUrRRvB6uryI9bK8JEN3b
onfTPnxRNjk78hSfHmL0bkTU9S2srF0IXdp4j4pihXqYBycqBuEVtx7m0aho
VGxxv/ry+h6cPHK6tF3f5nybPDGzbX8tcz+FhhvTxBTbvaHBudGD0zZpaHTg
nGUL4UbPeWHeMci5bOLbyuo2Xo62MKIpPpWzI49SLBoPY54jD+tl6Jg5El+Z
4Ccoxa7xDs+5+uS7kxoIw66zure+L13dEv2NtzTOJKNx6iVBqE7L7juFXoGh
XNI7Qd9Ii/KQ5t/RvT2lXJaj9jNigj5bXOwXy5UO+9vBrV0GyLR0/Jht788c
2ancqK6rFM3JK01IlPmS4LPrPmzPARdKP9+u+q778yn8TJad0z99biM0/qdm
+bkYlurqxrdUbqZzm8zhVsd4GD+bLGdHHEEn9OZd6jGzu7k2pPXr0Lub6c2g
1UbtPJv9GnNicgivHO7qMFsbkmMo8tLmL0gJcz1H43CjfdTEN6OPsZopHzcS
dMg0YYfwkX62JT9svK3Yx/EhFPSW+iS0CH7wgx/8/j/xuuOOO7w8/FN7nXt9
b7t+LaD+/frnXb9GEfy7KP+tXL9GSd2yU/iWRexf6LrF6b2VcbMI3nXXXT9Z
rr/8y79sC8uvlm9ftd/+9rd/8t7Lh/83v/nNn/xar7/5m795++23fXr7+9d/
/ddG/4u/+Isf//jH8PGSU5Za1w9+8AO/uulksntP/Pu3f/u3/uqlJWh/9Vd/
VX7XLv/6Tmkr1etrwDUAARyj+HeAe+jm/94uz/3VfUD5yTvAd77zHQ/d//CH
PwRHGxzDKw9/uF3ICWH3fk0H4KaBGyO6b4NL96qzeeJ+uodn5HRVs766J672
Xv7sz/4sUcYuOJSx+QfbBY57AtVM9851l+iScCHj1zCsu1891KucZm48/OIX
v1jEUBzWJdxWtqyXX7374XZDVFyptK5+8jeE3Y+MDPTH21XIob/u4Qlt36q7
gTAfSjVA2iuvvKIBaOTyPmqJMy+++CLhlpwzNUvQSS1WJFYPE0ESHCBG/PrX
v+6zt7RdnTb/yRZ4haKE7ibNRH48XDlTsIDn5bfUEszYoqX72LXKRWNzME3w
XEc3vuLzew5wLYftCQjwVWrrDNIY/KjTzN/AdrXzj/kzF0gKkM997nMFFJxl
0Sh5c7YRjQLP5hpo+pajPum7SRnWoT3EHwJK98g6D2zA/3K7Kq8WGvFtNL/J
2OjVxioHXRyO200BDbIGsf2ll17SrO6xKNzWCbhe2hShA8PMyI+2q4FGyZs4
XeBnhQqQcV82M0gCtTLBRYiUHPcyyGYB4OXQ2xlkCNAEmOBJJxkSXIqU9GH7
p3/6p1iUuUOyEXXM4CQCD0fWOpqD2uPDyIXm6w6+xmP6xqAZyOwrt//glnHL
Iq0DucFwhE/Lztait/kY8t13c5bJNxLNP+OyCO72RTv287GPfcy37X/9r/+1
JMO7r8hfo39wrp9vKQddZeAsoIbCFIac1Izryfe3aB1KYu2o2tdTTz1VgDO0
8cqXeIdGBrjP89IC0xP81xJdeZaBMpzuxUOVzBkaRjdoefBWV9HPtyy+WEQW
8Ck5tkG9URArQ1S0DlCduMgLXwXM0vPmj6Yh9957L3LeeeedKrJBsozHulO5
Uo4bfYa+du1aVeHALLftBz7wAfPi8ccfB7xsAFhBNP/wD/+AXktz5ZxwA7EE
GovYcKRdvnz5+1vGeAzMFUi1Chz++7//e6OA/LOf/ewf//Efn3jiCcyEZE4W
KOEPwqF6dKg1s+5y/PSnP73//vs1xpYCJKuADDfdkQZbDPHTGhNtaCKAiRHJ
iHCvXr2q/cWLFztx0c7nlStX8sDeeeedplhnISq9B2e9Tg6p+HcbL9jSMba8
G/n4SCR/TUXrcqLBEyY4hsM4RqyzR4qZ2FUi2UL7S5tfIDbEAug5jj3yyCOa
ra4x2vXQQw89/PDDpX0mF2NBHo2leK107yc/+ckisHTP7Jes9Xirz+vfky3l
DnLWQDMj4kApvqsuB0/doYHViKVsH//4x5kaonz++eeNXqQ/MgswH1CAP/DA
AzDP+YUi3DMNP/KRj9CZ6tviDEXqhmU2XGJlPEvH6q/Gly5dKq3397c0+MnU
iHADvALQAM7QuApJLCLczlP95m/+pi6UEBP0QqYG//2//3fmi+ZroyU+mIwU
r4hCXEUjWXiIbxp7Qouqc015UKQlckzS9AqX6Ewn1qDXiSMzEQId+9xpFFB3
3303fJgOPPcOVu5iA31luz760Y9mXsYVSPc8MbrZZ1Aysg5iCBJwyULW7mIV
Q2ALefMIQ/wEGVTku+xE1mqRaILZDY5x4TAodSzno9tlwjI4SHODXTiQXIgg
1yEdNqJ/S4lvLLr6zlJrknYRliWDilZz2QSnFXp1bq0jBytucMZPWlGWjAKW
q+bpY2o9E0V29913n+cIxDQsKlgVYnqZszETYiYRgKirbMev5TrXP9inikkH
K2I9WyzyX2IdzErjc9WlXUiGSUdEcIORIVzKb2j8qWBrmfapq1lW5K8bsluj
cQNeJfTOKAIFOJEVWIrznf5ifH6xFbunNkBV69xA6wGGZh9TY3QtIdDrvXlK
AylDWT7Yq44+Mi8gwLBFrTOTJW1ArO4GpbdVeWAZ6g6OZl6xtByHMpPbiYhO
7HRAC5AS/2oPjY6DYlEHigzaPapbyNBFeztrV85bQ7jBtA4UVTi4wrIQ0KuQ
Z9SV9qQcKTDEedMWNDerA+gnW9Zxml+mlE6EgtMR0NCANp7MsYdrW6nuskBX
Q7ZStp36QHXhG62DWNrBKv9WDptNM6kr3UtYWbNzkxI0UEkYTEN8K3d6x2w6
v9oqCU8P/bomCyq9OcmWXiNr0+EKEkzKRF9Ycdn76cnYTxLUpcMJf7BdxUd/
6EMfgnkHOSpBW1oSEFABPtJgy+LhP1mcO4M0w2F862UMUSCYDlUDwUYyJf1e
k9DFypFCJyTp82rkO+RT5oSq2UKScnZCFfyUmegxEM7mF/w77w35jtTis4Gy
bBW7h17fQTWDIVbD0KQYYVXJurTSVYsoZ3XHjRBiUGjgBhZ1Qhj8zt4gML4x
oQVZaGB6Vlm7d8JyF1BpOHfArO0gU54KmUGdHO5sZCtC+YLW2u6xqHM7FKlj
ybSlmgvmHTjlB/DTvAgZvfOTeEUKZaiGG4Q7IV+4eutgVg5KGO6dFkr0ULMy
Yp17SA8niYB08DCUKtXdSfjWo6oANMUKrsdn7Tuq7Z5cwOnlEC2TLOJoS1bT
ebBqGWuTDcTtklroQgTrKT5c8hODSegQoEWd84EnE0ElRutI0KsIgPETMu0D
dPq302Jk0b4ZHNaUO//r17nrYOcKTt+bvHG9/iXWwZOl9OTxofrk6SGFbLEn
Vw+VTLs/XrJoHh9SVsbYXaDKyZLrr7MQE7505VC1ZIDTRlOmpHkkvkuyd33L
5DkhbHNz9ZD282waw4lNm5YTvDMNzu0+YT4NPSE8/VSA9rVDxtRh0drm6JB6
NOpWFl1bsiwOPgXgJ4Ih8+qZ/JArbmXgXFlU31RoODwDTbBV35I7AV07ZJoN
wrTfxcStgu79M9aNBG+UN+b0kIZ0ulw7ZOOcyK919KvvTcZ48t7Q1JWinXb1
WXr1vbV318C640M2zsof+/Q+OSQv7ddh+zDHjXeMG53RGr7tlPzokCRzlBwc
85eS95lvibxyJk36jZR8WDQqcVbJhxtFja3MPFqyaJ6r5BOSGZ9/qZLPoD2c
eTFK3sMZcTcB1+n/PkrOGqz5ds5V8t2sGdzWIzHDhJHviGmn5KPYx4carKNR
72P/B/mVtK5YseI5chkcxj7E+VUuAR+GjEKurDs6pBRe50twjg75ZteBdlNj
ngzya9ThPBxp3ogJ/4zrpsdNzHWyVYS09BQ7nJcq0XdEqjNjndQqAfLKCg+9
n1NXU/t4qZtQdpGrh8QmPSzvRIlr9GrH4+RQE83DPBE729uZq6PtuGOnqjys
6OeYkZNDlc/0rVOUia9TmqfbATzUlax4YlevHLLl17LX4w56pcyT7j7MVypW
dfJvW+vXl5zwk4aiI1517yzZuR9NrW5EPMmEO7h4fKiGcH2rtIuEwefaoRz2
VAeoxtBI7eRQh/edpXBGAK8fsugnwdPts6sTkqTp9e+dM+VZf7L5fMtX4KUx
PPPt9sHo193qnLC8Rh4dSmy3u9iRv+NDiYpzj7GlnB3FNHQFsLLnHZZb9bDU
oAi5up3ru5EIVqmB3EZH37w0P533cGd+r20FYVHnVwT6kNH++pbuAKNuZBy0
pNLYYiDfF/69eihYcHQoo3zlcJVK5dqhjMXgebIV550Z6mtxqsSO6s4MBVnj
o/ee6YVq2QziRmI92s6EN7NGl65txQtaUKrm3ByhVJnH0bR3DhUlTpZKEDNo
zh0jZniDeXU7of3uoTDxJMOZ0atrtgrodNslw8M17iaF7zzwaMIAP94KdmdG
Ykh9r235aiZJUWh4WHL+9c1wlLOc9tNyp3Knm6HIDbdOMeKGcHSxCWW3rnvn
Zq8dCtO7DB0TxrhdO+SfaebuRkxjKXm0/PxQmmTyPnUG+Fzzcgtet9Q6WEid
D3NTtcB20qzEVVnvCmIl3K985Ss+opNd3bV87rnnnnzySeT43P7oRz/69NNP
l9Izf1bJZiuA5fnv/u7vvvXWW2DeddddvtnLAuTTu0PaLGpGftBr6+DZZ591
4zsdqBIUv/TSS7fddtvk8DzeytpWH5Na5nqrOFopcIvlKfwKkLIiF7H74osv
FuhkIGhDwEMQ0Pu1r32t0njf30pkFlr+9ttvF0e5btxV0RVAnxj5qjSrPh16
K66KS9/61reKxzTi6TY7diarILI8brBt77TgsgceeIBpeu21177whS/gFXpR
VGU32OatY38uX76MmTiT1L773e9ihRsIjG2HeUkpcR5p8Cwwsw35LA8cMGoN
HDvaUvsWpFl4FIrMSnwrwBnzL1y44O9YFV3ABP83fuM3SnaNKDCrN8pewVN7
D/uQ3L2smumaUbAiQFOA9meSy9WlrG0bQa+//jp6pyTil770JYOWLmBEMPC9
SkFYA5pP9/xaruOHHnqIhpRYrLPoZb/80Ic+hDNIhj9lhiplw+dyROyQP938
fWj0l/aCSUY0CjmwoiG5fT10T2o5E6FhKlVtcLTijTfegFtJsxFFDz00DUmB
6A1h/oJTCsTK+A4mqMjrSnDQ9muVcytvBwfTpAz26MIoTKZUKDK//Mu6GhR8
sjB0cxna8b+c+dDArtVtpOND24XbhFImfxOtspKvvvoqxWsjWne05ymAhl+D
M1PD6Ahc3zRIBGTW40//9E8Bz1uBpbpDicLjIUqvbjvbuI1k+gMHbUKj1AHV
hdQgH2XA28AHEzcqA60NfpbFna6uKzIIt99+O2I7YOBiS63mDAgkr29VEXGA
CMAs42sRhWV3T+WubpHR0U4WFT+FLYazIbvCnUaksQYy+4olLPZQ9/JLAEhY
2Hv6b+G6ddZBBsSMBrk3n8K0qU0T9v777694tDb0tvBecp9zAkdbtfRiePO0
knj1bTsPQPeqHUDVc4QBQrJ+MvUqpEJ25246adbmOUUteL/g98JyH3744eGG
lpoVF2wi0Ipcb+ZsFUVTm9LUe1i0uJZFK3upo3udQunwjKvTCLpoz/ppkF8D
Jsg0f1f9pP8G7WRaPrjKc+REK0E0OLhRkYIy7naSdpWFCVL0eqam8seYb/QP
fvCD5JKfhdEAHFEawLPgfX3LUdybRlLzEMfAvHjx4gQmn2x5ZoxiCPw3MaEE
T+IwELBVbTDWumqw5yUZ9sZbRQ/kFD+lcdVs80vOOsiq+BUOJi+wRqT2OXlz
A5UBu+MZlhvWac1PfrrVSm6JRwX4mRqklRb+6lLqMbNA6JU4AR/rOp9QapFE
sBZO7QxY8nXvra8yiEirrm6fV0Ug5p3pXEQpnSFsrBiiZZm0z1VjVLBOHU3U
vjO0GPKft4sEyyBtRJxpIVu1YpKio44GNonc0O1Lly7pXiImzcDvHMjIGuad
E+uE0j333OPfcqR0HALtVBeG+ejx1r8meGfnOrAKee8MON9cLgbcv1U57011
4iJT7Cpl9ybZYYCqHuTch3l+tBLC+3uypZ4GHECj04qyAJ290O7dow9tLw95
r3JolsIFYhQJD6s3bdGsyEWRdOXZrho7KmgUeoddp9u7dy9RHd2sOgw4uenX
rWwQiA+eHUHpfELFI4xoZlWYIKHkAa8QTKcaStnx/S0RkGasqBHLDQUlc6dU
UesGrye9cuB2XxkIJ7tcwEmknAa3VLz8ja5bZx08XQqZtV9RXGqbDzlNrhwK
v55ur+hrNryTQ1HCcRa0HUqghHv1kMY5+FcPdVRPD5sbbc6caz262rQJgauH
GmHtQlxZqoC5oXjUYHZlQ3K9D432yedhKLWxP9uqK8IhOZyZnaujM1lJp2XA
Zwd1/IMh38bU+Ft3cK4eUlifHEoD1/072xU3Gj22J6Crh2prwW9DeKTGRHek
f7fh3K9Db3tcyXe8D7u9x5Bvx2nyPV47FDq8figMt5NgFK0aFZeuHiqczq9W
ip0XZlqGbV2ODlV312Z5c6bL+4hgh9s0SD2m2Q7+kNYOfJv54dZNCczfR42H
XYl1nHfthqU/SXC30ToOpnWGDmPXGToSXF/S2sb0q9ckC1NJ72N4mjMujNGf
Nk5H/VYyI6QRG300dkV4JBVpV7eTq5VRWHX76FC5eBQsSb3PbvPs5w+SV7es
Al5UvJkM8GuHCtchORvRZyf4Weda8GdOTfezclk1YXZQgxmeDTSjnyxHEYax
R4eilkdbhUHLbq/ZTdLdiKNIKw9nu3W091xHw6123TrrYC4YLxjesiwiFTZt
Kp09G9Bk/8lWEdJ7u1eadv5zzdzIj+wnWuql+h/+4R8MVCrsjEmqsk6r0aUa
rPv2/+2//TeDlpDB58NUAV4nVPOx/OqrQb5+KKY5iXFmsci+9TD9vHKoWH1t
q+V67XBq4uiQYLlMXyfLQZqfbhf0mgXjWBm3Re6AlUUwhJJe5coAMC+JmzV3
2ekh9bdPlfBhIsrm4YnnN7K9iIWn9saFmLHKZj9snxwU4MT2461O6+T8f/dQ
5nW1k9DLgzyMRQKEDTEr3ViD40MOoh2SA3O1FTluvI2vR6QgY0RqefWQEybl
mWMhUTTnUuYd4/Tg6+mgpp/wrW+WWRfGJJ4c8urs1v2/366SGI9Czkq0Ljo5
/tIlnL9yKE17dDh1VrW+9QUS2OZdept7aCgaAa0o+TedKWWKmZg+Y/7ZE0pg
+ja5tmU++dFW1+/kUGX43RsUoR7dJlAAdczbGNvnpSXG5hME8O/+7u96qLHP
5DmPsTtWUeXZMS/j65/JmJR3Bnz0sC5xwz2lXXdiY3uOs3lFnLUmJymjEfym
2+khedTRoWJvGjUw04rgYIV1vKTuI4t8oCDPWra+MCPWp2Kvl/MCuSKMFdg1
NSnm4NDuZbJMRM0yCPTtvFt5Mx36Dg8jJ1DwzCeSKG8d7+EttQ76YH/kkUf+
y3/5L1jtu9s3NV6ZDhcvXvTpHZNL3WPh81V+5513Fi7xyiuvvPzyy9/4xjfu
u+8+3/VXDmWyd5pMVUy9yuM+9dRT7Tj5fn/hhRfKyOfjsePEjz/++DPPPFNF
4KIOZwM279UnP/nJT33qU/TB0G+++WafgVpWs9VNLq1K5q1J8unDo48+aizU
offpp59GiFGeeOKJzx0utABeFuI2Rqqf+2d/9mc0pxox+aORs27f0bSi8Lxs
Q0yzNl0B7Ljy7/7u7yKtcMvpVfza888/3+ETv45zqqjGd7dySKxNqSxvv/12
+LSx5o3RetFebuWNjpZToF2mJzzbnMFJIkNRezswBDCUXnzxxY985CMeVkCt
inVmTVxt/7Mqb50Phxs9nLF0gfBnPvOZsg3neGWjvvrVr2pmXDd+0nfVimrd
VjlOlyJWvM9D5o477vjzP//zaanBgw8+qAFM2lGkJ4RYwVN8JkHowZ+AHnvs
Mc1mRTAiXUImDhT4jHAP830bF7d1ARxjAXS/HtNyoxkWgVCazSJQUrOSS2OI
7h6WPJOswaQzlVemqHAub1jRx+s6CGfzzl99i1H6oz/6owr2eQL+E9u1lk8F
4YEHHiACJp0Bd8/4l47S1WtYlZVoKWZ++MMf7gxbc62TTpcvX05nOgS46gyc
021oAJ4/vSlTwtsSDlPXDgCwGFT64Ycf7p6JANxkKfAh11WQ/VRybO1pbzFH
5gvWIScX7b333kth1i1K99DGBOtFRXVLI5/c/Z2WJimYgJOOlqggO3xAOCrI
lxTYhE52GQUVbiDALPzFdhXlNBnFc8vmaM6TSA+px0iQDt9///1GKVyIUrXX
CjGqhVdT0LlgDWJdF27iM/11NLS/bcDSfH3XUuan2z6tgYBCuOcaHG151M0v
96Xs7ugC9l64cMHQRJDxIUdzmQQx0I2BtPTTLbIU3jrroMluohXV3rZJ8qoO
ZsdFejmsRBdVwV7/Vk0bz6vAjtVl5KMGa5TxOhD5mj4MBW3JX0x2RjGFPbee
mmX5HTpbsmZiJHpToLhjAxX27h4O5hEIlLa4VMDpg1/hNq+jurBjRYrBXBcD
mTWmXg7u3FioKJSpuvZlBjA1DESR4HzuXo2HmuGM9nNOhikAxHCsSrGWlbKd
eZRpLR65QpwV79BLe+RAAJ9LV8i8k4uXvSnEWXSbSQp+zqld4sphu5mSS6ga
5RVr6JxDh4suXbpU5v+iofGhmVs1B8+LKcOukns3E4MPSfgYwkM2pyBcM7f0
v7oTt/vIGazQTgTsp+faFL8JB3h6+P1D2W68cu9JGVqK/IJzq1uhZ0bPKVnw
3Wqp0G5BMWswlh0urTq+VTb6nnvuyfcNBytar08gz9fotS1/QrHnupRCGU8s
XjCp9goekiDyO2pFT4xeUWNWy7838n3nC9bSlKGurQuoqLwLZIgp+eLMcJux
pScdk/Cy4Q2kdCLYXqxfDk2vQG7Qdffdd2tgUpdtwJtVydhxCcxiCc81CyjK
D5i3uijyYkVZbNMTozSAuYcvbBftKhiNyBBlRA1mvhgOhvrqqHtHvLAdmZgJ
OCODLhxYvSTMftV7yzlAr9yb4JUUwfx1VWo9LcU0sAwsMnsFNTTcKCS+GQhD
SFOX0nfAx0QDkM0ZYeWWnblcpv31LHTvXWXnnnD4ojW1xI0crx0orWTPeurM
vPareQ2xsqYjn0LSZx3X9xP0lrjATSnB0ZWeVAS5ygh+RZp7ME3kMP/ZdnmI
gdVkKTXKjTaR/pWvW2cdPN02GUon2x5jn9j92/b1tMwxl4yuHRIXz+7B6bbX
Z1m80db07CydLGet2woYF14brVcONV6n7+wttH3XQfH6hvycP2+/a3cav62w
64cgxMikitQvmxBpbWjMKfRwjuS2Pc+lK3Laa5oYh4kimQ3bdoqmV5hPg047
j4vqynsLfdbsdHuvLuxivGA9jIoboTcUzaH9QSmurnEig9J4QtcwhDlzvspl
NnNmoD6c331vyMmqSCO1uufEmdGn5WwZJYvOrkfIbHylKt3sjgckvlXlcqM0
+jhorhyK2O624mPCtUNwQbRbFCwfVw4ROiu9YX7tEH3g08xqdSOhzN7gOh1G
88NqfEn1ShazCRa9w7133xt+Etg2/9teGE1ow7aUC+eiN7uacWCNsLh6iCLM
R9+O4mwqxiLrizeWNaVPUyO2T9jF0Nu8GL7tSBg9GddqVOzmiEGtONUOmDij
BBSXwq2HMXmsinXQor+uU6fvncurfFdZzL73WI9pGWmj2O+ciUIa4KPYceCs
s3XmxcAc3cumDd+uHIIp5tfRmV3LW+G6ddbBvGksfN8d3hka4niJLL5yiCe9
stVinjMe7eoPqF9suT5o1Ph9Jvry6hIlenwobVmznx8KeTdoVggOJunuu3L1
L185HJJpx/Lc8O2TLRzPO7mpMb6kllHvqzni5+Ecw1gd2chZvy9ONzWzIBYR
FhrzVjB+sYEzbutxH4yN1Ste5dnPjJwegsSvHkJ9g+MTpgOE0zKHxbxUzMMZ
bpzmq4C0h3lxYXP0YuxtT+pSZFzvxiPoceOebi88fX5mZnd6cq4sSCFZMI/x
kHx7UsGFcFstM41qWy8rsVOeML9yJuNEATjZJboB5vFWOsTDc3cqEh99q9hr
HtX8YkPaulamrv4CGL3ufarMeZujQyx2V/MrgEPF0Xkh5JF25VBtfPfysFOz
EniuqzatTqnmlNTp4YhO8/FsdF7KMzRGTsslhrzz3sIlgJPRlcOxkzlYVffy
W54eYjk7D1NVkeND6P21MwV2xzsPuFVsPsZzQXpI+hMll30YBEyKstKtmrny
qnzCqwlap+cMNFYCMqguYmUUewxOK1fe8+P3Jk9olLXloOEJDZwq4T4P57jU
oHTlEKieET45JHbYUVTgKimfq8P/Fq9bah385je/2WY7O9AJ3rTaR3QxFL7E
P/vZz1aKC9pkQb07Yv32228PKGr8yCOPPProo767qyUHZsWzfKTr699iu8yX
j33sY77FWBIf76XBbBcrgK2D63mJX2zVTis2V34woH60FQy9fPnyyy+/fJY0
AItN86b3+uuvFwFUNARMLl68+KUvfSl/lrFee+21gsLae9S4D0B4rmaWWX74
4YcjfFInQR5iSP6jP/qjtinKV+zXajtWjK/95ODQ9hL3VUQMGrpjIJTywenV
Tmwl7wnodEsbCEhRG55Ux/ONN97IU9Zus4dFGbTVOTlajYjAb33rW75lqv/b
vjQCn3zySUzA1U5044+51u4cEZQFVC9ElQAKQ4i1AseFxlTE7amnnkLp+J5W
G368xfeBDzGsfuihh8o0W07REt9V9W/96AbqwoULWn77299uvwtuepVjjf7U
HV0jo7TonnvuISAm62tf+1r1/rDu2WefpQanhxLwq6rMOoix5WgFuTgX45JL
O9glNOtMPs4bpaReTBY5YldVGuEGh7G0b731FhUl7soxJ1zaW2CRloboADwE
8B/O0KASRXwMkiZLUtMAQz784Q8jZ5hcPV+IGQXapI+riIIwUCReROo47LoK
6ixIoeRjtKjEdOAjp2ak6SdCz4cOOASgYZ5iL6LoCT4g5GSrZ1RYojmLjWjU
7JXtgv9YMEzzb55HBsF8LI547BKE2ZNKIaP0K1/5Ctzyg7isKQVzaVm9P5Su
X4g0FgnxqpCZEhFX+nBetzAQAuRrEhlde22oh4eVWO30gu55W5p95QemgThc
HIehkVwoyrrbzJ4QfQkJ9froRz/a3pFmZUHUBdiCyMyLonUKPGmuzdcBlct3
f9bW/Ru9bp118HiLHzRB6DwBseT5B4t2ueuuu8orSC4ml5luynzjG9+okKtr
rT1aNGiBhMSdl839vffeS8fc09USGJp0jz32mAlrfmXtqajRc+qdi+dPtuqf
9I3uwdB0xo2cHdArsnjXBXA6RoHpFSXMXVXsvCljilEzUzi/g6ldYkaWBHwK
iS2eE1OZloOJA3iVVpfxmOGi9ug1Fu6VNboMLeWgBpmNuu+++/Bt4CAWHFYF
7TBsq//73/8+RjGzmKMxJI1eanrYVuoCE8CsiAATEeZuOjxDIsSUo9YKApl5
NTWhXt4ukK04WTP2oWUI563vgMC5LNZlTEVFRbQBL5qy4wfIL6kymTJQ/hKc
v54zTVnC1dFjdL8akW2kM5lHCkB2FOMz2+VXo6ybaV6esaJw+zIxQg+X4Ext
sL10i7g3J2zRi8AHHnhA44LcYwhGFT9OT9BFi879bmXKwMzdWQ7wIkn9m0eM
6mKdZYU4NChCs/clvYqYLv4ugB230BKeREZbkGB09MINSrhqxJLilp07z4Je
BTbOko2cpEbchZB7DxzMvSyBg7ewLfaTpOBpuuEPaMTRy8Z6EKVU0tilgV/L
WG5cQ1iYeqWJCpLtaBNU84qiyEOjmOBwBgrh5b3xEJ7YnouNHGnUpUuXGPlR
SGtBr45gErHp7P7KUoOeIkGpj7WSqCcOTKCoLCEaPbQMETFQpvP6AYt1WFQF
h84AgB/MNbd5Sx44rde5g4tMNIpxS3GvL6NXHDFVx23vNjQNwoYgSgpZdmI8
2dWS9msFGTGHfAlIA0LxvOMWFdVFKSTbni2ktwTpTFbvb//7XbfOOni6KWRb
Pe2HdPD42paGqL3o/o5/oR3mjs2s79VtPk90T1siphJZl3WtbdUB3nw83gpr
tn1tpp97qGCatcPf3n5dPCzF0Nkuqzck30RkhkZU9LAt9M71HW/FNCMZMu5X
t8sQnuPp6pbCazadwipnSucSW0rQxfStO36Rc3SI/AoND7090nnWONJqM2i0
XZY/5WirBDF7aHG+Lm5MNAZ2tw04pOX4iN72D/NQ9Kbav7UcevM4rJmpuu+A
Ym7E8eO4se7s3LvjIolXU5L12iEMrYHWr8i0KMvZ6dl2k1Ktq4dCrhNRtcq9
baspqhvygcLeG20uTURYTB62jz5EyGhgo9eyMyplkN7Nr3eWFGrB9A5gWYRG
uJU7bn493Rb0uV/pioq15cqu6r2mG21IjtrP5F15VcumVX60RNmh01WCgHfk
I1akLWMlksWoRPJtr6+ZXv2OXdLglGfV4Z1ztiezHX3lkCmxSRdpOTHPGoFh
UXMt1ZrpueNqtiUlbF7EmRloMhw2+hA++vyLQ167czmcAzSUfnGoJpzTNrb/
4pB0MTMycy3On2vf/je4LIK+2V/6J1533nln2b3+bV3ebW42Cjf5enG7fvXG
/8oj/vv167p+dbb/nyag/9Po/ffrV7ksgv8/bW4t3g==
    "], {{0, 400}, {600, 0}}, {0,
     255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", ImageSize -> All, Interleaving -> True, 
    Magnification -> Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Magnification[1],
  ImageSizeRaw->{600, 400},
  PlotRange->{{0, 600}, {0, 400}}]], "Picture"],

Cell["", "Spacer"],

Cell[TextData[{
 "The Excel file we will use for our first example can be obtained from the \
U.S. Department of Energy\[CloseCurlyQuote]s website: ",
 ButtonBox["www.eia.doe.gov/cneaf/electricity/epm/table1_1.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.eia.doe.gov/cneaf/electricity/epm/table1_1.html"], 
    None}],
 ". It contains data on net power generation by energy source for the years \
1994 through 2010."
}], "Text"],

Cell["\<\
A copy of the file is included with the download materials if the internet \
file should be unavailable or changed in some way. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Excel Spreadsheets: Importing", "Section"],

Cell[TextData[{
 "Microsoft Excel documents often contain a number of sheets. The default for \
the ",
 ButtonBox["Import",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Import"],
 " function is to bring the entire spreadsheet into ",
 StyleBox["Mathematica. ",
  FontSlant->"Italic"],
 "This works well when the spreadsheet is not too large; sometimes it is \
better to bring single sheets into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell["Import the raw data from sheet 1 of this Excel file.", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"electricData", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\<http://www.eia.doe.gov/cneaf/electricity/epm/epmxlfile1_1.xls\>\"", 
     ",", 
     RowBox[{"{", 
      RowBox[{"\"\<XLS\>\"", ",", "\"\<Data\>\"", ",", "1"}], "}"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[TextData[{
 "The size of the data matrix is easily found using ",
 ButtonBox["Dimensions",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Dimensions"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "electricData", "]"}]], "Input",
 CellChangeTimes->{{3.427186071233418*^9, 3.42718608340213*^9}}],

Cell[TextData[{
 "You might want to look at the first few rows to get a sense of how it looks \
in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"electricData", ",", "5"}], "]"}]], "Input"],

Cell[TextData[{
 "Row numbers are not included when the spreadsheet is imported. If you are \
working on a machine that does not have Excel installed, you might find it \
convenient to use ",
 StyleBox["TableView", "MR"],
 " (currently undocumented) to display the data."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"TableView", "[", "electricData", "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Excel Spreadsheets: Filtering the data\
\>", "Section"],

Cell["\<\
We will look at renewables up through the year 2010. First we determine the \
number of the column containing the data we want to use.\
\>", "Text"],

Cell[TextData[{
 "The information we want is in the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["9", "th"], TraditionalForm]]],
 "column."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"electricData", ",", "\"\<Other Renewables[4]\>\""}], 
  "]"}]], "Input"],

Cell["\<\
Referring to our table above we see we want rows 4 through 43 and columns 1 \
and 9.\
\>", "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"renewables", "=", 
   RowBox[{"electricData", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"4", ";;", "43"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "9"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableView", "[", "renewables", "]"}]}], "Input"],

Cell[TextData[{
 "If an entry from a spreadsheet contains a mix of characters and digits, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will import it as a string. Here is a little conversion function to handle \
the problem in this case."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strngConvert", "[", 
   RowBox[{"str_String", ",", 
    RowBox[{"splts_", "/;", 
     RowBox[{"VectorQ", "[", 
      RowBox[{"splts", ",", "StringQ"}], "]"}]}]}], "]"}], ":=", " ", 
  RowBox[{"N", "@", 
   RowBox[{"ToExpression", "[", 
    RowBox[{"StringJoin", "[", 
     RowBox[{"StringSplit", "[", 
      RowBox[{"str", ",", "splts"}], "]"}], "]"}], "]"}]}]}]], "Input"],

Cell["A quick test.", "MathCaption"],

Cell[BoxData[
 RowBox[{"strngConvert", "[", 
  RowBox[{"\"\<12,390R\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<,\>\"", ",", "\"\<R\>\""}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Using pattern matching, we convert the strings to numbers and extract only \
the yearly totals.\
\>", "MathCaption",
 CellChangeTimes->{{3.508228291077619*^9, 3.508228305555793*^9}}],

Cell[BoxData[
 RowBox[{"yearTots", "=", 
  RowBox[{"Cases", "[", 
   RowBox[{
    RowBox[{"renewables", "/.", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"str1_String", ",", 
        RowBox[{"str2_String", "/;", 
         RowBox[{
          RowBox[{"StringLength", "[", "str2", "]"}], ">", "0"}]}]}], "}"}], 
      "\[RuleDelayed]", " ", 
      RowBox[{"{", 
       RowBox[{"str1", ",", 
        RowBox[{"strngConvert", "[", 
         RowBox[{"str2", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<,\>\"", ",", "\"\<R\>\""}], "}"}]}], "]"}]}], 
       "}"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"_", "?", "NumericQ"}], "|", "\"\<Total\>\""}], ",", 
      RowBox[{"_", "?", "NumericQ"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
Using replacement rules, we \[OpenCurlyDoubleQuote]clean up\
\[CloseCurlyDoubleQuote] the rows corresponding to the years 2008 and 2009.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"results", "=", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{"yearTots", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "1"}], "}"}], "\[Rule]", "2009."}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], "\[Rule]", "2010."}]}], 
     "}"}]}], "]"}]}]], "Input"],

Cell["Put in a formatted table.", "MathCaption"],

Cell[BoxData[
 RowBox[{"TableView", "[", 
  RowBox[{"results", ",", 
   RowBox[{"Background", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"LightGray", ",", "LightYellow"}], "}"}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", 
        "\"\<Renewables \\nnet energy \\n1000 Megawatthours\>\""}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"ItemSize", "\[Rule]", "Full"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Excel Spreadsheets: Estimating the rate of growth\
\>", "Section"],

Cell["A plot of the data suggests exponential growth.", "Text"],

Cell[BoxData[
 RowBox[{"dataplot", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{"results", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", ".02", "]"}]}], ",", 
    RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]}]], "Input"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s use ",
 ButtonBox["NonlinearModelFit",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/NonlinearModelFit"],
 " to see if this gives a reasonable fit to the data. Note the translation of \
the variable by ",
 StyleBox["c", "MR"],
 ", to get the curve to fit. Raising \[ExponentialE] to a large power is \
going to give misleading information."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"model", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"results", ",", 
    RowBox[{"a", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "c"}], ")"}]}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "1990"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"model", "[", "\"\<BestFit\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"model", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "1994", ",", "2010"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Pink", ",", "Thick"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", "dataplot"}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell["\<\
This includes the yearly data with the fitted values as a third column.\
\>", "MathCaption",
 CellChangeTimes->{{3.427646793845379*^9, 3.427646827827965*^9}}],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"exportResults", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"results", "/.", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a_", ",", "b_"}], "}"}], "\[RuleDelayed]", " ", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", 
         RowBox[{
          RowBox[{"model", "[", "t", "]"}], "/.", 
          RowBox[{"t", "\[RuleDelayed]", " ", "a"}]}]}], "}"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<A model for the rate of growth is:\>\"", ",", 
        RowBox[{"model", "[", "\"\<BestFit\>\"", "]"}]}], "}"}], "}"}]}], 
    "]"}]}], "]"}]], "Input"],

Cell["\<\
Finally, export the yearly data and fitted information to an Excel \
spreadsheet.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<RenewablesGrowth.xls\>\"", ",", "exportResults", ",", "\"\<XLS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.488205875060966*^9, 3.4882058779269657`*^9}}],

Cell["Open the spreadsheet in an external application.", "MathCaption"],

Cell[BoxData[
 RowBox[{"SystemOpen", "[", "\"\<RenewablesGrowth.xls\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.488205885631439*^9, 3.488205893272252*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["CSV Data: Importing", "Section",
 CellChangeTimes->{{3.5308759991915216`*^9, 3.5308760081353493`*^9}, 
   3.53088744497033*^9, {3.530962673161063*^9, 3.530962690500106*^9}}],

Cell[TextData[{
 "CSV files often contain rows of varying lengths. That is the case for the \
file we will use in this example. This was downloaded from the site ",
 ButtonBox["http://www.census.gov. You will find various links that will \
allow you to get data for your neighborhood, assuming you live in the United \
States.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.census.gov"], None},
  ButtonNote->"http://www.census.gov"]
}], "Text",
 CellChangeTimes->{{3.530962711013278*^9, 3.530962781469384*^9}, {
  3.5309654750523376`*^9, 3.530965481401903*^9}, {3.530965520412135*^9, 
  3.530965586379755*^9}}],

Cell["First we get some sense of the size of the data.", "MathCaption",
 CellChangeTimes->{{3.5309656398228493`*^9, 3.530965653652667*^9}}],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"Import", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\"", ",", 
       "\"\<DEC_10_DP_DPDP1.csv\>\""}], "}"}], "]"}], ",", 
    RowBox[{"{", "\"\<CSV\>\"", "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.53096565665163*^9, 3.5309656615678387`*^9}, {
   3.530966999226948*^9, 3.530967026080421*^9}, {3.5309670678567677`*^9, 
   3.530967099875352*^9}, 3.5309672218018417`*^9}],

Cell["\<\
Since this data sheet is not very large, some experimentation was done to \
determine what elements were going to be useful. We use that information in \
to bring in the data we want.\
\>", "Text",
 CellChangeTimes->{{3.530965690775963*^9, 3.5309657643182173`*^9}}],

Cell["Importing a selection of the data.", "MathCaption",
 CellChangeTimes->{{3.530965602429924*^9, 3.530965612659696*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"popDat", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{
       RowBox[{"FileNameJoin", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\"", ",", 
          "\"\<DEC_10_DP_DPDP1.csv\>\""}], "}"}], "]"}], ",", 
       RowBox[{"{", "\"\<CSV\>\"", "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"4", ";;", "41"}]}], "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.530874071479001*^9, 3.530874090111816*^9}, {
   3.530874148995034*^9, 3.5308741556491537`*^9}, {3.530874186739376*^9, 
   3.530874224682424*^9}, {3.530874269483532*^9, 3.5308742761715927`*^9}, 
   3.530874341764989*^9, {3.5308745512123423`*^9, 3.530874556103045*^9}, {
   3.530874592625846*^9, 3.53087460776143*^9}, {3.530874954113913*^9, 
   3.530874958582583*^9}, {3.5309606438087387`*^9, 3.53096064641514*^9}, 
   3.5309742728589354`*^9}],

Cell["\<\
Looking at the data with TableView reveals we only need every other row.\
\>", "MathCaption",
 CellChangeTimes->{{3.5309657832570868`*^9, 3.5309658123590603`*^9}, {
  3.530966388464678*^9, 3.530966469399226*^9}, {3.530966508412348*^9, 
  3.5309665151071157`*^9}}],

Cell[BoxData[
 RowBox[{"TableView", "[", "popDat", "]"}]], "Input",
 CellChangeTimes->{{3.530960650623127*^9, 3.530960659693379*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Manipulating the Data", "Section",
 CellChangeTimes->{{3.530965835632716*^9, 3.530965839719898*^9}}],

Cell["\<\
Base on the TableView we start with the third row of the data and take every \
other row.\
\>", "Text",
 CellChangeTimes->{{3.5309658485926323`*^9, 3.5309658849839897`*^9}}],

Cell["The first step in filtering the data.", "MathCaption",
 CellChangeTimes->{{3.5309658995547457`*^9, 3.530965912441091*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"popDat", "[", 
   RowBox[{"[", 
    RowBox[{"3", ";;", 
     RowBox[{"-", "1"}], ";;", "2"}], "]"}], "]"}], "//", 
  "InputForm"}]], "Input",
 CellChangeTimes->{{3.5308746970914288`*^9, 3.530874699713891*^9}, {
  3.530875008343717*^9, 3.530875025702952*^9}, {3.5308750686079397`*^9, 
  3.5308750741275997`*^9}}],

Cell["Next we add information about the columns we want.", "MathCaption",
 CellChangeTimes->{{3.53096592356348*^9, 3.5309659447692833`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"popDat", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"3", ";;", 
      RowBox[{"-", "1"}], ";;", "2"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], "//", 
  "InputForm"}]], "Input",
 CellChangeTimes->{{3.5308746970914288`*^9, 3.530874699713891*^9}, {
  3.530875008343717*^9, 3.530875025702952*^9}, {3.5308750686079397`*^9, 
  3.530875105407493*^9}}],

Cell["\<\
Since our goal in this example is to create a bar chart we separate the \
information about the values from the data by using Transpose.\
\>", "Text",
 CellChangeTimes->{{3.5309659615705843`*^9, 3.53096601471424*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trimLbls", ",", "trimData"}], "}"}], "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"popDat", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"3", ";;", 
       RowBox[{"-", "1"}], ";;", "2"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.530875145714467*^9, 3.5308751581454372`*^9}, {
  3.530960774345702*^9, 3.5309607785117826`*^9}, {3.530966029953637*^9, 
  3.530966044931295*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Putting the Data in a BarChart", "Section",
 CellChangeTimes->{{3.530966058773941*^9, 3.530966073627408*^9}}],

Cell["This creates a default style bar chart.", "MathCaption",
 CellChangeTimes->{{3.53096608003069*^9, 3.530966093751996*^9}}],

Cell[BoxData[
 RowBox[{"BarChart", "[", "trimData", "]"}]], "Input",
 CellChangeTimes->{{3.530875179822095*^9, 3.5308751895301447`*^9}, {
   3.530960799314196*^9, 3.530960803439898*^9}, 3.5309660518320827`*^9}],

Cell["\<\
In the Palettes menu you will find a Chart Element Schemes palette. we will \
make use of that along with options for BarChart to format our chart.\
\>", "Text",
 CellChangeTimes->{{3.5309661223171453`*^9, 3.5309661840455427`*^9}}],

Cell["\<\
Rotating the chart, adding labels and a background make the chart more \
attractive.\
\>", "MathCaption",
 CellChangeTimes->{{3.53096621580807*^9, 3.530966253358186*^9}}],

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{"trimData", ",", "\[IndentingNewLine]", 
   RowBox[{"BarOrigin", " ", "\[Rule]", " ", "Left"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"#", ",", "12", ",", 
         RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
         RowBox[{"FontColor", "\[Rule]", " ", "White"}]}], "]"}], "&"}], "/@",
       " ", "trimLbls"}], ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ChartElementFunction", "\[Rule]", "\"\<GlassRectangle\>\""}], ",", 
   RowBox[{"ChartStyle", "\[Rule]", " ", "\"\<Rainbow\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Background", "\[Rule]", " ", 
    RowBox[{"GrayLevel", "[", ".3", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ImagePadding", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"100", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"15", ",", "15"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesStyle", "\[Rule]", " ", 
    RowBox[{"GrayLevel", "[", ".9", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.530875179822095*^9, 3.5308751895301447`*^9}, {
  3.530875248020927*^9, 3.530875272859823*^9}, {3.5308753696877728`*^9, 
  3.5308755797595587`*^9}, {3.530875620073271*^9, 3.5308756255010633`*^9}, {
  3.5308756623983107`*^9, 3.5308757396071157`*^9}, {3.530875789128194*^9, 
  3.5308758077607603`*^9}, {3.530875859484363*^9, 3.530875862472722*^9}, {
  3.5309608163083982`*^9, 3.530960908021531*^9}, {3.5309662616270638`*^9, 
  3.530966283844705*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Text Files", "Section"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`chord$$ = 25, $CellContext`dihedral$$ = 
    2.5, $CellContext`span$$ = 42, $CellContext`sweep$$ = 
    14, $CellContext`tt$$ = 0.32, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`span$$], 42, "span"}, 35, 50}, {{
       Hold[$CellContext`chord$$], 25, "root chord"}, 15, 30}, {{
       Hold[$CellContext`sweep$$], 14, "sweep"}, 0, 50}, {{
       Hold[$CellContext`dihedral$$], 2.5, "dihedral"}, 0, 5}, {{
       Hold[$CellContext`tt$$], 0.32, "taper"}, 0, 1}}, Typeset`size$$ = {
    432., {214., 218.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`span$3050$$ = 
    0, $CellContext`chord$3051$$ = 0, $CellContext`sweep$3052$$ = 
    0, $CellContext`dihedral$3053$$ = 0, $CellContext`tt$3054$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`chord$$ = 25, $CellContext`dihedral$$ = 
        2.5, $CellContext`span$$ = 42, $CellContext`sweep$$ = 
        14, $CellContext`tt$$ = 0.32}, "ControllerVariables" :> {
        Hold[$CellContext`span$$, $CellContext`span$3050$$, 0], 
        Hold[$CellContext`chord$$, $CellContext`chord$3051$$, 0], 
        Hold[$CellContext`sweep$$, $CellContext`sweep$3052$$, 0], 
        Hold[$CellContext`dihedral$$, $CellContext`dihedral$3053$$, 0], 
        Hold[$CellContext`tt$$, $CellContext`tt$3054$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         ParametricPlot3D[{
           $CellContext`af3d[$CellContext`t, $CellContext`span$$ \
$CellContext`p, $CellContext`chord$$ (
             1 - $CellContext`tt$$ $CellContext`p), $CellContext`sweep$$ \
$CellContext`p, $CellContext`dihedral$$ $CellContext`p], \
$CellContext`af3d[$CellContext`t, $CellContext`span$$ $CellContext`p, \
$CellContext`chord$$ (
              1 - $CellContext`tt$$ $CellContext`p), $CellContext`sweep$$ \
$CellContext`p, $CellContext`dihedral$$ $CellContext`p] {1, -1, 
            1}}, {$CellContext`t, 1, 62}, {$CellContext`p, 0, 1}, Mesh -> 8, 
          MeshFunctions -> {#2& }, MeshStyle -> LightBlue, ColorFunction -> 
          "GrayTones"], 
         Graphics3D[{
           Tube[{{55, 0, 3}, {-35, 0, 3}}, 4]}]}, 
        PlotRange -> {{-40, 80}, {-50, 50}, {-8, 8}}, BoxRatios -> Automatic, 
        SphericalRegion -> True, ImageSize -> 6 72, Axes -> False, Boxed -> 
        False, Background -> ColorData["LakeColors"][0.73]], 
      "Specifications" :> {{{$CellContext`span$$, 42, "span"}, 35, 
         50}, {{$CellContext`chord$$, 25, "root chord"}, 15, 
         30}, {{$CellContext`sweep$$, 14, "sweep"}, 0, 
         50}, {{$CellContext`dihedral$$, 2.5, "dihedral"}, 0, 
         5}, {{$CellContext`tt$$, 0.32, "taper"}, 0, 1}}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{741., {240., 245.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({{$CellContext`af3d[
           Pattern[$CellContext`t, 
            Blank[]], 
           Pattern[$CellContext`pos, 
            Blank[]], 
           Pattern[$CellContext`chrd, 
            Blank[]], 
           Pattern[$CellContext`swp, 
            Blank[]], 
           Pattern[$CellContext`dih, 
            
            Blank[]]] := {$CellContext`swp + $CellContext`chrd \
$CellContext`xFun[$CellContext`t], $CellContext`pos, $CellContext`dih + \
$CellContext`chrd $CellContext`yFun[$CellContext`t]}, $CellContext`pos = {{
          697}}, $CellContext`xFun = 
         InterpolatingFunction[{{1., 62.}}, {
           4, 39, 0, {62}, {4}, 0, 0, 0, 0, Automatic}, CompressedData["
1:eJw1x8tKggEUhdGdI4cNHDhoYBEhImFWal5+fy+V3cFHEBr7Cj6yj6Dg8sBh
7e96s13/V5JcHL/I+fZTozxR5SVrrPOKDd7wlndsssU279nhA7t85BOf2WOf
A75wyBHHnLDglOXJHTPTzFwzC80sNfOqmTfNvGtmpZkPzXxq5ksz35r50cyv
Zv7KA8F3J4s=
           "], {
            BSplineFunction[1, {{1., 62.}}, {3}, {False}, {CompressedData["
1:eJwB/QEC/iFib1JlAQAAAD4AAABVTRB1HwDwP+nMqQsjAPA/BFp8p1bT7z+Q
GBoAcz/vPx0nM7EApu4/BQ8FNpDj7T9I3jVCW/rsP7CttjC57Os/CUzBwdG9
6j+EGupG3nDpP8Ia1uN6Ceg/lg+SM56L5j/Y639yafvkP1fBCF1yXeM/o5Xn
isu14T88S0fSoQngPw86kVteutw/JGSA7c5q2T/UkAHIhi3WP3zWXF7lC9M/
2EnRqYwN0D8tLTVqXn3KPy1HES3+M8U/E34Bt3M3wD9pJZTGqGy3PwePZWCX
SK8/FNG0cbGSoj++bO90GQWSP3LSJKqEcHU/AyE7BwQBTL8hQ7rrVQJOv5eF
xHZLgXI/Oc80Yklcjj8alhBxmFCeP0ClET7D1Kg/crQvZ+RAsj/MQefp8BW5
P8tw6P7yfMA/EOv8PdX9xD9D11aTnSLKP+7KX+rrxs8/FWrYJhLg0j/2PbTr
aALWP3SIPniPQNk/Gej44dWR3D8K0Vxq1ezfP0eKfDjoo+E/kmdGBBBN4z9H
tAJViOzkP9SSLvCNfuY/lPAfZvj95z+1FX1tKGfpPxy/2/qtteo/dEaCEFXm
6z8Bk80JO/XsP+C4D9D73+0/GWv6MVSj7j8xtMva/j3vP4Xs/TwGre8/BB5e
SVAE8D/el5DWaQDwP1VNEHUfAPA/Yaj0Rw==
              "], {}}, CompressedData["
1:eJx9zs0OwUAYRuGXlZ2NhUUXiAiJEP80mo4qWi0SlyCxdglcsjtAzJklk0ye
nPkmk6lfbudrUVLhsyO59Qz/WzKv7yob2xWsooc1bGATW9jmnQ7dxR7nfXqA
QxzhGCc4xRnOcYE+7/r0EgPOAzpEY32gVjQqolFrGhXTqA2N2tKoHY1K7L/u
CZ0yT/mv6z3zjPsZnTPPue/6wPyIp5++AR82Xz4=
             "], {0}, 
             MachinePrecision, "Unevaluated"], {}}, {
           Automatic}], $CellContext`yFun = 
         InterpolatingFunction[{{1., 62.}}, {
           4, 39, 0, {62}, {4}, 0, 0, 0, 0, Automatic}, CompressedData["
1:eJw1x8tKggEUhdGdI4cNHDhoYBEhImFWal5+fy+V3cFHEBr7Cj6yj6Dg8sBh
7e96s13/V5JcHL/I+fZTozxR5SVrrPOKDd7wlndsssU279nhA7t85BOf2WOf
A75wyBHHnLDglOXJHTPTzFwzC80sNfOqmTfNvGtmpZkPzXxq5ksz35r50cyv
Zv7KA8F3J4s=
           "], {
            BSplineFunction[1, {{1., 62.}}, {3}, {False}, {CompressedData["
1:eJwB/QEC/iFib1JlAQAAAD4AAABN27+y0qRUP8HdxCAJg1Q/RRdpUrGpYT8o
GH1eb650P9GxPBRhZIA/7KUYtZPehz/Q2k99iVGQP9WSKzLYN5U/yPYEbO2K
mj/cZQCn3BWgP8GWfv9fAKM/vclZc/7wpT+PrbSqQt6oP+92Zqhfs6s/K/rg
/+Rerj/Bg7vTo2awP+BvrjwFeLE/aq25UDhXsj/kwWYqC/6yP5grKzF0YrM/
d8Epcq1/sz/HqQqfdE+zP/zJxnUS1LI/aWZBzqrPsT+Q3088JSSwP941IH53
tas/gUNSvZw3pj9cJSNjZ0GgP59I9ou0p5Q/+xT6WAUvgz+MZWFhs0oyvy3o
zeyu5YC/GKf8IBkpjb+3JDtjyU6Tvwn4Bm3cFJe/SrAyfMB7mr9hLMX4ZN6d
v4ivB9XgyKC/dvhZ7/y/or/ApvexlKakv+Y7ETjMBKa/bSo3XRzZpr+XJ9Wa
hiunvz+WDITeBKe/q4pzL+Fwpr9fUD4Ujn6lvydP2iusPKS/kptFSn+/or9R
0BWbbQ2hv/naSAHEfp6/4gMJ/siymr/M+FWIqOKWv9gkMooXFJO/G1BxcTvl
jr+1K5VuSw6Iv7lUrvgt4YG/MS0Mcckeeb+ikqFhb2Bwvy9VRIDiRGS/C/Nr
TXy6T7+lQct8vQVgv03bv7LSpFQ/uY//Qw==
              "], {}}, CompressedData["
1:eJx9zs0OwUAYRuGXlZ2NhUUXiAiJEP80mo4qWi0SlyCxdglcsjtAzJklk0ye
nPkmk6lfbudrUVLhsyO59Qz/WzKv7yob2xWsooc1bGATW9jmnQ7dxR7nfXqA
QxzhGCc4xRnOcYE+7/r0EgPOAzpEY32gVjQqolFrGhXTqA2N2tKoHY1K7L/u
CZ0yT/mv6z3zjPsZnTPPue/6wPyIp5++AR82Xz4=
             "], {0}, 
             MachinePrecision, "Unevaluated"], {}}, {Automatic}]}; {Null}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Picture"],

Cell["", "Spacer"],

Cell[TextData[{
 "Engineers and research scientists often get information in the form of text \
files. For this next example we will use a file containing coordinates for \
the NACA (National Advisory Committee for Aeronautics) 23012 airfoil. We will \
show how to bring the information into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", select the information we want to use and convert it into a pair of \
interpolating functions that can be used in many different ways. Finally, we \
will construct a 3D plot from the information."
}], "Text"],

Cell[TextData[{
 "These airfoil coordinates come from the Pubic Domain Aeronautical Software \
website: ",
 ButtonBox["http://www.ae.uiuc.edu/m-selig/ads/coord/naca23012.dat",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.ae.uiuc.edu/m-selig/ads/coord/naca23012.dat"], None},
  ButtonNote->"http://www.ae.uiuc.edu/m-selig/ads/coord/naca23012.dat"],
 "."
}], "Text",
 CellChangeTimes->{{3.4475856899931602`*^9, 3.4475857177568817`*^9}}],

Cell[TextData[{
 "Additional information about the airfoil can be found at: ",
 ButtonBox["www.centennialofflight.gov/essay/Evolution_of_Technology/airfoils/\
Tech5.htm",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.centennialofflight.gov/essay/Evolution_of_Technology/\
airfoils/Tech5.htm"], None}],
 "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Text Files: Import from NACA 23012\
\>", "Section"],

Cell["This imports the data.", "Text",
 CellChangeTimes->{{3.4272002165795593`*^9, 3.427200237571753*^9}}],

Cell[BoxData[
 RowBox[{"NACA23012data", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<naca23012.dat\>\"", ",", "\"\<Table\>\""}], "]"}]}]], "Input",\

 CellChangeTimes->{
  3.447585758819232*^9, {3.488205950387698*^9, 3.488205955650025*^9}}],

Cell[TextData[{
 "If ",
 ButtonBox["Dimensions",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Dimensions"],
 " returns a single value, it often indicates the array is a ragged table. \
That is, the rows vary in length."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "NACA23012data", "]"}]], "Input",
 CellChangeTimes->{{3.427200303301835*^9, 3.427200317055731*^9}, {
  3.42720052414647*^9, 3.4272005257019978`*^9}, {3.427200731331396*^9, 
  3.427200732980947*^9}}],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"Rest", "[", "NACA23012data", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.44758621952078*^9, 3.447586232929783*^9}, {
  3.447586268221859*^9, 3.4475862813407507`*^9}}],

Cell["\<\
Here is the first row of NACA23012data showing it to be header data which we \
will want to discard.\
\>", "MathCaption",
 CellChangeTimes->{
  3.447586129771968*^9, {3.447586161450037*^9, 3.447586194056464*^9}}],

Cell[BoxData[
 RowBox[{"NACA23012data", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell["\<\
To create a closed path we add the first point at the end of the data.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"afData", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Rest", "[", "NACA23012data", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"NACA23012data", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}]}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Text Files: Interpolation", "Section"],

Cell[TextData[{
 "So what are these data? We can use ",
 ButtonBox["Part",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Part"],
 " to get the information we are interested in from the original data set."
}], "Text"],

Cell[BoxData[
 RowBox[{"Length", "[", "afData", "]"}]], "Input"],

Cell[TextData[{
 "We will extract two lists from the data: the first defining the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "-coordinates and the second defining the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 "-coordinates. "
}], "Text"],

Cell[BoxData[{
 RowBox[{"afData", "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", " ", "1"}], "]"}], "]"}], "\n", 
 RowBox[{"afData", "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", " ", "2"}], "]"}], "]"}]}], "DisplayFormula"],

Cell["\<\
We then interpolate these lists using spline interpolation which has \
continuous derivatives.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"xFun", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{
    RowBox[{"afData", "\[LeftDoubleBracket]", 
     RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"yFun", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{
    RowBox[{"afData", "\[LeftDoubleBracket]", 
     RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}]], "Input"],

Cell[TextData[{
 "Using ",
 ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"],
 " we can easily visualize our interpolating functions."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xFun", "[", "\[Theta]", "]"}], ",", 
          RowBox[{"yFun", "[", "\[Theta]", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "1", ",", "62"}], "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", " ", 
         RowBox[{"9", " ", "72"}]}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"AbsolutePointSize", "[", "8", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"xFun", "[", "t", "]"}], ",", 
            RowBox[{"yFun", "[", "t", "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
      "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"t", ",", "1", ",", "62"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Using the information from the dynamic output above, we can examine the \
leading edge of the airfoil.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ParametricPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xFun", "[", "n", "]"}], ",", 
        RowBox[{"yFun", "[", "n", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "26", ",", "36"}], "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"afData", "[", 
       RowBox[{"[", 
        RowBox[{"26", ";;", "36"}], "]"}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "}"}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Text Files: Extending to three dimensions\
\>", "Section"],

Cell["\<\
Even though these functions are defined in two dimensions they are easily \
extended to three dimensions. We illustrate this with an interactive graphic, \
but similar ideas could be used to create simulations of aerodynamic \
properties of the wing.\
\>", "Text",
 CellChangeTimes->{{3.427273043896949*^9, 3.427273098507721*^9}, {
  3.427277420857573*^9, 3.4272775905803223`*^9}, {3.427277623774869*^9, 
  3.427277640694024*^9}}],

Cell["A function to describe a half-wing in 3-space.", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"af3d", "[", 
   RowBox[{"t_", ",", "pos_", ",", "chrd_", ",", "swp_", ",", "dih_"}], "]"}],
   ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"swp", "+", 
     RowBox[{"chrd", " ", 
      RowBox[{"xFun", "[", "t", "]"}]}]}], ",", "pos", ",", 
    RowBox[{"dih", "+", 
     RowBox[{"chrd", " ", 
      RowBox[{"yFun", "[", "t", "]"}]}]}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "Here we put this into a ",
 ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"],
 " to make it easy to vary the parameters dynamically."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"af3d", "[", 
            RowBox[{"t", ",", 
             RowBox[{"span", " ", "p"}], ",", 
             RowBox[{"chord", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"tt", " ", "p"}]}], ")"}]}], ",", 
             RowBox[{"sweep", " ", "p"}], ",", 
             RowBox[{"dihedral", " ", "p"}]}], "]"}], ",", 
           RowBox[{
            RowBox[{"af3d", "[", 
             RowBox[{"t", ",", 
              RowBox[{"span", " ", "p"}], ",", 
              RowBox[{"chord", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"tt", "  ", "p"}]}], ")"}]}], ",", 
              RowBox[{"sweep", " ", "p"}], ",", 
              RowBox[{"dihedral", " ", "p"}]}], "]"}], 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "1", ",", "62"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"Mesh", "\[Rule]", " ", "8"}], ",", " ", 
         RowBox[{"MeshFunctions", "\[Rule]", " ", 
          RowBox[{"{", 
           RowBox[{"#2", "&"}], "}"}]}], ",", 
         RowBox[{"MeshStyle", "\[Rule]", " ", "LightBlue"}], ",", 
         RowBox[{"ColorFunction", "\[Rule]", " ", "\"\<GrayTones\>\""}]}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{"{", 
         RowBox[{"Tube", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"55", ",", "0", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "35"}], ",", "0", ",", "3"}], "}"}]}], "}"}], ",",
            "4"}], "]"}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "40"}], ",", "80"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", " ", "Automatic"}], ",", 
     RowBox[{"SphericalRegion", "\[Rule]", " ", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
     RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
     RowBox[{"Background", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"ColorData", "[", "\"\<LakeColors\>\"", "]"}], "[", ".73", 
       "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"span", ",", "42", ",", "\"\<span\>\""}], "}"}], ",", "35", ",",
      "50"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"chord", ",", "25", ",", "\"\<root chord\>\""}], "}"}], ",", 
     "15", ",", "30"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sweep", ",", "14", ",", "\"\<sweep\>\""}], "}"}], ",", "0", 
     ",", "50"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dihedral", ",", "2.5", ",", "\"\<dihedral\>\""}], "}"}], ",", 
     "0", ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tt", ",", ".32", ",", "\"\<taper\>\""}], "}"}], ",", "0", ",", 
     "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", " ", "Left"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"af3d", "[", 
       RowBox[{"t_", ",", "pos_", ",", "chrd_", ",", "swp_", ",", "dih_"}], 
       "]"}], ":=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"swp", "+", 
         RowBox[{"chrd", "   ", 
          RowBox[{"xFun", "[", "t", "]"}]}]}], ",", "pos", ",", 
        RowBox[{"dih", "+", 
         RowBox[{"chrd", "  ", 
          RowBox[{"yFun", "[", "t", "]"}]}]}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447586637722508*^9, 3.447586638342643*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["HDF", "Section"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    RasterBox[CompressedData["
1:eJzsfXmcZlV1bakPB5Qhz4eCAQPy0wYkYVJkCleI/CDwZJIg4jy0RAgQEfCh
plUeEcwvioKCAQERfDIpyAwiCooyTzI2zdjQ3fTIJIIgvheKrvLRWVW1qtau
vc/3rfXPspcft+4999xzzzl377VX+9i+O0992cDAwHYvGRi48aUDA//5vw3D
MAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzD
MAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzD
MAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzD
MAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzD
MAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMHoDj3Rm
8zAbhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEY
hmEYhlEf2f4EZrO599kwDMMwDMMwDMMwDMMwDKNXkb3/WoVVyL6OVtvNMAzD
MAzDMAzDMAzDMAzDMAzDMAzDMAzDMAyjdbQSl5Udd2Y2m83mttkwDMMwDMMw
DMMwDMMwDCMa2fugZnNLbBiGYRiGYRiGYRiGYRiGYRiGYRiGYRiGYRiGkYXs
+Cmz2Ww2m829z4ZhGIZhGIZhGIZhGIYxmcjeDzObze2xYRiGYRiGYRiGYRiG
YRiGYRiGYRiGYRiGYRgGQnZ802THQWVfh9lsNpvN5vGzYRiGYRiGYRiGYRiG
0Ray95PMZrN5stkwDMMwDMMwDMMwDMMwDMMwDMMwDMMwDMMwDAMhO77JbDab
zWazeaxsGIZhGIZhGIZhGIbRCrL3Ucxms9kcy4ZhGIZhGIZhGIZhGIZhGIZh
GIZhGIZhGIZh1Ed2nJHZbDabzWazuQ02DMMwDMMwDMMwjH5G9rrcbDabzf3F
hmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmHUR3ackdlsNpvNZrPZPBIbhmEY
vQ2/RwzDMAzDUCF7/Wo2m81m83jYMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzD
MIx2kR1/ZDabzWaz2Ww2m4dZhejjG4bRP2h9PDQMwzAMo3+QvZ4zm81ms7kl
NgzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAyjXWTHH5nNZrPZbDabzb3MxuQg
+z6bNdw6stuvX9rZMAzDMIzJR/b8xWw2m83mXmbDMAzDMAzDMAzDMAzDMAzD
MAzDMAzDMAzDMOogO57IbDabzWaz2Ww2D7MK2ddhNk8Gq9D6+RuG0XvwuGQY
RuvInieazWaz2dwLbBiGYRiGYRiGYRiGYRiGYRiGYRiGYRiGYRhGHWTHE5nN
ZrPZbDabzWaz2WweP0cj6+8axliQ/fz1O/cb3D5GPyN7vDGbzWaz2Tx5bBiG
YRiGYRiGYRiGYRiGYRiGYRiGYRiGYRjGksiO6zGbzWaz2Ww2m81ms9msZyMX
2fffbDZ7PDSMkZD9XJrNZrPZbO4dNgzDMAzDMAzDMAzDMAzDMAzDMAzDMAzD
MIwWkR13YzabzWaz2Ww2m81ms9lsNpvNVdgw+hnZz5/ZbDabzWbzWNkwDMMw
DMMwDMMwDMMwDMMwDMMwDMMwDMPoT2THrZjNZrPZbDabzWaz2Ww2m81mc3U2
DGPiyH6OzWaz2Ww2m6PYMAzDMAzDMAzDMAzDMAzDMAzDMAzDMAzDyEV2/IjZ
bDabzWaz2Ww2m81ms9lsNps5Nox+RvbzZzabzWaz2dwqG4ZhGIZhGIZhGIZh
GIZhGIZhGIZhGIZhsMiOdzCbzWaz2Ww2m81ms9lsNpvNZnN/sWH0M7KfP7PZ
bDabzWazeTxsGIZhGIZhGIZhGIZhGIZhGIZhGIZhGJOJ7O/kZrPZbDabzWaz
2Ww2m81ms9lsNvcjG8ZkIru/m81ms9lsNpvNZrOZY2MQ2ffBHMtGLqLvo/uD
YRiGUQHZ8x2/Bw3DMAzDMAzDMAxDj+x1vNlsNpvNZrPZbDabzWaz2Ww2v5hV
yL4Os7klbgWtn3+/Ibtfm81ms9lsNpvNZrPZbDb3Gmch+7r7pZ0NwzCMyUH2
e6YKG4ZhGIZhGIZhGEYFZK+PzWaz2Ww2m81ms9lsNpvNZrPZbDab+52Nmsju
F2az2Ww2m81ms9lsNpvNZvNksGEYhjE+ZI/f/c6GYRiGYRiGYRjG+JC9njOb
zebJ4x22Pv/Uf774ghf+PTBw7pmbbbPDN2+k9d3fN3DDorsuGtJ/P332Rqtd
eFO4zp5ntfZUXW9W+7d+v8xms9lsNpvNZrPZbDabzebJZwT290ZNZPcvs9ls
NpvNZrPZbDabzWazuZfZMAwDodq4lD1emmuxYRiGYRiGYRhGNLLXPWZzRY5G
9vWZx8rRfhpT99r2iX3++NMhfdOXH7nm4/fcHK6r/ByydJV/RbX2j/blGPxX
/nNlNpvNZrPZbDabzWaz2Ww282z0BrL7kdlsNpvNZrPZbDabzWaz2Wyuy4Yx
FmT3U7PZXJcNwzAMwzAMwzAQstcrZnNFRsg+L/Nkc7TPQ5afg0pn2yHaH6NX
27na/WX1wX/lP89ms9lsNpvNZrPZbDabzWaz0Rqy+4vZbDabzWaz2Ww2m81m
s9ls7l82cpF9/81mc++wYRiGYfQSst+rfv/WgtvfmExkjytms7m993X29bXH
qrz+LD8H1ufhn//lWystfOOlQ/q09TZ/wxVL3RKuX7r1vidsuOovhvTLP/Dw
0kevfSt9HHRdWe2s8tlQtfMvd/wf6z+57mVD+lKHfeuZf3zPbTKdvY/s9bLt
xvqrZD3v0eOGfUjMZrPZbDabJ4ej55PZ12fOYfcHs9lsNo+djVxk33+z2Ww2
m81ms9lsNpvNZrPZbB4rG4PIvg9ms9k8VlYh+zqirisarbdPtfMxegPZ40f1
564astvVzHE0sq+vevv0KrLvm9lsNk+UWWSfbz5n5cuzPgDROvI9iNaj/Ryi
fR5a0VnfklbuF6tH399qvivR44/zPc1ms9lsNmdxlh9ar64T+833o1p/sF6z
n5jNZrN5LGxMDrLvs9lsNpvNZrPZbDabzWaz2Ww2m81ms9lsbo9ZVDsfoyay
+7X5v2YW2edrNpv1z7UK2ddtNpvN5omyKr8pK1+e9QFg/RNUvge3v++iX523
xeVD+m7ndPM3+dzt3d0f+9B7D9j5l0P6sffMnfGaE+9oRmfbAbU/q7O+EOzv
s/wxWter+XWw4wCrsz48Kr8R59+ZzWazuTJn+S1Yz9VV6zLVuiDLB091XWx7
VusPqn4SvQ/Qq3rW/a3mQ+L3SG/cL/vSmM3G5CD7PpvNZrPZbDabzWaz2Ww2
m81ms9lsNpvNZvNEuXVkt19Ue2Zfh9lsNpv/a45G9vWZzWazeayM4s9V+e+q
fKgsPcs344G9Xjb3bR//1ZB+z6uOuu6e39wZrqvOE7UP0rPy4Nj7q9JRe0Yf
P/rvtu7XofJdqZYX6Twjs9lsNv85V8trVr3HVXq19Qg7L2pl/VVtHp61/oqe
h1e770iPvi62v2X1z+j1V7X7rhrfov0So8e96HV0tf6gul+sbh8Ps5llY2Rk
3x+z2Ww2m81ms9lsNpvNZrPZbDabzWaz2WyebM5C9nWbzWaz2Ww2m83mXmA2
PlxVBzY6j0DlaxGtz9n/lC888ZkrhvQ3vX2LS89aOB3qC//l3cude8ivh/Sp
H5n/44NXmNGdu+XLXvXVP/1mSP/xkbtf8MkL7oY6e3z2PFV+Haz/Q7X724q/
StZ1ZfmlROcrqfKnVPlE1eoaD/4r//1nNpvNvc7RPhisrvK5UunV5hWq/H2v
s8a3zlLp7LosWmfPn12PVLvvWesyVf+J7s9Zz13r/Uc1bmf1q6z+0IquWqdH
61nrd6/3zWNnoyay+4XZbDabzWaz2Ww2m81ms9lsNpvNZrPZbO5fViH7Osxm
s9lsNpvNZnMvc7TPRnQ+QjUfA1W+g8pPI0tX+XWweTqq/J2sutVZ+YDV2r/f
fDzY/Fnk46Gq52tfjlx2+5jNZsT2zRjUVX5W1dYjvapnzVdV66mtzv3UD997
5lVD+iV7fuMlvzjq3u62N9+41Vs+fM2Q/tCqM3/wmp/el6aj86zm49FvOuqH
rN6KTwvrP8PuG2T9Pnp/o9p9j94Xymrnav6l7D6Ayl8LzaNU/h72AzHHsaFF
9v00m81ms9lsNpvNZrPZbDabzWaz2Ww2m81ms9lsNpvNZrPZbM7naJ8NFL/N
xo2r4t5Vcf4qnc2HQr9H+h5Hb/jgE8teN6T/02ue2/ai0+6X6ez5sHp0vkZ0
3k20rsoTjM6XYdszK88lKy8mK49G5csR7eNRLY+m3/6u2Wye+POYpav8MVR+
GtH+GCo/qyy/tWp61nxYNb9V6Wgd9NQrjzv4l5deP6Q/8fsVH5l6zAPdjj/7
8vJ//44bh/RDZ27w7f/+bzOhjo7D/t3odV/WelC1fszqP9V05NPC3nfW70XV
r6r1Q7YdVL/Pet6r6Vn3sdr4Fv1eVs0rVPseaD6p2vdoZV/CPBZmUe04rSP7
/pvNZrPZbDabzWaz2Ww2m81ms9lsNpvNZrPZbDabzWaz2Ww2j86qutUonw7F
RaO8dTbPi62XWq1OsSq/AOVbqfK/2Lwwlc7m9UTXg1bla/SqHp0Hp/IDYevb
ot+z41iWHwjS2TxlNM6zusp/o1o93Fb0wX/lzz/M/cGq/hntO9Fvuso3I9of
g11HqHSVHwXrUxE9L6qmR8+fVeumFZ8898PrLnfTkL7sDdtv8vODHrT+gp61
TmxlXcn+XVW/Ve0PtNLfsvYxqj0v1e5XtfvO6tHnWW08ZMeHaN8ndn9J5R+i
8lll/UDQfDt6P2TwX/nrxhhuBf3WDtn9wmw2m81ms9lsNpvNZrPZbDabzWaz
2Ww2m81ms9lsNpvNZnM/sqrONVuHmq0TzcZFt1KnGMXh3/83c378+tnD+rcv
/tS9e33qoXB9v+9t/+5ZR/12SD/5myesecU2s2W66jyj82iy8gVUPirR7aDS
Ve0Q7YuSVR+2Wv1ZVV4JW3+W9eVQ1aW1v0c/5NeYVRztd1HNN0M1nqjGsWid
zQdUrQuQHu2PofLTYH0zouvdV9OrzYdbX8edtsdfPvfcpTcP6Sv/n0MOWfF9
s6CO1mvo96p1per4qvVjtfx9VT9Ev8/qh9H7DCo9un+q2od93rPOP3ocU417
WfrJG/zk4/t+8pYhffl3/GC/j711Tvh9b6U92fNR+bew/iTsfhSaB7K+r+z+
TLS/h/cT/pxbQXY7mc1ms9lsNpvNZrPZbDabzWaz2Ww2m81ms9lsNpvNZrPZ
bDbrmc1DZPMEUfwtmwfH1ndm6xpn1SlG8d4ofl6lf/lnd5284ZtvHdJ3n/bR
Y+54fE73oa1fPuuPM4f1k69Y5fLtL3m4nM5eb3T+hSp/oVq9V1ZX5eNk5Tu0
XudapbP5HazOjudsfjTSUb62Skd5Jaye5e+R5RMy+K/8+ZB5bBztj5GlV/Op
UI0nSI8eD1ld5Y+h8tNQ+W+wflbRfhpZ8wrVvEg1T1PNM6utL7LWla3r1e5X
ls7mrbM+AN7H0O5vsO2T1W7s30XXFd2e1dptxfe//x///aO3D+kb7XLUX2z6
7nnh+qY3rTvliu/fNqQvfM30h391yFx4nuj30eeZ9Zyi/qB6ftn9MdV+VLSP
B+ubyu6HeP8hgqORfX1ms9lsNpvNZrPZbDabzWaz2Ww2m81ms9lsNpvNZnMt
dp1ls9ncOlerI6/Kc1TVp0Z5c6r6zmy9Y7Z+saqepipPJDqO/U8P/uup71n1
jiH9a8fuvPFPVphfTlflBbDx86yuyu+oVke1FT26Pm/r9axZXVVHHumqPGL0
vmDzRFR1YFmdzUNR1ZlV+QOo8l+8jhuZW5lPsvPMaj4Y7HOk+j3Sq/lgqHSV
r0W0zvpmZPlsRL+vVf6E0fMWlS9ctM9AdN6uKq+8dR2tE6P/bivtz+4/qPwB
qu0zRO9XsPsY1fRoPwdVP1H1w6x+e+FT09/6wHF3DulvWuuaw477Pwtk+rcP
XmrvUz8wffg9/ulDz3rtvgvDj7/fa9b98T//5V1D+vkX/t0dX33HItnfnbHP
WXPfcO9we97+wLIfnXLPfKirjhPdP1W+H2g+o/LxUO3PqPw6WB8P70v0ErNg
j5N9fWaz2Ww2m81ms9lsNpvNZrPZbDabzWaz2Ww2m829w9XyXKzXrO9svS19
8F/540uvc5a/RHRdaZUenZenqjfN5pexdY1RvpWqritbZ1MV58/Gh6P4dlbf
4ajdF71j+nA8/CAekeko3p49T1WcfK/W32T7raqebK/WG229XrYqz1RVF57N
70A6el+gvA/03mF1lCfC5o9E61l5+mje4vVXb6/fo30wUL/K6uet6FnjD+un
wY6rrK4a/1U666fBro+i39esrvI3i54vsfO9avNhlR69Puo3nW1n9n6p/DGy
9h9UumqfQeVLwO5LVNPZ9mGPw7Yb2w+jrze636L9tHdv9+YtLpwbp2838MgR
Gz0zcT3r70bvZ7J69PjD7nNW8/FA81uko3k16+/B+qCy+xv+zliBo5F9feb/
mllkn6/ZbDabzWaz2Ww2m81ms9ls/k9m98+rxQF6/99sNpvNZrNZy9Xmda3M
91TnWa2dq+XFqPJoquWnV9Or5UlZ7408vsF/1Rmfo/0xVONPVt3naL+L6Dw4
No8Mxc2ydYqjfTPY/JRo3wxVvD0br/7351384IWvnjFhXRWfn+XvEZ3PklU/
Nzq/THX+rfufsHkN0f4haJxU1W1X+ZCg8R+9L9h6rGx+h8rHIzqvHOno/Y50
dv6gylth53tZ8/xeXb9H+2O04jtXzaeimj9GtG9GK34X0TrrNxjtgxHtd5E1
P0Hzrtb9KNh5eLV8/9Z1dn3H7iewOusXwfoAVNPZfZJq/qLVfB5U7VCtn1Tr
n6r9OvT7rff81w03XnnJ31sfWVftc6r2P9lxBo3z7PuI9Xdi97XYeSm7L8T6
eKD1Dtr3QOvTaL+Oat8HzeY4jkb29ZnNbXC1eBi/N81ms9lsNpvNZrPZbK7P
1fLyVHGA3t8wm82I/bybzeZqXG3e0ooPQ7XrrdbOWfkpKD6nFZ2NO1Llrbeu
o3yfavfX+qCeNT6weta4mjXuqfwxousys/XX0O9Znc0vY/POUF4zioNFcbNs
vhVb7xXpKK6Y9cdA8c9s3geK697qr3Y87KK1x66/65Y3TN/4b5fUt/zqQ2+9
+N2Tr6PzQefPxr2z8fCq+PZoXVVvt990Vb6bSlflUbLjG9JZ349onfUJYfMv
VDp637H+Hqr3skpn5xUqfw92/cjms0T7eHjfQDtvz5rPt65HryNUusoHA+ns
+MzqqvcIen+x/hgq/wpWz5onsP5mqvVglk9CtK9Clq7yB2D9IrLWa1nno9qX
YPcrrA/q7P5DNb1ae7I62kdi99OQrtqvi9az9v3Y/UBWZ49frR1U/S1rXGLf
O+x+ncrfQ7WPhPZz0HqH9SnN+i5ZLW5k8F914oLY8zGbzebWuVr8XnRcpcd/
s9lsNpvN5t7mavsD1c7HbDabEVdbv/dqHavoumOt5J8O/iu/35v7m6PHsWrj
Q7V9XY8b5grPtaoftjJfUs2jVONedH1P6zXrolarr8rmrWTVS82q+5xVV7pa
Hduserhsf4g+/2rjAKuzeYgqPXrcQ+NVtA+Gqm5ydF1jlY7+LtLZespsnWK2
vjCbf4TyYpDfAltfko3zR/Hh79z8rH/Z5ENL6ps//rkbLt5nSX2zU7ZabdMv
TlxfdNaxPzt+vYnr6Pjo/NH1Ip2Nz1f5e2TVwYzO31HVC1b5nETr0fWI0fiT
lY9ZrQ47mz/L1q9H+chsvrNKV71/VTrrE8L6h6D5EjtPY+eHaJ7pfYnJ0Vvf
Z2Dn/63oKp+9aF01vqHxFo3P6H2h0tl1EKuz79MsPXpeofLBUM0Ds3Q0v82a
b6t0dh0Rvf5S6So/Afb30Tq779GrOrv/kHVfWrlfKt8Ddt9JpaN9MNX+WPQ+
Ifq7qn0/VTtktY9KV7UD2/9ZPxPVvqjKf5j1v0X+Huz+ElqPsH4dqu/Lqu+J
0d8ZW4mracXPZPBfcfFm7PHNZnMdVsVzDpColg+SFZc++K/8frCYq8XJO97e
bDabzeb+4Wr+bKrfR5+P51Hmyux+NTlcbf0VndeZVceKjeurpqv2t7Pqnfl9
Z648flbz5+k3/x+PA73NWfMW1XfeVuZFrdf9jM6zVuVHsH+XrUMaXefU9U/b
qqOK8kTQ76vViWZ19npb0au1j6oed3S+mGp8i9aj892i+xuKe1TVQVblf6G8
4Oj6xdF5ZGw9YjYfiq3riuJ+UfwwG//PxnuzvhYHfHjeIXtstOT5I/3CDY+c
c81Pp49Z/8Mym/7PdbuJ6+j47Pmz/h6qOPZq9T3ZvB5Wj64Pq8o/qlb3k80H
VNWtrlbHnM1vZevIq+qfovdU9HuWrbvK6io/EFZn50usjwc7P2Tn+dHzZ9X+
RjW/xGg9a32qWhf0qh7tE8iOe6p1CnpfqHwn0PsrWmffs9E6O09QzU9YPwrV
PLCaHu3zoPJ/UB0/ev1SzU+gFT163a3an1Hl9Wddr6odWtGjfWVb0dc/7O9W
e9l5Y99Psz6yzu5bRutZ9519HrN8PNh5HbvPhua3aH2B1i+sryDaP2G/n0bX
laj2HTNLV9VNyIpnrpYH1G/xk9Xax/elNzg6LnSARLV48uhxdfBfdcaNavHz
zscxm81ms7l/OGt+0kpeoXXnY07kOarmq9C63m++FtF5oL1ax6pa3eSsesQq
H29V/2x9HBj8V/77ZrK42vjZ+nhVza++V/1Aqu0PI259PlNtflKtvmf0+MPm
L0T7QmTNo1R+C9Xmh2zcSL/VOe3Veqmq+s5Z9aaj61ar8uCi69Kq+oOqn6vi
01rX2XEg+nmP9rtQ6WxeWOv1i1X1jlFcKxs3y/pmRNdDRPHPrA/GOx564Mxv
XX7nmPVLjlz/sx+86o5mdfZ6kY7aE90XpFerg5lVN7OaHu1noqovzNa/Zn08
quls3VJWZ/N20XuH1VnfD1ZH8wGVzvprsXq0H4hqHYHmt6r5c9a+TfQ+ico3
L3pfQrVujV4vZOnsOiVaZ8exaB8MNP6z7x2VzvpLqN6z7Htf9XdV58POu1g/
xqz5ocrXgl0vs+to9vdsfm7WuqPa+s66Vmfz0NnjZJ2/6vfs/gnrA6A6PrvP
Zt36n+usz7Bq31Kls37IrB69j5q1T8j6fqD9OjSPRX4dKv9Y1f6Mar+FrbMQ
vT/Tyvdi1ie2Wly0Sq8WR10tbrPf9Oh49VZ8ElqJd7UvR83nKEvv1fZsxbdq
8F/5+TNms9lsbpOj55nV6vlWyytsXW9l3lhtPtbKuq9af+s3PTpPM0vPqjPb
q/WtonXWl1u1X531Hm/lvZO1j5qlq8ZPNm+9mg981vcjlV7tPRs9bmTt//fq
+i56/pPln5M1brQyX1LlL1gfOY+jWp1TNp+oWp1TlX8F2w7R9VKtjxx/xbZ/
dJ4d2z/ZcaDfdDZPrZV8MbbuPBvfqKqbzNYpZvO2qtU7ZvPFUP4Rqj/L5suw
dQbZOG0UF33QJf/22qe3WlL/057Tp1/2P5f0o0D6llsevPlbbrx9Cf2y337p
mDP+cFuzOtsOqD2RzsarV6t3qdLZ+Pno47DHz6rXyepsHW223nd0vXJWZ31F
WJ2tT8rq1d6naJ7A6mx+OprPsDqaL7HzNNX6JXodocrjYPVW1heqfQZ2Hary
x2tdVz3XqvWOah2kGv/RegS9d6L9rNj3o8rPoXUdzX/Y+ViWzuaNsvNS1n8y
Wmf9A9njsOsF1fql2voOXW/W+s56TZ3d72J/r/q7SGf3hVT7SOz+kkqv5vPQ
yvVG95NW9Kz7jp531fuI9Rdi/cHYfTyVr130/hVal6n2eVT7OVl1K6LrX0T7
fqjipdnftx537byV3s6Xr6ZXazdVvx0AUOVLthLv3fp9bEVXtUO1+5XlU2Q2
m83m3mbVfLX1/KnWfTlaP/9q88Nq681+m/+z/bmaj0Q1vVfzPbN8J1rJ92T3
h6P1rH5VbV+o2v5D6+8v1XshKz89Ws/y66jm75Glex4+OfPD1uc/1caZ1udL
0fVAVT4VredxsH4CKl3lb9CKHu0XweZt9ZvO+hJU8wNh+1tWfFTW8dnfs34a
Kv+KLD06/0ulozhJlOfF1gtW5aNF57WhOFWUZ4TyblD8rSpun/WFQLrKp+LY
o/76jL/9zK1L6Ae8b/rPrp/32/I6Ov9ov45Ljlz/sx+8auw+Hln5BdH5Jlnn
E/132TwjlV+Hyt9DlV8Z7ROi0lX5tqxfR7Qe/T6t5q+F9BXf//5//PePDvtE
bbTLUX+x6bvn0T4haL7HroNaWXe0okfvk7D7AKifqOb51ebVrfgIse2pGodZ
/4pqPhIq34bo+UP0fCPrurL8KKJ11o9CpbPz8Fb8B1rR++16q+nRvhbV9hmy
fA9Ufq3We1tX7ev2ql7tfqn2OVW+H6r9PZVfbrTPbfT3JtYPJNrflfUJia5/
Ef3dGcXhRMd1q+JCVXGk1eKuW9ej46uz6ia37puRlZ81AFCt3ly/xUu3kr9W
rd2q5ctE59cM/is/P9xsNpvNE+NqPhvV5oEqHc2vkF7t/LPyKKPbuVfndVl+
OKze+nOtyt9Ev6+Wr52Vv8n6DLN6dJ6mKn8zS2fbLdoXOtp/IOt9F72/VO19
hPTo90W1fPMsP5ys54s9Tuvv8dZ9TlTzPZUe3Q6t+FRkjRutzKPQ9+4snc3X
VtUZUR0/uv6pSmfrk0afT5auqtPK1nFmdTZfTFVvWlWfulq9XVX/Qc81q6vG
nyyd9b1hn0e2n6Pnhc3HZI/D+lqwdZNV+VxsXePoespIZ+s7s+2A4ktRPCqq
T8fmI7Bx1ypfix1WPvSGD3/ixXFGWF/r3g3uf2TGjRP+PdLv/bvLHnrZ6ddP
us62A6uzPh5bbnnw5m+58fYx9wfWr4PNQ0HHRzo6/yyd9Uthj6+6L2wdT1X9
TbYuJ1uvM0tHeQeofihbVxS9F1T+HtsNPHLERs8seV9YXZXvUG0+oJo/sL5h
aJ7GzhtZ3zaV/yE7D2d/H+3TGH2eqvU+uu9oPo/6LXqu0biB5rHRfkRsfhY7
nrDPKdJV6wj2vrDtxurofcTq7HsQ/R69f9H7Gs0rsuYzqvNX6ap2YHV2nqn6
PVpHZ+loft66zq7vVOtKle8Be57s9Ubr0e0Zrbd+X1Q+ANX2PVg9ep8ner9I
5XPbyr4Wu9+VtT9W7e+qdHZfl/096zeCxmfWTwzNb7P2zVTro2gfQnY9i/YB
2O/71eoLsPtOKn9a1icEfb9m48yrxW9H52GpjhMdP1ktz9359bm+JaifDJCo
Fl8dnfcXrfdbXltWPHnWOFNtXIquk2ufkPFxdPv4PprNdbha/XHWZyM6T4rN
B8zygaxWZ7kVXZUHXW29WU2PXl9Uqxsenc9YrZ44On50XfKseuWt1BOvVied
3deN7icq/4GsvHiVT2kr+7fs/hU7zlcbV1vRq73XWter+au0Mm9X/b7afK/a
8541T0Pzh+g6oar8a5XOfn9n/S7Yv8vqbB4Kmw+i8oVoJd6DvV42fz+6viqb
d6+qG6vyJWDbM1pX9R+2bhEbL9SrOmo3Nk9N5UfB6mzelsoHg613zObZqfKF
WT06HlJVjxjFkbJ1b1k/DRR/i3wqjrzqDa96y3evGbP+7C3X7bDntCsmXWfP
M0tn/TpYHxKkI18UNk6bjd9m+yEbT876wETrqvuiul/RPh5Z9alb0VW+Imxd
UVbPel8jHZ1n1vlEz0NYPxPWN4Ctrxq9Lqt2nGidXY+z6wLUT9jnC40zSFfl
+7PjnqrOssqPKDrfSuWDwb4X2PZn76Oq/6D3r2oeoqozXk1X+bNl6arzVPkz
ZOnR+f7ROruuVOXFV7ve6Hzwau1QTVfl71sf1FvxhWhdz7q/7D5V9P5btX1C
lV80q7P7jar9Q9aXQ+VfF72uVO2/qfwG2XUuWj+i9SzaZ1DFCUT/no03iP7u
j75To+/abB0fFK+lqsMYHaeqiuuOrqeWFe+t+rvRceytxLdH51sNkMjKn1LF
IVfzl6jWnln1NKvVse23fM9q/htZfg7VrjdLz/Jvmej9M5tb4Gg/jSyfjej5
SVb+Xdb5++/WzKfuN1++rOea/T27X6TaX4quD96KrvK1YPXoOrnV6vmyfiCq
30f7e7C+H+zzW20/ROUXHb2vy/pOs+8LdjyvNo5F9/8svdp7MOvvVruPqvlM
1rpApavaod/6D3ueqnkX60cRrbN53Gz9U5WOvsurdJVfBFtvF8VLsDobX5Gl
s/n7bB3VanWZ2TwvVX+oprP9hPWlUcX5IL2V8Y3100D9U+U7odJVdedV/hgo
3g/FMVbT0fmr/DHYvDO2/i+qh4viXVG8MeunsfUO+6+9zdeuXEK/+hcv+esP
XnbpEvqGszc5dY/f/LT70C8fXffYA7/ZZetn7T7lM/++7+VLnGeWjtpT5csR
7deB+hWrq+LS0fWy7cn2f7b9WT8W1d9V3d9oHw9Wr1ZnmT2Oqh46+x5h8xHY
PIVq8wT2PLN0Nl+e1VXzT9b3o9o6VLVuZX0w0PWyvg3svB31fzQ+oHwo1XgV
rbP5XGjcYPOYsvTocYntP6p1DdJV7/HouvNoHhWdb6s6f/b4rK7yl1D5Y0T3
h2ifBNXx2XWcyi/R+sh6Kz4Jqr+b1T7R+xvV+lXr/dP6yDp7H1l/BnZ/idWz
9jmjzzNaHxCB9eVQ7ftF75up9tNa0VX7YKyvbPR+EatHxy2w3/1RXA1bdwPF
O7G+HNXiG6vFJVbzE+hVvVoelio/q1o8rfWa+aet5LdWy99EOvv8ZvkIReeD
W7f+57p9PMy9xNG+NyqfDTa/MjrvMroecVY96+j67L1a513VztX836r5+2Wt
R6L7bbX8a9b3gPVPYHWVD0Z03XNWr5bvifTo+uwqXxHV/Y32MYh+H2XNH1T7
Gyrf0Wo+G9Hjc7SeNd6qfHuq6dH+S6r2rOZrlDUequaBqvZU9f/o+541vrHP
kcrvAn13jtZZ/wqVzvpgRNddRXEIKh8JlLei0lXnqao/y+rRdVTZfCtWj46r
YfO2ovsVW1daFbejqstTbXxj/W1QP0H9Pyu/ia1jpaqrxfpCsHl50XVy0d9F
v2fz8lidrbPM5g2hfAcUH4vy+pEvxPeX2f/N+1134Qv+FSd2i/Vl3/ajE7/w
2/O6ZX6w51Vz1jttSL/+Jd3bVv/5md2Gb/ubP25xy3nj1nfd/idrb3TNqd02
zx//4lF1dJzP7z5rlUPvPPuF8//JqDq6LtQOrI78SVD7P3vLdTvsOe2KJXTW
r4P1nciqt6jygUHthtpfpbO+K+g8s3S2/6jqaaryd6LzE6PrKavyT1XvRzaf
ndXZPAjVfEB1/tG6yi+F/X30fFXlB4J0dp3LHp/1u4j2bUP3F/Uf9Lyo8tCj
8+uj8/SjfY1Ufkdsf2D7iWp9l+VvwOafRtc3V+WBqs4nK0+/2jyKPX61fhWt
R/dP1boyKx9c1T5Z4wCr92o/z3peVH6YWf02q/9E+4dE71eofDOy+ic7Pkf7
0LLHifY3zvLHyEJ0/2d9PNh1R/T+WzU92q8S7WOofCzRPgy7/6OKW2D9OtB3
f6RH+3KgeC1VnGq1uO6semTV8tCj6+q24uOhqjMe3c7Ol2wrHzNLj67DmDVO
ZuVvRufRRPt4WO9PnfUHiPbrGPxXvi/DaNzKdan8UqL1atcV7aeB9Oj5J9LZ
eU61utu9qlfzvcyqDx7t86aaH2b5+1V7TlV+Eap8ZzbPt990le+Eqo55NZ29
rmg/kOj+kLWv28r7TrUPVs0nVuWzwc5nUP9RjWPWc3U2f5/VVeOwavyM9mlR
jcNZz7XqeVf5tETf92rzOvY5Zf0uVDrK+1blg6t01h+D1Vl/CZVPAvJ5aF1X
5RNl1VFVnT9bH0eVb8XWcVbpKj8Qts4Oq0ePS6rxivVLYf00ouv5sjrrg6Hy
hcjKn1LVR4s+vkpn68yy9fVY/wHWB2PdY1d/87tvP6lb9XU//Pbhh186qv6l
366624yfHd7Nfma5o/f5wS/HrbN/l9XZdkC/Rz4erB7t11GtPiMbb8/6XSBf
lA1nb3LqHr/56Qv6N7vRfh99f5GOzlOls+2J7gubH1Gtbimb96SqCxxdJx29
j6q9H9nzbOW9r9LRPI3V2bwMVlflcWTp6DxZfxjV/UJ6tI8BO19l9ehxj9VV
fh2sTwV7fFX/YcdJVX9Q5XtWm8dW07PmRVnzHJWOzp/Na1b1W3YfoNo6rtp5
VtNVPpat6Gw/Z5+jfmtP69b/XFf5GkXv47G6av+T3acaMEqi2jo0et8py39S
5ePB+k+i77PIvzQ6ngHprF8H+n6t+o6P4pdQHBSKe2Tj9rPiw6PjvVX57NG+
FgMksuLD2evKyq+vlldVLU8hK1+v2vln1QmtlocS7e9RbVyqpiMfj2p6tXbr
1fuCfABUx1H5eLSiR/s8WJ8cXeWnET2+Rdc3V+XvR9cLVv3d6LwzVX1nld7K
fFI1z6yW71zNT0PVD1X1u7P8NFh/iWp69Pmr6qT3ql7NJyR6nzZ6PzZLb91v
in3vRO9TqfLTVeOb6vmtNv6gfHn299H59ayuap9q72vV+Kzy61Dp1fwlst6P
rcxXVf4bX/7ZXSdv+Obh78u7T/voMXc8jv00VL4Z0T4Y0b4ZrJ9GNT8Klf8D
q7P+FWzd217VUTuo6uCo6uaofELY50IVt8M+78jfg/09Oh+ko+tC7aDy00Bx
XyhOLDqfTlWnnj1Ptg4sW4+vWn3MARLR9Y5RfC/rm4H8AZAvBPKdWP7Gt276
q18f233h+eNcNqSrfDNa11U+Hp/ffdYqh9559gv36ydDOuvbkOWfEF13kn0u
0HWh54VtZ/Z+od9H+7SodDSesL4lrK+IKp8iq85p63WHo3VVnd9qeRZs3q7q
etnjq/JHVLoqryTaD429v9Xmva3Uc8/yR2KfF1VeFfu8RI8z7PqFfT+q3teq
+WqW3koddlV+uur9pXrfqd6/Kh8M1foo+u9We47Y56vaeraajwf7vLN/t5rP
SbV1X7QfQtZ9j/aFqDb/zPLTqOaLq/LLVe0jsfufA0ZTUI0PaB2U5SMXvX/C
+nKofCOj/TrY+IToeiXo+zX7fZ+txxHty1EtPjwrL0lVJxHpA0loPV++lXyr
rDrarec7ROcLtK5H36/oPErV+Flt3MjyEbKu1QdIRJ/PpVvve8KGq/5iSL/8
Aw8vffTat9L+AOxxVD4e1fwZWtGzfFFU/hVZejUfodbrm0fn4/eqHu1XifRq
edBZ81Kkq9Z37N9V+WZE90+0b5OlZ/khsPtgWeejyu9mdTZ/s1o+uKodWD3L
l4PVVe+jLL2V/ROVHr1vhtqZHbeznjt2fEDjmEpHeeut69HtltV/osd/z69q
zuuq+aGx80DUD1XjFeungb53R+uqfHY2zx35A6D4gWhfC9a3AeXdszob74F+
z+ps/EkrOttubB2cLJ3tn2x8DtLZ57Sazo4DqP1RfWrWj0KVJxVdnz06b0uV
hxWdv5Clo3xw1jcD5a2j/H2Zb8ZfnjL7Fxfu273neR+AK4b0xWd29NPX7tKd
f0236vfeu/zjSy+S6z9f5bn1Dzj+yu4933vykCeOWwTPJ00X+XWg+7Lr9j9Z
e6NrTu22ed734OIhXeXXEe2TwPZ/Nj6fPX60/wa6L0hH95fVo4+PdNY/JPrv
qvp/dD9X6aq8yKz3I+s3lZXnqMr/Yv0KWr/e6Lw5dv6p0rP6p+o9GD3OtK6z
z2+0ntVvVf2NfZ+q8iiz/i57Pq0/v6o86+jnSOX/mfW+yBr/s/4u+3yxuup8
qj2PWc979HGq+WlYnxw9ej6fdZ5ZPhjR7x12/sPuQ7K+r+y8bsCQQvVeVvlo
Re+HsL4c0T5y7HdAlS8H69fB1hdQ+XJExxWw3/3R9270fRzF56h8OVB8FBt/
rqorp4oPz6rbqIqvHghGdFy3yq+DzaOP/rusnwD6PduvquUp9KquqkMXnc8S
neeSlYei8jWK9vFoxY8I+Xtk6a34I7Ht2av3i9VVPiGszvp7tK6z7aBq52p/
N1pX+WmoxklVvn/0/JOtX8zOf9h8pWp1h1XHz6q/XM1HTuVDmKVH1xnPygdU
1a9X7S+p/CWir0ulR/tRROdNs3XVo8+zmh+I6rlQ+XhUe0/12/tRtW+jeh+h
/sD6XaDnHenou4bqOCh/nP09m4eOvuOwOvudSKWj60I6226sHt0f2H4S7U+i
8sVq5f0Y/Z7N0lXzbfa+o+eC7f/suPHtg5fa+9QPDMcD/NOnDz3rtfsuhLrK
HwPpKO+ezcdHPgAqfwy2/giKc2B9G1A+PtLZOBCVrqovk6WjuBpVvA0bh4N0
tj+wuqouD3qO2Po70b40rM4+v+g+on6FfCpYf4msOn2qfBP2utj43ui6dSod
xfeyOor7RXnfKE8c5ZsjP43x+ma82Ndisf7Ptx574Kuuv76bf8KFxz762YWj
6t/49cp3Xz/t5u4rJ3zu7IU7LRi3zv5dVi/j4yHy5UD9AemsLwTqt+xzEZ0/
pRpn0Pmr/DdUfjiq/kD78Ij6LX188jli24f1M2F9PNi8kuj3ker4qnzkavMB
Vf61qj57Vj57tbz1aJ+lavPJanr0/a2mq/LQ2fyv6Pz0rH7Lro+i319Z78dW
3r8qf7zoPHq2Xjmrq/KdUftUWwdVG4dbn7dU06Ofa+sj69V8LayPrGf50rDv
EdW6UjXOsPtprI8ruz8zYEjR+joxer7KftdjfeGQHu3XkeXLEe3Xofpen/V9
X+XLgeKa2PhANu4uK89CleeV5dehqkPdSv4R0lX59Wz9x6y8KlU+o3XrY9Gj
/T2i80Sq+Xi07vvBnmdWu7H3Mfr9Et0fqp1Plo+KyvfD+vj8IrLOJ6u/ZfkC
sc8puy6IzuuPzufNyi9uvf5ytP+bSq/my5fl+xddlzy6bnsrde1b96NQ6Wxe
sEpn851VerX2Z/dXVf0/+j01IEL0e1N1/GhfVtU+tur9wuZ3s3ncrG8D8peo
pqvyx9H3IFZHx0fnk6Wr2p/tV9F+Juz5sDr7fmSfx+j5QL+9l6vNY6N9hNhx
kvXNYMfDLN+Mann3bD4+q0fHn6C4F+QbwNa16VW9Wr0epLP9lq3jwz5HKl+L
aB3dFxQ/huLTUFwcisdT5d+p6t6q4nhVeV6qONtqOsrLZnWUD07np4/ip3H0
09fu0p1/Tbfq9967/ONLj+6ncfJub7/24cdu7C46YaUpjzw4uj/GEW/7bwvP
WfqWbrsT7vrbBZfOH9KnfX/ec9856tZuxRM2u2reW0fX0XHQ30XniXR0vah9
kD7pfh2knwCrq/wHVHmL1fx20HWxeQGoPWW+Eyq/F/I4i1uQ9e1RjUusPuHn
Otjfg9Wj31Oq96bKh0qls8+pqn1U4yTbnqrrjdZRu7F+R9XmjdbHp7P+RdYH
9X57LtjxIVpX3S9WZ98X0f4Dqv2K6DxHlb8omx9dzSeqFT3aPyfLryP691k+
HiofKuvj06P9Jar5UWTpqvcd+76I9mGrtm+m2lcZMKRg572t+F9Fv79U81XW
h5/15UA6G5/Qiv+G6vs7+10e6ShORuXLgeKOUPwSG5dYrW4XG0+u8uXI8utQ
6ex5svlEWdfF5htWy6uKzgvIigtV5X2o/q6qDnKWnlX3NnqcVPl7ZPkOIV+I
ftOrjf+t69XmD6yu6lcqHxvW34P1T2B/b703dFU/V/nsRef7o3lCtXrB0Tqb
D5VVHznan4TtV1n+HiqfmWh/vKw612z9a+uTo7N5stV0Nl+YrZ9e7XpV912V
F9yKzo5j1eYDrB49j2LfI+x8RuWngb5TqHwqovXtBh45YqNnJq6j/O4sXXVd
Kl11v1D/YfuhyreE/bvsdz3WD0R1HJXOzhOqvcej3/uq+bzKjwXdR9XzhXwz
0LjB+mmg7+9IR3U32DgBVDcExS2w8Q/o9ygeA8WBsDrK62fz/a3n6ux9RDrb
f9g4IqSzcUrs88L+XdXzwj5HKK4MxfeieDlVPiPSUbwoW68tuj4vG0+raodq
OuuDsbgnoTx0Vkd56Cod+VognfXT2HXaxat+/Md3dGcf/9y9c5aaN6q+5/K/
XW7am27vHjr+uF3mfmfeuP8u6+PBthuLifaHcL8FkZ8AO45Vq6vO6qrxTeW/
sbj/RI8bKt+eaD8f9u+y48OYfTzY+yvSo89H9Z5l82tof6okXTV+quZX6nEm
7L0maufofsveX+uT026q50j13KnyB6PvC+u3Fv132fOxPqirfEJYX4KsfEY2
r1ylo/NR5Tur1kHRPjOqdVnW+Ufvs1XzLcnyFVHpaHzI8itgz6cVvxHVdVXT
Vfe9mh7tm6HyP2Tnk6r1/oAhRbQfXTVfrOj5rcpHbgCA9etgv6cjXw70PVfl
16H6ns76cqh8PFCcDBtvg+J2kC8HqrPD+nKw9cXYeDk2zo2th4V0ti4VGxcd
nZ+epffb9UbnVani57PyIFTxotXymFTxrtHtEJ1fw46HbH6H6jmK9kFS6ax/
Aquzedno96rz8XuqN95T1dpH5avD+nhE69H+P9bb0lV+cdE+b+x8oFfrFKt8
DKrVWY728cjyA6l2/tG+gmy/UtUrZ/PyqvkkqPapsnwqkI728ayP7DOs0rP2
P6v5eLTuE5I1b1H587D9ivW9Qc8X64+R5V+BvqegPGv0e/S9RqUj/3aVzp4P
ah/VcVA7s/cXfRdjdTavX/V75DOAdJUPSZbO+opE69H+Iez8gZ1/ot+z56Ma
/5Gu8tNgx3PVeIvqdLB+Gqj+CNLZeigoTgPFdaD4EDbOBMWroPgWFD+D9Oi6
YOzxVfHq0dfLtjMb18TGKanqCql0FAfFPhds/4+uH4ri39h4/qx8RjavUJWv
hOJj0XFgHCzpA7D4DqE8TZTXPOZ850k6HzbfHOWVs7oqr5z9uyjPHflm/N38
E9fbZpPp3bTjP7zX7P3mjltHx0c6e13oPqp8CSa7P0f7dbDjkipPMEtX5RHQ
75FRxivUf6r58LDjRrSuGm/RuIH0sT7vo/2efR+x+ljHsaxxabR2UPnGqHT2
vo91/B/tOGz7qPr5ZPfDanra+zr5eRxrP8yat8jWa63o5PwtS8/yFVHp1fw3
2PV+lv+AKp8R6Vl566r86Gj/wOj1Uet6tD+Jynelmv9GNb+OVvwW2PGNze9W
HV+lV2t/1bit0lW+Rux7hB0n2fmSah9svOsUQwPV/FM1L1X5e6jes+w4M/aW
zwX6/st+H2d9Odj4kGi/DqSj+BbWlwPF4SAd+XKwcZJsvCIb76eK31PFv6E4
MTbemM1zUeXdVKvX3Kt5W9HtEB3Pr8r3YZ+XavVws/JlWjlPdtzLygNV5V2i
/GKVnwDKd1bp1f4u256tjM8qn5loPStvt5X3Pvtcsz48yA9BpUc/163oKv8f
dHz2vrDHb2UcZsdVVd6oyo8xOl9eldfMzp+jfeR6NQ86el3Wuv8hm0/N5llb
1+pov4utD450Nv+9ms7m56r06DzcVt5r1Xy0snwtssbV6HEA/Z59TlX+GCg/
GunItxzprC86q6M8a5XO+sBH69Htyd5fpLP9qprO+o1E66x/CKtXm4eo9Fbm
Lap5Kfu+YN8L6Ds4O/6zvhlIR3ECKK6AjU9AvhkqfwCkI38A1jcA6WwdLjbe
j/UZYPVqcY/V4lez6myy/U1Vx5Ptt9H9U5UHraojv1hX5elH1amfrPrmrB+F
Kr9b5UehOp9dp1286sd/fEd39vHP3TtnqXlyXZX/zubFo/NBvhmX3rDsLR/8
+l3d8bu9dODKGQ/LdVW7sXn3qud9ouPDeH8/YX8PcpxBeZeqPMFqeY6yOp5i
/wF2fGPHgWrPe/S4Gv3eUb2n0H1UvS+ix0l2XqG6LtRPVO1ZrZ9U06s9X2w/
j/b1qqar/FWq6RP1z4nWy/mWFNOj/T2y9FZ8PFS+BNH7h+z+LZtXrsqzVuVN
V1s3Ib1135tqfinRviJZ+cvscXrVbyTLj0LVztHfEVR66/5Iqn2tyfrOwu5/
Ghq0/n6v9r6b+B2pCTa+gq0TgXw5UDxJK34dSEdxOChuh/XlYP06UDxSVj2y
6Hg8tt6lKk+qlThwVlflf2XVqYzOd4tu/+g8oOi40Ky/2296K/k+qrxLlC/J
1km3PnK9eNZHIivP1HqunpV/rRoHVL49SM96Hlm92rgUravuV/Q4zPoMZM1j
o/OGovOjo+sXt+43kuUHwq7vVOvxXl3XZ/lLsHq1dVa0rsr3RD66bJ1xVmf/
bjV/D5U/sOr90vr7opqfBuuXhe4Luo+s7w16LlCeu0pn9+3R/j/6joB09J2C
zY9GfhRIR99l2LzpaD3ruxXrS6/yq2e/i6n87VX+HiqdfY6ifT9U3/uidTQP
UY17qvFWNY+Knv+o3lOo/7B+Suh9wfoURftjIB3FJ7B+GqzPBorfWOveDe5/
ZMaNS+hsvUJV3HV0HUNVfHUrdYWqxVtGx5dGx8eq6qCp4uii66MtvnI2njO6
rjpbZ1xVJ111XdF53K3oqrxy5F+B9GrXu/fy+55y1n4zuqPfsdUP9nznsL7y
Tjd84WXvvbv7xusO23aZk+eMW2fBtlsr+b+TnU+aVYedzfurlhem8t9A92W0
+4v6D/KZUY3P0eNANb+O6Pca+16I9kFix1XUPqgfIp31x2DfU0iPbh/rg4j2
h+k3P5BW9Oh1U7/5ooT5eLB1yYv5b7DzT1av5svB1qPP8utQ7R9W8/Fg9zNR
O1Rb70Svj7Kei6y8YJWPTTW9374LVPPriD4f+12MrFfzQYoeh7N9y9G6wNCg
Wn9TvZej37/R7zV23Eb3F8UzoHgJtr4Dit9AdVKifTmidTZORuX7ER2vyMa1
sv4eqrhBNt4PxX2xcWtsXL0qTj66/hRb97Banhp7HDZOPjpviO1X0fVtq9XD
rZaP07qeVUdPNR6y+TvR+fut6GxdeFW9eDYfis17in4vqN4X7HFUv1edf7V8
vSw/n+jxgX3uovO72TxH9vyrjZOtjMNsO7Pjqmrei+YPbF4Sm6+t0tl5MqtH
ryNU87TWddX8Ifo4qutV+dWwuuq5UOkq34no8UTlgxGdj8/mUSJd9Xerjf/s
ejl6PI8e59n5fzWdXR+x4x7b36J9LVQ+GKwe7Y+B8qPR9xf0XYn9PdLZPGj2
+xc6Dquz56k6Ptv+rfh+sH74qu9r7O9VevT4E62z/g8qnxN2vlRNZ9sn+r3A
+mOw47lKV42rKL4C+Wag+A0UB6LywVDpKJ6HjYdn4//Z/IKs+GS2Hdg4RlbP
+rsqHbUz7Cdk3vTAC0D52i/WVfnai4+v8sdg6zKz+cuszualsucffV0oP5HN
/2XzYVvR2bzyaufPXtc131xnp103vac77HdXLzrzFcP6sa966tk/vuS+br9z
dtzkd9fPGrfOgs3fR/0W9XPVOKDSVXmpYx3nkR7ty8Hq0XHg0XVCF7czeg+i
+8v6IKnGbfTcsc/7524+/M2n/tW93ZdvWebbO+81e9RxhtWrjauq64rW2fcX
64uC+qHqfYR0tr+p/Dqq9UOV34tKZ/06ov1wWJ8Q1fud9QmJnm+o/ExU85xo
XbX+quYTws73wvzZWtGL+YGwPm/VfA+i98ei93tZPdrnNsu/RfV3o/tt9PGz
fG+i95NVx4/2/c7yFbE+crtF95/o/s8+1yqdHcdU+nh9ztn5ZPR3CkMD9n3U
q350We81pKv8lFAchcqXA8V7HPC+6T+7ft5vl9BZXw5VvB8bB8jGz7B/V3U+
Kt+PVuIY2fhAto4Ymy8QnZ+VVfeQrc+l8nlQ5U2o6q62olfLx2HzCLLyd/ot
Xyn6uYjOP2XziVDeDZtXzubvs/nyqnq+WflK0Xmj0fmebF5ktTzTVvLBVT4h
quNXywdU5WVn3S9VO0TXN8+qt956PikaJ9l5iKq+MzuPUtVNVtUprlbXmNVV
vo7WJ0fP8ldUrWejddU6N0uPrnfP1iVX5asiPXo8r+b/qfLDzNJZ/yLWH0w1
z0E6O26w+cvoOWLz7lkd7c8jnfXHQDr6HoG+a7B+Eeh7E/o+hXTkM4++f7E6
+30tWmd9+NFxULux3wdV/vys74fquxirs89j1nFUPiS9qme1D/q7Kh31B9YH
Q+V3pBr/0XgVrat8M7beYf+1t/nalUvoqJ5XdN1ANv6N/b06no3Ns0BxbhPN
v4jWo/MjVPGHWXkco7UnWy8s2nciOk+KzTtm8/XYPMHouvPReY5sXjabD8vm
vaLfs34XrM7mI6uuV3X+6O+q9MfWXGOPKfvf1+11xJH3Hr3+rFH1E/c8bNPP
7XZ/94EdV1rr7qcfHLe+7ba73bTjrPu6T3z6tkM2OeqhUf8uamf2ucvK52Xz
WFW+HKq8zkmvz56ks3kTo7UDak90f9n3kWrcQ34a7PiAdPS8s+MA0lU+IUiP
bh+VrrpedrxlfTai319sO0S/r6PnCSp/FdX8VvWeVc3nq+kqH4zW9Wp+HdX8
QFTzOnZ+0uw+Uo/6e6h8eqvlUap8DFR5+tH14ul9S9E6RbaP2qN6tedF5SfZ
bzr7XLPjA5vHrdLZ72Kq9onWqz1H0eP2eH3LVbrKT4Od57Pfa4xaiH6+ot/L
7Pwzyw8K+Wyg+ArWZ4P130A6ijNB8TBZuipOpprOxpdG1zVjfULYuEcUD8zG
laF4NhQXzda3UuXjs3Ha0XXNouttsecTnW9Sre6Yql6bqq4c6p8qPeu+q/JG
2XbLqrunygtT5Tex+YZsXhKbB8TmWavyj9g8a6Sr8jej/S56NV8yyz+nlXxD
VT6vKq8cjSfRz0v0fem3+u8qvxGV/0m0jwE7DqPxgc37RvMWNi9Mlcek8mNk
/eWq+bBVe+/4+JOjR59ntA9ktK9j9LpbtV6OrmsfnWea5aPLjufVfDsHkpDl
q4nmM+z8lh2X2HlO9HOE9rdZHeXXs/vtqnxq9H2BzY9W5SkjHX1HQ9/d2Hxn
9rueSmevi/XzR+3JfmdkfTxU/v/RPvlIZ33yVb9nv8epxqXWdXZcRe3P6tHH
Z8dzld+FyheIfS+o9Oj3C3pfoPcLG9eH4mGifRUWX0l03Brrb8DGp6HfR/sq
qI6TlYcSXfeWzWdB7aPyl2B9GKLrWSOdPX9V3XCVD4Mqv7WazuY1Z+mq+xKd
vxzdDio/jaf+7cIfnHT1/d0/rPOBG774wWF9x9PnLHfdZg902y97wv5vumzm
8Hgy87Tv3XTaA93Ad288+6KNhvW1V957vdtWnNmds+ZLH93xrAdG1dHxWV8O
Nh9ZNe5V89+oVoddpbMY6/HHO59k/dbQfUf9DfVb9j3Fjhvs+BA9DqC/y+qs
LxDbDtE6e/6sjvpJ9PxB5dPC/j56XhE9b4z2JUN6lu9cK7rK14tdD0av11TH
V82XkN6KH4hqXyJrXyVan+x5ZriPazWd9GdQ6Vl10lX519F52eF+FNX6YTW9
2HPRyvPIHp99flmd/Q5lXXvfq+lqfwzVPCTrexY7f1Z9x0G6UQtZ86Lo91e0
zxvy2VDF6bHxb9H+G9H1YpCuqhfDxlWyOuoPbL9S9R82rlLVT1ifEBQnqYp7
ZOuXRcf1Retsflx0PS/2fLLOPysvJrreWVY9NdXx2ftVrZ2z+qHKV0TlU8Tm
P0bnj7N536p87WhfCzb/mtWj8xxV+YxZx1E9R9F6dL6hKt9W5YvCPi9ZecSq
51GVp6/SVf4qrfgFVeuHaFxi50sorwfp7LqMrU+t8v1Q5ZVX851DerQ/Fft3
o/0V2d9Hz4uiffOydNV9jPaHjN7HYPeXsvaLVPtLKl/crHGV7W/s8QeSwM5D
VL5wqnUo66eqen6j87XRfIn1u2b3ydF+O5t/zeZHo+8R7HeWrHpM1erjsPVi
sr5Xst+b0HdA9jtjtP8/ei7Q85WlI78Flc8DO76pfq/SVeNkK/Umor+ns74T
qu/yKh+kaH8MVb0/FFez+IxRPBsbh8bmO6jqt7L5L2x9YVVdY9a3QVUfuVq9
YNX5qPKJUPtH1+Nm64BH19GOvi4275jNw836PXsc1p+BbZ/oPNloXZW3G93f
WF3lm/HKrz26871PzOxev9XUvb94wv1D+tw/HrD/nBsf7A74yJUP/+jr98n1
Y3ZZ5/LpX5nZTb1gg3XmTBk9T5/Np1a9T1XvqSz/q2p5l1l5ryo/E9ZfC/U3
lC+vGk/Qc8T6ZqDxIUtnzx/p7DiJfo/aWaWzfh2qeUL0+4vVVfMTpEf7d7Xi
49G6zq5TWvHxUB2n2nqZzQdUHT9rnlZt/lPt/Fm92vwW6ey+KMrnZX2GJ6q3
7i8Br0vk5zze/fCo8xlNj+5vrTx3k/68WB9Rj/YPaUVXtUPa/Z0k//xq41L0
PCfrOya7/jLaRrX3AtJVfm6sLweKZ0PxG6o6Uyr/DTaeR1WnBl0vG/eC4g9V
cSwqH6fodRM7T1D50qD7oorXYvszW6cp2k+G9Sdh4/FY35Ks+EZVnHn0ebJ5
f9ZH1lV+ONE6e9+j+yGbtxXtY6Oqa6zKQ1T5eLC6Ku9bVbeXzUtS5SFm+SxF
61nPV7QeneeoOr4qzz0rP1fls1QtL7WVfH9Vvnx0P8/KF0b50ey8CPkoqvKM
ov0Y2fme6r0Q7beG7m+1cZUdb6N9EVW+K6p5crVxWzUuIT26/yOdza9n9zdU
+fLVdHZcVY2f7PjG+nNm+XYOALDHYX04Vb5trL+c6r2A+hXrg8E+1yifnc2L
j55HoX1mpLP52qyfBvqOwH6vUdXpWHzGE47zKVYniP3uqfLxQN/v2O+hqu+b
rM+/Sme/+7Dfg9hxA/2e9cNnj5PlU6HytUD3F/U3lX8F+xwhHT2nqjoRaNzI
8iOK1rPjCth4M7bukspHAuXbqnS27nArenQ+F5sHzbZ/NV1Vv57N92f9BFT9
hD1/Vf30rPr1KA83Wmfzc6vp0fm27PFV54mOw/pjIB35VCCd9dPYbcONllqw
+UPdlIVPT9nq5cP62394yVuefMOs7vWvvXib2XPvHtIv2meF1a54dlY3a703
HnrS6XeNqqPjoL+Lzh+1D+oPrB8Rm9+qqueeVW89+viq+pvRecHs/WJ9t1if
DXY8QX4RaHw48IpzZs782IPd1TcfdfrrXn//qHq0Dw+rs+eP9CzfD9bfw/MB
rR7t46Hy9bK/h1Zn1/vV/Dqq+YG0oqt8PFTzBNXx+03P8kVR1aNvxR8P+TC0
rqv891T3N/q6VOdvfXLu44v1yfIxGKvvisyvJjpuwfq4dLZ/TpauGsfY975q
3oLmn6we/T1U9d3H6E2kjVciXw7WfwPFmaA4FhRXo4o3i9bZOCI2/ge1p7qe
C/s9gh2HVf6o0d8pVP6cY52XquJCVXXfVHFlKl0V18r6lkTHi6r8T9g4Urbu
m0qPrlPJng+bB8SeZ1Z7qvTo84+uV8j2N5SHUq2+vCo/kfXxYOsCs3lJbN43
m9fJ5oup6vm2oqvyJaP9oFS+T+j+snq0b4nqPFV/N8vHiT1/Vb6nyj8kevxX
+bdE59tW8xFi+yeaV6D5tmqfoVr+WvT8n81PzxonVeNM1vjfSnuyvgHsfJjV
VeOtyg9B5aehmh+yeamq/ZNqOpuHy+5XqHwp+01XjT+s/w/7XKvWoew+D9tv
2ec6K9+fzRNX+Wmg/Wq0b4++C6jjEKrFO5WJFyJ9PFi/DqSj/lOtTgHr71HN
9yNLr/adGvUfVmfrQbDfu9HzleVHpNKrxbNFX9finsHGVaryJdn8DjbuS6Wz
eU/V/AeidVW+WDWfB5RPl9We0b4BbF5hNT3ax0B1HKSzedAqnc3njW4HpFfL
/432XVH5ZrB55dF+GjM3vvnRVebO7k5b7onbp6w3vF+27FKHX37g7XO6fRdc
tcYZ59826u9PunfaBX84bFb3hb9Z5YoVps8Y9fxRP0f9mfXlQPMTNn6yWn6i
Ku9A5ZtRLe8Y6ex1sT4bqN+qxgHWb6dXdZVfB9JV72vV+131/mrF3yPLr0Pl
yxG9/lLprC9HtF7Nr0OlV3sPtq6z87csnfXrYI9T7TxV+UdZfiYqP5BqPgP9
prP3pZp/i+p6q/ntVFtHt+7Dk3U+1fxJqvlLVNOz+hv7XVKlq+Yt7PyT/U6q
8tOI9kVHutGfUI1LY/Vxiq4PxebLs/4bKL6IjTtifTNQfJHaNwON82ycSXQ8
ier7PhsXEe0Tm+UHgu579Hym5/zfwHOXNY6xuqqeHZsnwtZHU8Xt96peLT9I
ladZ7TxV/jOqvFE2Hyq6ni+bN8TW7WX9NFifDTaPlfWjUPlOsHWB2Typar46
1XycWL11nxM2TzP670br1XxsWL1aXiqrt/68oPEEzRNY3zy2Di+bf4f2K1T5
d6o8VpV/oMpPT+UHFa2r/AlV8wSVj6LKNwDN91S+SdF+RCqfIjZPH7U/2x/Y
9SCbl6raP1HpbH12dl9aNX6qnt9WxkPV+K/y4czyx0DPHesvwfbb6O8v7HcZ
dn6lyhNH38vGG18R7YueFd/I6tHxYxP1UWfrGrDfVVU+5KzO1kdQjQPRevR3
YXRfkM7627N++6yOjo901gcD1gcRj5PV4g+j48ei4xij42bZuDK2jhLrnxCd
r5RVT7laHWe23VS+EEhXnQ+bf6fK40N5iKyu8nOIrquuOh9V/inrV4D0aD8E
lO/M6iiPGP0enQ/bDui+sO2s+rut6Gw7sPf91/v84duPnvFQd/bvd732wmfu
GdKRnwbytUD69rd85quf/szs7spVv3rm1H2G91OQn8Zpey5Ya/XtH+62mPG2
nfY56NZR9YNOWHf3qz8yp/vacx8amPv4i78DLQnUPqz/BhrPUTwkysONzutE
x0HzN7b+e7RvBpo3Ip3Ng47Ov1bF5bLzBzQeov6PxgF2fEA6exz2fLJ01XtZ
pbPva1bPeg+q/D1YvZpfRyv+HtE+Iej3aH9ApVfz8Yj2A2Hfv6r8PvbvtqKz
8yvrubpqXq3yObE+sq7Kj2Z/H6234mPDPi9Zz2/0eVZ7LlT+mb2qR3+/Y/9u
1vlHf09U6dHjqmociJ5PRu9TsX71qu+qKv9Mo7eh8rlC496Y8+vJuDI2LgjF
PbJxU6r4KDYOio0vWnwGKA4H3V80TqJxjI0HYOs4qL7js9832Toaqv206P0l
9ntZtD9qtD9nln8jGxe3xDhJjods3CMal9A4qcq/U+XZqerEoXwTVs+qx8fm
O7C/j65/F10/kY3Tzqq3yPp7ZNUvVtVnZ/MNo+t6o+uKzitk63erdDYfmfVH
YnXWh4fNE1T9Xbad0f1l9az+k+V/leXH1YrfF9tPqvnwZOXvq54X1qcLjVfs
vA7No9i6vawfYLW8PPb37LwO3ccBEqr3QrXxJ9ofL/r9i8YNNl+e9RFi59sq
nz02T1/lI6fK62f9NNhxg92PVemqeuvo92ifXOXvGu2DpHreq62nss6H3b9C
9x31HzafWtWfo/PB2ecR+cyz+njzxNnv/mifH313UOVrsD7n0fXdsuqFsfEh
E/YtB98XUD+Mfu5YH4lo3wl2vcP+XjX+wHFjnL4TqC7DRL9njfb76Dgr9nlU
1feJrjedFS8aff5Z7Y/eO2wclyouwrpWj46XU+kqn4osXeXb0Iquqkevyhdm
dfY8o8+H9Ulgr4u9v6wvhEqv1s+zngt03y/aZ4XVrnh2VjdrvTceetLpw/ue
yDdj5sY3P7rK3Nndacs9cfuU9e4cVUe+GZ849pWfWOPsud1Tpxxw9bmX3TRu
vbtxuyNv+NXD3erXnHDQupvdMqSrgN4jbBwjWqer4gyr1YVn83PZ/ZCsOpts
njj7d1F/Y/152PGWHR+Qzr53VMeJ9g9hfUKi32sqHy1Wj/YlU/mtRft4qOLw
o9dlKl8O9jjRerS/h0pX+X5Efy9Q6dHn2YpvCfv7ftPZea91ra5aR7Til1Lt
e0Sv6qrxQeXHWK19or+/V9Nb8Z+Jjk9gv5NWO8/o77+q77PVxrGs+J9q+2aq
dS5apxu9DXaeoBpXJ+rLgeKL2PwR1n8D6eg4KP6KjTsdzU8DxTWxcUfovqPx
SuV3ofr+jo6v+q6Kjo+ul/XrUH3/io53zdKz4tayfEVQvPSY/TrI8bNaXTy2
HmV0fTq2Tq6qbmY1PTouOlpn67yr6sKjfqKqC8/6dbD1iJGuytdT1f+Nzh9E
7abK12bzsvtNj/YLYvOyVb46Kl3Vf6Lbp5oPVa/qbDtH90/W9yzruYiuz87O
G9E8BO1vLP4v0f7AWNcLqjrabB4uWl+wuspXkM03j/b3i9ZV/nIqP0C2PVU+
YCh/X+UXpNLZ+SrrF8fqqN3Q+IzuOzt+qvZj6TxWcX4rm5eqqqv+4vNh869R
O7P77ez6V+VnpZo3Ru87qfxO2XkFeu8vPiLr/6Cq48P6Ib/4PMf7nLLfX9h2
YNsH7T+z9SZQ3Gy1uoFsXGs1f/LoekCsX8FY+zn7HSFaj/a3Yb+n0H93nN95
2XpDbHxRK3GDqvo7bHxRv+nR+QWquHf2vca+79j8IFXdEKRH12tmz5PNu2R/
H10nWnW/2N+z90VVB1ylq+JtonU231OVD6vK50V+AgedsO7uV39kTve15z40
MPfx4f0X5CeAjsP6FSy71OGXH3j7nG7fBVetccb5t416PiodnSebB83mIyOd
vV/sfY/Om2avV6WzzwXqh2z/QX4arM/Gnwb2uPaWNeZ1Vx9932MHHnLjuPVo
/w0VVOvu6Pl8K/U02fmkSlflv7M+A+z7Go177HjLvtfY46jeR9V01fsxS1fN
G1U+Hkhn5/8qPxCVrlqXRft1tKJn+XhE79urfDxa0futfbL8RqL9Vapdr/WR
ddU6QvUdQfX7Vr539NtzkXW90f2T/btZ/VmlV/PhYf0Zqp1ntJ9/VvtE+7iq
9rWqzXujdbQ+iv5uy66Xjd5AtC+lKj6tii8HihNm85HZuO7xxmmj9mHjM9F9
QfNGNC6hfTa0r8jWTcjaB2brDrC+HGjcZt8L/bY/1sp6PKseH4r3fvG4wda/
Y+viVcu/Q/kFKp2tf8fW3WPbLVrPiq/OygNV1UNk8z2RjvJr2LrDqjrsbH4i
qn+N9Oh8QKSzeZpsHqsqv5vN42b7VbTOnierR/s+qZ5TVT4g20+i/Zqi7y97
36Pf+9HzDZXO+gxkjUvoPqp8MqPndar5HvTnHGXfgM3rjPL9Y9cRrI7aRzWv
Y5+j6Hxq9rlTHYfVo30Uo/2I2Plzr+po3sv6HbF+BdH7rouPqPINUOXLs9/7
VD637L79WPO+WX8ndB+j/TNZPwq0z8DmiaPjsL7i7Pxh8ZWz+d2o36J+xdYj
UO1XR/vMq3wwsuKgUHtm1YVX1Tdk/TrYuMpo33LVdwe2P6PxnPX3GPO6YJy+
N6rvodG+69HzBDbOhx0fqsXzq94LqvcRez6qOKJWdFWdVlV8FxuXxb6/VHVJ
WtGj87laPx+27kwr/hjRef1snI+q/jub5xud/4t8A5DfBcrfv+Xtpz3z+U3n
di+/eOnvP/bczaPqKp8B9vhIR8dhfT9QO7P51yr/EPZ82PNk+201nX0uWD8N
9nlB/fzGLd/95MVPz+uOedu/fn7Xfxje37z7qP/YbPn3z+++vMeBK9613Yv3
2fsH1fKh2H0Adh0RPc9U1dlU+Yyx8xA2HhiNb2j8j9ZV47zKxyNLZ+O0Wb0V
X44svw6VnrXOUvkZRo+fqvV+1nmq9Gr7S63rqn1Fdr8x63yiddX8TbVvnJVf
U+26ousFq3TV+bPtHH0+rF7tubY+sl7tOepVXeUbb3187aza54muF6A6z6z3
OJofquaZKn+M6P0x1iefXUez3+OMXKjm4dF1plBckKp+04vjpVV5GSjvBuls
nbjR4s1QO7B+Gij+Ct1HNB6y++1sXYDo74+q/V52f5X15YiOX1X561bbX4pe
n6rmY2zctcrXaKy+HIv1sdaFDNdF+XqsPwObT4F+L6ufO866eNE6W1cxS4/K
D2X9PVi/DjbvmM33RPmGbD4dq6O/m6WzdbdZH4ms/G52HsvqWf5FKp8idByV
347Kp4LNa2brv7PtwI57qvZk+3+0f5RqHpJVR1j1XLD9hJ0vRc/f2PsyWfM3
lA/O1jtW+Tyz9ehV87ex+n4gHbU/+1ywz0vr/jxZ8wGVzr5nWb8O1u+OnX+q
5tusLxyrs/NhlZ8GGp8XH5HNz0XjHtqfifaHV8Vvq+pQo/Nk/XLRvlaYH9Q4
38vo+Gg/DZ0n66+iypeP7ufs94Lo+t3o+GwcKern7P5wdBydqo6qqo5DdDx2
Vt1DlT9AK/Xm2O8X7HdelY7GsWp1WFT1ELPqv6jmFapxgNVVdZ/ZduhVPasu
LXt8VV5htG+Dyj9BlS9WLS+smh7d/tV01k+Draej0lU+GCpfBZTvz/4e+QOw
PhjIH+C+uQ8dPPWS+d3Fx+xx3oe3vGJU/ZEjpi23/BcXdGe/5Fv33PShS0fV
0XEWbr7+VRevsqA78brddn5wo8tH/T3yMUDXxbYP6x+i0tH9ZX0kVHniquOo
/m60nwbrM4P6Ifsc9Ruq1fPKWmdFryOy/MdU/hvo/Y7iftE4kDUOR4/bqnhp
VXw10qPne1n1Gdm6jVnz9izfj6x9Y5WuysPK2u+y3pau2ofM+j4SravySlR6
teti55/R11XNl1vVPqq/y7Z/tH9OVv/P0nt1/Kzmb1/tO2wr3/Gtj6yr9m1a
0auNM6r4oqzvs+y+WdZ3W7TPYNREtfcvG3+L4qkmXHeJzL9g89TG67OBzp+t
e4jama1rhsY3NG6wPhuqOg7sfjW7P4z2b1X7nNHxqFn16aqtI6J9R9m4VvY4
bP07Nm9OVeeO9fdgjx/lw6DW2fxB9vzZvI/o+Gc2LjpaZ88TtRtq57H2B5QX
Fl2HndXZuuRsPh3rA1BNZ+d70Xnc0fn41XRVPjt7HJUPAOvDk9VvVX4C0brq
OUL9ZLGuev+yOjo++3fZ+ViWHxfbPmx+rmreqLq/WfMl1odZ5e+tqset8hWc
6H5R9HuhFZ314Yk+frRfFuuLxfq2sTryCUE669/F+oaheT7ryzRePwQ0PqBx
if1+p/pew/qfs/lQqrwkdl8UnQ/a/2TzZNH9UuWPq+oUsN9Ps+qRsf7/7PdE
Vf1rVfwz64/NxuVm7c+zccKq8Sc63pv1La8WT6uKw4yO26zmcx49rkbXMVHF
82fp1fKzouuxVmu36PZXtVu18VaVh6hqN7afR/shRNd9Zus39aoPRvT8Nktn
/TRUPhgoD5SNI8rK62d11gcA+U4gfwDkd/HcrKv/Yep9C7qDn//9hUP6SzZ9
/Xcv3mJh99jzvz97uD0P//gDy520sPvS878/ZdJ0dJ5IR9fL+oeg46B2rubv
wfY3Vmf/bjU/DZXPBtuvUL/tN0TXbVftj6l8M7L8DFldNb9C81U0r0DzB/Qe
R+OAyn9JNe6pxsNoHySVzs73kI76g8qvI2teXc2vI8uPkV13Z/kuRp+Pan/G
em/orXzvqOb327pPcvT5Zx0/y1eBzQtm2ye6PaPjB7Kel6y/y37HiR6HVfel
Wl6eyv+/mh7te1PNb6qaXq0/VPMLYseN6PEt67t59HpNtT/G7hsYvY1oPyg2
X4PNnx1rngXKm2Dj/Mfrv8HWq2Xr07E+G6xPNeuzEe1THe3LwcaxsPEn7P5b
NV+O6HV39Lw02q8j2t8j2q8D5bmg37N1P1kdHR+dJ6uj46t0tt2Qjt6bbL4k
q6vyVlTnw9ZnVPnVjDmvE8wHUF4nm+8ZrdP576PMf1S+NKzvzVjrJo/3OGzd
ZFZnr1d1XdH+SNHtM9F2Q/2ZzddGOspLRTr7nI7WH1hd1U9U/RD1B9V7n/VF
ZOdj6DgqPWu+wc5jVXm1bDuz16vK51XlwaG/y8Yfsjq7nmJ9P9j5W5a/x4vH
K/i+EOns+wXO35L+bpbO+n4gvw6ksz54rB8Iez7sfiY7D4F+GuP0H0bPKRpv
0fij2udE+4Fo/5DNA2Lzg9h6uCiPgNWvWzhw1tT/N55+9Pk8gutH/bvoPNF+
rMrfg/3uxvpIsDqb18bqqvNk4+FZna2riH6vOp/odlblq7K6Kg8iq3+i82e/
j7Bx3a34LWR991HlK6niQ6L9rFR6dN462w5ZefHW22rP6PEzWle1pyrfUDVv
rJYv1m86O/9hfSpY/0M231A1f2bn+SrfDLSuRDrrJ4DWudG6ap2O8v2Rr8Vf
zDxzjan/bVF35T/+p/6dIX2/H33i60f97+HvLotxxerX/Wi/E8euo+Mg/e/3
O2vaKftP/PdvfMez+1w8deI66wfC+nWo+g/rxxK9L8Tq0c8je13IZyPaxwY9
j70KtH+r8h1l9wdU+4HV5tvs+aj2Ldn9Pfa9r/Knih73VL4f7PyH9fdgvzug
37PzOtQf2H1jdr6q8vFgn4vW119Z/o3s+Jy1f6Jq52r7V9YnR1f51WTp0f63
/aZH+wZnXVe0L3qvto+q/kI1vfXzj76/0f1E9T2aPQ673lf9XfZ8Wtez/HxU
9WWi73uv6tXea9W+d0d/z2X3B9B+hdGfQPFXqnpJqnwZlDexRH4EyJtT5cGN
138DXRdbzxG9p9g6LOy+OvsdnP0ex/pIo/1eld8yG3eq2m9pJW4zy8cjOr8s
2vcjuj6dyscA/R79XXSe7PWy18XmdbI+Eqr7osrfZPt51rqMnVdEtzOb74ny
N9H7XeUzoMo3j/arYccNlR8Lm58e7beTpaN8RqSzPgPRenQ7sPnXrK7yb8ny
e0E6Gt/YcUPl3xXtQ4XeL6p5ZvQ8UHV8dv6gWo9ktTPrUx1dx5xtn+jv/mwe
omoeqJrvqXzbVO9fdvxUjdusnuWXFeWLovK7U/lXID3bB49976Pnhd03QOMG
Gq9QHKOqvh5bZ5atj8nWzURx+yivRJXngv4uOk8UF63yVWbzvKLrJ6rqKka3
D9tuqrjurDqPbJ4ge5zouHFWV9WjVOmsz3m1epHsd/ysuFw2ziG6TqUq/oHN
X4jOs2DPh73eanVRs3S2faJ9D7LyVvqtDm9W+0TrqnEp2reBzceMvq5onY0D
qTa/Us1vo9cLbP0dtG5i83BVOuuDgXSU76/aH0D7AN+ds+LxhxyxpP7Ih778
s4+ctaT+rlsfnrHZ9RPXVzrm7ddt//Ox/13k74HOn9XZ/Q1WR/dFpav6CXsc
tN+F+jPSWR8M1h9Dtf+GdNZnA/1etV/Xb2Dn8+x7XLUvxO6HqPL92Theto6e
Ku5XhaxxQzXuofkG6+/Bzq+iddU+tmrfVaVH+3tU27+yPrKuul/Vrqua3op/
ab/tvyGd9R9W7Q9H+xpVa+dW9FbaWfU9S/WdUfW8VPt+qvKBb+V6q+mq9md1
9jsy6yfA+kG1orN+C6rjqOIBonV2PFfNW6pdb3QcS9b7sdp6jf2eyO4zoP0Q
o7ehyn9n89DZPFmUB4Hixpeocw3i2Nk4fLX/BmoH1j8cjYdoXw7tZ7J+1Oy+
NNp/VsUzs34dbD0+dj9NtR5sZX7I5t+h37PjkkpX1XdT+dSx47AqH5Mdf1T+
ddF+MtE+iuj8VXUA2ToIqjhtVf6m6nlh5xtsfXmUR6bSWR8bpEf7CLF5yqpx
WDW+se3M9gf0e9Zvh/URYnXV+bD+Rezx2XZgn7ssnxbWpyJaZ30wWF8dtv+w
4ww7/rDv36z3oGoepdpfjfaPZddB0X7j0fVS2XUiagdV/mZ03Ahb9zza10U1
b1S911TvL1ZXzWNZP5Nond0nZH1CovVoHwzUD1l/J3Y+j55rNE6ydfTQPiHa
h0R5Cigens1nYfNNkI7yWZC+9/LHz1/r7onr6PxRXgDKT0Hxz6o6sGx8dVa+
DOqHrE91lq7y01bVs1bVy2bPU6Wr6ktG66o4edV3FlV+ikqPjgtVnWdWe0b7
z2TlNah0Nv+9Wpy5qp6yqn2i+3+1+1VtPMw6TzY+yrpWV+W1qf6uan7C+l1E
z8ei56WsrvLZiK5rr8rPRfn1SEfrxGig9Tta7//iKy9/zSueQfn+j4z590hH
f5f18WD9PdC+DdrHYP090HFUOvJtUOnIR4LVUT9XHZ/9u6zO+myofHHZ/UZ2
n7B1oPc+ei+jfZWsfTN2f4n1s0XHR/t1bLxutH8UQvQ+LTvOqN77SEfzEDSf
YffPWX+PaH/pXt3/zPJhtj6yXs0fu1f7D7sP3Kv7Nq18v2hFV/XD6H3Fau1m
fRCtfL+I/g5o3fpY+ls1vZqfSet6tfurGvei49Krtb/q/ZJ1H1Xz/6zvgKyO
9hmM/gSbD67Kj0B5ECgOHOV5sfXrXxz3jvw0xlt3Mtp/g41jR+MSGgfQPq3K
b1/1PR19r4+O40X7sap9mKz5QHTdZFXeXLTO5uVF15tjdXYcZvM3WX82VR5i
lq9atO9rdP2prPW7Kq9W1c9V+ZhsPprquVPlBavyylmdHW9Z3yfWJwfdL5V/
EesboNJV/Tnav0XVzmx+NKur/E9UuiovGx2f9atB/VDl08WOV+x+F/v+Zb+7
Rc8rVHlGKr9Wtk4iOg76u9F1NFT7gdHxFar6RKo4QDaeCrWDat84a12W5R/C
vmdZvyOV/6HKZ5JtN3b+0Mr7F7WDav2uWp+q4qXRfiCKm0V5DShe/ejtdn52
xfljz0NhdXR8VledD9JRHg3Kl0HtjOKT2fhtdH+j69uyeRPs+ah8PNh9clUc
PusrguK6Wd8VlX+LKi49Oo49q36lah7I1pmtVne+Wr0MNi84Wledp2rd1G/1
T62PfL/6rT+oxje2PdnjZN1Hld+C9bZ01XyGzYdl9ej5Z7TOzsOj69ez+bOq
9WNNxO0bZOloXwLprG8q0lk/EPb3rK8I0lmfB7Sfo9oPUe2fROuq82fvF+v3
i/oV6v+tg903Ru8d1f5Ylt+vyjeG7f8qn5ms573aeMXuA7P7w2w9RNV+qWqf
M3p/Mmufk90Hq7aeUsV7tLK+i9ZZHxi2ndnjq/otu6+b1W9V11vt+4Uqvivr
u0D0+bDtoPLViT5OtN7KeUbv81c7/9Z11fui2nVVe49U+26lqvsW7Ycf7f+j
0qvdR9X33Ky6G6p+Uq2ds+5j9Dyw2vqO1Q1jLFDldaI8BZQvEOXLsVj/+SrP
rX/A8Vd27/nek4c8cdyiUXV0HPR3UXw+yiNA+R1o/EfjEtovRXG80d+p2e/j
rO806weC2gftD7P7OdXmyar5HptXyOZJqfRoP4es+8K2s+q62Hg51XMR7YeW
ta6PnpdmxZ1G92eUd6byc0DzFjTOqPJ/2X0/lR9Ulk+Oyj8E6ag/oPkn66+C
jsP6D7DHydLZvNpoXeUTgvJeo3WUL8zm5yIdXW81ny7VeKj6PhtdJ4X1TVXV
H2TjpdG6CcVLs/V90PoL7VNFtzMbbx9dd5JtZ1ZX5fmyebKqeC22n6j6Dzvf
Zv1GotfLKh/yrO/UrD8Seh+p5odIR8dh/fdQO6N+yOb7sPVk2TwatI+H4ntR
/ceR48zr5Im0riM/EJQXgO4jGxeN7jvS2TwUVlfVt1XFdbN1G9nfq+o5suND
1jyHnf+odFVdS9W8S1XvtVq9S1X8sGqfll13RK8vVHHj1e5LK3or9Vyq6dHx
+a33B1U+QivPr2pcYsfJrHE4+r2QdZ7sfmaWHu0Lp8qXZI+jmt+y83PWjxHp
aB3K5hGjdVxvoM4+Q7Su8kFFOvIvZXX27+69/PHz17p77P4M0TraF2L3c9h9
HnYfBh1HdZ5IV/m9sP4bqL+98NebHd/Q+4t977D7Zug9wvYrtj+wz0V0/1Sd
P3td0Xr0fi/qP1n7tOz3etX3X5W/R7Se9d1ftf+WtS5jj9P6elDVr1T1Q1vR
q+1vRO+TR+fxsc+RKt6GbYdq+2zscVTjbXS/qvbdp5oeHS9qfWRdNb5lPUfR
87pq392qfRdT1blrXW/lO3Ir59lvusofslp8SzUdzasNYyxQxe2z8fAovh3l
qaH6ldO+P++57xx1a7fiCZtdNe+tw/4YJ+/29msffuzG7qITVpryyIMLhvSj
n752l+78a7pVv/fe5R9fWu+/gfLvUDugPFk0TqL9TLRPi/aTs+Ki2e9o6Pco
npn160D7z+y+WbQva7X5sMqXrJp/F7u/pOoPqjwmVR6iSlftY0fXi8yap2XF
w0f7YGf5Fkb7z6jWL6zO3hd2vY/aX+UHguaZbL4qq7M+cqxPC3ucaF3lV6PS
kS9EtI588Fid9W9h/UxYHxg2z5f1zWDHATT+qPbhs+puq+oJsnWa2DqAbL0k
VbwZWpeh80HrU9Q+qnZm49LZ+8LGQanq36nyf9F9ia5jhfoJ286q+lCq+lOs
/6eq3hBbV07l26CqZ8ru26DrQu3ArlPQOgK9B1X3BfVz9Lywvgeq+Fs2f+GF
o1kvpqO8D3YfmM0jQP2HrXvL7ier6pBG172N9v1Q+WarfEJUOvs+Us03VDr7
/mXnOap1jSrOk90vzcoXZvXo9szSW69PGl3X0vVfxqe7n+e2Z9Z5Ro/DqvGZ
1aO/b7LHZ9877PWq9lfZ+Uy0Hj3fy9LZ+TDaJ2Tr+7DrF1UeNDpOb6DOfoL1
ydGjfUhYnxC0T2J9EGw7DyK6X9UB+72A3Xdi98lV95H152H3IVXnqdKjnyPV
94toHw/WryNrXzRrP1M1P2fXEdHrvuj9PdX5qOJnVOtBVX+I7m+qeCG2f7J/
t9p+SOt6VrtV+74TPf60ct/ZfTmVD1WvflfKykNR9f9q11ttvtGruir/qNr3
o2jflda/I6t8fvxdeBBZz0sr7ezxvzd0w/hzRNe7RHleKJ8R5Z0hX4u9l9/3
lLP2m9Ed/Y6tfrDnO4d9OfZc/rfLTXvT7d1Dxx+3y9z/t85brH/j1yvfff20
m7uvnPC5sxfutGBUHfl7sP4b6LpQfhxqT7RuhfksZPx8tD9/9D4/2j9n833Y
+s7V1k3V/BOqzUPQ+UfH80Tvg6HxQVUPl62Dycb5qM5H9b2mmp4V78eug6LX
p+w+gGqd1YoftcpfhT2Oyo9F5bvC+n6g+Vi0zta7Z/1GsnTkF5Gls74WSI9u
N3R/Ub9V5Quj8QSNV6rv6eg9zsb3sr4TWXEyrA8GWsehdRBar0XXg0Png9aD
KP6NzSeN7g9svDf6/Qv/1Zh1Nn6PjY9V1ctj+yGrq/Ky2Xi56Lxp1b4EWn+x
/iqq8eeF/2rCumqfB7UPen+x3+vZ+n3ovYD6CbufNog6+QLW29LZ/V70e/bv
svMKlZ9G9L40W2dWVTdTFR+O9Gifrix/D5WvFHr/svuf0X4gqvqY7P6kKq9Z
dfxWdPa7QDUf7GrxLa3Ez6jqb2Z9x1Q9p9H5IFlx1Fk+sdHjdlbeULSuul/R
eT1svlL09+Ksv8v65ar83Nh5YLTOzodZPw227o8q73jk/aheRZ19A+vWx6Kz
3zWi/UOy/Aqy/IpH3jfuPaD3DuoP1e6LSledJ9JVz7XK54fdd1XtryKd3Udl
62uw+6LR89LW/T1UPg8qv4vo86/mE5jlgx29nlXp1eKTo/uhqt9Gt2fW/obK
pz2rHar57fSqrvLFZfc/s/axq7W/6n71ap6LKn44evxR9edqeX9ZvujV6i+r
6npU81Vgv1eq9GpxFCpfu+h2UL1nVXq18b/a+xfpRm+AzWdkdbb+O1uHHeWL
oXw0VCca+V1cesOyt3zw63d1x+/20oErZwz7cuw67eJVP/7jO7qzj3/u3jlL
DftyIJ8N1n/jmm+us9Oum97THfa7qxed+Yo5Qzqqf42uF7UbGs/Rvq4qLroV
He3Ds3leaL8a7QdGr0+z9uvQcVqvGxgdb8PG+ah0Vf0aNu6d1dnvR6rvSuz3
pqx4LfY5YseB6P2xrPVd1rovK749y0+V9VdB80k0z2Hnq2//4SVvefINs7rX
v/bibWbPvXvcx1H5fqh8QlT+HsjPAelZfxfNh7Oul/W7QDrqn6yO+i1af6Fx
g93HRu8p9v3Oxuuyed+quClVfR/WZyAr7quarvJ7VPlF+L70ho7uY/R9Z/8u
6reqvAbvCw0CtSe7PmX9lOynYb1FnfXjyvq71XSV35Rq/oPeF0hH4yQa39g6
16zvh8onpFf3M1V61v5kNb1aHnc1XbVPG+1HkRWP1EpcTbSueh6jvzNmfb9T
6dHjYdbfjb5f1d47qvsS/X05+u+q5jPs/Eo1P1TNA1XHZ+fP7Pyf3Xdi99/G
tw7tVdTZH7Bu3Xrrev/A3/Vq6ll1B1r3Q662L5q1n1ktLrcVnY0fbl1XXW/r
/a3aPli0/2TWfkXW85W13xJ9ntYH0cr+YbXrbb3d2O+t3gceWY9u/6z89+jz
6Tdd9V24mn9CtXFV9f03+rmO/n5a7f3bil4tHskwJgLWf4Otk876cmy77W43
7Tjrvu4Tn77tkE2OemhIRz4YyJcD+Wnsufxvl5v2ptu7h44/bpe535k36u+r
+W/4+8IgUDugfXi0f87uV6viQ9g6zqyuyithfb+zdNV3B/b4bHyLqo6z6vjV
9Oh+khV/Ff39q1f3wVR61rq4mp8J6/ux7FKHX37g7XO6fRdctcYZ5982qo78
OqLnmcjHAM27onWVPwOrI3+JrPNR+VGwvi7o92x/Q/2c9ctFOvv8onEbvS9a
8cewbv3P4X5l3Xpdfcpv3r33Z689o1tt51sePfJ3i0bVs85zNJ2tn+hxybp1
69H1XlV1opHOxqWj/WFVHUnW3yNaZ/0G0e9Znd33Y/M62eO0Xk+z9Tp00Xnu
qnqCWXXQWB+MrPqG1eqTsvGQqu8X0eMJq7PjJ/teUH2fQufJXq/Kt191nGg9
q1+p9FbamY1ziJ6nsd/ro+d1qvNkfTNUPq4190PGDtW6bHzXy6LOOte6deu9
qrOY+P7Y5KBaO1tn9az9UnZfVLVfqtKj90XZ+NhqelZ9OtV+bLQevf/M7quo
7mOWL03ruuo+Vrsu1b6f9fHp0eNDK+M2u++n2t9u/bthte8FKj26rm4r4221
9wvbn1Xf6VhflGp1tKP9E6KvS/XdVnUfs74rRf++2vql9e9ureitzxMMIwJs
nhpbJx35cqy98t7r3bbizO6cNV/66I5nPTCkP7bmGntM2f++bq8jjrz36PVn
DenIH2PlnW74wsvee3f3jdcdtu0yJ4/u14F0dHzkE3LMLutcPv0rM7upF2yw
zpwpw+eP8gRRXh4alxz/Pz4d7duzPthsXDE6DpvnqKq3qKpLovq7WXUh2e8a
qjiWarrqu5XKf76aX32Wzn7n8nx4ENX2GVTx7UhHQL9n/UDYupNoPnPangvW
Wn37h7stZrxtp30OunXcOppnqnxCVLrKV0R1nGhdtV5Q+V2wdVHZ+p7sfiC7
D4bGeftm/Nc6m/f9gyv+8/eXdO86+ZSZU+YtepF+bXfoNjv9ZofbhvULj93x
5Kv/dFN36jFvvmjmNS/+/YxuuW9+/+snnDGsb/Xzz//1yza4r1t35oFf2uD7
w/pqy5z8xTnr39kt2Pz67776grEef8nz+e4uf/jm+/7jim7qk1+49af3vfj3
S14X257WR9bZ+5J1nkhn+/9mz1/Xrd01858+7bOXja6j47h/tqWj/ozGK7Y/
tObXYd26detIV9V3VtWLjN53RftvrB7t75HlBxLtL636fVZcIrsuzqrHV83f
uFo7RPshq+KgqtUHVO23q+KWs/zkVb76WfnsaP+NfZ+y7zvV/WXbJ+s9GO23
30o+QrX6F6zPs2reqPr+m6Wr4g3QfB6tFwZRZ900so4Ql887OT4bCPnfTbwv
Z9269Ynp1VCtfawjPToeNTruUbVfqop7rDavZteP0etQ1d+NrjdXbV9adXy2
PaPPP/p8qn0viK7zWG1fKKsdWtdb2Vdppd+qvtNF93NVO2T5sUTvk0fXU1a9
v3p1XI2+3ujv4Fn1fFXfK6OvV3Uc1XWxx4m+j9HjW7VxLOv9FT2eZL3XqvWT
LD809rk2jAio8uaQjvL45v7xgP3n3Phgd8BHrnz4R18frt+94+lzlrtuswe6
7Zc9Yf83XTZzSEc+GMe+6qln//iS+7r9ztlxk99dP7pfB9I/d/Phbz71r+7t
vnzLMt/eea/ZQzryA0H+Iaz/Bhofei1vrjWd3efPOs9+06O/y9Ss/1Ln+xfb
/tE66wcSHQ8WvU8YvR+YtT+gmodXi69m465VfqGqupZsvUvke8D6fqj8FlS+
Iuxxov+uyueE1dnrQvdFVc8U6Sp/DFV9TPS+6LV4WhTPifK7R87jXtLvgtXf
dc1pz7xz45ndZRu857V7f3JY//xhr/z4o6+c1b32sofe9ervLBzS57//uztf
Mmd29/39t/7p/ssO69e/9Ffr7XzKvO7ndy19ytbPzB/Sb1vqrbs898n53Xp3
v/P8+aePX196pT9c9E8Xzu2efcn0+f/9nQtG1afsd/P0256a1d1zzOsG3vme
haNe78jt1j8+CawfBWrPQ5/3Jbi/e8/bt9vvN0eP3s6on7M+Huj5Qj4JyB9m
6fP2/8xb1nywO2SZQ64/cbXx62x/Q+eJrte6Vkf9X+U7xPZ/dD79lhfQb+Ow
devWeV1V31m1Xxrtu9tKncpW/H6j686z+4pZ9cXY40TXL1Odf3Qdmaw6UKo6
mK3XY0XPKTteseOnKo9J5cukOk/2vfnCX5/09zv7/lW1W5Z/frRebb4RHZcY
3Z6q+iNs/qOq36qui/Xn6bX9/4npCBMfP7Xnw2Ly2nNkv27kkzx2/2RWZ/3D
0e/Z43g/zbr18eqtI+79Yj1XZ/2Kq+2XsvPVaF+RrDpr7Losaz0YXdev2vq0
2jo9up2r+du0vu+R1Q7V9kWzvnO1Mv6r9k+q7eO1oqv2tapdVyu66r1T7b6o
+hWrq/a9e/U7frR/V5avQr/prcwbs8YBv7+0uqrdsuofqeI00O8NYyKIrmeN
jvP2H17yliffMKt7/Wsv3mb23LuH9N023GipBZs/1E1Z+PSUrV4+7MtxzC7r
XD79KzO7qRdssM6cKcN+F8iv48Q9D9v0c7vd331gx5XWuvvpB0fVkb8H+v0r
v/bozvc+MbN7/VZT9/7iCfcP6ch/A+Uhjvxc19n3tm7duvUsXVUnNOu7WLU4
xmrryuh5des66zfC+nugeHjkb8D6e2TprJ8D+/vodmD9Vdj7GP13VfkXqJ9H
+4Ky+7rs++KF/6o5HcVDrrbMyV+cs/6d3YLNr//uqy8Y1pFfAcrrP//4zee9
eqWHuh1mn/vV22YM+0sg3wnkm4H8K25949dWXPGX87sVln/vcXttPeyDcc87
Fs1Y768WdAu33PuQuQ/MG9JnHbzCWl/cYGH39bvO3HiP8+YO6YuO/ezC7xy+
sNtj2V+vOmvHYf2p6zb97LVbL+pW3/+xhTMPfXj49+feefbZ8xZ2224x4xVT
5z886nHQ3539qXOmTr19QXfaKf+x85yV5o16Xcg/BLV/6z4JqH+ifoh8JD60
zrpbHnrlw916a5y63j2HLBi1vyFfF/R3R/Y9WDIuGvkYoOOj80TXxerf2eqT
V594x5xu7+3/14GnXrVg3O2Arlflw4COw8aBo/ZH4x7S0XFUOupX6HxY/yLW
d0V1/qr4fLYeqCrvQKX3mz+JdevWeV0Vrx5dLzIrvk5Vp9L1wkbWs+oGVvMN
Zv08q9WvjK43pPI7zXououPc2H0nNK6i7yPRed/ofYTeI1nn2YquyiNj6w6o
/q5qnsD281bqArDPNevzED2vY9uN7YdsPYisftWr9TvGpyNk/d2s89Hvb7P7
k2i/jt23RPt1SGePo/q77H4aq6P7Zd16+3qvolo7W1fpqvpirK6ax1Y7/6z1
VPR8XrXeUa2zVO2TtW+fpbPtqfJ7rKZn9Z/o5z2r3bLGW1ZXvY9U+3vRetb5
qMYfVf+v9rxEjxuq41d7H6nue7VxPno8iZ7XRdfzVe3zV/NNav16o+s1I131
PaL1+VvW+ajGk2g/sWrr3+hxVZXPqMorNIwWgXwqkP8G0g+84pyZMz/2YHf1
zUed/rrXD/tgIH+MtVfee73bVpzZnbPmSx/d8awHxq2jv7v9LZ/56qc/M7u7
ctWvnjl1n+lDOqr3jcaTQYy+z4zyVqLzEdjztG7duvVsnY3XamU/sBUf42h/
7Gr+56q8DHYdwda1ZOPn2bh6lU8IqyOfB/R71fVG1ydl68yyv4+uV8v6TKJ+
zvpjqPZFe61uHZrnj+wPMPZ8bZSPj/wBUF4/8gFA/hK3LfXWXZ775Pxuvbvf
ef780//MZ2PHnU7c7vMLupsO+N97fWrasH8F8sH4/azjNp110qLuFT985W0f
W/3hF7XnI919d77xZ/dfOmfSdOjvAc4f+YogfxJ0H1Ec7IvPd7J01gcG+bqg
/obaDfUr1J7o7yI/iq1+/vm/ftkG93XrzjzwSxt8f9Gov0fPF3pe0HWxOvR1
Ae2A/HPQ9aJxBv0e3Xf0e1Zn/SjQfWd11u8i+rqQzt4XlZ8JG4fP+t6ojs/+
XZX/hvf3rFu3vhgj5wMuiWr7V1l6tTgNlR7tyxF9fJVPBauzvp2t62w7oH0k
lX+IKr4r63lBuuq67F9hvbKu+h5XLd9NFe+t8nloJa9wEJPf39j72Nt+GsbI
yN/fRvtmqv091X4pu4+H9jNV+8Cq/cNoH+D/H9XGB+vW+wHV2tl6K3pvzw8n
fx6umrez65es9eYg4totKy++V9f71nP1QdQZ31rXVe3cyv2t1p+rvS9U4y06
T1av5j/WSn9oRW/Fdy7LN8C6Vq92H3t1flvte1b0dVXrV9WeL1WcVVYckWH0
M1i/DtbHA+m/3ucP3370jIe6s3+/67UXPnPPkD5z45sfXWXu7O605Z64fcp6
dw7pqG74WOOg0Pe7rPj/rDqkqH2sW7dufbL0avP/at9fov1LW8nXaCXeu1r+
Auv/wPpIqM6/Wn5EdH+IXs+y+QhZ9RMHUed9NFY92mcD5Y8jnw2kI98AlNev
8t+YdfAKa31xg4Xd1+86c+M9zhv2r0B+F4vbd9EOCw764oZL+ma85tc/3XCV
H88esz5RX45F59559tnzFnbbbjHjFVPnj9+XA/lRsP4JqF+hfsiuc5EfBeqH
qP/c+savrbjiL+d3Kyz/3uP22nr+qP0B9R/Unqg/o/ZE56/y2Zj9qXOmTr19
QXfaKf+x85yVRu//6Pfo+Kg9Ufuj80fjA2o3pLP+P6wvEHscVkfnz/q6qHxC
lj5v/8+8Zc0Hu0OWOeT6E1cb/fjofFQ6G7eP8heiddbfQ+XLgcZVle76odat
94qOMPH9MVWdL5XPbVZ9OlWdiywfXVW9G5XvbrTPLXsc9jyr3Ueks+3M1iVh
fVPRc6EaT7L2mVl/VzZeaxDV3jvWrVu3bl2rG60C7SOxPszsfiO7j6ryE2b3
FVX7kKz/M+snjHTVvp/9Paz7/TJx+Hmxbt26devWrVu3bt26devWrVu3bp3X
2XgwVdyUKl4IxasYhrEkTrp32gV/OGxW94W/WeWKFabP6EbTL9pnhdWueHZW
N2u9Nx560ul3jfv3p+25YK3Vt3+422LG23ba56Bbh3RU5/2F/3fUcYyt88t+
T2S/G7L1C9jvlWzdAVW+AGp/Nq8BHce6devWrcfoWb6+1fJKVHkoWfkXWboq
Tr6av021OsVsuw2izjhTRVf5GLDrCDb+E8Vzonx2pKM8fdZ/A/kDIF8F5Gux
+H4g/42Nz97trN2Om7WEPvX43635rX9/aMz6WP06fj/ruE1nnbSoe8UPX3nb
x1Z/eNTzh74cpL8EiuNF8bFsnT7WD4G978h3gm031qcC9VvWZwbdL3Q+6PzR
9ap8OVid9fFA7cOOD6yOzof1G0E664fDxsOr/ExYvw42Pp/V2Xh7tm5mtF9H
dF3OkffTJu7Ha18O69atZ+ut+N9m+Y2o/Emi/Xhb2Udi95dU94VtT9W+jep+
Ze0XVRsf7JuRo0fPSz3vtW7deoxu9AvQ/hv73YTdb2R1dl+R1dl9zmifYaSj
/UZWZ/cnVfuHnrdYr/DeYffzWbD73v8/Rp/no99bt27dunXr1q1bt27dunXr
1q1bt96LuipuSlX/mvXrMAxj7Ji58c2PrjJ3dnfack/cPmW9O4eep2WXOvzy
A2+f0+274Ko1zjj/tlF1dJzuxu2OvOFXD3erX3PCQetudsuQ/tysq/9h6n0L
uoOfr8N+4Yue49HHK7b+ryofgc2Tis6DUOUpqL5LquqT+vumdevWrVuvpGfF
mat8URzfbr0XdOSngeaZaB6L5s/IN49dX7D+G6yvAhtHqvIxQP4DT1236Wev
3XpRt/r+jy2ceeiSvhzIN+PEgY9+ZO/HZy6hX3rgOqu8eq8ldfT7bdaYsveT
/2NJf4+x+nUs1pF/yFj9PVD7IL8C2P7AhwH5RUDfDOQvAXR0H9H1ot+z54n8
K9jrYs+f9mkhfTlYnfUPgf4w0TrpE8L6q7DjG9LZepcqHY3/Kh3Fw2fVwVT5
2UbraJ+K/b1WH7svrvfBrFu3bj1Gj/aVZc+H9RthfUKq6dH+vex+2iDi+lsr
52m9N3XtvlncPJn9jqxqH+vWrVfVjX6H6vuIyk8Y7XOi82T3FVXHQTrrM5y1
n6nat1T5CaP5EjufyaqTpdLR+fSHrgfq5ypdtZ8fXffNunXr1q1bt27dunXr
1q1bt27dunXrOG5EVS8G6YZhTByfOPaVn1jj7LndU6cccPW5l9009Jz9aWCP
a29ZY1539dH3PXbgITd24/19lP8G8u2P/m7I6myd0+j8iKx8iui4LNX3QdV3
SX9vsm7dem/pLKqdv3Xr1ivqI8ePLTkPZOPf2Hlvlv+GymcD/R7Fi6I8euQD
gPwQkL/BIB7pNj57t7N2O25J34wj/u2Ik274/INL6O/7v+y9fbSlZXnmWX5E
DYjaBDPQtCYVm6B29/g1MTF+bMKQQeJSCUZSdLpjYqZi0kqYNkQSSS8TJF1p
V0UFmQT5MA3YE7WZhCljRFHAL0hAhdCASJDBlJZFURQEF8Z8dJimzijh7LrO
Odc513Xu+9n7uv45a13rXe9+3nfv877Pcz/3/btv3PPyXQf+5ZSPeB0nH/Tp
Hc959FenfMTrQOM59EVv+/pHD5vmeCC+x2KOB8t/WO6+sfwQ1kfnZ3kmi33E
x2B99nNZX8XlYPknKp/lnLA+y+Vg+TNuLgebV6/qj8n2tWTz5Nm+lm4+rSpO
xfa7dPuqeJebT5u4U/z48ePHr/DDfY0/yz6aX6F5ncpn9x/RvBTNz9n5P1uX
ys6f2b72bJ9u5Ge+HT9+Vz+ad6n4GGi/g/VVcU50PHt+VdyS9Vl+CBsvZeOZ
qrilKs7JzmdYn90ndX+uijPcYz62fmLj86yvis+z65fMn+PHjx8/fvz48ePH
jx8/fvz48ePH1/ko34blcrB+FEUr1+f2bLhk89l3TX72EWfd/uc//flv/z99
6Xff/aIn/dTuyW/u5Wb86bf9PS957p999Cl3Ty743KbjvvJDn/y2f8eur562
+WO7Jx8953Ufes2Rn/m2j/gb6DmwoIeeJyg/B+3TqfYfVX0EVHUTbB8BtI/D
+mi/hq1TcO8Drm5/0Ldf6c6vq9rHzD5a/Pjx48ePH1/Vp0nVlxPNS1EeEZrf
svPkKv4GW2+O8jnZvFNYjw98VNe/IMyFuGDDz/7MiV+f5mw8+zXH77z0NV+e
8s86ZssHD71qmteBzoN4HazP8j1U/ub33P+Ms7b6eCPoPOh45KPvlz0P67t4
KYi/wXJF2PPQPBCSE4I4Huz/O/s8QfnkKp/NY2d9FT+EjUep+leiuBMbX6rq
08e+36u4tavj0Pr6VyaeEz9+/Pjx48efN39186jpeZqqT4HKR/NeNJ9n95fZ
eTvLu3P3r2fn50vvL6ePfPzV+e511tJc6+V+h26x1xXNu1T7F2g/AsU/WZ+N
lyKfPj/gIbvjq6zPxoFRXJSNc6L5jNtneQiq+ZI7Lurut4XeU6o8OpXQ7409
virezv4e2P16Fafl4aqfv8WPHz9+/Pjx48ePHz9+/Pjx48eP38l3czmiKJrW
9Ue+/Bsf/Zu7Juf8L7916vGvvnaynM/yNJ7wjp/7yydetGfyG3v9933b/yfb
/+jpmx99z+RPf+FB/+xv++ftPPg9p5+5fFwdxfNR3UFVf1Xks30BWO4H8tl6
ClX9hbuuoaqewr0vqeKHqHgj7v3TKv/h6jMvih8/fvz48St9Nl/XXY/AzgPZ
vCOWs8HWL7DzdnZ9wdabq3z0uez1ovMvCPMiEGfj/js/ftqWi+9Ys4/4Hifc
uOfluw6c/lw0nsvf9Kyn7P/6ae6Hmwdy5tvOvOi6U79iO4/q/Kzv5o0gXsdK
OR7f8u/44lM//uXL189X8UNk+eQgD5z13c8x9/OQ9VXxJeSz+eosr4PtU+nO
H1adRxV3UnFrV8d3nZ6nufuzq/rFuzm0Km7Jw1U/n48fP378+PHn2Wfr+FTc
V+Sr5qvIR/NwtO+s4gGiz1XNq9n7xs7D3f3r3fWq7Pz54ar/P51Vf+l1h68P
CLt+7MHliCJOMK5I8sDdXGXEPWbPD+O64PzIR/fBzSdB50ffF4q7quKibP8s
VbyU3X9U7WO6+Qzd+nC5peJjV3GwVxffXvm+P5tniOYn4UXHjx8/fvz1XKdX
fa7qfefeD63an+22jzy6776f3epBVHw/97y0Wz9c1e8qdT3xO7xPRxlnt/F3
83Pf4sfn/ROf9J7dz/zS9P8F4nKwfhTNs1j+xp6XPPfPPvqUuycXfG7TcV/5
oU9+20f8jaf+4N//0kc3T//fIc7G0vyc5Z8baP/CXU+Bjkd8D+SjvCY2P6qq
j6p735DlhKj2rVTXpco3Y/P63H63fVU3P4SNR1XFnUZZd7jjUapxVvmq34+7
PmtW7398rV8VX6rap1DlmbD/p+76SlU9AjsvUtUdsPNDdv6p4m+wvD60vmDX
New6Aq0X2DxDdB6Un7kgzE9AfIzrDrrzoh2HfWnKf8wRWw7YeMKta/bR+c++
88d++OL7/t8pH/E9WF6H20f3E42zymd5HchHvA7kI/4Gy/FwcT9QnjbMGxfl
b6v6P6o4Ht14ICwnlo0jqfLMVXnp7Ht59DiPistR5VfFZ7rFkVTzeTefJHWX
8ePHjx9/nn02brb0+316nubex0TzZ3a/mI0Lsf3ou0nFLXHP/9l1BxsvVfUf
f7jq/6+7+SpOtXsdF0XzLJYvgbgZKI66oLVzkpc7D4oDo7j0WuPGKD7MXi97
fnT/0feF5i2quCs772L3y9y+m4c8SjzTLTfvRRXfruJvuPnSKl6HOx47ej6M
6vzs+Kv8qvtWNX7V586q361evooz3+25Gn91ftV+qHs8bk5plT/Kvrm73oTN
W6iqc3H/X+T3qb0/q+Ox+PKxVfkzKv5JVb+eUeYV3Xjabt89P3y4Vr//0u33
ia4rfvxO/pX/8TGPf+zfTf9uEa8D+VE0D0I8jSohzgb6v17Q8s8HtC/A5he5
6zVYjgfL2aiq13DXU4xS9+GuB1HxPVhflQ/WbR923ngj7nUl+7kqXkrV+lQV
31DV9VfVYbnX6d3iiu71+8O1fvuAo+zvuD+323unW90lm1fD8jRUdbIqngZb
H8H6aB7L8jdU6wK2jxgSus/oe0fHo/EgDsCCcN7pWcds+eChV01zJDY+cMhJ
x2y9fcpHnI13vvr4Iy+/75Yp/9g9uw49b9eNU/7N5xz5A3/wezdM+ecefc4r
th11/Yo/F3E8EB8D+eg+IK4F4oS4/fvv/PhpWy6+Y8XHo+tieSNnvu3Mi647
9StTPsvrQHwY5L/06Yef+I2DVs79QOdBv/81cznIfo7ufoisjz5XdX42vqTK
G2fzydn4EuureFMqTqy7z6Aqj72bz/JDVLwRNt+G/dwqLi4bR2LP4+476V7P
xo8fP378+Cvf/117nTsbj1JxVtn6TTTPh+sOch00b1JxdNl1BxvHYz+Xnc+j
+WFVXZiqPgh9rirfmOX2qPjSyFeJ3YeNos6CcUvSXy03A8VpUVwXxZlRXBr5
LI+ajVer/JXGpdk4MxtPZuOxKL7Kxmnd3GY2XloVP6x6D6ri3ux8nl0voO+L
3e9W3WcUb3THe939tlT5D+5xjuKr8qZq6wTHvQ/uelL3/e/2+1H9HpZ+fvr+
H6ueS6rnajd/Vq9L9R5nfdU+7yj716r7yd43dr/b3TfN3SeF9VV1NO7fYbfx
uH8/VXka3fJS3H1/VM8N1fNzlPdst/eXO0+p23pzLF+1HunT1zsckvnwUf3+
773suL8/eDf7/UZR1EfLPwfQ+wjtU6B9K9gHwbzfp6rLUPUzUtVruOsvuvmq
epBu/BBVv3i2TraKN6KKz7j7cCFftf6qWo+r4gPdfPf9d8cb3et61X1w7wtU
5QmwcSf3763b/6N7P6JbXaTbVz3PWd4C63ebX7m5HCpex+hari8byvNEfAnE
ebjuoDsv2nHYl6Z8xMfY9MxLb3nrFX8x5W/9kXc98owXf2HKR/yNa/Yef/WU
jzge6HMRV4TlWrDnV/noc9nxIG4Jy/FAvx82L1qVL83mUa+07yHKf67idaiO
V/ls/If12XiRKn+bPY+K7+TOcx6F16qab1RxYqv8qvvv7mPu9lVcPlW+cVUf
iqr+btmnjh8/fpWv4j+rOOHu+Kebs8FyM1R9Itj966XjJ9EoUsUb0fx/6Xiv
j5Nf5bPPE1U/iyrORhTNs9h45nL8DcQ9RlxlFL9FXGiWs43Og+LMiAfi9lfK
i3bHmVXxWOiD89DxYTJvkOVyqOrd3P0UkNB1qfoUuH027s3uF6vin6r8OlXf
MVU/EXa+5877cuftjNK/TFWX1+0+uPu7ufPxqs7vrp+tyo+d1eeDu7642/6a
qq58Vn12PlC1bzurvjtPgM1bYOex7ryOUX6Ho+R7dKtX6vb/qOoP2O37Yu8/
+37slofT7Xeluj/d1pWqdYebl9Vtn6uqH667X3Pypkb2oyjqo7X2RZqeJ6D9
DjZPid4HJPcHkc/uD6r271Qc/tF9tu5D5avG4+7PxX5uVVxllHqZqvujqo+u
ioewn9stnlYVJ0ncaX189z6F+3fu7g9excGu+h1WPa+q/o/c/IoqblgVr4Od
10Wd9S3Oxicni/0rd26/7s3bL5vyj9zrXzvlH7tn16Hn7bpxykc8EMS1QOdh
OSTo+He++vgjL7/vlhWPE/no/Ow43bwOlBfN+iyvA+U/s7wOF8cD9j0U9a9k
8+pVn6uKC6G8cZgfLuK+sse7+z+q4lGzypVVxX/cXFlVvo3qvqm+d1X9o8pX
rY+68RW79Y/T9h3r34+D3Qcfpa/Hw7V4X8k3HvS5s+q7v3f2d6j6nah89nNZ
ngZ6DrD9ENn3hapuQsV9RfMKNI9C8wR2fovm53BfWLSuWRBax0WjSzU/R757
PunmYHfr18nuB0VRpNJ03PJbPopzspwNxFtGcV0UZ0Y+y99QxYdZrgiKV6Pz
oPu80ri0mxdN++44MIjTonkpmveq8nzc8xCWs4HugyrurYpXs76ba43inKo8
N1W8VFVP5O5zVPW5qnF261PWzXf3I3PfTxVHotv3UvX7V3GH3J/r3odin/9s
f0bVdVW916r2B92+O5/NvT9blac3bz7Lx3PPb935Bmx+RVUfYdV9cN9Pdx6L
+3lS9RxTfS+qurBueeCjxEPc94edr6rup3udolpnudd97n7Q7j7FbL6Tqn+H
J98DqT6vZrb8KIr6aKX8jennMJpvoDyo5fKX2H3btdanyPYHwXlo/j/w0f5U
N9+9L8b6o1+X6nNV+4lVdTRs3ia7X+zet1XV77jjJ6r4Xrf7UBWnqoqvsv8v
VfEcdz3a6HF+Np+nat9q3r6vbtdb9f/l5smo4rSq/4toHoS5HMhHfA/E8WCP
Z7kf6HiVj/geLJdj4wOHnHTM1tunfMTruP/Oj5+25eI71uyr+h6iPHA2L5rN
00Z51KyP4i2sv1auCPJZXis6jypvnOWvsn0bu/k0n0TEFXHzaVVxmG48W3ec
h72fbq6LOx/G3fdnFF6laj+6qs9a1f47u9/N9rNg981VfUyQj8ZZ1XdydfkG
688nUfU3UfFtqvqzrI4fsvY8E/fv011vrnrOq3jUKJ7MzhNgHR/J2VgQXnew
6ya0XkPrvn1zI6NZVRXHuFv9URUPPJyNKOom/N5EfAmWp8HGgdF5EOcZxXvZ
uC7y0XnQvIKNP6P7rIonrzXeu9x51np+Nt8PxXvRvBTFqdj8E7ZvFBvPZOOK
9PxcFPdW8TdUPGp3XLoqr4mNf1b1qVHNn7v1EVPN87uNv+r7ndXfYbfrVeUL
dauvVHHs3T47f2Cf8+76cba+WMUTcOchV/UVVfUh7dZHlf3e3fPkbn1yVfNe
FQdPNf6q/Ieq711Vv9MtL8Wd36J6vrl/P7Pa55r9XubN7zZvTF/pBbnzjtzc
Evb8bJ6SitehygOp6tsyph9F0Uhi89zQ8x/NA5erm0D1Juw+JvJd+4ayvgDA
R3UQLN8DHe/2Vf1ku10Xfb3m65LV45j786r2f2EfNLYeSuRX3Z+quBB7/0fZ
B3f7qut1c4RU+x3u491xsKrflSqeo+Louj/XHQ/sxrtWxc1U3O9u/QVU+Seq
8UTzrHsnt+zlZmybLPavP/dB/8IpHx2Pzo/Og3gd1+zlb1w95S/N/bjB5iMe
CPIRr+O6g+68aMdhX7L5LPcD5WmfdcyWDx561TSvA+Vvs30M0fEoT5v1UbyF
7c/o/lwUn2HPw55/zXEest+iivvK9u9296+0xyvMcY9ROCrdeLxsnEQVP6nq
gzkK32/0fl7d+pio+new/SyWPt7XZ1B7XWvnn6j6MKr6j7D5DKrPZfkPqvum
4rew52HHw3KBVP9fbL1St7oDVX89dp7AzpMXhPdt0fyfrf9FPloP7nv9GEWr
k4pTUdUP2s0JiaJoFOH3JuIhozgtiveq4rrovY/it6zPzjdYH32uKo6q4o24
48lr5XKw8TcVXw7FUdE8meYnm7nNsnGK4ors/Vd97+58G5VfVafcrc/RKP3Q
R/9eRrk/o99n93NjVv2q/obd+gmq+AZV/TRVPjtO1XXN6v2smr+Nsp+uul5Z
3YpoHt4tj6Lqd+LOV1Hlb7Dnd99Pd92E+/vt1he72/1k31+quiFVXyEVn6Rq
ntltvTx6vpPbV+0DqvI6VPkzbN+ch6sbHyNcjiiKHhL7nETPczR/QPtcC+L5
/+79UNV+30q5H6g+Avksx4P12ToO+zhF9SluH+YNis6j4rqwn9ttn5fdj2Z/
J+z1lvFSmvVHbvf7abZfz/5uVfff3Z963uJdqt8VG88ZJW6j4qWMHkfq5lfV
943eBzyKVi5/fA3xPa7cy9+4bMrvxus4ds+uQ8/bdeOUz/I63vnq44+8/L5b
bMereB2Iy6GKV6j6IbKcEHY87DjZfGw233utvFYU9/jW8YvzvVVxleU+l+0j
6eo7yd4Hllsi45mQftXnsuNx59vMW36LKi9OlQ/v5itW1Xd3893rIFW/DLQv
w/YfUeUzsPW8LK+A9d28EXd/E/f3i45X1U27677d9ePu+8/6qvoLVf9r5KN5
CLsvsyA8z0TzdnZ/Ga3XUF0wWvfdf+fHT9ty8R2L/Ciqleq9E25GFEVaYZ7G
pmdeestbr/iLKZ/lMKP4LXq/u/kYaL6BfJb/jOKuKs4zex5V3Bt9LorrrpTD
rOItq/jJbNzYnd/lzrPqFrdkx8Ouj9j1VxWX2F1/3S0vpaov9uj5Nu74tpsP
oOob5f6/c3/vVbyFKr9bHuMoPv2eHaSvQVW+uru/Z9X1qnz3PFaV568af7f6
l6r1gur4qvoF9/de9X+hGqe7X/Moz6uquqF5q2Ny1wep+gW7OSGzyvl09z9V
9fdR5Wm482Tc+TAqLsd5e8/zmcnmb/z6TZfd8ZB/+NUPHn/xZONxN/7Vu+6f
N15HFEWzIJifCd7jaP9oQXgfjd1/ZH20H6qqZ2E5Hi5exyh1HO7rcvssH4Pd
V0X3jfVV1+Xun6vimdj7Ag/CjZF9X1VcHXf9URFvpCpu3I1P0i0OUxXnccdP
uu17uvM3ZrXfCntd7nhRFX/DHS+KIp/88TjE5UD+Ajfjk1M+4niwPuJ+nHv0
Oa/YdtT1YDwr53ug8yDuB/IRrwPlgSNeB8rrZuMb7HlUPvrcqnGycRiWE8LG
c1iOB/JVfFd3/0qVv9LrUsUlvnX+tXJC2PO4fTYP351XoFqnd+OfyPITyHoB
lnuJ1oMqjoc7v5rNQ2Dz21X58Gj87P4+u85S+ar8BPa6WE6LKl+CHad7Pau6
D24+D/u7Yu9D1e+k6v9FFedR8TTQe0f13l9uHoX2B9H8VsUPZPeL983TwP6+
63yjKIqiKJoWjruy8VjE30Dva1XcEp2H43ch8edX8TrYvDj2POz53VwONn5b
5a81nslyRcryo4rigez52Tghuy7r1v/aPU42/un2Vf2JZtV39zGv+n1WjbPb
91t1/1W+u96W9d37UO34AKP7In5aVV79KNer8hdE9AEpul40TrXv6quCfHc9
C/u53eo7VPfH/ftkx6m6/6r3TrfnUtlz3vx8K3tPFeX5qPic7Hqq27q7W96O
Ki/C3efI7VfVd7B1GchHXI6NB7z3LTuf+8XJ3S/5/Hn7f3j54xGvY8H/2OSo
975v++F3zSqXI4qiWRaahywIryPQfpkqD4rdb2V9d98BVX0Hm+eG/PWuv1hu
/Gw/rC77oas9P3s/Vb8f932YtbhT9XW5vkcVvwWdX5UnoPK7xWdU98fNeVbl
b4+Sp6Hy3RyPUfIf2P1oFcdVVXdW1R9EFf+pis+o+BtsfAb5UbT+8sfprj/3
QX7FhVPzsVv2ci222XzE92C5H4jjofJZjsdjjthywMYTbp3yEZeDq9vC51Gd
nz2e9VGfaDY/nK2bY/PnEZdVlQeOfBX3VdVfsspXcWu7cU5U/krX6WXcTjLP
ZLX97lfK++3Gm1Xl86v296v2/dl1qKrPmio/vFvfEHffw1HW16rzq9bR7Hjc
9R0qjmsVX1TVD6iqL627X6eq7mC1PA30vkb7UGge6+4Xz653UD3vvv0oiqIo
ilaueydb98Z7vzD1nkX8DRR3ZTnJKD7J+mxclJtX8OdH8xw0fjYu6vZVcVcU
V0Q+G5+s8lGccK1xsG+dx8UBdvdRstffmfuJj9L/ulsf56r+11Xnr/K7/d66
/c67/R+V5eOJ6ppl4yx6zsv2lYrG063f5YLq+ADu/qRr7We6XuOv2n9Xnd99
varxo/i5ah3hruvp5rv+H1f7HHPnmbj/31X/1+zzTfWcZK9Xdd/W+rta7rrY
63X/rrr33Xbn+XRbX1T1sVX1+UV+tz6wVXUfrK/q08rWcaj6pbJ1H+ft9T8z
2fyNX7/psjtmlcsRRdH8Cs8D0bwO1SOgfUP3Pia7D4t4HWifUdUXgN1/rKqn
UMUH0PFs/Uu3fVXVfrF7n5r9vrrFYUb3q74vFednrXGb9YrzV8XDXXEbGe+3
KI9CFVcpi9uI4jnu/XpYD9UsH4Ctn1LFT6rqsNx1MWwcRtUvmI3DsPGWS/fy
Ov588v5zDvvI9mvD2Yg6qlv8DvM6WB9xOa7cy8G4bN19lvvBcjlQPjnKG2f7
P7L55+j4Kt+dZ87mn6s4q8hn88/ZekO2DlF1fpWv6oOpioe4j1fxeKvWoao4
AHu8Kl9ovXmzqnUlnb9N7o+r+rW5+4+4OaKq/AGWc6LqL1nFS1H1PWH5Ayp+
hbs/i5ufQD8HRN8v67PxJVX9C51HRPJg2f9H1XXBOgVRPHZBPE+e5c6h+SGa
t7Pzf1SHi9ZN3LosiqIoiqKV61vx2Bum3rMovorey+g9znI5WB/FM1XxWHQe
9Lksn5nlcqh8Ni9OFfdj47eqPD1VnFCVt6Py3fVTs9Y3il1nueu42fVgt35J
VX2fR78P7vwuVb1/t/5W7nwzWZ9x8vtaUJ9+c24Ow3K+u365W35p1XuWrQtm
9/tYjpmbS6DKk1eNk71v7roMt+8e/yjrFDZfpSpPo1udC/s8Yc+j+p2rrkv1
++82TvY87PNTdb2q53bVfeger+i27pCt14rWm1V9flX5D+y+v6rvicpn+R6o
jwzL31D1b0X9Vdk6EbYeZLa4HFEUza/4eAuaB6L1IMvfYPdn2ToRts8CqvtA
PltPoarvcK/HVfEB1XWpfFV8g/XddTFubkw3v9v4Vf9H7niO+z64ucrd/LX2
R0a+O57AjmdWfZqLIuKsVsU9yuqnyLqSbn1mVdzUbhxUNq7CxklYP4r6q1tc
T+cjLgfrI+6H+3OP3Mv3uHbNPuJ7oONRvjryEQ+E5Yewn8uOR8XxYOM2qj6Y
KD6DfLauUNV/U3W9bl8VH2N9d7yIjZN049m68yWqzu/mx641D5Pdr2frspE/
q/1G3f1EVOfv1o9Vxjcw93NUjVPVn4X9nci+d3O/HlUfVbZegH1eVT0f3Ne1
XNyVzfNX9eND8xmWs8HWvarqYdH6aN9+FEVRFEVrFx9HVfGQR+EYu7nHVXFR
d/ytW55YVX8rd92Zah3hjhOq6mRVdaxrjR+q+w2tNR9pvfoluevoR+37rLo/
6n5Vbg4P+3+kyhus6sumivOonm/uOmU3r6DbPhf7vnD3c6yan6DPrZqPufkA
Ks6Dqu6AvW+q+bl7Hq4apzsPgf1clC9Rtb4b3a/6/bj/L9z/v+77yfpV43Fz
clTfu6q+zz0fUOXtqDhpLq6aaj3YLc/Hvf/erY+tqo+Pqt6ErR9heR2qvq5u
LsfC8Z+dbHnpj1/9ypvD34iiaNaE5xtoXoTmdahOAe0/on1Ylc/uh6K8MlUf
WHcdhGqdWBU3GOV+uv2qOppu8TRVPNC9v+/uP1Lls/Gfbvzbbn63OEPVvmS3
/VBXf+Sqeo2q+g73+VW8DrY/rIrLwfI3VHEVlr+x8YD3vmXnc784ufslnz9v
/w+74x5RNAvqFu8b30ccD+RfuTcP/LI1+4jvgY5f4Fp8csX+NXvjFVev+XiW
E4KOV3E8VP0x2To+N/eV9dk6AlXfT7fP9jdX+SoeCPK7xQHc43Hnv6nyGVQ8
UlXePvLdfUir8pbXOn5VX8Ju/RaXuw+quoOVxiXc/Vir+pay8RCUv4GOH4Vb
W/U9rnb8bL2G63e+2voXN7eZrS9A70d2v4/d10P7cWgey3IFkY/WF2j9sm8/
iqIoiqK1C8ch2fikKn7I+t34G2z8k81Pc8fZ2Pmk26/Kt6nqr13VP6iqvkl1
H1R5SlycEEnXx1nVd56Nc6r6L7v9bn2aqu5Dt37f3fxu/d3cz093Pal7nO73
ftV97rafiPxR5ntun83z71Z3UPU9svUL7PoFHd8t/6EqT6Pqetm6Knd9UFUe
i6p+R/V/oRq/+7nhfr6h53zVe8o9P+k2D/eux+v6Aq+V+8H67frygHwMtm6F
7gPLcjxEfWPdXA7ko/oRtt8r29dVVW/C9nt9uLrls0dRFK1UfPwfzT/Rfqgm
z4rfz1X1ZVD1a3Cvr1XrULT+7VYnwvqq/Wt3nKHqeqvicmy8rts4VXGAqnhp
Vdygav/Lzdl2X5dq39O9P1vlr5XLgXwV79Rd5+Lux6qKq9B9XUVxEnf8hOVv
qPilKB6yNGdjmjv6cCUuEUXLq1sccHZ9xOWoGg/rq7giLMdD5bN9MFXxGfZ4
Nm9fNR6WQ+L2WW7JrMZn2HyGbnESdz0FWter8glVx1flFbjXrVXj7JY3rsq3
V+U5sPUI7t+P+3q7+Co+w2rHU1XHsVZ+hfp6q+pi3H1a3c9nFAdm8/1U+0Ro
fojmq2jey/IA2fXFvtc7URRFURT5pOYMrz9/o8pX5Y+p+L3ueFpNXRKSrp81
Gwdz1+F2q/OtqpOt6t/ExRuR6urxNdflH2e3OC0bF3Vzqt1+FX9b9Rx2P7e7
3Ydu9fXd8lpV+1+z+r2o9h/d88OqfVg3b8FdR1/FhUC+qk9K1eeq8iVUn6s6
XnUe1fW617/d8lu61Ul168tTxQ9RPYfdHNGqOIZ7Xu2ui3HXuax3PgDyu/W7
cdenyHgdg3M5VP1eWf4G8n/0ilP/1aOed8fk2dvf9BvPu/Ah/0V7ORs3Ta7d
/TcfOOUTy/M3Dr/6wbqViycbj7vxr951fzcuRxRF0VrF92NC+5IoX8tdD6Li
e7A+yltjuR+qdWhVH1jVvnM3v6rfrnv887ZOH2X97va78T1U/E93/KGKv10V
31BxPKo4IWye/1rjHqo+nnauKcnTUJ2fjZ+wcRKWv6GKn6jiIao4CeJvePii
URQ9pH78h/iz7SO+B+vfsje+sW3KZ/PwVXV5qrgQG89RncfND2HjMFV5GqPU
Kbh993hUfViq+jGpxuPuj6Y6fvT+bqq8btZn4wOsz47H3W/XHT9h4yqoTsHt
s31I3b6qD2m3cVb9/7p/z+7/axVnA82v0HyJ5cuh+erSdbXT83+0XtiwT7Hr
kSiKoiiKfMLvcVU8UJVnVcX1VflsHE+Vz8POM7vxdd39hbvVI7vjb6q8JtV9
dn+/qvO4443I7/b7YevQVfdBFf9kuQrsel8V9x7l+3XzB9zX222/A/lV+1aq
93jVflkV96DbPmPVvi07z3TPS9n4qttX3X/WZ/MN2PUOu15T1ddUreO6jVO1
/nWvl6v4map1+ug+26+nyh89n6fbPN+9XnCv10bJJ6mqZ6nyV8oDoetKgO/m
ciD+RhWXg/Xd/WH3+9DJv/z9z/jK5PQDTv/8BRuX53Is9IG9bfLEMy58++9f
vDyXA/WN7cHliKIocgnPG9F8ns3jYvO7WF/VZxb5LA+EjTOw60F2Ha3ilrBx
FfY+qOpZusVDquIeVXFFNt7Yrf+ve13vjldX7cu498HdcQzVPlpV3KMqvuEe
D9sXw13vsNZ4BfJZXoeK4+Hmfqi4HGychI2fIJ/ll6riIX/ynpfctf8hX528
8mt//J9uvu0hH8U3FvyPTY567/u2H34XG6+Iomh59eMzxI+/Fp/leKC4iooT
wn4uWy/A+qo4CeurPpet33Tn4XTrl+rOm0KfW9VHphsvVFXfwfJC2XW3Kt94
lLqSKh5pVd/Ybnnm7j6zKh4Iuv9uXquKN6vqA8ueh73/7PHu/s7d+MlonKrn
M5uHz84f2Hkgy8Fj90k37FPJX4miKIqi/tLFA1Gczd3/CPlsXlNVHI+Nd1X1
V+rGD+nWL7hbPE3FtVDVJanuW7ffg+p7QevNqvpx1fm7xS1VeWWqOHa33+es
+t36o6m4Ad36/bG+e56jyqcd5b6xee/ueWy3unu2TkG1jlDdT/c4VX1v0fGq
/rndfPf3ovJV/XHY83S7D1X/v938bs9n1lf1CXK/992c0qr+vKp8G3d/Xncf
GXe+AapnYXkdrO/ib8j6zLr7vZJ9YLv1h2X5Hqq+sYjLgepTUN9YxN/w9JNN
XkMURV2E54cq/gbiZqB9XjROlc/2h2Xz1tg6EbTOZfPxVHl3rO/ub6va3x8l
ruK+P6PEB1R5C+44gCr/wc0/cfujxB9U+2jueAgbr+hWL+OOw1TFPVR9XV28
DhTfUPkqrikbV1HFT9i4hyoewsY9EJdjy7nHvveaB748edUPvOyNV/8eG6+I
omj16sdPiB8//rSvivOo4hsqbq2KH6vKn1HFJarqOFT82G79ekbph6Lq51LV
x03FX2V99zjZfGZ3n9NZ7T+oum+q++nuT8r2gXX3Ue3WV1R1nqrzV40T/c7d
z2F234HNu0bzK3a/dcM+lTyVKIqiKJo96d7vaF7B8m9V8Si2PsidX6SKa7nr
Zdj5p6qup6rft7vP+yj9f7v1i+8WV2R/D1XxIvd61h1vZH+HVfHPqv+LbvmB
bNxjlH0H1XVVvde67UNV7XN1G+e+fST/PLPb/Nk9/2evC61fVHUcrM/u76Nx
qvrbsvkS7nwGVZ/fUcbvvg+j/B5U+TNVcYml/999z0n2PaLiBbnzalTxkKp+
x+51mTuewPafddeJVPmI16Hqu4H6j1T1n0X1LK4+s2xdCaofkdWVmOtQVPUp
7r6xqD8sqk9BXI4X7a1buWly7e6/+cApn1iey3H41Q/6F082HnfjX73r/iou
RxRF0VqF51dovoriLb3yvsb32f1u9/1n61nY49nrrVpfu+toVPGNqnhgVbxC
xfcYfR+hql9wVX5Ct/07VX6Fuy6D9UfJz2fjJKyP4iHId/M6FvsojvGt49ca
DxmGa1rE32DjG4izwcY3EF80iiK3+q0f48eP7/NV8ZCq8bBxBvfxbDxH1bdF
lW9W1WeHjYe44wMqnqo7XsHmu1ZxWVV9Ydi4RDe/Ks+/6j6r8mSq+ua4++yo
uCvu+zNKnyP2fqrGo/q+VM8BlqfBvu/YPHmWh79hn0o+ShRFURTNj+riYO44
TxWftipepKrHrOojrMqHGb1fMBv/UcUf2HiUiutS1TdZVS+Gfg/d+h+5eTVV
cc5R4rHu/mLs53brp9atr7rqfqquV/W+U3H1R/Grrku1zzhK3b2q3yjLkVD5
7P47Ol6171/Vf1blq66LPc/o9zPXtTpf9f/l5oeo+vJ4+z6z6hdPUPmq9aAq
L8W9TlTlLbB9WFT70Sq+h6qPrbtfSTdeB6pPWWufWXddCVtvwvru+pRR6lb2
+9DJv/z9z/jK5PQDTv/8BRsfqkP50StO/VePet4dk2dvf9NvPO/C5X1Uz9KD
yxFFUbRW4fkSmneh+WevfLD4s+K719es745buuMY7utV+aq4h4oLXRU3UOVp
VO2vuetfqnwV71RVl8HGQ9x9bN19Wt1xEhWvA8VJUDyEjZOsNL6h8ueNv6Hi
iKJ4xVHXfuDvjnjB9sknnveq7zrx5+9Z1kfxiiiKqtRv3RQ/fvz4o/jueA6b
n+bu21JVV6LqV1Llu/vVVvWlVXFZq/rPuvuiVvUlrIoLjcKJHb1/q5uj4j6P
+3sZnXvs7jeq6kfJzk965eVGURRFUbT+Gj+e484PUfW5dvtVfXNU41TFZ9z5
OVXxsW79gFjfHa9j7wP7+2F/51XjV/WJVp2H9d39squuq1s8XPWcVH1ut/uj
is9063fPzme6zbu69StUzRs37FPz56cfa/z48Uf3q+pfVPs7VX2Q3fkzVfM0
93qkW/6GKk+gqt6ErStx94d1941luRzufrJr7TPL9oFVcTncvA4kVM9y01N/
5+CDP7V78uQn/eT5rz96eS4H8hF/A9W5qPgbqJ6F7Sd76d7j/3zy/nMO+8j2
a8PliKJoVOH5AJq3oDxYNI9Fnxs/fvw+flU+p7tvb7e8C1V8YFbjEu59W1Wf
AnS8Ku7h5pe68/ZZH8VPVPENVTyE5ZQivyoegngda+WU0vEQ4Lu5oyx/A3E2
VDyNhbjBbZMnnnHh23//4tVzQaMoqlK/+Xz8+A/qjU86+WV/eJ877hw//nz4
qv4squNVfBJV3xY2LsFySFTjUfVTc/dncXNf3XGVbr5q/O4+OFV8WjYe1Y1z
wvJb3H2E3Z+L7gPL90B+tz6/Kk6R6jmseq+xdRMb9im3H0VRFEVRH40TJ3H3
w+1WL9NtnO7+ROw8lu0T5I4LVcXBVPwQ1Xnc98HdN1n1O6yqF1N97+z36+YS
dPs/Yv1uz5Oq+Ln7feHt/66Lw1T1AeyWr8v67nGq/NHHHz9+/Pjxa/1u7xF3
vKVb32TV+kK17ujWJ1e1z67qN6Hie7A+qntVcTzc/A13vQny2b6xa+VyfMtf
XJ+C+sCyPlu3Yu8na+ZyuPvM/sl7XnLX/od8dfLKr/3xf7r5tuXrZVBdzIt+
4m/POOHdN02u3f03HzjlE8vzN87be/xnJpu/8es3XXbH4uM/Njnqve/bfvhd
y/M6VsbxiKIoWqn4+QaaF6H5HprfovHEjx8/Puu74//ueIK7z2+3/Tt3PkBV
nETFO1XVR7D5/1W8DpaPqoqTdONyqPilbDxkrXGPKi4HG8dA8QoVfwPxPxFP
A8UTWD+Koir1mw/Hr/TdWvl4EH8jXI748ceJS7jrVlT5n1X5tN3qNbrVO6g4
ru789m4+2z8RxYXc3Azks+NRxanY8ajyiFTxMRVvxP257P1X8S66/Z7Z/1N3
ndrodRb79qMoiqIo6qN+cQ+V7+Z4zKq/YZ/y32f2c1XjVPFAqvgk7jhYt891
10NV9ZVW/T7Z+6zK7+r2O6/iRVfdn6r3Bfs83LBP1eVnqsbj/tz48ePHjx8/
fvxufrc4RlV/3qq8C9V+JbvP7t5HVvnu+hR3HQpbb+KuK1HVm1RxORbXoSDf
XZ9SxuX4wXtue8733D3Zc+SJp+/6y+V9xN/Y75C//cgbLt01+ftH3Lr7wCMe
qnNhuRyHv/GGW2/+5o7J7ed894YjXrU8f4Otl0H9Zy8999j3XvPAn0/ef85h
H9l+7fJcjvA3oijqKTzfQPMWNF9C871wOeLHjx9f61fVxbj3T93xE7beRMXl
cNdrqOoCVPxSFdcUzU/YOMm8cTnWm0eK4hs0d5SMY7DxCsTlQHEJxP9U8TdQ
3ADFGaIoGl395pPxl/L76/Rf+et3X3LN9HsC+eFyxI8/f747H5XNo+jWTxbF
GVSc1ar8Z7Y/oKofqPtzVb6q7yeKF3XzWb5Blc9yblluBsu7YMfTzVd9L6r+
vO5+u6rnFfuc37BPjeJHURRFUdRf3eYP8ePHH8GvqpdX8U9U4+nmj8LJcftV
HIn48ePHjx9/9n2kbuOMHz/+PPnu/BC23qQqj0KVh6DqJ6vql4F81De2qp+s
u96ErStR1Zt06w+L/JXWoSCf5XLQdSuieha6zoXsP4u4HGxfWlQXw/ar3bK3
zuXLk1f9wMveePXvLa6LuW3yxDMufPvvX7x8Hc3quBwr96MoitZHeJ6D5kto
Xofmh+hz48ePHz/+6nx3vMLNL1XVy6jiGyyXQ1UHURX3QFwONh6C/Cp+KfJH
4XKo4iRsPGSt/A0Zj9TM5UBxCRR/QJxPFX8jcYAoihAnIfwEhz97OuPWN+/c
dmF+P/Hjx+8Xl6jigXTz2etifVXcxs1rVcWdVH1L3X1zVPk2qn46bn6CKp7G
9v1x+24OCXvf0PGq/k3dOM9V/Wc37FOz6kdRFEVRtHZ1e7/Hjx8/fvz48ePH
jx8/fvz4K/GRMs748eP7fdW+npvvoepjy+7bVu2/s/1k2b6xqroVVR2Kqq6E
rTdR1aF042+g/rDId9WnuLkcqjoXFX/jp5/17CO3/Omdk+c8/f3Puf305fkb
h7/xhltv/uaOye3nfPeGI171kI/qZZCPuBxsfQ3icrB+FEVRrfB8ieVvJJ8t
fvz48Xv6o9TLqLimbu6om9dRxR1l4x6IU6ril6q4HCquabf4iYu/gXyas2Hm
b7BxCRR/YHmeGw9471t2PveLk7tf8vnz9v9w1vtRFC2v03/lr999yTXTzwXk
h6uwFn/2hH4n4XLEjx8/fvz4fDzKzY9V9eVh41ru/j5uXgd7HhVXhPXR91LV
d8nNZ96wT2E/fWw7+lEURVEUrV3d3u/x48ePHz9+/Pjx43f2kbqNM378+PHj
x48/T35Vn1ltPoCvnsXdT9bdN5atN0H1I6p6E7auBPlsH9gqLgeqT1nsq/gb
sn6ypE/3mRXVv+x3yN9+5A2X7pr8/SNu3X3gEQ/Vv6C6GMTfOPW3H/dzf/W4
HZPv+sRXj9r/7OX5G2x9zUK/2tsmTzzjwrf//sXL+4jXgfwoiqLZVr/582IH
1aegOpeqccaPHz/+rPsq/oa7jkBVd4D4GyiOoYpXsOdBfhWnFPksl2MUXgcb
J1HxSNfKHR2Fv4HiBojPycYBoiiKLnnvb/7Wh4+bfi6w/kWTf3j+h9688nXr
6OtZtE5fmi8xe0LfO+JvhOsSP378+PHj876KP6Dq46Pih7DxNFV/H9ZXnZ/N
X2LPw94fNx+D/d2Gnz+PfhRFURRFK1e393j8+PHjx48fP378+A4fqds44yOf
zaNg8wRUx7t9Ni8C+WzeRVUejvt7jB8/fvxZ96v6yVb1xWD7ZbD1LCouh7sO
ZfQ+sKp+r2wfWDeXY6V9Y5Gvqmf55udeeMpnj75n8rST79uzfcvq+Rvu+pfP
P/LTzznufXdNrviL/d539N895J/9oz9/zQW37Jyc+IpffdP7/+zuZf3dP3Xe
cR/b+bXJhScffdnJT3ioXgbxOlRcDlSPw/pRFEXzqX7z6sUO22dWVf9S5S9o
7fExdJ748ePHX87vFt9g8/PZuIc7jsH63bgcGx845KRjtt4+5bvjJCzvlI2T
sPETNk7Cxj1s/A2Ss6GKP6A4A8vfOOraD/zdES/YPvnE8171XSf+/PL8jY0H
vPctO5/7xcndL/n8eft/OOv9KIoe0ie+8ztu/Mgzp58L1/3Sb3/fxx457auO
V3EbVL4qXwJd17wJ3Yd547TEjx8/fvz48f1xNhUPRMWdcH8uO54N+1T8+J39
KIqiKJpndXsvx48fP378+PHjx4+/tO/O03bnCbj3qdk8f/f42X38efPZfjRI
6HiUP8P63e6bKg9kVv3wSeLHj79ePtpHVvE33LwOVLfC+qNzOdx9YNl6E7av
q6oPrLs/rIrXsVKOB1vnQvefJbkcqP7FzeXY75C//cgbLt01+ftH3Lr7wCMe
qpdBdTQsl+PU337cz/3V43ZMvusTXz1q/7OX53KgehzE60B+FEVRtJ5ae1xO
FReat7hK4hXx48dfL1+Vn++OY7A8UhTHUPE33LwOVTykil+KfBV/Q8XlUMU9
1hqvgPEHksuh4m8gnqeKv4H8KIqiO/7b/v/+8lv3TD0Xqnx23YryUlR5FKr8
h3kTug/s95t1ffz48ePHjz9/voq/4R6nyh99/PHjr96PoiiKomha3d7X8eOv
xVep23XFjx8/fvx581X9B2t5EdNSnUfVL1K179/NR/vjbH8TdB72/Gz+BjvO
br57/Kr7rPJVeRru/BnVOFU++/yp4ueoeEHJq4kff3Z9VT9Z5FfVs1T1k1X1
jZ23ehOWv3Hm28686LpTvzLls/1hq7gca61zQb6Ky4HqX772ix/cvPkLd08+
8L53H7fzkL78DVRfg7gciL+h4nIgP4qiKFpPrXyejNbLVXGPUeIkbh4IG1df
UL/1V/z48X0+299TFQ9BcYxr9sYZrl5xHIPlb6A4hiq+4Y57qLgcGx845KRj
tt6+4jiJil/KckrZeAgb90DxDTbusVb+xjc/98JTPnv0PZOnnXzfnu1b1o+/
geIMKG7A8jcQVzP8jSiKkFT7+Hf/0DuuuHKbLx+AXVeq8iLQdSE/WhC6n8hn
84WQz+Z3ufMiEgeIHz9+/Pjx48ePP6KvmlezectRFEVRND/q896PH3/tvkrd
rit+/PgdfLTPwu7vZL9mfXyWq1DlI1XFQ1T7pCqf3U+v2hdWjYflM6jyCh7/
qN/9N5957cp91XnY87t9pNHH88D5Bz7hU29bue++Lvf/C5tH5B6P+/+923Nb
lT+Tupj48cf33fUpVXUryHfzN1T1Ke56ExV/44Qb97x814G+epMq/gbrv2Db
pks2nb9yH9W5PP6qy57/lD9cPy6Hqi8ty+VAdTHIZ/kbKi7H4W+84dabv7lj
cvs5373hiFctz+VA9TvIX6jT+exky0t//OpX3pw8iCiKoi5C6183z5bl3LLH
q3iz3eIS7jhG4h7x44/vu+MbLF8UxTdY/gbro3iIKk5SxeVA8RA2TsLyS1Xx
EOSr+BsuLijN3yD5n7f/4D23Ped77p7sOfLE03f95fL8DcTzdPM3oiiKkNh9
eTd/w+2j9SbKc0D5J4++4YCX/vGtd6/YjxbUrZ+Oux+Kqv/I6tRvvRM/fvz4
8ePHjx+/xmf3lao4/+w+YxRFURT1ERvP6TNPiB9/PbW6PCWkbvetm4/UbZy+
9U7VeJCvyvdben8Baf3vG8thUHEJVPtB7PjdfehU3Hj2utDx7PflzhNm4wyq
87jr0931+6OPRzVOdvwof2C/C37reRcdN50n8Mj/478/9cxrdrfx2TwHNv9B
dX63z46fPd7to98h+ztn8zdU/1/u/9OqfKSq+LmqT27618SPP39+FZdDxd9g
61mq6lBU9SaqupJRuByoDkXluzke3etiEJcDcTagL6qjQb6K14G4HMhHXA7W
j6IoimrFxrer+her4qhVdVjueIhqn0W1H+Ter0n8JH78fvENFZdDFd9gfRT3
UPFLR+FysFxTFA8565gtHzz0qpXHSdi4BxuvYHmha44zkJxPFDdg4wDs+n2/
D538y9//jK9MTj/g9M9fsPGeZf0oiiK0HnGv40bpA4LOj/JkWH91+ZCzJ1X8
oRvPU8XrUInlcIbbGT9+/Pjx48ePP5bP1mF14/lX9amMoiiKorWrz3yA9RMX
iu8QGy9lxc5vq/olqfyqz2X/31Xnr/oeq87DcidU/0dV9xONn93fUa0TVftK
Kg6DajwqPomKk6na/0Vy7wuzx6P6d9ZX7Ucjn63fR8e7P7fqfqq4Fo+b/Mp+
v3nktP/YL/3vX/7p5961Yn/DE+6+/6SPTvvo/N181X1D6nZd7O9Kdf5R/h9Z
X8UhQb47Lu3Op3LXv6h4Hap5Jjv/THwjfnyd765PQVwOlr+BfFXfWLbehK1D
QfUmbF2Jm7+BfFUfWJbLwfaNdfuq+pfHX3XZ85/yh8vXxSAf1cuwfWm/9osf
3Lz5C3dPPvC+dx+385AV8DdILsfN3/EvfuIffn735DlfOuJPdv/X3cv6bD0O
8s/+0Z+/5oJbdk5OfMWvvun9f7Z6Lsfhb7zh1pu/uWNy+znfveGIVy3vR1EU
RT2F1r/ueqiqeEtV3KNq30S1n+LmrqviJIl7xI/PxzfYuAfL32C5HMhHXA4V
j5TllCJfxd9w80u78TfY+AbicrjiD1X8DZaridbj4WRGUcSKrbeq6mdR1ddD
tb/P5pPMm9g4w+j9R1TrbjcnEynr9/jx48ePHz9+fK2vyiNV9QWuWve5+5Mi
oXVfFEVRFK1cszd/SF7H0v5sXNfaxcZFWanylNxxWlVc1/25bl9V118Vn68a
T7e+YG6eg2q9qdq/c69z2f1KNj/WPX73/Wfrwdnj3b6Kz0DzBwCHQeWr+ACj
fC7yH/ivt3325R/Y1d5neR1unx1Pt/tZdd/cvoqLUsWxUY1T9fyvei+7+9uO
kifTrZ5ldXk43eID8eOvzVfVpyD+Rrf+sGwdiorLgepKqupN3HUoyEfnYfvG
unkdiL+BfFT/sta6GJa/QdfLsPwN4LP8DZbLwfI6UF0Py+vYeMB737LzuV+c
3P2Sz5+3/4fXHi+PoiiKvFL1mWLrodxxFRWXtWo/gv1eWHXbx+wW95iNvIj4
8R/uq/iirI/iHiyXw80pVfE32LiHitehipOouKZsHEPF5WDjD935G2j9zvIz
oyiKWLH52Giej9aP7r4V3fr4sP1Q6HyJOVNVXoGbk1m1LmaPR3LnIaj6KqLj
46/OH+V7qeo3yv6eq/qWLqjP7yp+/PjxVb77+enuv6ziqLv7z7rrVtx1Pap9
QxXnP9yPKIqiWZJvPqPibqmOd/e3Vfnd5oFV942N+7F8gKq+RazPjhNJNR7V
PF91H0bv9z3K57LrL9X5kap+V6r9uCqf5QOofFUdtCqP182FQPX77vuMhMZT
5X/HqT9x6Yu+b5oboPK78RCQr7re/37MZy/6F+fcuWL/UYcc9Y5/euDafST0
uaN8v+77r/Kr7if6v1Ydz56H9VX8nKr3ZjdeBzsvqsqfUeXbqHh0VRyP1K3E
j8/XrbD1LKgORVWfwtatVHE5VH1gUV2Jqt6ErUNBXA6W1+HuJ1vF5XDxN5Cv
4m+ouBxV/A03lwP5URRF0Viq2gdRxeFV+w7uvEE396Nb/ZE7HuKOYyS+EX9k
XxXHUHE2WF/F5VBxSt080ipOqYq/geIeLI9Uxd94wbZNl2w6f9rvwt9A6320
Ts96PIqiKrF1YSpOo5t3ocpPq+o3NG9SrX+79QFh86ur6h261Vn05Bgg9Vsn
LnZU3An3fe5WH13lu/k2iY/Fjx8f+VVcoG7PebZetVtdIVufVVX3pMpDVo1H
lS/NXq9qfY38KIqi6B9r/edXbh6XKh7ljl+5x8P67PeC5P5eVPE6FWdD1QfK
7bNyj6dqnl8132Y/1+2z3D/2frLnd/tIqrxEdh2k2u9jfbaOuIqrUMWpUN0f
tj5dVefejV/h9lX8h/hL+x//2pWb7nrs4ro17P/Qfldc9++2rtxXjdPNqUCf
i36fSN2+324cjypfxfFg3y/u96M7j8hdb9KNI63i3bn74HTjcrD7/tnHjz+L
/ij1LKhuZfQ6FLYPLKo3YX03r0PF31D1mXXXv6yVv/HXO85/4Y6L7pk89g8e
d/Nrn/bQfBbWywAuh5u/wdbduPkbiLPB+v/lMy8/8ZTP3jZ54hkXvv33L2bz
T6MoiqLuYrnr3eqSqnjgbq5pVZykimvq5nK460oW1G89G38+/W58UeSznI0q
/oaKR6qKe7DxEHd8g+VvoHgFij9sfs/9zzhr68rjEijOcM8r7/61tzx/ef4G
8ln+xk1P/Z2DD/7U7smTn/ST57/+6NVzMqMoirqJrQ/q1kfJ/blsX5JoQaOv
f1V59d3yB0bxq/gGS/cV9XEw2OtScVfcfWFU42T/v1S+6v8U3Z9uv/8F9YuH
xI8/j777vcb6qveI+3nu5mCo6ubYOim2no5dr6n6Cbo/V7UOVfVV7HZ/oiiK
ZlXufh+qeYu7DqXKV/W9rerbi3wkVZ6M+/6z81LV/JOdl6p8Vt36MbE+O/6q
/RrVvFQ171X93tj5vPt+qtYd7PGq/TLV/pq7Pr2bz/IuVPX4rI+4BFU8AZaf
4PZVnAcVRwIdf+xnPvnl1791cT4W9t3nUZ2/ymfH774P7O8Nyf29qP5fVBwV
9Pxhz88+x9zPTxXHw+27OR5V8XP3uold36nyedx1KKPk22QfP/4s+mzdShWX
g+0bi+pNjt2z69Dzdt24Yp+tQ1HVrbD1KWx/WJWv6ieLeB1uLgfL32A5G4vr
X77lu/gbdB9bEX8D1d1UcTmQj+qAoiiKotmWap9OxQlnz9MtHuKOk7D711X1
R6p+wao6BbaeRdVXdEH91rnx59PvxhFVxTfcXA4UD3HzSJHPcjlU8RA2vuHm
crD8jcVxBuSzcYav/eIHN2/+wt2TD7zv3cftPGT18QG0To+iKOomtO6o4mmo
1o8qn80HiJbW6PyNqnx7Nn9AxQlRjdPdj5XlFaj4Bux5uvWTdeeZuPv/Vvmq
+1zVJ5f1VZyZqvibqt9Q4oRj+e7vXfVeYPt0u58n6Hi2nrSqL5uqD7Kq37Sq
j7C777C7z6D7c9nzj9I3me1HGUVRNLrc6183R0IVp1LFwdDxKi6Zav6mml9V
1RO5z+PmY7jnmbJ5HVBVXyd23suORzXvVfETUJ0mnFcDqdYF7Pnd6wj2vrH3
k87PBHKPH9URq86j4hKM4ruvF9W/33Thp//d7n9YnK+j4wa4ffa64i9o97/9
01+/+/7F+VsbNvzCb1z19Te8efp45KvOg8bJnkc1zm7fl9tHGmWcSO7ns4r7
wb4H2fOwXI5ufA9V3Yp7/eJej1T1pa3icrh5HVX79ar99Oxfx+/ku3kdqvqU
c48+5xXbjroenH/tdSiqvrEqLoeK18H2mWXrVlj+Blu3wtazuPkbK+VsIF/F
2ZDxN4Cv4m9UcTmiKIqi2Zasj4Co/kjlq/ilKl8V32D3wVXxDVU8xB3fcNfL
hL8Rf2TfHa9wczlY/oab18HGMdxxj1nlbyBeKMvfWCn/k+VvoHgCy+WIoiga
XVV901R9ssrWrdGSqqrHVO3vd+uDOYrP3p9u/Uqq/FF4FN181f/j6P/Xo/wf
qfr7qHi8qnFW+Ww808037ua7f8/dnm+qek8V772qHzHyVeNxc+CruIKqfboq
7qLqelX551V9KqMoirpJNf9h4zZun51HsceP4rN5L6r5lbu/MMv3UPnu+Wq3
uD1St3lp1b4DOy9VzWO7if1ekNzzdndfe9X3q6ojZn3ESWD5Cap6/CqfrTdX
fe5bXnjNd/zSv5/mD7B+t/vpvt5uPuJIIJ89/+9943P/00m/sDiv63/MNw75
7Nv37J720XlYdbvPVb6bc4LU7f/X7bPvI5Wv4gupuB9VcU7kV823q/oBufvS
sutH1Xq2qp+sqs+su0+Hqs5lQf3qGuLHX4vP9p9V1a2ouBzIr+JysD5bz1LF
5XDzNza/5/5nnLW1nr8B619IzgasfxFxNlQ8jXA2oiiKovWUKv+Q3VdlueVu
fqk7HqKKb7jzAdg4ibuOSRXHcHNEw9+IP4v+KFyOKk4pyyOtim90i2MgvqiK
v7HWuATyVVzQKIqi6P/XIPmr7LqV9aOlpaovqOJyqHy2fkTV70NVt6I6XsXl
cPcxUfmqcaq+31F+h+66qm6cn6rvRVUH5+brsj7Lt5lVn42Xsufpdr2q56rq
OVbFH2PnXSreeFXfYeTb+3GLxlm1fqnKf2b3DVX7jKr74O5HifLt2Tz5KIqi
bqqa/7D8BHYehc7Pfi46vqpPbrf5oaouqeo+qHjXrI/mn+y8kZ3PIJ+VikvA
zgNV18vOG5GvqtNUHe8WO59nf2/sPFx1/1V1uKrxuPkPKj4Aex72/IgnwPru
enzVON3+6ONH3Il/duN1//me7Yvzn7DP8iuqfPa6kM9K9bnoPqvuP5Lq/rPn
Z49nnzNI7PNZdX73ewH57PuR9d0cD9U8U8XdYufJbl6xu26lG5djVvvJuvfr
u9WzhMsRf558VV9aVOfC1qGo+sOi+hTWd9etdONvsP1kVfwNVM/C1rmstM8s
W89i52yAvrQ3PfV3Dj74U7snT37ST57/+qP1nA03lyOKoiiKViSwTnfn47n5
7e74iSruofLZeIiqTwcbr0DHq+oFVHnmiVfEj6/jcrh5HW7+hpvLMat8UcTf
QPENxN9AvNAXbNt0yabz187lQP5a4xtRFEXR6uSuz6rqOxatTu56UjfHoxvf
oxsnZJR+JW5fxUlwcye6/Q679QWet+fAvP2fdrtv3Z7/7H2r4udU3TdVP+tu
/cRVfbHd+01VffFY372P5s6L7tYP0X3f3HV2bh9dVxRFaxc7P4kWpJovqeZF
Kl/FW6jy3f183Rzmqj7FKr/b/LOqXg+J/Vx2XuSe13Xr885yEtDxSOg8bqH7
zx4/yvfo5jyofLYu3u2j+v2TfupHT77xtSuv61dxAFgfjbObz/ITVOdR3bfP
/tK/vuh5v7Q4/wn7qvuG5P6+WHX7van8bs8rpG7jZP0qTpHq/Ox8ye2PEoes
ikt32xdQrVureJVsnERVn1K1L1/VZ1bF61hQvzqF+PHX01fVs7BcDhWvg/VV
9Szu+pT77/z4aVsuvmPKH4W/wdazuPrJIv4Gzdkg+RtVnA3kR1EURZFDVfl+
bn4pGz9RxVuq9t9VeRTd4h5sfQrbN9Ydr3jjk05+2R/elzhG/Nny3VwOlr/h
jm+4eR0ojoHiHm4ux8YHDjnpmK23rznuccKNe16+68Bp/gbicrBxDMTlYPmi
Xo5HFEVR5FY3PmS4HFq5+4SO3neDretR+aPwN9z3bZRxuvsCq/5PWb+qrkp1
vVXfY/z18dnvXfX/1c1XvZfd/ih1l26+t6ouku07rOIbqOr73P2s3f2U3f2v
3f243b5qnKq+z24fjZP9PUTRPAitv1QKf2NBqnlUla/Kx2DnaWxfXZWv6tfD
Hq+aX6n6+7h9d56Ve/7J1t+ppOJIsPM6d191tm7UXU/KjgeJPV6lUb4vt+/m
VKi4Cv/8q9ftf/rOaY4B8lXnQT7iKqjOXzXOUa6r2/1E/m9+8ys/vP3ri+u+
eJ/9XNZ3i70u9v6z91P1e1BxUVRix6ni2Ki4N6P7o3A80PwW+d14HWjd4a43
qeoDW8WT7MblYLn03fJzWP5G6lnixx+//gXxOlA/2ao+s+FvLPij8je++bkX
nvLZo++ZPO3k+/Zs31LP3whPI4qiKJpndeNpsHmYbt6pO67i5pe6+Ruq+gJ3
v0U3X5SNY4QvGn9k383fYDmiyGfjFVX8DdZXxUPYOEkVlwPFQ85825kXXXfq
4n0tHPdgOR4avkcURVHklpu/4eZDRquTu89p6ugX5F7XV/ElunEtun2/7vr0
qnp5tq7Kfb3s/Xd/v/PGhXD73eoE4y+oimuh4l2ofBU3g/XRPg6bD8zmCavO
X8XBUI2/W9511ffL8jRYv6pOk/XZ60J1AVE0olQ8SZYfyM63Z1Vu3oVqnuY+
v2r+xs7rVFyIUbhbVVy1bry1qvmkWypOAnueUfgJqs/tVlfLSnW9qvOM7rP1
3WydexXHwP253cav4jmo7tvo/jNOO+mGM39t7T7SKOO/ff+//cUjH1icH4Z9
9zjZ379b7HNPxVdhn8/seZCq3lNV8xM390zF5Rid1+HmbLvrSrrVm1T1ga3K
K3Dnmaj4G6yvqltBXI7wOuLPk19V/6LiciCf7Rvr5nKo6lDmhb+BOBv3nHvK
nrPfsWfyuidc9b07jn1ovjAKfyOKoiiKRpQ7f5KNb6j6Z7m5HGxcxR0nqeJv
VNUrsXEMltfBxjHcfNHEMeKvv88qXI6Hf+40f6Mbx6Mbl4PldaA4CRs/Yc+D
uB/I3/d5oiiKIrfcPMmq9S97/lmVu0+9m0tZ5as4Bqo6IxVPwD0e1eey91P1
+1T9/qv6Ao/iuzke3fz8Hpb2Wd4Ce3z8pX1V3aLKd/e/Vs0nVf2sWS4ByytQ
5RW7z+8eD5unPcp9GOX7Zes6ka/qp+nuv8nWHbj7vUbRSoT2c9F+MVoPovkw
Ow9k55OzKvo+mOeBbD5GFTdDlcdSNT9014Wx89IqzljVvMhdD+hWt77n7PxH
1Xcefa6q/lTFW3Bfr/t7YeuUUR206nORVPwEt++u94+v9REngT3Pf/w/T3/E
fadPn6fKR9eFjh/lulh/9Oty//5VYs+v4od089n3qeq9qfKr5pPu+J4qXlq1
zmLrRKr6vY5Sb+Lmcqj2zUfhb8xbn9n0pY0/T76q/gX57joXtg5F1R8W8TeQ
r+JvsH1gWf4G6uu6Vv7GX+84/4U7Lrpn8tg/eNzNr33aP+JsAP4G4myo+Bs3
PfV3Dj74U7snT37ST57/+qPD2YiiKIqiB+XmXbDHd+OduuMn7niIKs+HjYew
x6t4He74Bnt8t/hGOB7xK3w3l6MbX7TKr4qTqLimKH6CfBQ/qfI5rkgURVFU
JdX+O/JZvoeqHwfrj65udejs/n43rkJVnsO8+SqOgdt38weqfHd9nJvjUfW9
V/WDVtXZdfPZOjs2bqzyVX27uvlVfa5V9YxVfatZ/oCqDzXbX5jNN1adX3W9
qnFWXZfqet2+O4+d/Vx33r67npGt04yitYjdD0X8DRVnQzWPgvkAsyrzPL8b
V809L2Xnmch3zw9V80kVL8vtV83r3PMN9N5nxc4TVJwHtg60yq+qM2XHU3Vd
7vvP1juj46t8lqvAnh+dp8pneQtV40H+C7/nie++YL/15xigz51VP/dzad99
XVf/+PN+9sLvXZzvhX00HpVUz5Nu/Jyq95eK19FtvuSOp7G+O245CpeDXee6
84JUdShV/I2q/rCq/XFVHYq7v4yby8H2k1XVs6jqXNKvNv7IvqoupqqeBfWT
RfUmqroSVD+C+sCy/A223yvib6B+rIjL8dKnH37iNw5aP/7GPeeesufsd+yZ
vO4JV33vjmNXz9lg/XA2oiiKonmWmzta1W9iFK6pKr9axSl11zWo4iGq+IYq
7oF8FN9gfXd8I/GK+BU+G39AvupzVfENNu7B+qo4iZvXUcXxQHEY1kefy/r7
vg9RFEVRlVQ8DTd/Q3V+9nO7qRsvohv3g/WrOAzd7gPrs9dVxW1w9xF28xOq
fPb+qLgTqv5B7Hjc99Nd79atns7Nba7y2Xi4ap7j9qv6VrvrFtm8WVVeblW/
v259ruPPhj/6781dl+quixxF7HM+Wp3QfigrtG+L1vsqzgY7P0HnGV4izoZq
fo7m/6p5sns+rMqfYeex3Thas8rFYt/LqvOwPqqXRFIdP4qP6mG7jXMUn+VL
uH0k9jyovps9fnSfFarTZ493cwNm1X/25pe+8xH/cnE+zf/4P/3Vf3vFz/zg
4nwd7KPzIL/bfYi/tI/+j7p9v2icrNjnG8tH6sb3GGX+042/4eZ4VK2nVLwO
5LvrVrrxN9g4But3239355+o8n9UXA5VP1kVrwPFXVX9Z1V9ZlPnEn8WfVX/
WbZuxV1XwtaJqPq6hr+xb/7GjtOe/My3PG/P5O1/8UcveN2H9FyOKIqiKJpn
VeWdqnyW49EtTuLmmlbFW9xcDjevA8U33HESNh7SLe6xoH7r1vjxHb6K46GK
k6h4p2xcReWz3A/ko7gNywlhPxeNH13vvu9zFEVRpFK3ek83f4P12c+tUvgb
S/sqngZ7PMsZYMdZxQlx+1X8ChXHVdU3x82VHcWvug+j94kehVOhmid089n+
Yu6+26p9ClXfanfdH1tnx3IGuvEH3HWF7vpEdvxVdZRVeebu71H1/zL691j1
+1f5VULPbbYuIKoVWtejdSWaJ6N5oGqe0y0OA/MHgNh1H7teYPMoqnhx7O+h
iqeh4myo5o3svFQ1j2XfgyxXahS/ip+AxPZb71aXqupTz16vqn+9+/6j+uJu
voovwXIeVFwI9ni2Ll4lFf8BieU8sPdBdX4Vp4I9D8vNOPx77rrkG//hNpvP
fq6b+8Gef3Rf9Xuu8rtxPNz8ItV7thvHQ+Wz82F33MzN31DtU4zC5XD3e0Xr
d1XcoFtdSdU+taoPbFUdiorLoapDYX22DoXtJ8v6bJ9ZlssRXkf8kX22jy3b
Z5atH2H5G8hX9WNFXA7E3zjrmC0fPPSqlXM53PyNx1912fOf8ofLczkQfwNx
Nmj+xg/ec9tzvufuyZ4jTzx911+GsxFFURRFS6mKp6GKt6jiKmxehDuPultc
hY23qOIhbJwE+WxdlTtOgnyWX8pyPFTxDTbukfhG/Ph8PETF92DjKizHQ+W7
Oausjz4X+Wj86H7u+3uJoiiKVHLzNFR9MNn1oGo8o/M3VDyNKs5GNy4E64+S
X1F1XVW+m5+giiNVcWKr7s8ofjeuhYofNbrv7vPl9qvqAd1cCHe9uao+rlsd
fTffnaft/t673c/ROQ+z6rO/W/fxyHc/t5Gq+o1GWqm4iGiejOZpqrwIlOdQ
pdHXHSxHbpR5uztvRzWvZuvLur03q/p0d/PZOkok9nh3vWo3H92fbuN0+6r6
ZVV9dFUdN1JVPb5K3TgDbv+Oz/zqhVs/vbiOiPfd558338336OZXXVcVz6Tq
uY38bu9ZlV/F96iaD7vjwFXxMXe8i/W79XXtVlfC1om4+71W5T+480O69d9R
1bOoeB2z2meWrXNZUL96hPjz6bP1Jqq+rqr+qojLgfquIi4H4m/cf+fHT9ty
8eL56b2TZ7/m+J2XvmbxfJPnciD+xub33P+Ms7ZO+2vlb/z1jvNfuOOieyaP
/YPH3fzapz00L7jn3FP2nP2OPZPXPeGq791x7Or5Gzc99XcOPvhTuydPftJP
nv/6o3cv60dRFEXRPKsqD7YqDlOVb+zuj8zmmag4Hm4OqpvX0S0eooqTsHEP
N6fUHSdJ3CP+PPkoTqI6P+J7uH0VDwTFf5CPzsOOB13Xhn0K+VEURZFKLO9C
lW/Prr/Q8Ugq3qO7XlglN38Drb/c60S0Pu3G2UB1Sd24E/Pmq7gW8Zf23XlK
bL/mbn639043vxsHA/ko/9DN60b1p6r+2qp6f3efaHc/4m79BLvVFaquS5WP
7b5vs8rfqOKljOKzv6uq339Vn1BVPbiKBxKtUuS6ieW8sTwEVX/YKqnWNex6
R7WOYM8zyvy8ah5exalTvY+6cSrQvF11fJWP1K1udFZ9xJdgeRTsedz+KNyM
qnrzefO78RziL+1vecNjzvq+/fuMp8pHHAzkV41HNf6q5wN6Dnd7f6l4U934
G+55Zrf4cLf46qxyOVR9XavW9VVcDtZ377Oz8TpVHUpV/xd3fUpVn9kqLoe7
noXtP4v8BfWrL4gf/x/7bL2Gqo+qm7+x8YFDTjpm6+J1QPgbLH8D+VEURVEU
rVyj8DdU8ZYqPqqK1+GOw4zCR3XXH6E4iSp+ouJ1sJxSVdzDHQ9J3CN+/PF9
xA+p4nhcuTdedNmKz4+uy+tHURRFrFR1xFXcCSQ3f4Pt36FSFRexqm+Fir/B
5g+MwtNg+RJsnsbovqruKf6CunEtVHxd9r3Avi/cnA32feTOi+tWZ8fGw9Hx
bh9xM5CP8kiRr6rLU/EuUJ4w2x/Q7bu5H1VckW58km5+Vd44y9+o4jlUcTDc
1zsKZ8Ndf+2u10bnYd9rkVbsPJmdp6l4Yuj4KrH7+6Pw+qrm+Sy/xc3ZYOft
LGdD9bztNv8cff7P+t04EipfVT9bVc/r5kWwPhJbB81+btX1Ip+tT+9Wj9/N
R9yGefOP+K6zfuvSH19cd4R99/nd43GPUzWebhySbpyT0bkcqveOat6imkfN
G6+D5dqNwnNm40tu/gYb36iqB3HXd1TxN9w+Wz/iritR5YeweSmqPBxVHQry
VX2LqngdrM/Wp7B1K+h4VLeC+saq/AX1y/+PP5aP6jVQ3YSby3Hsnl2Hnrfr
xikf8Tc2PfPSW956xeL1B+ZydONvvGDbpks2nb94PiLgb/zxF7dtu2vP5Md+
5LbHbt79kI/4G1/7xQ9u3vyFuycfeN+7j9t5SDgbURRFUbQeYvNJVL4qbqPK
H2bjNqzP5pmPwk1VxWFU8RNVnETFR2U5Ht3iJGz8hI17sPEQFPdgOR6Je8SP
389HcSHWd49T40dRFH3r+bD4b4TkrmtGPjseJHfdgareWcXlUK13qjgbqn1z
N0+yG39DlV/RrZ+Lyh+dF9HNd8e72D7a7PHdfFXdXLd+0904G24ONsvHUPXF
VtXjq/pQq+rOkNz1U8mjXp3P5lGPzvHoxt+o4mCw41H5VTwQN49Cxa+o8tl6
alUdR7Q+UvEWVHkR7PwKfa5bqvVpt3UK8t1cDtX8X8XfYH+faD6v4mmo5nXu
eS9SFY/CfZ5uvAg3d4I9vqqOOP7Svvv76sadQOfpxlVwj2fHRzae8oqzv2g7
flbH/59/5o9+4Su3L+43rDt/t/s8ut+NszGrvI5uHA83N8zNA1H5o8SNVfFY
Vfx2VnkdVX1akd+N11HF96ja93dzP1T1KWzdSrd+sqg/LFtXoqpDUdWtqPrP
qupTWD91K/EVPqqnQPyNa37kXY8848VXT/mIy4F8xN/Yuvf8X5jyu/E3Ltjw
sz9z4ten/fXmb3zzcy885bNH3zN52sn37dm+ZfVcjiiKoiiK1l/uvF82buPm
gbD+vPFXWb9bXIXlnbrjJ6p4CBsncfsqDiobD0G8DpbjkbhH/Pjxa/0oiqII
yb2fWzUe9343e360nkLrHZazwXICVfyNbtyMKp6Gav2r+lwVf4OtG2I5ot04
ElX9cVR8hqr+yN3Gw8brVMerfFWdGlu/puIks3FaVR9qVd2cKt6uqjd398Vm
6/JUfZNV/XPdeddVfRhV/bir8qtVfdLD31jaVz2XVHng7vxzle/mflRxMFhf
xV9inz/sOGdVqn1q9+e6OQaq+hHV/UFScS9V6yNV/5FZ5W+g349b7HyefT6z
z2EVXwIdz6obL0Lls3WprNycBNX50XlQvbDbd9c7u/1u9dSq+9yNO6HiOXTz
ES+imz+r1+W+D1V+N85GFScHyc0XQsernudV84pZ5W9U8Tqq4sOqeK+Ko+uO
37Lxwyr+hjsOo+J7uPcf3fu5yGfjP6P0gXXzOlR1JaP0h3X3jVXVm7A+y+VA
dSiq/rOoDiV1K/EZH/E3rtzLzbhsykdcjvA3FnzE33jp0w8/8RsH6fkbyEf8
jSiKoiiK+kgV36jiqbp9VTynKv7jjud046+y8RnksxxUNk6i4ni4OahsvIXl
dbjjIayv4niguAfrL6jf+j1+/PguP4qiKHLvz7r3c1XnV/VlUPE0VPutLPdP
xd/oxtlAx1dxMKp89v/dHX+o4kLMm8/Gl9w82yq/2/VW9ZkaxVfVb7rj56r8
THf/a1VdXlWdGut3q8tj/ao+iVV52u7+iSr+hjuvu4o7wfrd9g1Vx7P3E/0e
kFS/z6r/R/Y9wtZlsP+PSOz/FytVXwl3P1BWLA+hqr6DnefLBOIA7HrcvS5W
1YO4ORsqngY7/0diOUtV83l2Xqfi5lX5rLrxCpBU9bkqXoR7PKP4bF121Tjd
PA10fBVnQ8XHCP9hQf/bY1/8r9982LT/wP99zcue9IbFdTv4eOSjz2XPz45f
NU7VeebNR/+PqvOMzgNx8zfc75dunCiW2+zmfrjn1bMa73VzmNm4rmo9qOJy
qOKWbo6Hqv7C7Xfbj1bVg7j7lVTlj7l5HVX5S6q6kqr+sOh4xPFw95NV9ZlF
frgc8Rn/lr2cjW2Txb6Ky7Fw/A1TPuJvPOaILQdsPGHxuiT8DdaPoiiKoqi/
2DjG6H2mWL+K46qKI7G8jm7xH5XPxmeq+Kjd4jDIZ+MtLNfU7at4p6zP8j1U
/oL6xQHix59fP4qiKKrqX6DiXbAcDNV+KPJV3DzVfBt9Lhonu8+LfBU3Q8Vd
hCriabg5Nsh399tV1QG5z++Oq6iu1/25bJ1dN78qbsaOsxu/YnTfzdlQ5Vui
fE5VXV4VT4PNc2bzn0fP666qT1T1VWT7qs8bf2OUPons883N7a/av0NScRjQ
96iSm7/B1juo6sdV/A0338bdD1RVp1A173X//6LrZfedWbFxALTudnMvVT4b
H6gSy4lixc7bM5/X+qzc/eVV/Iqq8bN+FUeCHWe3emrWd9//Ku6KiqfRjScw
Cu8CnUflV31ula+63ipex+icEBU/p9vzn30vdHtfq9473ThpqnjvKPwNpFnl
LbP8DXccWMU9rurH6o6PufdJR9l37tanVdXXdZR6EDbfTJWH5uZ1sP2hVLwO
d99YN5dDVVeSvrHz4V9/7oN8jAsni33E5WD5G+cefc4rth11/ZQ/On/j5IM+
veM5j147f+OeV979a295/uL34TSXY2k/iqIoiqJZkjuuUhUvUp2H9d08WHee
1Sh1DWxcyB3PQXlQqnpAd10hG89h4zBs321VXaEq3oJ8xPFQ+ar4DOuHsxo/
fjgbURRFrKo4G1V8DNW8l53HVvHr0PFILH8D3WfVPjLkZoj2x92/f9Z31+Ow
dTTduKBuv1sfnKo+wiqew7z1M6q6rm5c4iq/Wzyczf9U5amifFo2j7db/nO3
fHJ33+FReCBsXve89Ul08zTYvGh3n0RVPjZ7HrfY+8bue6pU9X/h9t18GxWX
w91XlJ3fuufDLA9NtZ+OrgvtO6v4G6r+oe5+FqNwM9yqel6xnA03N4OdN6rm
pW51q5N1+0jdxjmKr6r7Hp3LwfJPqu6/iifAchJU55lVP/yNnuNkf8+zyutg
nz/sc37090LV+4Xlb7AcDxXfQzWvdvOWVZyNqvjt6PGrWeUzj94vlY2nuTke
3fp9uOsy2PO7uRwqf/S+rm5eB/LZPDp3fp2by4H8cDni78uv4m9seualt7z1
isXzdD9/A3E2znzbmRddd+ri+cW9k83vuf8ZZ21dOX/j0Be97esfPWyav4G4
HOFvRFEURVG0WO5841HiTqPkX40Sv6qKO6k4rqr8JZbjoep37Oa4uuM5bBzG
zU1F8RY3N1UVz2G5H2w8R8XxYM+PzhM/vs+PoiiaH1XtS7r5G6p9Q1ZVnA2V
j8TyN5DvXl+w652qfrVuH61n2XU0Or4bRwLFE1ScUnd/HHd+juq6WM5Gt7jT
rPqjcC268TTYOmjkq/pfq/pcs/2vVXV27j65s+qP3ueRzQNHv0P294z+L6ry
t0fhb7D171XcD/b575bqPYW+X/Q7qVK3OoVu+8jufV43j8K9LlDN91TXpaov
QKribKj2zWdVVc8x1Xye5W+o5vOq81SpG8+hihfB1v9W1SmrfPS5rN+tHlzl
o3Wo6j5X8TequAej8xa6+f/lJza9+P/advOKj//pv/vq//yiv7lpzX63+9DN
H52z4fbZ90u3+UM3vpMqjuqOr6r4G24uB9Lo/A02rtuN11EV76qqX1DxZt1+
Vf+Iqv6nrF/Fjx2Fv6Hqr9qtjsPN5VDVd6jy8VR1HGy9hqq/auovZsu//twH
ORsXThb7LH9j4fgbpnyWv7HxgUNOOmbr4nkr5myccOOel+86cO2cjZMP+vSO
5zx65ZyNF2zbdMmm8138jSiKoiiKommhvC82H6wbV1bF/VCdpxtv1h3vcsep
VPElVVxIxWV18z3c8Z+qeA6qB0RxG/Z4VdymiuPhjvOwx1dxP+LHj6Ioiqal
4sV142+o9gFV80a3rxoPEsvfYOfzbv6Gin+oWsep+oaw+Q8sT8PNkXDXf7G8
iG7+6DwHVf0ve9/YOFU3X3WfVfXUbDxTFf9Ufa4q7q2Kh6P8T1SXh3xVXR7y
2Xxmtn+i21fVE6nGM0p/SVUeuyrPXMXrUOV1u/et3PnSrKp4F7Mq9N5h3xfo
+Cp1q0dwzx9G2bdV8Tfc81jV/vIoUq3H2f3xUcRyt5DYeTWrqnm7qh6QFZoH
IqH5p0rd6nDddbvdeBHx18fvVt+t4oewv2fEAejGwWA5Euh4xItAYs+Djlf5
7PWyvoq/0e0+dONvsD7S6BwPNyeqiqfULT45On9DxSVmz8PyNJCq4qtuzkY3
LkcVV7aqHqFb/cIofR/cfUxUfNoqzoa7L2r4G6vzu+XdVdVxoLoMd71G6i9m
y3fzNx5zxJYDNp6weH2A+Rv33/nx07ZcvHg+iDkbl7/pWU/Z//XTnA3E30Cc
DZa/gTgb4W9EURRFUbTeYvsAduNsjMKnZe9zVT6Yqk+Zuw7CzYl1x6lYn40v
deN1oDpKVX9z1mfjP8h311eycSE2XsTGf1Q+iiOxfjiu8VfuR1EURSx/QLWP
6eZvqPj8aL+P3Qdkz8PuPyKfvS4Vt6Rqnxf9ftDvTcXfcPcBYet0WL9bnkkV
L2IUv1t93Cj5V1V5XOi63PeTjTeO7qt4y2w/a9Zn+1yzebls/jCb5+yur2Hz
3tk89qp6JRUnpFsfTBWXQ5Vn7s4b78Y9iKJZEvv/pZrnIFXtq7LzVZZTwe6T
ouPdGp2zgeSup+jG33C/35FU8wSVXzVvV6nqc5G61ed281F9NMsx6HZdqvvQ
bZxV9eNIKv6Gm7NRxd9g+Qks/0HFkVBxKkYfT9X1zipng/W7PQ9H5yCp4nij
8ITRfNjN2UA+u65h+Rsq/rDKZ3mDo3A5qnjLLIeZ9bv1A62qOxidv6Gqa3DX
L6j6mY7e53RWeRru/qps3pqbv4F8dx9VVZ1F+Buz5av4G8fu2XXoebtunPK3
/si7HnnGixev23T8jbOO2fLBQ6+a9hF/48y3nXnRdacufv9j/sYLtm26ZNP5
0/wNxNMIZyOKoiiKovUWm8/szk9m42mqPGpVfMwdT6vi37L9NKv6H40e72I5
sWy9ZBUP1h2/quK1qjiuKu6rO46E4jzuOBIbX0q8KP7K/SiKokg1n0S+m+dW
xWFjfdV8kj2Pil+HfPd+Lvre2d8Pu05h9/FVPA2WM8n63fJM3LwIVR2cO7+o
Wz8gFf+hW59xN++C9dl4bJWv4hi7+5exPptfyva5Rj7iErD9rFEeMpsv7eZp
jO6r+lZ3y89nx8nm27N58ihfnZWqL2S0IPRcUh3PStVXlD0/y5lBx0cLcvNt
WP4Gkmrfc5T9TXb9GM2nVHwt9nnu5tqxftV8XiU0r1PJXeerqtOvquuv+tyq
cXbjKqjG2Y1ngsSuW9319VW/E5YX0Y2b0Y130W08Vdfb7bk9it/t+dktXod8
Fe/C7bv5GG5ftY5Q8TeQWJ5GFTdj3vgbLDd+FP6Gav+9W58Lt6+qL+jG36ji
aSBfVb+g4myEv7EgVR2Em7/B9j9190Vl+5OGvzFb/i17+RvbJov9a/byNK6e
8hd4HTdM+Sx/4+w7f+yHL75v8Xz23smzX3P8zktfs3g+hfkbl7/pWU/Z//U+
/sY9r7z7197y/MXvpXA2oiiKoihaf7HxIjZ+NYpfFWdzx99UXA5VHYo7bjZK
PhvyWS4HUhUPVuWz9ZvuvupsfGmUuBMbF2J9FEdi40ts3ImNRyW+NA9+FEVR
hITmXSr+m5vPpuKtqXgXrN9t/7SKp4GOR987+ztxr1NQvgHKfxida1Hls3EG
FT9BlQdVxVNFPpJqnKPwad3X6/bZOK0qX9HtsxwMVX9qle/ucz06Z4Ot6xml
7qmqLkD1Par4IVGtVM8TVBfM1h27n7eqz0Vy11m7+66q+DbofY2k6negmler
xO5LqvYN2Xz+8DeitYh97lU9/6vm7VXz/G7qVs8bX+vPG39j9HpzpKp1uvv3
Ngr/YZRx5roWNDo3aVafb1VxLZWP4rQs51YVz1Gdh/XZ+InbV/FdVVxBt98t
P5/dn2L3xWaVs6Hq76DiY3Tjb1RxNtj4m5ubwfIxVOdR1SO489O61R246xTc
nA02746td3DzN6rqKdg+pOFvzIeP+BsLnI1PTvnnHn3OK7Yddf2UH/5GFEVR
FEWRVyhe1C3+puJpVMXf2Licu06B5eKOwt/o1s+XzaNT8Trc/Fg2flXF91D1
W3fXeyIf8TdYLocqvqSKI7HxJZWvikctqF8cJv5SfhRFUeTe33Tz2aq4at34
G+h63X0ZRvHpfXMglr+B/l9QHgVb39SNg6HKt2HjCSw3g63XY49nOats/IfN
42LvAxIbX0LjZPPoVPE61ee6/SpORTdflUfK5seq8n5V+cwsN4P12Xx1Vf/f
UeoCZpXvobquaCyp6nbd/A3385/tH4qkeo+w94ftl6rqr8r2S2XnaUhu/gbL
o0NS9QVg5d6XZNen4XLMtth6OtVzz81lqprnV/E03DwEVH/t9lV14qrPHeX8
br/buq+bj/6/kKrWj934G6NzHkYff65rQd2eJ938eeNpIF81P1T5VVwLdl2g
Oo9qHeHmb1RxOUbJ5x/FH6VvZrf8gVHy/1F8jPVVfTmr8v/dn+vOK2PzzUbh
bKB8M5a/4c6LU/UbreJvdOtPGv7GfPgsf2PBv2HKR/yNxxyx5YCNJyxex4zO
34iiKIqiKFp/ufO65y2Ox9ZZVPXlVPE3qri1qjy3Kp6tinNbFZdjubKj1G+6
+Ruq+JUqTlXFd1XFl1j/jFvfvHPbhSv3E6eaJT+Koijq1l/Azd9wczlUfjfO
BsuvcPPuZJwNcB72dzir/A12vY98FR+jioOh4mZUxZ2QVHWLLO+iG+dhVn13
fe4oPlsPrurfx/I0WM4GyjNnfVW9zCicjVE4HlW+qi6sm9B+EPq/QPdBJfR/
N0p9B8vfYI+vqkdActd9V/FJ3HUZKn4amt+qeHosf8O9X6kSy9NQcTbC35hP
se8LlVTPYXaer+pX7hZbt66qf3fzMarqrGe1rtz9vVRxPNz18u7xd+M9ou/X
zeGc1f+7XNf6+N2eG1W8i9E5G+74CfJV870qngbLx+vG33Bz+dz8jaq4TTfO
Rrf+mPOWt9+Nv4HiRVX5/FX5/8h/1CFHveOfHjidT1LF32D7bI7C2WDzhVR5
Ze6+Tt18d/2Cm78xSh1E+orOh+/mb2x65qW3vPWKxeuMeycbHzjkpGO2Lp6n
3zu5/86Pn7bl4sXzzSr+RhRFURRFUR+5+y3OKn+jKv6m4uKOztnoxrNVxdlU
nI0q/gZbp6aqd2Pjaao6wSr+hooHq4pTdeO+VnE5wt/o4EdRFEVI3foadJvX
VfUvUHE20H0YZV+bvS7V8ar7ifIlEH+DXZ+y62U2DsD6Km5DNx/lgyG/W7wL
ic1DQ8ejz2X70Y+SV+nOhxzl/rj7Sqt8d39qlpvB8jTc+epubkZV/YK7LmN0
f3SeBlJVv9qq+pFudR9s/bKqLkP1vkaqep+y42Svt6qfQhV/Q9U/FK2zWKnO
g6TaD0X7leFvRCMKvV/c83+V2PmMipPQrb6b9f/DbxxxwC9ffOOUv/vpV23b
75XTxyOfPU+3+9Ctvt79e3OvH6vWHUjudYqK2xP+Rq5rPT/X/f9YxaFV8Ver
uBnd4icq383TYI/v5qt4pN32idz7R93y7dl90m77vGzcieVjqHga3fL5R+Fg
uH13/j/KJ0F+t35J7rwgdz8mdLyq75KKa/H4R/3uv/nMa6fz890+y9NguRas
z9YjuOsXVHUNbN1B6hFmy7/+3Ae5GRdOFvtX7tx+3Zu3Xzbls/yNd776+CMv
v2/xuureyXUH3XnRjsMWz9/vnZx954/98MX3LZ4X3zt59muO33npaxbP++6d
nHDjnpfvOnCav4G4HBds+NmfOfHr01yOffM3oiiKoiiK+ouNs3WLE3aL+6ni
clVcXLYfrqrfU7f4G4qPofop1me5GWycTRV/c8fluvXXdvdJV8XZqjgbqjhY
FWdDxeVQxcGqOB7seFSfuz5+FEVRxIrlb7DzxiouR9V+Luuz46niaai+r1H2
91WcDba/MFovs+t0N2eD5TaouBZs/WA3n83fc9eZsuNH52fzKkfxWe4Ee7zb
r+JdqHw3N4Otp0PcDDdPQ5Vvr+rn6+6D3K2uxN3fmRX7PVZp9O/F3Z8aPTe6
8Tfcz210XSzHQyX2PVulbn1O3fwN9z4p2yeUFbsfilRV1xDOxmyLrfseXar1
Anq/s6riZlTNw1kOBsvHYLkZ7HlUn6u6XvY+zyp/o9t6E6mKV8nGDVjOSfgb
S/u5rqV9d5xqFP5GuBlLy83fcMdVuvExVDwN1b6Jil/K7qNV8di78TfcefVs
v4Zu/S5H4W9UcTZQXj2bn8+ev8pH+fwoP0TVz0iVP6PKm6rKw1fl27O8C8Sj
6Oar6gLYegE3B2P0OoLZyMOPr/YRfwNxNo7cy+W4dso/ds+uQ8/btTheeO/k
MUdsOWDjCYvXSfdONj5wyEnHbF08T+f5GyxnY/N77n/GWVsXz0funbz06Yef
+I2Dsu8URVEURdF4UtU1dMvvUsUJu+V9qfLEVL6bp8Hmg6niZipuBoqPuXm2
o8ffusXx3DxbVdysWzzNHddi41duf0Er5124fXY8Y8X9oiiKIpVU3Iyq/gss
P6HbfLWKU8H6bu6Kar2DxF4vWpehdR+bN4J8dj2u4m+weUQqbkZVPpvK79af
C/lIqvxJVX9hVf1vtzxV1lf1xevms7wLt+/mY7jraFR1AakfWZ2P6tq61XlV
qVsdULe6GFX9CPu8rXr+q57b6Pwqse9rt9i6jG77tlX9SUfZb63aV41mW+w8
oaqeHQlxBqrEvt+RRpk/qzgSbq5F/PXxu9Xpj+5X8TdYvxt/Y/TfTzf+jJtr
UfU7V30uy6th44Td+BgqXmiV3y3ureJRuznbKj6526/i2Ks4/FX9KKt4Gu4+
leg8bp/lYKj8bvGlqvx8Nm+fPZ7N22d9Nq/G3b9S1VdIlVePeBesr+pfWZVv
r/JZroXbZ/kVKp/N83fn58efbx9xNq7cy9O4bMpH/I1zjz7nFduOun7KR/yN
6w6686Idhy1eB/CcjRNu3PPyXQeunbPxgm2bLtl0/uJ5RPgbURRFURT1Vzc+
hjuuqMrjYvO72HidO86misux8TqWZ1sVl0O+m4+h8rvF2ZDPxtlUvipex/os
N2P0OFviY2P5s3G9URRFESt2vqriJ7h5C1V8OdU++OicjSr+Bit0HpazgdaP
aF2M1tFuzgab14TiHm7OBpsvp8rHY/kSrI/yG1lehOp4t6+q82X707Gfi8bf
LV+3ioOh8rvlY6O8cVVeerd6maq6lar+1Kq+0u7PnVXOBlK3+iZ3PY67nsX9
flS9L1TPZ1WfXFbdOBvd+qK6+RvsPiwSWzeBpOJyILF9SKNoJap6n1bxGdxS
zcPd82c3N2Pe+Bvfe8tHX/cX37lyv9v43T673hmdn9CNk9CNY8DyN9xciFG+
d/d6vxv3tZs/q9yMUTgbbLxidP6GioOh4m9048az+4Zu3n5VvMXNzWDz4av4
G26eqsqvyudn40hVPA22r6XK79bvUpW3z/aXVPls38mqfpRVPA1VX0vWd/fB
HKU/JlsvsKBuee/xZ91n+RtH7vWvnfIXuBw3TPnvfPXxR15+3+J13r2TjQ8c
ctIxWxevJ+6d3H/nx0/bcvHieS7mbFz+pmc9Zf/XT3M2Tj7o0zue8+hpzsa+
eRr3Tg590du+/tHDpucLURRFURRFa1W3/KhuflVc0R33mzeeLcubdcfTquJs
qnpAN4cWxcdY7oTbV8XTUBxMxadl42Yqfqw7PhauRXyfH0VRFLk1On+D3b92
H6/idbjP417XVP1+kI/Wj2jdita/aL3s5mag49l8JxQncXM2kK/K01PlHyK/
Wz5nVd/5+PEdPpvv7c4/71YX4K4HmdW6uW4+W6c2utjfW1VdG9vfWcXlcD9X
q+R+zne7XpXcdR/s/JwV+lwkdt+WrddQid0XjiKHquqFu82jqvgb83Y/R/FV
HAx0nv/nWT/wyf/1df9txX64HAtyz/Or1sWjcALd8YcqDsMofI9u3y+6b1W+
e/xufibLr3D73eK6Ko4ou9+BxHIwqnzE2WD3xViORxVnw83TQPETN0+D7SPp
7jup4p2qfHdevcpn9/eRz+bts/0x2T6Y6HNZbgab5+/O21f1x1TlHbE+m7fv
zvNX5f9XcTNUnA03N0OV/8/2tazqj7mgbvnn8eN7fMTZuGUvN2PblL/A0/jk
lI/4G1t/5F2PPOPFi9e7mL9x3UF3XrTjsMXrD8zfePZrjt956WsWz0Mxf+PM
t5150XWnLp4HYf4G8vd9niiKoiiKommxdQ0qn403snFIto7DHSdk87LQ8Wz9
iyr+5o6zsTwNVTyN9VX9l1X9qVneBeuj+Bjrs3EzVbyL5VGo+BVsnErFr2Dj
VKq4Fsu7CB8jfn8/iqIoqlIVf0PFu3Pvg7v5eO7xoPszOmcDrR9ZfiObl4LW
4yg/x83NYH0VTwPly6nyA935jSgPU9UXvlu+q8rv1qevW3/A0fOl3deFjq/6
HrtxNtz9W7vVZ43uI3WrG60Sex9YDsko/A1Wo/Ml3PON0eXu0+rmbMyq2HVZ
FK1F7HvQXVc+qxw2Vuz9yXx7aR/xKFhfxbtQfS7yu93/Kp+dn3fjb7h9Ff9h
Vvkbbp6DO27TLb5UFWdT8TpUn+u+3m5x3dF5Gip/Vjkb3Xy0P+jmbLj5pVV8
jKq+k6yvyqt396+s8ln+hiqfn+0z4s7/d/MxVDwNd34RWxeAuBns8ao+m1U8
DRU3Y/R+mio+hrsv54K65Z/Hj7++PsvfuGYvT+PqKf/co895xbajrp/yEX/j
MUdsOWDjCYvXbfdONj5wyEnHbF28/sCcDeSfcOOel+86cPG8kudyIP+sY7Z8
8NCrps+/b05IFEVRFEXzIDYuV8XZcHN9q3i8LH+jKu6H4mxs/I2Ns6F4GvLd
fFo3b5atg2P5sSrfHQdzc1xH4VqguFAV7yJxqvjz40dRFEXdxPIWVLwOFf+h
irPBrjvQ+qJqnFX8DRWnEa1b2TwTlqeB4gAoboDiEii+oeqLpOJpqDgbs8rN
qOpz586L7sa7qMrfHt2v+l1V/Q6r6jJU9RequqSqOkpV3Vy3/tGs5o2zwcp9
f9g62Ugr9zxndLHzbZWP5ucqoc/tJnb/Oor+sdzzjdH5GO55nVuq76vb96L6
HlXnZ7kWqnWEirOh4n50+95VnA30fxH+xoLcnA3VecLfqP1c5LPqFp8cxR+F
n+z2q7gZVfwNlhtfxbXoxtnoxhdl89tVeewqrgXy3TwNVf68Kq+e7VPJ5uGz
52fz+ZHP5vOzPtuXBPlVeT7d+u+gfB53HYGqXgD5Kq4FW0fQzWfrF9x+FWcj
dQrx4+t8xNm4ea//ySn/yJ3br3vz9mvB8TdM+Yi/semZl97y1isWr4funZx9
54/98MX3LZ7XI64F9lkuB/I5zgbih0RRFEVRNKLcfIyq86j8bjzebnxdd/yN
5dOq4mluboYq3sX6bk4s67M8DXfcSRX/WVC/dXH8+PHX6kdRFEWzKhWvo2qf
neVjdONmIB/dnyq+iirfA/ksZwOtu9H6XcXTYOMkKN6iykPrxs1Ax6vyLVX9
1rv53fLSR89j73Yfuv3e3FyUbt/L6PVB7nrAeesfjRTORq2q+CrR0nK/d0ZR
t760LH+DPQ+qS0K+ql8wWwfE7nd3E/s+jZZW6uuX9pFUvAWVVN9jN18131Zx
81S+m+/n5mnMG4dQxQti+Xij+0gozsAez8Yr2HgI+r668Teq/FmN73XjXai4
wW6eBuJ7q3yWK+7+XJWP9onY/SN2/ciuK918DBXXgu3P6OZgVOXDs/0LVH0h
2Xx1lc/mvaPzoHx4NzeD7Ufp9lV9LVV9MFmfzd9w5/8jn+2b2a0/pqqOAPmo
LgBxMFif7bPJ+qr+m2zdgbu/Z7e+nwvqlh8eP/7K/OvPfZAvceFkvX33OK/c
y9O4bMq/Zi834+op/9yjz3nFtqOun/IRZ+Odrz7+yMvvW7zeRZwKzLVAXA63
f91Bd16047DF67Z7J485YssBG0+YXmdHURRFUaRXFV+iG3+jylfFJ9m4pTve
6OZssPG9bjwNN2dDVQeH4mZsXIvlYLB8DBTvUnFlUbxLFddKnCd+/PhRFEUq
oflPNJZG6XPB7u8j383NUPlu/gbK92DXrWj9y3I22D44bs4Gip+weXFsXh+b
Z4h8lPeoyrdU5YWiPFhVvq6bPzAKl8DNN+g2zm4cklHqDkbnrlTxN9i6pKo+
6VV9pVV1aqzCc1idRqmHjbRyz6+6ScW7GEWq9QVbP6USy+WokqqufHS5OQDs
e8o9b1G9H1VSjd89D+w2z6ziOcyqPwp/Y978cDaWFjqe5WmwcTNVnK0bf6Mb
LyL+6nw3B8PN03DzKLr5Kh6723fzLlR8DJXfLW/cnWeu8lV56Wz+eVW+uttn
+06yvAt3P8pR8u1Hybdh+2l264Op6o+p8tl+miwHA/ks74L1U18QP/7s+ohH
ccs5D/rbpvyb9/qfXHcfjYf10flZzsaxe3Ydet6uxfE2xKPA/qZnXnrLW69Y
vJ7DXA7WR9wM9LlonOh6931/oiiKomi2VcW5nTe/231j45ksB9gd56zibKji
hN24te5+0yoOrTuexsbBVPExFQ8W+Qvqt36PHz9+Fz+KomjtYvcfo56qyhNQ
5QO4eRro+Kr7xvI3VPkqbF6Nm7OB4g8sZ4ONq6C4GZs3qMpXZPMwu+XHIl9V
7+nu29iNP+DmaczqfajiUYxyP93jZOtcutXvuLkZqn7lVXV2bH2iSvPGbVDV
cav6noezMZaq5l2zKhWPwl1XxUrV73hWVcXTcH9ut7r+0X03p6KKA9Ptfnab
J8+qz97nKi5K1fmreBrsOlp1nm7reiT2eKRucRt0XSqOq4pvrOI/uH2WF80e
X8W1cH+uitfN8jTQekTFFVT5bv6hirvI+oh3ofJZHr47TxvxKNw+2z9RdR5V
H0ZV30aUN87mk6Pj0f418lH+OXs82xeS9dm8d+Sjvh7IV/EukK/qh+LuC6Py
UR4+66vy9lF+PupTWeWzef6sr6oLQLyLcDDix4+/nM/yNK7cuf26N2+/bMpH
PIoj9x5/7ZSPOBXo+H2fHwldFz4eXRfL30DjRzyKd776+CMvv29xPIPncrA+
+tyte69rcdwIj5/7vtDvKoqiKIpmQ6NzNlTjr4qvqo5X8TTc8VI3T0MVn2Tr
htwcXRXPlvVVcTw2Lod8FJdjfVU8jY2PIT/xsfjxZ9VHGmWcURRFa5eqL0DU
U6P36WD9btwMle/mbLB9c1jOBoo/sPwNFIdB8SI3ZwPlhbI8DZSPWpWv6+6f
PgofQ9UfU9VPcxQOwyg+ex9U9QijXC/7f9GtToetS+rG3+hWv8nWtbFyn38U
dasXVtUXRz2ler+o1I3z4ObpsVwOtO5QiR3nrKobfyN+/HnwR+GZzKrP3n83
H0N1fDcuB1pvutfRqngUex4VZ6MqbtYtDqmK07r9Kh6F22f52FVxfnY8qvWL
mzeIeBEqXjrLqWD3lVQ+m3dd5Y/Sx1Dls/nbo/dJZH0VB0Pls/vmKt4Fu7+v
4mN06xep6iOp8t28C1UevqqvJZuH7+53yfoqDkb6Y8aPH1/tIz4G6yPuBMvN
QHwGxHPYt68Sz99AHBIVn4S9b+z9XOCE3LDiz0XfL+KNIB/dhw37VOpToiiK
otkQ4gBXcTZU56/iaajisai+Y5Q4LRt3dcdR2Tgny99QcTbYeKOqTzQbV3Rz
blkfxfHccTk2zpZ4Wvz4a/dZLg0b30Y++n9Hzwf2PKrnicqPoiiqUvgbs63R
+Rvoc1XrMjevA61DUf6Mir+B1tcsZwPla6E4A4pvsHEYlvuK4mwoj5HtU8bm
nVbl2VblXVfxAdB5RqlfYBX+xup81X1QcWlUHJvwNxbE1jd1429U9ftm6xzR
8UjhNqxO7j7mKj8aS+7nPxJbD1UlVb2Yqn5NJfe6Y3S5n3vs+V+15Y/+2cWf
XpyvqTve7aPxdBtn/PidfTefhJ03jsK7UPlI7HpTFXdiz8PO61THq+Jg7viP
mw/MnmcU/gbLeXZzOVi+RBWPQjWeqvEjHiDy2XVTFdeC9dF+E+uP0seQ7Veo
8lX51Sqf7XvYjZuB8rfR8SreBdqPZn0VB4PlY7C8C/Z4Vf8Od79INn8D5bGr
8t7dXAuWd6Hy2bysUfgY7vzb9M2MHz9+ta/ibyAOw9J8hmnOA8uL2PfxVfJ/
L4hfge7zNXvv29Xk97JyPgbiiqDrqvGjKIqiSCs2nozy+VXx1Sp+xej+6Dzk
Ks6GO+7KcoZZzgby3XVnbs6Gir+h4uW643iJp8Uf0We5EOh49H+h4lR389l9
B7ePxomeh6lbj6IoijrLzZ1w53uouBysz+a9sPk2LJeDXUejdTrKy0J5Xyhe
UcXfqOJsuPvcdcu7dufDs3n+qvx2VX3EKHUH3fgYVfwNFdei2/+j+3t398N1
czm61Xmx/Z1V9X2qvtJIbF1btKBudaDhb8yG3PWSSO4+yKrzIx/lA1TV67FS
cTPQPISV+33d7TnZjYNRxfFwj2dW+R6zel3xl/bd/A32/LPK2UB+1bpVxb2s
ircgdYv/qHiqKs7qKPwNpCrudDeexui+iqcxOn9Dxc1Q+VV51Cwfgz2e5WCg
87D51VU8jW79E9154Ow+NeuzPA3WR/vyyEf7+1V9Idm+JCqf5W+wee/ufpRV
PA3WR/moLH9D5XfrcxdeR/z48WfFR3wGxHNgeRFX7vUvA5+/VvW7nywHg/Xd
46/xoyiKomhB7rg9Gzdm47fd+Maz6rN1H1X8DVW81x2/reJvdONysPwNd7yx
isuh4u6iuNmCuq1H4o/io98V+n2yv3NV3J7dL1A9H7r57uckErrP7nFGURRF
0Xqqir+hyvdwcznY/BnV8SouB5s3xfI3UDyEjc+geBeKm6G6POSr6ulU+cOo
P2BVfrW7fl/F33D35WT7iqrqFJC68Teqfj/seFTj7FYH0e3+u//v3H4VT0NV
Z6c6npXqPKOL5VR0q/cMf2O25X4+z5tYLh/rq7gZSCoumeo9Pqv8ja/e/oxT
Dvq+aX4C8hFvQeVXjTOcitWNH93/ebs/8bW+aj0SjseC0PuLfd+p4lEsJ3Pe
uByquIrqPCr+Boonq+LM6DxV/I3wOrS+m7PB8hWRX8XfqOJysPtlqrxxlC/N
+ir+BptHPTp/A+3Dojxt1fHIR3ngyEd54KyP9rXR8YjLofJZXgebl47yBFhf
1Q/F3Y8SHY84Hu7+laq8elW+vYrvgc6D8pxVPsvrQHUBLA9E1Q/UPU43/4Q9
nuWoIJ4J8lXnWVCf+oL48efHZ9Vt/PG1fhRFUTSKusWfWf6zOx7L1iOojq/y
3eN0x59VcWbWV8V1WZ/ldXSL36r4xqo4J4pDsj6Kc7JxSzYOyXIG2HidKo6k
igstqNs6aPZ8dP9R/BPFn1E8nOV1o/871b4G67N929n6VtVzqZuP1G08URRF
UbSecnM5VOumqnGy60GWv8FyOVC+EOJssHlZKJ+N5Zqy+YQoT9LN2WDr40bh
bCC/W52+qr6gW19RVmy9pKpfp7tOwT0et++ud3B/L6o6XPf/NTp+dP5Gt7o8
VuFvaNXt9xD+RvSPFf7G0nLXD6rEctvc/KvR+RsqHkU3zgbL31DxIkb5vlS8
C/Y+d7uf8WfbZ9c13fgY3Xz2Pci+T918SyT2PN3iit3imd3iXUjueJqbv8HG
+VX5xrPKA3FzOdjj3bwOFd+DzQ9H53fnn6v6IaJ8aTa/WtUnER2v4n64+y2O
wglR+Wz/R9XxbB9JluOh4nuoeCAqv6qfC8y3FPFDWJ/liqh4I6rzu/t7qrgi
Vedn7wNbT8Gev5vv5rqwHBVU98H6LD+ErVtx++GfxI8ff3V+FEVRNIqquBkq
3nIVD7mb774PVffZHX9muR9sPNkdN0Zyx3vZOC3ie7DxWBUPmY2LsnVeo8Qz
2Xigm/uB4mno+E9853fc+JFn9uGHLKjbumzaR/ErdH9YbgbLx2C54qr9CLa/
ucp3c9rZ/Rf3862bD/knURRFUdRY3d6nVTwN9+ey8zGWv4HWxSx/A8UlWM4G
m2fI5meq+laPwt+oqqPv5o9eFzA6p2JWfZa/gZ4P3a5rlOeGu85IVRfs9sPZ
GEvd6ivZeuRotuXmFLGqeq6q5K5/ZKXi1Knep6PwN6p4CO7PDedhQSwHg/VZ
zkm+r/idfbQuYH3V+VVcxCquCPt+RP4o/A0VR5f1u8Ux0PdYxcvtFm9Uxdm6
+ey+g2r/ws39QPnYKl/F91DxQFT55FX8EJRfXdVf0t1vUdVXUcUPYfstVvV5
VOWZI04I66v6SKr4IWx/SbQvz+alszwQlhOi8lV5qiq/Kt+ezcNn80jd/W7c
fT9Vx7vPw/ZtZPs5qvgwqu9LxZ9huTFsH1i2TkTFaWH5Iex5VONkfVTnwvqI
i8LyUlgf1ZssqE9dTPz46+mzvB0VRyiKoiiqlZu3PKs8japxsnFa9j5X8aVV
97Mqnqzie6ji0myclo33snFaFc+Zja+ieCnrs3FOd3yyiocM69ZJH8WjVNxj
FL9CHAmWZ8vyQFTxEOSzn4uuC8XfWG4G2x+c9d37GqrnBuurxl/1/HGfH4nl
tyA/iqIoimZJ7nwAlT8KDwTNT1AeC5rXoTwftP5F62u0TkdxAxWXg+VvoHxO
Nt4Y/sbqfNV42Lzxbvn2rLrlw6vy51X59t18d94+O555e86464uruBxsvVhU
q271kir+Bst1cfNhotWpG0doFJ/ltnXjb7D1sKr3o4rrwtZxj86pCG+hp6/i
cnS7rvhL+/keZ9vvNt+o4n6w/A0kFffDzfdgz+Pmb4wSRx0lPtmNvzG6r8rf
rvKrOB4qH8nNG2Hzsd355KP3W+zmqzgkrO/uF6nigbj7S6r6TiKf5X6o+CFs
HgJ7HlW+Lnt+d7+8qn5/qrx9Np+fzc9h+4eqfHceURUHhuW6uO+z21fxW1jf
zaVxn4etZ3FzQlR9chGvw10Xw/po/CzPZEHrz3lwf278BaHfM/LR96X6v4ii
KIrWR904G1Xc4NE/d1b9Ubgro8SZ3XHaUeK3Ku6HKo6qikOq4pbo+Kr4pIof
AuvrRTxbN1eWjaug86DPRfeBrStkf1eIO8H+H1XtO1T5Ku46u3/B7he4fdV4
VNyPKIqiKBpSzfZhu/E3kK/Kr0DzNJRvg9atbJ8mlr/BxrVQPLCKv4H8qjxk
Nu/anacd/sbSmtV89dH7V47uu38/3f7vkK+q96nicrAKr2N91K2ucJR60mh9
1O05NorP1qWq5rGsj6Tib6DfCeurvpduz9X4s+13e2/Gjx9/7T5aH1VxFN3j
qeJ7sH4Vf6Pqc0eJo47O8RiFo9stfoj8LW94zFnft//0vgnyVecZne+B9qe6
cT9UHI+qvH1VXn23vG53frgqb1zV55H12T6PVT7LA2Hzz1E+Oco/d/sqroi7
P6Y7n9bdF0/ls/mx3fqBsn3x2HG684dHuc8q3ouqvyHLM3H3e3JzYFS+ql8t
y/1AdSVsvQk6nu1vi7gfqnGqxs/6LLcEcTxU/BCWF7GgPrwL5COuBeuj+4C+
F9Znz6/i0kRRFEVazSp/I36tr/re2biryu8Wd62Kx7rjtOx5kK+Kr6o4zGyc
k41PVvluDoAqnsmeX1WPr+LZqrgfLAcYXZfqPnfjV4ziqzjnqv9Tlrui+v9V
7Ueo/CiKoiiaC4H5KjsvdfM3qjge7HqBnW+g+RvK50HrU3Y9juIAKC7BxnlQ
/JCNQ7J5pN34G26Oxyh54/PG35jVfO/4Wh/9HqqeG6PwN5Bfxd9g67+66eC3
P/VffvW266fGifxu6lZXOLofrU6qusiq51s3n+VvuPuno/epqs97FY+FrTtm
j+/2fIsfP378+D19FR8DHY8+t2qew8o9vxqFv+Eevzt+UhWfYeO6VXFRNl6q
iqclTru0r+JyqM6DeBosB549j8ofhdfh9rvljavyyVXnceeHq/K6q/pCsuNx
55Oz+/jufpTs8Sq+R7e8dzc/xO1X8UCQz3In2POr7ltVHrLqPqjy9t3fr4pD
4uaBsByYWeWWsNwPFQ+E9VXjZH3V+FX9ebvxQFiOBDpexc2o4mmwfAz2PIij
gnz2+0XcmyiKomhBKs4GGw/sxnNQfW5VXFF1f9zjd/8ewltenc/GY1XxW7au
R8UDcXOYVbwOluPRjZNcxf2o4opUxaNYnq0qzoniclWcahWPQsWHYX33/ani
e1fdT3acSOFvRFEURdHKpdpHQ+dh97+q+hGwXA7VPjuaD6P1Glq3snlKKA7A
cjnYOBKbJ8nmc1bl8VZxOUbxVXnj6P6opPr9dOuHqOqfGH91Plt3UPXcUNV9
uOtxquqXR9HonA22Lq9bXeH/x97bB9tZl+f+CFIwIDqIPcQXFDyI0HYEmaYi
1IVMPKCMvASl8VffSgsUEK00mko4pUgwlkOhUGsDiG0SzhQoP2SiCIi8KS8a
XgIcQERkpJEQyE6iMFiqFs4xa2zsXvvae117X/e+7+9a1+efPXPNM8961rOe
vdbzfL/3/fkiqh2n6jwPG/ZpTC5nzxsium9U9fuF9lPtc7FPw7lz586dR+Qq
z4bKE1UtR7A+DdV9V+v+DfR+s3yk1fwb0eOx1XJ7kieXR48bo/kddvtW8iwv
R/TrZtXPV+s7YOvS2e3ZunFUdx29zmNW3oo/JDpHdQJsPbzKB6LyhLA5W4fP
ekVUHhK0n+g66uj1Adn9ZJ2H6PfVSl6t3lu13mL08as8Lew6UKr1ZFvPWZ8J
m6O6QXY9Mtb7gTweKr8H8jCwPgdVznotVLnq+JEfI+t40Odr/4YxxowPO47H
bs/Wz0ePy0WPp0V7KqLPD+vHiH5f1cY52ZztN4n2Hlfze6jGe6Nz1bhltfFJ
lVc5+nhU46KqcdTo8bdqvoJqno3o8x/tK0bbqzwnqvHe1q9PNjfGGGNMHGi+
hs3RPBGab2Lns1Cumndj5z1Vfjz0XIOej9BzK+vPVHk5UB7t5WDrOVV99Gj7
anXIreSo3hvBejmq+TRarzeOPv5h84RkeYGi+0FU/T7R/o1qoL621j0biGr9
gyr/BkLVP5jl37CXo0uWF6iVXNUHyvo6EKrfHTav9rmw3yet+5GcO3fu3Pnk
8ixvBjqear+bWfdR7P0Gu59q/g3W/5nl38g6nmjvB+t3bcW/UW0c2Pn4oPHh
auPkbI7my1TejywfSCtekei+huh+B1VdevQ6jypPCOvfiM5V77fa+0I5uw6m
at3M6PU02XU2o+vknU8uZ9c/jd5e5YdR7b/auqsq7wrbB4H2z+5HtT5m1rqx
reRsf4cqV/lAkN8D+TrYddNUvo51bz3nxpuWTz1Hfg9VjnwU0fvPytFx2r9h
jDGTI9q7m+WXyBqvs39jet5XK17iaL9xtJejde9HtMcjy4esGldUjUNG5+g4
o8c/2XFRVa4ap1KN27Ti01B5d1nPBuqXROMkKEf7Ufk6or0rqu2r5cYYY4yJ
g/WloxzN76D5JpRX82+wXg72fgzNm6PnMvR8qqoLYsc92HEhtm5wUPv32Trh
rLrlrPpqluh1ANk8a9091f9X9P6jPR7R6zy24uWo1p/C9vWw/UetwHo2Wvdv
tNLfHb2ud7Vc9b6GjWqfo8ojkbW+ebR/o3Vvhur/V/V928r3uXPnzp23kkff
Z1a7j0VU+52tdv+mur+K9m+w+2dfN8t3Ee3ByPJvqPJq/meUVxv3a8Ujzfo0
qh3noPo9BjWv5uuo1u+Q5fFQ1YGznhB2P63n7HlQ+VKi6/bZOnxVHXu1envn
4+fR64dWW8+0Ws56P7J8NazPBL0u60uJ9oeo6urZPousfoesXLXeK1uXqPJ1
oBz5OlCuWq+NzVm/hCpnfRcqj4fKs2H/hjHGdMmqs7V/Y3J5K8efNY6nOs+q
163m68jK2XG86P1X83VUGz8c1DzL+6HyJ6vGnaJp3bPB+hZU4xuqPk3W1xo9
XsR+XsYYY4wxiGWd52dddXLvvMCVF592xtVz+p8vQPMsyOuO5o/Q/FSWf4O9
P2T9G+g5BT0fRa/Xw44nsOM/0f371fruq/k92Pre1v0briPNzbN8Ha18P0T/
f7Xi34ju147m8Ud3n7/DLvf1HCfKB9W/Ed0P3kr/47Dlw0ZWn2krPg1Vzp6H
av8X0Tn7/Wb/hnPnzp3n5tV+R1rPWa8Fu3/W91XtPk3lx0B59HhCtKciy7+B
3m8r/g32vGX5N1Tj5Fk+Ddbfm/V+q3lFWP+GyudczePdel7NNx49v8P2BUTX
52etX6naP7uuBPu6reTRnhCVD4RdfzN6vU52XU7V8aj2g46TPQ+q41ed56xc
1acQfZxsf0R0rurjiM6j/SGqdWBV3g92HVjV8UfnKv8J8pOgOkB23VhU94jW
KWPXO0N1mKoc+T223eILH7j1qN66UJSjOtJ1bz3nxpuW959n+T2ycmOMGVRU
dZ72b2iPpxX/hsrDED2eFn2cg/p+BzXP8iez43vRHuCscT/V+FhWHj3OqRq3
QeMkpiZZ66Sz3lT7N4wxxhhTDeTfQDnyeKN5EzQvg+aJ0HwT6+VA81xszt5P
ovk4dJ/G+jdUz32sf4Ota1KNy2X5Oqr16VfLVfW0LFn1nGxdZbTHuJXx8Gp1
vNW8HGxdvSqP7ltR+TdUoD44FtazsWjWxfeecuq9feetoOorHDb/hqofMLrf
0L6O8am2zns1bwaileuzWq76fsvqK6/W/+7cuXPnrF+o2n1j1v0kyhGsv0J1
nOzrVruPqubNsH9jevbPvq5q/+x4UbRnI3p8LGv/0Z7t6PHDVuYXWC+3ahzY
no3hzFXzINU87dXq0lvva6iWZ62/2fp6ndG5z5s2r7aeaSs56rOodpxsX4lq
PVmUsx4PlKP1m6rlqI9GdR5UXhR0/Kp1aZGvA/WJsL4OVH/IejzYHK2bxuao
LhTlKi/HoPo6jDGmFbLqulXjOVn+jaw63lbqjdnjH7ZxHudt5SrPcJavw+NR
05Nn+UbY8SIznLTi32A9tMYYY4wxKq68+LQzrp4T599A8zLIy6Hyb7A+DfZ1
0X0jmo9D84Csl4P1daDnOJWXQ+VTZb0cqnWyVL4OVV7Nv6HKWarVMWatI4Zy
Far/u2r1sVnrIQ6bfwNtH+3fQH1bqn7kIxZ9+TWX39K/f0OVZ6HyV0T3P7Kf
b3QfpaofUJVX8wm04uWIvn5YVNdblgep2vWmyrN8F9X8G1l98dWO37lz5/W/
N6r9jqh+x1Weimr+rqz7mVb8GMOWq7wT0Xn0uE30eFFWHu2jUO2fzbP8Fa0c
f1bOjuvas+F8OnN2nqWaxyN6Hk2Vt9LPUq0vYFC9H6q6CNX6JtXOj+p8snUp
1fogquXV+jKy1pnN8nWw68BmeSqic/R+VZ4T1flkfR0jH/z2Keue7d/jgfo+
2L4SVGeoqm/M8nXMWHLG3svm9NaLbrvFFz5w61G99aWo7lTl66jm2bB/wxhT
jdbXa1Otr1fNF8EeZ7X1AaPzrHESdvxEtR/nbeXs517Ni+txm+nJq43zGBMB
Gg9B/ZWsfwPlxhhjjDHR3PySLe+/do9ezwbK0bwAmjdBXg6Vf0OVs/NTyPuB
7huRb42dN1StTxHt5VCNF0XXR2X5BFT1nNXqWllUnurodb6ix8HYdZGyGNR1
A1vx5ET3Qaj8G6jPSNVHVq2fGvk6qqHqc1T5N6r1RWb1UarW7652flCuun9A
ZPX/ZvlJ2Oski2reDHY/1frQW8/t35ieHN2foJzdT7X367ytvHWfRrSfrZo3
Q5Wzz4nR+2H3X81T0XpuH0WXrPGfrHzY/A/O28qrjVc7d95Prlq/oJqvo/X1
WAe1LyarHyErZ+sfVHUR1c5D9Pw4qktR1auo9s/uh82r9X1U609hjz/a44Fy
1tcR7QNRvS57HlS56v0iLwfKWS8HqgNEfSUo32Lm7HNetX3/68miekV2/TK2
ThLVeSL/BspRHSnKW/dvoPpbY8zgEd03Xc1XWc2zUe35vZofIDpv5TwMqj9T
9bwf7ZfI8pZU+7zs2XDeT86ObxhjjDHGGGOmH9bLgTzkaD4ly7+B9s/OK6H9
s14ONH+H5vtYLwear2Tno6O9HChX+YFVXg42r1aPF+0lQPtBsOPn0ePb6Dpk
x53Y/y82z0LVR9B6PXOWl4Nd95PtZ2H9Gyyq/im0vcrXoer/zSK6L3LYPBts
ntXPWO08RHsnVP+Pqv+X6POg6vOtBvs9HJ230oeu+t2J9s9UO8/Dlqv8G86d
95OzVLsPifZvRPsiVH4JVR79uiqyvBPo+ZrN2ef96NetlqPxEzav5gdQva/W
z0M1jy57PFnHrxrnj36/0XlWX0C18W3ng51H+zfY/bDzfVk+jaz+nWrvK3od
BPcxDUbudYHHz1vpu1H140T7RrL6g7LWn3U+uZz1irDrZKH6PeTlQDm7fivy
daD6Q5XHA9VDovpJlG/+Z/+x03kreutCUY78G2g9OOTfYEHejJUf+9wu39i8
tz6WzY0xg4eqTz/rflhVL926f8PPm9OTV/NAVsujvZTOc/NW/JzO28qNMcYY
Y4wxdUDzAmjeAc1roPkRNJ/C+i5U/g12noj1hKD5LDSPduq+K7b82Cd6vRwo
Z70c7Hwlu/5FNZ9zVn1RtXHpavV+qvHw6HoYtu6CXb+D/b/LQtWXger5W/Fy
ZNXzR6+Lyn6+CNRnFO3fYPfD+jpQH3E01frBW/FaVDse+zfGz1vv02f/X6p5
e7IYVJ9GtRwR7Qnx5+LceX1vD+uVqnZ/2Mp9XSv+DdYjwZLlr6jm06jmqVDl
rC8ievtWPBLOu1TzJzgfzjzaP+B8/HzY5sui59eiPRvR13+WPyQ69/fJ5HKV
ryO630q1nkjWfqL7qqr1f1XLW+lHa6UPLqu/KXp9lui8Wj+R6n2xdTuvuX/l
P21Y1b+vA3k50DpcyMvxwNJbjh95vv8ceTlYX0e0lwOty8Z6ObJAdbPsenbG
mHaJvn/Luv9spV462gOpqitu5b6dPZ5W7v+r+QwHNY9+jqj2ubDPlfZpTE9e
bTxBlRtjjDHGGGMGD9bjzXo5Ziw5Y+9lc3pzNC/DejPYHL0um6P5KTT/hbwc
aJ4OzeupvBxZ87Oq8cOscWbVekZoP9X80ihHRPs32HFglUdUtU5HFqq+Fda/
gerwq9W7svX/0eucqvplqvVVRa+/zHo5sqjW7xm9PnhWHyI6nlbWMWffl6o/
NNq/wZLV7xztSRhUqn2/OXcekT/+6O7zd9jlvjLHw+ZHLPryay6/pd3jr+aH
YX8Ho30Xrfg0WG8ee18X7bVoJY/2VLTi38jyZrAeCfslJpdX8zywxxOdq8bB
BjVX9V9H7z+6Tzy6Dr9a33crfeJsXu28Zc27teKFGNTPsRVPSLRnw76O3Dza
sxH9/abyclRb9zn6e0+1/2oej2jvR/R6KNX6Fqv1f1XrV2LX487qR2Prc5CX
A9XXoXo8lLPrcCFfB+vxQPWHKl8HvT5aMZA3A9XBGmMGj0H1y7U+jqR6fql2
P5nV393KcbbieXOuzf15aXPV+Wz9ubWV3BhjjDHGGDM8LOs8P+uqk/v3e//w
/2zziRse7vVybLvFFz5w61H9+zpYLzrrV0evy/pD0LwSmrdC819ovizay4Hm
Gdn5yta9HFn1Iex+VF4OVT0Yopp/I9ovyvptWO+HCrZvhe1PYftEWq/zt39j
/FzVJ6XyIWRRrb+V7cdkUX0u1fwV1XJV/2lWvy1L6/6NYfN1VOvTdz4YOfo9
RR4MlLO/y9H7r5aj41e9rywvBPu6Ku9HKx4MNmfvT1TetixPWpbvQvU8leXN
iPZaZHkz2Of6ap4KldeidT+GyqvQSh7dz1vN/+C8S7V6e3b8v1ofcbW+DPZ4
VOd/UP0b1fz81d5v9PuKPg/+nZqe3Odz/Dz6/yLL+zRsvyOt+08GNW/d75G1
Hnrr50fl60D1cq+5f+U/bVjVv5cD1e+xXg5UH6jycrD+DZS3Dqp3Nca0S7RP
rNr9j2r8J9r7Ef25qLwT1bxqreeoXlq17qEqR/eBrLeN7b9gX7faeWslZ9ex
HbY8+ntA5QtqJTfGGGOMMcaYcx8+ec3ypb3zDihHvg7Wy4Fy5MFgc7T/Fy7a
frtvndm/JwT53reYOfucV23fOw/FejnQPBqad2M9/GjekB0vQrnKq6l6Ho+u
k6xWV1atLkW1jgxbD5BFlmcD9Y+o+ndU/SyoL6Nan0Lr/g2UI6LXF1b1ebH9
d1lk9eFW8ydU81ewPopqng3VuvBZ/c4oV1Gtnz3av1HN41HtfDofjJz1YLB+
jKy82nnOOn6VN6Pa71o1b4YqV3nAVB6MaG9GtGcj+nkK7YfNs55Po30a0d4M
lXeC3U8132mWT7haH2jWcVY7D63kWX2v0f6ErPp8VT/gsOWt+ECq5dH9INH7
GdR1bKvNS2a931buW1Cuut9r5f0O6v9FK98zrf+/tJ5X6+us5lVTeS1a98K1
0j/L9uWp/BtsjrwcqG5Q5eVA9Y2D6t/IAn3fGjPMRP/+Zv2equ4TVO83+nxG
jweyv/tsvTqbs33ug7qfLA8G68dgc3QfOGy5qn9E9TlmvV9VrvK6qDwt7PcA
2+/Tupejlf4UY4wxxhhjTCv8GDxH9OYnvXzewVc83evluPLi0864ek5vvu6t
59x40/L+/Rhoe5QjHwjybGy23bpnP/71tb3HQ/o3rn/iprlrt+rfv4HmxdA8
Gjt/lzXewj6nR/s6srwc1erKsup5ouflBxVVH0rW+rZs30rrng2UV1vntxX/
BsrZPr5osvpnWb9BtH+DpZrvIut1W/dvZPleqvWzt+LHUO3HufN+UPk0WvFv
VPtcqt2fZPkrqh1PK3nWfZrKvxH9PKJ6PlJtj6j2HKryZrD7ifZsVPOIRvs0
2D4499N1aWV8uJXx7ejx6mpei1Z8F9XqJ6vVZ7bSZxHtFWklj36/rfs9qnkG
qv2Os54KlR+jmm/N93va7Qf1fi/6ecHXpzZnrxPVejcqr0greev3V+zxt+7f
QD4NVc76N1pB9TsVTfT31aBy3Mjrdjz2fXcMzfs146P6XVCNz6h+Z9njZPeT
NY6XNU7I9ne37pEYtryaB4Nd/1TlZ1Otu8puX81fEf25ZJ2f6POp8nKwOfv9
jPJW5mWGrT/FGGOMMcYYo6J//wabn/vwyWuWL+31cizrPD/rqpN785tfsuX9
1+7Rm6/82Od2+cbm/fs9Nv+z/9jpvBUjPTnybCDfO8rfOuPGlcef1evfYHPk
60Dza6r5OzT+wD7vq3yb1Z7To+eXs+oiEOw8oD0bk6MVb4OqjyZ6PVk2Z4+H
fV/VPpdoT0tWv5sKtr+4lf7WVsjq31St857lx2jdv6G6bqv1obdOtfPpPDdn
fRRZ/o1oj0f0eav2uavuT6r97gxbnuUfU92/ofv/LP+GylfZes4+/0Z7L1V5
NQ9GdL9ktX6uaN+vc+dTybPWzazmnXDuvEIe7QmpNs+YlWf5Oqr1j6uOX+Ux
q3afqcqreRuqXVfs+2rdv1HNK+i8S7Xv8+j/x1Y8OWwe7Qdj73/Q9q37N1R9
lK2QdZ1X+z6xl6OL/Rvm18nqt432cngcb/yc/R1HdePRfeXRPgGVPyHa2xDt
N1Dtn73vYveT5VuLzqM/9yyfSbX3y3pXWvFyqPp6ovt93IdijDHGGGOMqUkd
Lwfyb7xw0fbbfevMqfs3tlzw3mv222XqXo4tZs4+51Xb959f/8RNc9du1evl
QB57lI988NunrHs2bhyGHQdg/bfo+Z19rkfjull1fey4ffS8JCK6vt3jHl2q
9dFU6yeq1o+j8nWozg+C/Xzt3xifav2tg9rvz4L6NxGsl6OaZ6NazvZZo+2z
rnP/33Wp9j3mvK28mpcj63hUr1vt82Xzar9TrecqP5jKV6bKW/FpVHsuVvkw
2e1VXs1oD2crng22/2tQ+8XY8UbVOCq7f9W4rvMuray3GF1nzuaqOkY2b+U4
W89V81/Rny/7uav2z+bV+k2qzT9G/65l9RFHew+i+y6r3QdG36+yvoVW7oer
XVdZfc3D5o1pxVcT7XUZVE9LK98n1Y5TVV+E7pdUfbtsX1t0vx563WoMqmcm
63eTrd8zgwHb99o61Z67s3wg0eOH0eM50eNd7P8FqjPP8mZk+QdUOeujyDoe
1AehytG6qNH7Ub2uKlddD2x/Stb7is7Z88b26UR7PKL7elTzGu5DMcYYY4wx
ppesPk1UDz/YxHk22Bx5Oa68+LQzrp7Tm6976zk33rR86v4NNlf5Ot4648aV
x5/V699A+WG3fvOxE05/oidXeTlU84MqD+egejWj65xZ2P1E12MPKio/RnTf
UFb/UbU+oCzPBuvfYK8H+zfGp1p/qxkf1L+p6utk+0yr9fNm5VnXv8obgPJB
pdr3Xus5un6qHWe0fyPag4GOU+XTiPaHqN5vVq7yMlX7/VL5Mdj9RHswqvk3
svJW/BuIav7JLP8Gylvpk6rW74PyLD+Dyreg8gNX67/OWheylbwVX0RWvaLq
ONl5nOj3Fb0+pvMurVy31ep72Zydx4ye96zmd1J5Qlrvg87qx/dxdql2XWX1
EaO82nOZ8/HzLK9OtfNQzbep8hGp9qP63mDHB9j+4qy+XXY/9m9MLq92n1mt
3s+MT9Y4STTRz7kqqo0fZuXVxvdU17nKf6X6XVb5MbL691lfAfI5sPtH+6mW
s30TKEf7YXPV61Y7zyoPifMuqvVzo32Aqn4f1byDMcYYY4wxpn9U9dVsnXm1
PrJoVn7sc7t8Y/NerwXyYHSZumdj4Sf/7fwrV/T/uqx/Y8aSM/ZeNmddT751
55MzTjug18ux1Q/+5LEPvWXtlHPk5UD5FjNnn/Oq7afu5bj+iZvmrt2qN1d5
OaL9nOj5PcvLkVVfp1p/CpHl2fC8YRfWY8D6MbL6mKqt/4vy1j0bCPs3tNiz
MRiw/o3ovtRqfcTVPBtZXg62/11F9P4R1fr3hy1v3ctRzUeh8mmofCPs8bB5
teuB9XIMm38jy7OR5d9Qec+ivRnRng2EykvZigdD5ceo5tmo1reStS5tNf9G
lkdCNW7M9hO5bnz8XOUHiN5Plj+BXdcsev/RdZvRx6nK0XxZ1vFU835k+UNU
849ZXiD2+FXr6kZ7olTzp1nrp0ff11XzZti/MbntW/FvqDwA1bwKzp1H5K34
arK+b9nfZfb5NPp+ku07boVB9W9Ej0ex96vseFGW54EF/T9mEf38pfqeia53
jfY3IqqNZ6rGaaPHLauNg7EeDDZX9ZWz9e2s74LNWT9DtRz5IlCfAspV+0G5
qs+ilVzlFWnlelPl0Z+L6jyrvn+y+n3Y3xdjjDHGGGPM1FHVdaPt2XUqUb9A
tXVFWZB3MZplnednXXVy/56Nm1+y5f3X7tG/f+OFi7bf7ltn9u/l2PzP/mOn
81b0ejmQrwPlm2237tmPf73Xy/HCvzxy53su6/VvoPw/3nXnst+6oNfLwfo6
2Od6lZ9T9TxezcvRin+jWm66DKoPoZpnI8ub0YqXo/XrLYtqPgEzObL8Gyhn
n0eq5dX6vllU/o1W/q9VnoFqn3srPg3W/6D6vFQeiVby6POjuh5a//+q9nvU
in8j634j+nWH7Xmzmjcj2r9RrR+k9X6T6P67rHE/NM7Jbl8tZ+urs/qsWznO
6HVFBzVXrdccnbPHqarzzzpv7DwX23dQ7fNt5bpSzTNWy1Xfk+z2qt+jaK9U
dH9ltfnWaN9ItLdE1X+d5Sexf0Obs89l1Z4fnTuPyLM8qCofqcpfyv6+s8/1
0X3Qrfs3EKrf8Szva7VxJ9V9vur5qBrRHg/2eYeF/Z5RHSf7/MVS7f8oerw3
y8cSPX4Y7cGIzlmfBlsPj3KVN0DlqWC9E63nqJ8iOkf9GihX9X1E5+x1qMqj
vSjseaj2+ao8Kuz3m2o9X7ZvyBhjjDHGGFMHtt+N7YNj+xHY9UBZ/waqq0f1
1Wg8ED2XIe8E8mCoQPtn8xff99KDvvpwr38D5SpfB/JybPWDP3nsQ2/p39cR
7eVQPV+zXg6Uq+riWvFyDGp9l+mCPAboexvl1XwI0esI278xOezf0NJKf70Z
H/b7VuXTaN2/keUhVPk3/P/bhfUttO4HiPZasOdN5Ytg/R7Ou0R7ZrI8HvZv
TE+OfsfZ7dn7DdX9iWo/9j12QeOr9m/k5tXW11b1HVTzbLTu02D7HZxPT16t
zz06z/I/oJydl3HepVrfAZtHez+GzSsS3RdT7XtMNd+K9h/t68jKs/pGq903
VuvPbcVnMqj+jSy/h/MuWT4H511Ung12nEf1uauuEzQOw35Pqvqs2fuiQUU1
DoaI9mxk+TdUPg32eUH1nKjycrDPCwiVB0PlD2zFZ6u6nhGqOtis/9PozzHa
Jxw9bsP6LtD2bD25Kq/m2cjyUbTuu6iWoz6OLRe895r9dum/v6NaXs2v0sp1
iz53tt9H5YFReTzYfiJ2PV9jjDHGGGNMu0T3u7H9d6o+PlRXj+rG0Xgm8i0g
jwTrwXjhou23+9aZ/eesNwPthz3Obbf4wgduPar/HB0P8nWgnPVysOM57HM3
68mM9l6y62Gp1m+yf2NyuRkf1GeEvs+z+p5a8W8Mas5i/4Yxvajuw9n782p9
xGxere+b9Ru0TrSXoHUPQDX/Rit+iVbe17Dl1f4v2FzllVWNv0Xn7PG04t9g
fWWD+lzJeh3R9llejlb6aFS+C9V+VHm1cblW+hRa8Wao+pSj+6NV9eGqvBWv
BdvnEl333sp6lOxxsu9XdX7Y+SnV+puDmle7DqM/l+jrudr/i2p+ls3Z31OV
DwT1YWW9LtsXpuofVPlP2PtMdn5ctX/VfH30+432h2TlbB+3PR7j59F+hlbe
L9qeHVdh96P6XAY1V40Loe8H9nse/d6ZLtG+2VbGr1R9+uw4icoPGe1FjPb1
qe6Ho+s8o6+rrONkyfJ7tO7ZiB6HVI0ronGSVnwabL/59U/cNHftVv33+6O+
eFVff7Q3gM1RXwPb7xCds8fpvEu0b0R1HbJ59HWC1u1lc9Xngr6XWI8H+j5E
/UQoN8YYY4wxxhhEtfUi0bweGodE42boeY31YLD+ihlLzth72Zz+/RusZ0Pl
D1G9L+TlQP4T9Nwd7cNE45bI38KOo7LedbZeSzUfFF2PVK0+354NLarv+Wq+
DtQ/Va2vqvUcwXozVPuxf8NUJqs/N8vLwfY7o+2r+RDYfvZBJdrbUK2vPzqv
5mGwf2MwcpZq/xeD6t9g/RXs7zjrr8jyb1TzOlbzcqj8G9U8G1l9NKq+p2qe
Dfs3pievto5kll/CeZcsD0a1uneVZ4Cdl2HXtazmYchafzMrV83TtZKj9zts
5wHN27JekSzvSnQ/oCpn56NVHpJoH1f0uhXV+gqr5dWeF1rJqz0Pss+z0c/j
rA8hy48R7RWp5qNgc9b7Wi1nPy/W/2C0sOef/VzY7/lqnoRoL4fKa4fyaP+q
yv+m8s5FXyetjK9GezkG1b8RPQ6sev6NHlfMGrdB4xuov1vl01B5NlgPQLUc
9Slk5ag/gt0P8h6w66uyedbrsseD8mrXp8qbwZ43to+J7Sdi1/9Fnxe6/qPX
/0W5McYYY4wxppfFJ7/xmye8eaXvn0Wwdd1ofgquEwHGCdE4GBpHQs9x6PkR
5ej5lB1/YH0gyLPxw/+zzSdueLj/7dnnaPb5Gr1flfeS9VhGeznQuK5q3Tr7
N7S5GR/Wm1FtPeJqfVJsXUc1b0aWl0P1Odq/YVok2neRlVfrv87ybwwb1XwO
1a6fQfVsOG8rR9chotr/S5avI/p3M9rLgfZfzb9RzRvM+hureTmy/BuqdVdb
8W9E5+w6nlnrfqp8Gll16VnrEqrqq1vxb0T3a0R7MKJ9F1m5ypsRXQ8ffTyq
/auOh63/V+WqdTxV+0f7QX0NbB/EsOXRn1f08Wf9X7DfG+x631nf8+x+VO+X
nTdvpa8z+j4wut8W7Ye9n8/Ko59fhs3XkeXliPZsVPNXZPkx2O3ZcSq0/2p1
C+g4TU2qeWir+Qda98qq/GnVPBis3yzrPkRVR9q6f6OV8WR2HDhrHFU1Dqny
f6pylWeD9W+wng2UZ/kEWE8F62GolrOehKxc1Vei6sdhc9bzUO16Y98vOp9s
/9HKj31ul29svqHvHPUrRa8XzHpvUP8Ryo0xxhhjjBlmkGfD/o3pga1nRuOQ
aNwPjWuh5yOVB0Pl5UA5Oh70/ItydPxszu4fnQfWy6HyVaLxTLbejB2/ZddF
Uq0fpJqfGtT1bsz4RPdP2b8xfl6tzgTlqr4zlTfD/g3TItH9uShn94/6jtk+
5Wr91KxPQ+XfqOblqOYBUPk3VJ9v9HWlun6c5+aLZl187ymn3lvmeOy90eZZ
3ir29531dbDPaypvhup1qz0/Znk2WvFvZPk0WvdvVPNmRPevtVI/34p/o5pn
g10/sRXPRnQfNFt/zu5H5cFwrs2jPRjRfQTs/tF+BjVX9VOw6/dVe1+qdV3Z
41Rd59Hzy8OWq9ZBZnP2d5+9z8m6T8vygWTVJ6jWeVflqvVN4LpFxZ5bW/Fy
tOLfYMdzVD6N1usWVOuDmMEma1yrlTza35U1jqf6va7m5ajmT2bvc6I/F8Sg
+m1U/g3VuGv0cxzr5YgeN2PHJdjxnyzPhsq/wXoPUI76DqrlrNeCzVG/hqr/
RdVvEp2z5y36c1d5S9jzgDwYyJtx80u2vP/aPXrzKy8+7Yyr5/TmyzrPz7rq
5P5ztB/0uqzHg+1Lgj4WY4wxxhhjhoB3HHnUZ0d2uavnfpjNTVugcTM0HoXG
YaLHN9DzGju+hI6TfY5G3gy0PZtneTnQOCFbh6aqD2Trhdj1fVT1M1n+dns2
2sL+jS5Z66cMat0LOs8I1qdh/4ZpkWp9vir/xrDlrD8hi9Z9AtH+imiPRzV/
gvPpyav9H6lyRLXvZzZHv3fVfpfZXPUcl+XfqHafX82zEe3riPZvRHs52D4g
tL2qL4ntq2LHwar5OlT16qp+PVX9fyuejVa8HK17NrLqyVXrP6r2g3wRbN07
2g+7f9Zfwb6uyo/B9u+j7dm8FR9FdM56HtgcvS7bT8H2Waj2r3pddp2F6PcV
fV2p/k/R94xq/6rjUfUlRf8uqH7X0O+mysfF5ux9VFaO7kvZXNX/W63f2V6O
8fPocYNon0a18Z9WjtOeDTMVsjy3WT6Har6IrN/H6M8x2u/Rij85a/9oexb7
NyaXZ3k5osctVX5O1biTyrOR5d9gfRqoz4L1WrD9INH9IyoPA7tOa7Vc1YfC
5ux5js7Z40fejGgWfvLfzr9yRe/rnvTyeQdf8TQ6nh/3naP9n/vwyWuWL+3f
44GuH/ZzMcYYY4wxZhiwf8P0BTluw47PoJz1b6BxKtbLwT6/q/wbrB+V9Yui
88bWa7H+DTSOqlqvR+XfQHm19WXs2WgL1PeEiPZvRPs6ovunotcdbt3LofJ4
qPwertsx04mqX9iejenJo/vWVVTr04/2b6j8GCq/isoHkpXvePZOv/34I/f0
vf2g+iWGLWf9NtH/d/ZvTE/OejlU/g12P1meDZRXez6q5tlQ+TdU/TXV/BvV
/BjV6tVZb0bWOp7V/BtZddeqPMubocqj/RuqPuLofmSVf4Ptv45evzJrHcys
nO0LiO47iM5V/QuqHM17ohzNL7Pbszmav45eL5WdZ8/6HKtd56wfBuXVvq9Y
f5Gqr4pdpwP1i6l+99n7iuj7K7bOAfXxqdYlad3LoXouq+brUHkzVB6P1n0a
1bwW1Y7HDDbsOF70uBzyA0TnrOchy9dRzTtR7Xiq5dX8G6p60az7uuhx6Wo+
ZNU4arRnQzWON6j+DZVnQ9XHEe3HUOWonwLl0V6L6HVao18X+ShQnnV+UH7z
S7a8/9o9eo8T5cg7sazz/KyrTu7NJ+fNQPTv04jOVV4O9ro1xhhjjDGmRRaf
/MZvnvDmlT33tyr/hr0cAw4Yt0GeBzZH4z8oZ+uR2ONnvakqXygaF2LHndD7
Ys9btH+DratBeZZ/I7qeJGt+yuQybP1TKp9G9H6q1eG0UifTynGatkD9ztH9
wizV+qBbz6tRrd8/2r/Rio+llRx5Nlj/hn0dNXPWv6HydbSSD6qXoxX/RrXn
ymrPTa34N6I9HmzfDbs+r6rPSNUnVa0eW9V3YP+GNq/m2cjyb0T7MVTrNqrW
c6zm34j2ZrB9087Hz1Gdf7QHILq/gPVdqDwVKq9FdL9DKzk7j8z6OticXSfC
3g9trvILsX1SqnU9oj1UKl9HdK6qi4j2dVRb90RVj5Hl38jycqjGJVqflzem
Mqr/dzS+h8bZVONv0d/brfs9VHk1/0MrOXudVzv/Kqr5N1Tj1Sr/RvR4bPT4
Z5Z/Q+XlyPJvsB7ULP9GNS+HyqdRzbMR7Z1A3gzWU9FKjrwZKEfeCeTZ6ML6
LljqeDmQVwSdT9XnaIwxxhhjzHSC1lH9+uOLP/uet/WfIy8Hyo2ZCipfB8rR
uFD0/tlxITROgrZH3g/Wv4HG2dD4Hlt3xK7jo6pjUfk32LoR+zdMZbL6p/7H
Vr///528a1wdi2rdnEGt82mlLqja8ZiaoL5jtg86y/9Qrd+5lZztQ69GKz6E
rL7+audB5c1A4zNsbv/GcOaIQfVvDKqXQ+XTiPZvVPM3tuLlGFTPhsq/Ee3Z
YOv52frnal6O6Hp++zfGz9lx42ifhmr9RISq3rsVX0c1/4bKy6Hyb6jq3lvJ
szwY0V6OLG8G21+g8jaw/Qvs/Cnbp9BKjuaX2fUyUK5aj4Ndp4O9DtnrE/2/
qPJonwnrOYl+v+z3YfTvAusDQTn7e422R/cJqM+OraNg6yvQ/Sd7/xzt8VA9
70T3L7PPs+xzNHpOZ5/30bhB9DjGoM6Pm7ZQ+SuyXjc6rzae1nqe9TuV5eto
Pbd/o0s1z0br/g10f57l36jm783yb6ie36M9q+z4TLR/I3qd02jfRbTXInr/
V1582hlXz+k/Z70WrO8iOkceiS7R3gx2+3Zz5C1B1wO63owxxhhjjJlOUN0+
6+Wwf8O0COs7Rduz40JoPIodR1LlrG8ky7+Bxl3t35hcbs+G6YdB9W9E9z2h
/Q+ql8OY6UTlYcjyb9jLkZuzfehZDKoPgfWiDJt/gx2fYf0bKl9HK+en2ufO
/r6w/xeq/6/Wc+S1YL0cWR6PkTfdtnzGob0eDJRX829U83Wg50pVzj5vqvJq
Po1o/4bKyxHt38iqn8+qz6/m38jyeGT5NKJz1bqKqpytG4/Oo+vSq60vGV0P
z3ohsjwYWblqPU22XyC6rz+6jyB6PdCsdTzZdRaGLVf1fajW42C9H6ocHU90
Pw77flXrm6j8J6rvVdX3P+v3YNcxUXk8VPdXqvtG1LfIejzYeo/ouo5oX8ew
+TeMqUA1D0Y1/4YqV40TRu8nazxT5emt5rVoxacR7cdQ7V9F9P1Slv852p+c
NY6qGv9kxxvZXOXZUHlx2fG3aH+s/Rvj59H+jWjfBbsflR+DzZFvgc0n58dg
c5bo163jzcjK0fVgjDHGGGPMdBK9TivydRjTIqpxG7Y+il1vSFUXxI6/oXE/
1r/BrgsT7d9QrcPCjs9n1V3Yv2H6oRXPBsqjPRvV1t9R5ejzMiaC6P5clTeA
fV3Uz8vm1fqdWznOaC+KCvZ5vJo/IdrLUe34o8dV2M89ev/R71eVV/vcoz0Y
aP+Iat+3Wb9T1fwbKl8H69mI9nhk+TdaeW6N9mxU83Ww/g22Lp3Nq9Vps/Xt
1eqW2f1Er0NdzbOBxpnZ8Wd2P6r67aw8y7MxbP4NVX17dN17dJ28yl+R5cdg
c7Y/PbovQNXXH+0TQPOz0X0BbI7WlWDXp1C9rur8VDvP7PoXqnoAVZ9L9Dog
WeuMqL5PVH4PVc7+rqnWQ0E56+tA91Fsjuo62Jz1eKD7c/Y5AuXsOuxsfYiq
Txw9v2d5NlBuTGWqeTCi8+jxPTbPel8I1XGqPB5ZdYbVxmmr5Yjo/aNxV5bo
cWk2H1T/RvS4aJYfWOUNZscn2ecs1fghOy4X7dmI9m+w4wDR4zzIp7HyY5/b
5Rubx/k0kL/i3IdPXrN86fR7MNDrolzl05gez4bzwc6NMcYYY4yZHKp+NLZv
wphhgK1fUtWHqOrEWP8GW2eCxgnZ+kw0XsqO61bzb1Rb98T+DRNBNf8G6m9S
rV+set1WcmMiiO7DzepTVvk3VL4LVT8yux/V+WSPs5p/Q+UxqOYZsH9Dm7Pe
iWr+DZVPgz2ear4a1r/Bbs9SzY+R5d+Izqt5OVhfh8q/ofJ+ZPk3qvkho30d
Kp+Gyr8R7eWoVn8e7d9Q7V/l36hWL13Nv8H2A1bzZkTnqvUco70cWb6OaP9G
1rqT0fXt1XKVB0OVR6+zqVpfIDpH/QKs1yJ6nc1WctS/wK4fquqDYNcnZd8v
W1egylXXITrP0bnKi8LWaajWMWFzth6D9YGw66eoPB7oPoT1eLB+D7ZuhL0P
V92fs34PlKvqRrL8G8YMA6rxtOhxvOj9o+8T9niy8izY40TnuXWy6h6z6ifR
7zsi2r9RzQtdbRw42rOh8m9Ej09meTaGzb+hGq9j+wui/RvR/lh2PIQdL0I5
683I8m+o8i7V/AzOBzs3xhhjjDFmfFTraar6gIwZBti6DnZdGzSuFV3npqr3
YMchVf4Ntl6CraNgx+db92zYv2EiqOaRUHk8VHn08SP/iTHTSXS/bRbV+nBb
6ReOfl9snoW9HMOZq/wSKj9G9HGq8tb/L1TjeMOWq37Xorevlqs8GK17NrI8
kOxzZdb6sNXWwWTr86O9HOw6wqrxtyzPRjX/Bhp3Zbdn16GOrrtm+++Gzb/B
1o1neTlQvye7fZZ/Q5Wzde9sP2+WfwPVvbP18NE+DTR/x+aqOnxV3X50ruoL
QPPF0V4C5JFgt1flqn4E1fGw/QtsXwN7HrL8FdGfO8rZ88zm7HXF+j1Qvw9b
71EtR9//6HeQ/Z1FsL4O9n6G3R7dRyHY+z32fpV9LkDPKao6E9a/wfbLG2N6
Yb0KWeOHreStrEfDepvZcWYzOVqvn0S/+6zHo/VxYzZn77tU48BZXuLo8cms
cUj03BHt31CNQ7Ljgaq+gCz/BsqzPBus35Ud11L5N1DO+jFOevm8g694un9v
Bru9c+fTnxtjjDHGGNMl2rPBrjNrjJk67PpKKj+Gaj9sPQYaz0TjomxdhGq9
EnadEdU8AsqzPButzB+ZwaCaZ0Pl32DXL856X8ZEkNWfm8Wg+i6qeTayPB4q
qnkAnHeJ9kJkHT/ybKA8+n1VO2+t+zcQrfgxUI72bw/V+PnIm25bPuPQOD+G
yr8R7dloxb/B5sPm5cjyb1Qbf1N5Oarl0fXSbB11K/mw+TeyfBrR/o3odSfZ
deSrrUeJcpZo/wbrwajm01DV26vy6Lp95M1gc7Zun103s5pfInr9TdbboOoj
YLdX+SJUPhO0ver8sLmqj4PN2eNB12G0r0P1/cN+v6Ht0fcw+h1hPVQoR3Uj
bD0Je7+Btkf3Mwj2/grdH6Ic3fei+3/UB4qes6L9G6Ytqo3/sONUg4pqHK+a
7zfLp9H6OHCW59l0Yf0V0eupsa9bbVw3y6fB+plbGddVjWeqxiGrjTeyno0s
/4bK0xu9Xqf9G13s33DuvFpujDHGGGPM+KC6fZV/g93eGDN12Do0VP+mGjdj
1+dS+TfY9U3Q+G30uiFofF41T6Gal0Hrb7K5MRWoNn+tWoeiWm7MdML2Kbfi
30BU68913kXVJ85SzQOg+n+sdpzR/odq/opo/4bqfdm/0SXaN5Xl36jmwVB5
PFrxSrXi30D7z/JvtFKPjciqq0frb9qzMT15tfrq6Ne1f6NLNf8G68GOrhvP
yllPeFbdu8rjoaqHR/XqKv8GQrW+pKruvVr9fDVvhipHffEoV/k0UN2+qg6f
rc9n6/Cz8i7V6rqnnvu8TU/OejlYXwf6/2W/N9j+IPZ7jM3ZdWGq1aWw/XTs
ejFsju6XVHUv0f4N140MBqpxHnb8h92PapyqdVSejWrjmawfg4Xdz6COG9u/
MTlU467R/g32dauN02Z5NrLGh6PHb1W+YuSFix4/zPL9sl6OaP+Gahwyy9OL
xgPZ8UP0fKryb2R5OaL9Gx5Hcs7kD11wwO/+8z8s70x3rjr+sXNjjDHGGGO6
ZNX/G2PqoPJysHl0nYOqDgGND7P+DdazofJvRHvR2f4C11GYQWJQ57vt2TDD
APuc0srzDtt/ivpnUY72w/bPsvtRvS77flV5dH83yo9Y9OXXXH5LHQ8AOp5q
x1ktz/JIqPwYWf6NVnJ0/as8Fez+WbI8G9Vy1ncR7ceIfl37N7R5tfrqauta
sn0TbL+Gyr+Bxrvs09Dm0esYovHb6PUKUb20Kkfj1ao6bVU9NjsOX82Poaon
Z/Po161WJ6/yb6BcBZrnYtedVNWxs/XtKI/2abA568fYdosvfODWo3rr21U5
W2/Pbo/q8Fn/BltXj7ZH/gGva+ncef++DlWO/k/R9wDr81Hl6HsPfW+rfi/Y
3yn0u8n2nbHry7A56/dQ+TdUfcFmMIgeF4oeX1J5X1sha7yx2nhsK7nrcMYn
+vellfFbti50UMeHW/dpsHn0eC/rN44en8waV7R/o0v0+CQ7fqjy90Z7OVj/
BuvjZf0bWR7dLnXGZ5zH5Cqfxk1rVq08edV1PfmDG7f/Zt/b33PhL7df2pNz
78sYY4wxxpgu9mwYYxBs3Rqqx0Pjb9H+DTReisZX2fXjUB0CGvdm1wdRrfMY
7d9AsP4N1L9gTIu00ifF5p7fN8NAK35CVZ9ptDcjy7+hOk5VHt03jUD97NX8
A63kKl9E634J1fEPqn+D9cxE+zfYHKHaP/oey/JRZPkrWnld+zemJ6/mb2Tz
6P4Itt+BzVnPBpvbvzG5PLqOOtqnofJsRK9XyObVfBcqPwZbH66qJ2fnKVrJ
2Xp4tu4d7Qdtr0JVr55Vx87Wt6t8Guw8o8qnoaqfV+1HVVevylX19l3q1Xs7
d+584pz9f0ffGyhH/T6sDyR6PWL0PY9+X7I8HmxdDaqfQfdR6P4ZPafYvzGc
VPNpROesr3VQYccbkWdYNY4aPV+sel32fQ0q0eO3rA9ZVSdZLW9lvLeVceNq
48kqL0eWf4MdR1V5Nlr3b7Aev2gvR7QHWOXfYMcVq/k3kMdS5d/I8nJ0qTMe
4nxqOfJaIJ8G8maw+Yp3/N3m5/7+7T35ARv9G3f0vT06zrHflzHGGGOMMePD
rptpjBk80LgTGr9i/RvsuB8ah0Tjluz4KhrvZesNWP8GGrdn5xfYeRaUG2Om
Tiv+DXZ7Y0wvWR7CaF9Eln9DVdfE1ndF9/+iPmWUR/s3WA9AtGeAfd1qno1o
/wbrZ4g+n637MbL8G+znFe3ZUHkwovej8kVkeZOq5ezvUdZ9Bbufaj4NdB9S
zZsR7dlg1xVVrTfK9ke04tlQ+XWj67FZzzCbZ61LyPoxon0aKv9GtNciy4MR
vd6iykfB1pOz+8laL5LNVXXs0ah8GmweXcee5dlAfc1sHt2XraqrV3kzUF29
ar3Lk14+7+ArnnadvHPnzqeeo+8TlKu8H+z3JOpvQjn6/ke/U+zvIFuHw/o3
2PVo0HMNev6yf2MwqObByPK+ovGlQb2eVeOW0Z6N6Hlt1fz1oKLyabCoxmnZ
estW8mHzb6A82r/Rik+jmod5UP0baHwy2r+hyrO8wdX8G9FeX3b8kH0+ReOH
9m84j8xZ/8ZNG/0Y1/XkyLOBfBoXHnjBIctn3xOUG2OMMcYYMz7R62MaYwYP
dpwNbc96etE4JLsOGluvy9ZRo/FwND6P6smj/RvGmMED9UmpPB7GGBPt31D1
1arWV6rm32Dz6P59Nm/Fv9G6t4HdT7XzkJVX+3+p5tloPc/6Hs56X1keDNXr
VvNpqO5Dor0c7PNddB7t2WD7I9B6iNU8G63XUQ/q+oMq/0a0lyO6XpodV1ft
P9qDoarfHtQ8a11IFWw9uSpX1aWjXOXTUHk2VPXq1dadVK1HyeZZdfJd6tV1
O3fu3PlUc9YHwvo9on0drH8D3Xex9TDsOjJmMIgeL2J9sNHjYGicivVvoByN
L1WDPc+qeVg2Z2H9GOx4deuwXpronEX1/1XNpxGdVxtPbmVcOnr8WeXlaN2/
keUTZsczUR07m7fi31CNZ7LjnGh8MtoPnDXe2Pq4oscbhyOv5t/o7md0/Reb
G2OMMcYYMz72bxhjWFSeXjZHr4vGRdl139B4cuv+DWOMYbF/wxijQtXnG70+
UZaXQwXqy0b99SqfA+t5YF+X9UW07pfI8pyw+6l23qqd/2o563Ngv8fY/Ud7
PwbVsxHt32DPm+p3MNqjleXZiPZpZHk2or0ZbI7qq6P9G2g/KI/2b6i8HOx+
on0a7DqD0fXPKj9GdF7Nv8HmKs9GNX9FKzlbf67yZrB15qjPNNqnEV1nrqpL
R/257PqSWetCovrzVureUR27qh4e5a57d+7cufPpyZGvA30/Iy8Hu44z8nqh
+hxUJ4Pu89HzFPscikDPy6YmWZ4NlX+D3b9qHAyNR6GcHQdDx6P6vNjzPKg+
itZhx6vR/0XWOHC0r6aaByN6PLl1z7NqPDnay5Hl30B1y2z9s2rcONrDHO1V
VvmEq/k3qo2LsuOTKs+Gyr/Bjltm+X5V/g2VlwM9R3ep87zvvL+c9W+gHPk3
Vrzj7zY/9/dv78mRf0Pj5TDGGGOMMaYLW1/N1skbYwwav2XrYFGdJ9qe9Wyg
cV12/Jn1bET7N9g6B2OMMcaYVlD5N9icrVNC27PrKyFUfe5snuUNaN0XofKT
ZHk5BvU8sOdH9X/EeidU+4n2NrD7j/ZpqN4X64katpw9P6y/QuXfYPfP/r63
7tlAddTVPBtsPTbrzUB9EKr9V/NsVKt/rla3XM2/Eb1eIevBiPZmqHI0X4Dm
Hdhc5bVQrbeI6r1Rrto/61fP8mmgflVUB85ur6ozV3kz2JytY1fVpVfL2Tr2
Ky8+7Yyr59in4dx5ZI7q+aNz1fE7H66c9XIgbxX6XUb3Oeh+Et23o+cO9FyG
nkNZv6WpSbRPQ+XHaH38rZWcPf/s+LDRwo7bs+PnrK8mGnacNtqrzO4ny+fc
upcj2pvR+jh2NW+zyrOR5WFWeYlV/g2Vl0M17po1Lhrt32B9v9F+YJV/gx23
VHk27N8Y7pwdf1N5OQ5Ys2rlyavuAPvp179hL4cxxhhjzLChWp+XrZM3xgwP
qO4djc8j3zLrVWbrflWeDXT8aB0Q1fg8O+9gjDHGGGO6sH27bH0duh/OqjtS
eTnQ9q14ElTbR+fs58XuJ8vXoTrPWZ8X+7kMaq4aP8zyPES/Lut/aMWbwb5f
1fmJ9m9k1ee3UufPejayvBzRfozo+m22zpn17rZe51zNs8GuJ6jybLDj2INa
L428Gar1DVnvRLWcrd9GOYLdT1a9d7R/I2s9R1XO1plH+zeqeTmi69hRrqpj
71Kvvtq586nkqA4f1durcnZdTvs6nE8mR9//qO8J/W6yoOcOVN+Cngft2RhO
oj0Yrfg32OPMel+sJ4E9TnbdAXZcethg51myPOToeosmeny4msejWt7KuDSb
D6p/gx2vVtVvVxtPHlT/hmo8ttp4KcqjvcHIf1jNvxHtE2b9G6rxTPs3hjtn
vRw3bfRpXNeTo/E95N+48MALDlk++x6wn17/xlkb/R699SbGGGOMMaZt2Hpj
tl7aPmpjDNuPg+rw0Tg5mt+PXjcQjSejnB3fRu8L5Wj8354NY4wxxpjpga1P
Q/U/WUT34yNfR3RezfuBctZnkpW34sFo/XNR1UlWy6M9D6pcNV6q8khEj9+q
1rOrlmfVyVdbX1LlzWglR/XMg+rfyKpbjq43RuOf0XXF1eqZ2XUGs3wayGsd
7dNAdc7VPBuojprdHuUIdt3D6Fzl2WjFvxHtzUB146r9oDpzVd76+o8qz0Z0
XXqXevXSzmvmbB17dI78FWz9PFrXMjpHx4OOn/V12OPh/Jeg3wsVbP+sPRvm
11H5HKp5bp2Pn7OeDZU3O8vvrcqjfdrsOons8atQjVdX82xkjT9HezbQ/QCb
R49jR/s6WhkPV+XRHulqXo6scWbWyxE9HsuOo0b7NFTjn9He4Grjn+y4KPJs
RPs37NlwrsjZ8UbWy4Fy5OUYOzfGGGOMMa2jqvc2xrTL1x9f/Nn3vG20t3Gz
zRbNuvjeU069tydn+6rQ/Beab0XzC6yXgx2vZveTlaPxeWOMMcYYk0t0n6kK
Vb1Wlscj2iNRzYOhqj+M/lyq+TSiP9+s+k+2LhSN40W/ruo4Ua6qE45+3Whf
hMr7Ua1+OzrP8mag3/dqfgxUt4zyavvJWpeQrZdW1Tm3UoecVVeM6n6r1Ser
fBrIj9FKnbNq/cFqddGqnK2jrpajOu0sz4aqbjyrPpzdHuVoPUc2V9WNozrw
6PUcVes/snXp9mw4z8hR/Tlbl876JVifhqoenl2/EuVoP+zxsB4PlLOfY3Ru
T8h05FOH9ViyuRlOVF7ZQfVyZHmGo49f5YVuZZ4l2vutmu9jYevA0XWCQN8D
iGg/MzuerPp9HFT/RjWfRjXvtGqcvNq4epZ/A417q3zRKv/zA0tvOX7k+bjx
50H1b6j8xuy4aJZPmN0+2jPMjnOy45ke53Qemat8v2i8TjPeaIwxxhhjWkE1
f2FMixw38rodj33f6OcfzLmf+cGljy36TrPX/zuOPOqzI7vc1XP8KH/9/zr9
97/8krt78sUnv/GbJ7x5ZU/++KO7z99hl6n7N9A8HZo3Yb0cWePk0bkxxhhj
jGkLVT9pNFnrHKHnBUQ1PwY6flXOEu1RQf6N6Dzr/Getg8bW5bL1umzdrOp4
VF6I1tdVzKozR6DzhrwQ0XX1qjzap8F6M7I8G9H+ClWdcNbxqDwb0esGtr5+
X1ad8H9/fOU2C9f0Xz+MtmfzrPpk1r+hqk9m1w1UrSfI1jmz9c+sB0NV/6zK
2TpqtL0qZ+u3t/rBnzz2obf01mNH59F14MibofJpsPXkrE9DlbPrM6rqzK+8
+LQzrp4z9Vy1nqPXeXTO5KieHOWonpz1YKD6c1WO6tXZHHkz/vZ9Rx5ww9Oj
n49/3Dls/VOv/uJTo8eZcH7WxuMfPZ6Bt2c9Hmwe/bmwnhD2emP7INjrX+UP
ifWKTD/VPOFmMFCNE7binah2nFmeZ5WXu5p/Q0W0l0NF9DqMWePh7Hhylgc7
2hed5d9A27fi/YgeP4/2dVTzb6i801nj2yqPNDsuHe3fUHmV2XHdrHHXauOl
rGc4y7+Bxj/tGXbecs6OI7F+YDQeOPb4oTHGGGOMyYKt72U9w8a0CPJvoBz5
N1R5NNH+jUWzLr73lFPv7cmRf4PtJ6oG68GwZ8MYY4wxxvSDan12FWh8AN23
s/VybB0dgq27Y30LrOchut5PVa+o+lyivSVZ55M9zyqPhMqTkOVDyPJURHsV
ouvGW3lf7HgyW1+q8nug/UTvP6suV+WpiPZRZPkxouuKq9UJD2p9L+vTiPZg
tF5v3EodclbdMgL5N6p5NqLXMYyur24lZ+u9VeswqurD2bxa3TjyYLDrM7K5
yrPRpV69sfOaucozgOrD2RzVk2vWf+Rz5MFAOfJv/Mb+i1668/tHP//xOdo/
e5yq86Pye7A5e52oPB6q6zzaKzL2/28c9myY6aSaf6Oad5rNVfMLquNkveKq
+azo+S+Vd51FdT6jvRwsWePkKq+FyiMdPZ6fNU6u8ktX81e34rvOGodXeTnQ
eHjrXo6scWx2vFo1js2OD7PjrtX8G9Fejlb8G6rxUo+jOm8hZ8ddx/fW9uvf
QOOExhhjjDFGhcrHa8wwwPo3ovNPXP38Ry7+2Iqw/8d37fyOlbvvd6f/340x
xhhjjBkgUP0JqqtBsOMGrJdDtX4T8jZU8zOovA3RebXzE/1+o8+/qh6YpZqf
gc3Z86N6Xfb7Ldr/kFV3iqhWHxudV/tcVP4N1mvRSh1vlu+C3Q86nmrr7iGf
RjXPBlvHi/wbbH1vK54NlGf5NEY++O1T1j3b//ZsvTGbs/XJrXs2VHXRWXXU
bH01u5/WPRtsfThb743qxtk6cJRH13uzOVsH7rpx55E5qt9mc9ZLwHoSVJ4N
rs4c5ypvxsodnly2etfRz0M4V70um7PnB+Xo/Ku8HyhXeTmi/TCq/wuUj/1/
OnVcH2gqw44Pq7wTKGd9F1nzOCofCOvVj/Zd2L8xPtHzbqr10Vr3TlfLVZ7q
auPwWfuP9nJk+TfY8XzVOH+Wvzp6/Fzlr2bHw6t5OaI9z8jPzHqb2XFj1r+R
NR7Lejmi/Rus9xj5N1Reji71xvGcD2fO+jfGH+/qd7zUGGOMMcaoUHl3jRkG
kI8iy79x7md+cOlji77Td26MMcYYY4wx7DovbN2Oqj6KXb8sq96PBR1PtXXQ
stY1U50fVf0tex2i7dlc5YVA43hs/SG7H+QliPZyqHwI7Ptl1ymL9iSwuepz
V+XR7yt6fbqsPNqPwdblVlsvj/VjtLIuXrQfQ1Vni7wWKM+qy432XbD7R/W6
0XW/KEeovBlsrvJpsDmqQ472WqD6ZJSzdc5s/TNbF53lr8jKo+u0Vestsusw
qnwaqnpvtq47ax3GLvXqfp3n5mg9RHadROTNUOWoDpz1ZqAceR7+9n1HHnDD
06PHXXDO+ijm7nHNQ6ffOPr5W5ezXo6dX5j58XedNfr5ic/R8aDzwJ5nNke+
DtV+0HWFrk+V70WVcx6POOzfMJVB48DsuD07X8DOj7DbV/Ouq+Z9srwW1fwb
WajOj4pq/uph83JE+zdU4+eq8XmVfyN6nJ/NVf4Ndh5B5cdWzQuw26t8Gmic
PHocXuXliPZRq7wcWePPKEfjutH+5CwvB+tDVo3HqsZdPR7rvOU8x4dsjDHG
GGMQbB0sGn8zpkUWn/zGb57w5pU91/Pr/9fpv//ll9zdk7/jyKM+O7LLXX3n
Ki+HMcYYY4wxxkSjqvfI8nKo1juLritDsPWZqvXXVOu7Ra8HpzoPKq8Fqg9U
1Q2q9sPW1yFUHgPVeYiuz4yuS1TVQ0b7B6J9CNXWU4s+TtV6c9F1tlkejGrr
zal8Fyhn62ZVrxu9bl3WOnesvwJtP6jr5UXnbH2vqu4X5ajuNytX1Q+rcpVP
Y1D9Gyo/RvT+Vd6M6HpsNo/2ZqjqtFF+0svnHXzF067rdt5fjrwZqhzVY7M5
W78d7dlgfRooZz0Yi59899suf3r0c0n7OXseWI9HdI6uH5Qj3wW7H5UfZuz9
TD8qf6wx0wnr36jmOR9U/0a0v8L+jcmBPq8ssjwb0fNErefR/g3WsxE9zt/K
cUbPU2TNL2T5N9C8gMq/HT1ur/JvZHk5WP8GO45dzb+RNQ4c7eWwf8O58zw/
M+thZsd1l2z2Rx858Zne30NjjDHGmGGHHR8zZpBA/g3Wy4E8Gyg3xhhjjDHG
mFZQ9ZOiuh22v5itB0Z9+ll1mGg/CNYfovJjqDwVaD/ReZY3I2v9LPR/hFCN
+7H/1yhn/6/R9myeVX/I+hlYXwGqu1PlqjrGrPXOWs+jfReqPKu+VJWr6kvZ
PPp1o9eni/ZmsD4KlLN1s+g4VcfDrpdXrS73gaW3HD/yfFy9LlvHy27PrtPH
rt+n8l2g+uGsHB0nqk9m65+37nxyxmkH9L9uIKpnZnNV/XN0HXW0Z0Pl31j5
sc/t8o3Ne+ucVXXaqI6ardNG3gz7NJwzOaqLVtVLs+seonzFxn7/23tyVHd9
4YEXHLJ89j1g/70+DeQ3YL0EKEf+B5Tv/MLMj7/rrNHP2ThHnopnn7z+M4su
H/3cwOd7fvjINdd8ePR9ui5XHSc6D+z5ZPNoHwjaXnV9jv269bFPw1SGndeI
9mlE+zeGLVd5MKr5N6rBfi4qov0YqnmlVjwYWXkrfuys+axWzkOWl6MVv3e0
T1s1nj9s/g2V15odl472PKvGpVHOjg+z471oXJfN7d9w7lzn30A5Ow7MeZWN
McYYY4YH+zfMMPD1xxd/9j1vG10XstlmO569028//khvzvo33nHkUZ8d2eUu
/78YY4wxxhhjBg5V3QVbx6LqW2frmlBdFvI8qPwYLCrPBspZf0W1danY44z2
M0R7G1T1WgjV/tHxV1ufK/o8q+oA2To6tm6N9QOofhdQrtqP6nWj86zrJKs+
U/W6qutW5Z2Iri+NrlNVeTbYutbodeKy8uj62Kw62+i63Oic9WZEezZYr0VW
zvo62P2r6plVHgxUt5yVs/XSrAcjy6eB6qtRbj+G80q5yrOBvBnseoVsnuXZ
YD0JyMPA+jSiPRgof//969/z1Paj769/3Pn8uxZ95dW3xeXodbN8IOhzYXPW
16Haz9h5Hdhxb/s3TIu04uUYVP8G8lewOdp/K/6NVoj280fP96nmebO8GVnz
Wa17JFqZr8ny3g+bf0M1H6HyhGf5N7K82ShnvdYq/0a075odx0Ye6WjPBju+
rfIwq/wbqnFj+zec188R0f4N/Lr2bxhjjDHGGDO8IJ8GmyP/hjHGGGOMMcaY
8UF9muz67GzdCFsvxHo8WC8H6+uo5uVQ+StaydHnHl2HFl2vxf7fsbmqDk21
zlTWeVbVoalytl8e1ZWx/fisxyP6Osw6/1nvK+s8oOuBzaP9EiqPBPp/Yf+P
VPtH74vdT3SuqkdV1Z2q1o9D9auqHIHqXVWvy3ozUD0tm6N6WtV+2Hrd6Dpe
tr4X1fFm5ciDodoPuz4gqitmc7YOWbVuoCpH9cysN4Oti1bVSyOfhj0bzivl
bP0z8mmw6w+q/BgoP2vj8Yzuf433aaCc9WkgzwPrwWD9GDd86s2v3eaE0fe/
zn+Vs+cZfY7RObquxr4O64P6fI0ZBth5EPs3tO+L9W+wvoto/wabV0Pl2VB5
+Nl5uiw/RnRezZtRbb4sev5Ctf9qHg+VB0N1nqv5NFhvhipXebxVnm2VfyPa
g63Ko8fn2XF7NO4d7dmI9m9Ee5tZPzPybHg82XmdvBpo/Jnfz9jjw8YYY4wx
xpgKqDwbKDfGGGOMMcYYMzlUdRFsHYiqjgXVKaG6KVQnhurTVL4Oluj6OrbO
ja2vi65zY+vT2Lqmah6G6Lyax0BVD5b1utH99aj/XeUBcD5+3sr1pvJXsL/7
0cep8kigXLUf1Tpr1fJWPBgoRz4KlCPY/UTn7Lp1yFMRvZ5dtDejmk8D1etG
56p1+lifhqre+IWLtt/uW2fW8WmgOmRVrvJmsD4N1bqErot2npEjnwbKb9pY
n3xd37nKs8H6NFhvRrRPY+UOTy5bvevo8R7s2WD9CdE+jSWb/dFHTnymNz/v
zPOWrVww+j63Xo6OX5WzXg50/tnPEflV2Fzj60C06/EwZpAYVA9GK3kr/g32
faH9Z8H6N/Z/xefPuObw0fd5Ov9GNW8G68FQ5dW8Ga34zFVe7mrzg9HzyNGe
c1XO+v9V81PR8yysZ0M1PxLt31DNI0T7tNnxfNazgfKscfgsz0a0f0M1ztyl
3jik82HMs+DHpcf2POP9s+PJXG6MMcYYY4yZCo8/uvv8HXbpvb9fNOvie085
9d6+c2OMMcYYY4wx0wOqK2DrHNh6DLbeA9W3oHonVB+F6sRQHRqqc2PzrPo6
1qfB1qeh86/KUR1aVn1RtXV8UP8428+uer9Z/ezR6zGpPl+2Lout70J1ZVle
AnY/Km9JK9db1vFnvV9V/aRqnbJBzdnvE7Q9W+epqhdtZX03tn41ev24aK9F
tTyrzpZdF0/lr0A58ldk5ai+N7p+GOWofpjNs/wYqnpmNu9SrQ7W+aDkyJvx
0Mb64eV958in0a1D/mZPrqln/nHnrI37Gd3fifMsbwbKx/YS8DnrT0A+B9Yj
gfwV83a4ZfVeLx59n/vjztFfenb3z5/Vf472o8oPetNuJ/50h9H3y/Gvy+bc
58LC+z3Q9ux1yHk5jDGVUfkc2Jz1TmSR9X6r+TeyQPN30fOD7LynyrOhmk9E
87kqn4ZqvpL1Y7C5ylOh8iGo5luj/eHRx1/Ng6Gqx2hlXjV63oTdPsuzoZof
ifZvqHza7Dh/tDebHedH4+esl6OafwPlqvFq+5+dT3+O0I1jq8arx/ZCs6j8
G2j82RhjjDHGGNMPyL/B5sYYY4wxxhhjpge2ToDt+1b1U7N1I6geCdVNofox
5K9gfR2oLk6Vs3V0bH0a8mBEr5eEPvfoPn1Ub8P2g6P/F9V6OqqcXScoel0h
dj9oe/b8qz5Hts4KrU+EcrQflLdyXUVfJ628r6zPiz3PKm8G64Vgr3+Uq7w3
0eudZeXs9xKbo3rOrHpR5K9Q5aiOtFquWlcO5agONjqPXreOrZtF26O63Oh1
8dB+UF0uW6+L8uj9V/NgoPphVd6lWv2q80HJUb0xm2f5NMauT8aejcPWP/Xq
Lz51f0+OPBsqn8bOL8z8+LvOGj0uxefPPnn9ZxZdPnr8BufIe8D6EG741Jtf
u80J/Xsz2Jz1aeyzfO6Vcy/q9V1k5a/e78xnvr7r6H6p+Ndlzxubo8+L9aug
64fzdUw/aNzVGFMH5HMYVFTeDFXOwvo3qsHOG66+duf5hyz+Xt/bsx5+NO/J
+jSivRasn1+VIw8Guz3Ko+dJVT5wlbdftf/odQTY84m2V+Xs60afZ5VXn50/
yprvU81PVfOQR3vCWZ+Gaj4i2rPBerazxvOjPdWsZ0Pl3+hSb1zU+WDn0ePe
0b7oscexEbxnQ+WFHns/xhhjjDHGGGOMMcYYY4wx7YLm69l1z9n+VrZPma0n
QfVLqJ4K1Zuh+jR23ShE1rpUrGdD5c1Q9XGr1sdhr+fonK3DYfugo/+vVf3m
qjol9jxE10ep6qDQ/lXXQ/T1o/InRF8/0ddt1vFnrdul2g97/Ufvh/0/Yusn
W8lV9ZysNwPVf6K6zWgfhaouNMtTkZWjulbWm8GuQ8fWzbLrykXX07Jei2hP
RSu564SdO9et6xddb8zmqD4Z5X/7viMPuOHp0euQ45z1aSx+8t1vu/zp0eMx
upz1bCDvAetPQPm8HW5ZvdeL+/c5HPSm3U786Q69HgmUI68Fyre97bpZr72i
N99w6LpPnzpr9P1sOzl6X+z5QR4P9nNBn7vGyxGHalzXGGNaIcuz0Trs7wXr
5UA58myo5gdV/g3WU8HmaF4y+nXZeVK0vcojwc63qvLo1816X62ft+hc5Z9X
edpbma+PnidqZf4lej5FNV/AerlV8wiq8X/Ws4FydvycHVfvUm9c1Plw5irP
hmo8nB3HRr5oNI6d5d8YOzfGGGOMMcYYY4wxxhhjjGkXdl3v6HXSVX3EqD6E
9XKgHNWbofo0FraODuXoONn6MbbuC53/rHVqovvKEeg6Rx4GdntVrvI5sN4J
Nme/r1CfNaoXQvtB9UjRx8nm7OuqctX1Fn2dV8tV5zP6/7ra+cmqM2S/B9j9
Ox8/R/WZWV4L1heh8ktEv64qR3WqWTlbH6vyWqjWm2Nztg5W5aM46eXzDr7i
6XbzLvXqQp077yePXqePrR9mPRsXHnjBIctn39OTj72uH5+zdciofhh5NpAH
A+V7fvjINdd8ePR4DM6RT0Pl2TjvzPOWrVwwevwG58ingXLkeUA58kug/Iff
2+n6x27o9VSMzp+7a9/5dx64ofOGeU+vX7XoybL5v62+aN/VyzZ0tvrnrR88
6g2jnyf6f7+TPZ+s34P1cqDrauzrMw77N4wxxvQDOx+n8m+ovP1Z/g00/4hy
5PlX5dGvq/JmoHlV5+PnKi8Em2cdv2o+PXr/0es1sNtH17dEz5epvBkoj/aW
R3u8VZ4NlKN5BJV/I8uzYf+G82HKs8bPWY80O76tGveOzY0xxhhjjDHGGGOM
McYYY+qD5qNRXyGaH2fn69l5f7a/FfUXs14OVAeF6qnYdZdYVHVxyB/C1pup
PBsqP4Zq/Rq0/+j1aFT1MKqc7YNWvS7rl1Ctj6Pq11at44O+n6P7x9FxRtdZ
qT539jyz54HdXvV5scfD+ljQ91LW/y/ryWG3z6onjK4/zDrO6Jz9nlTVVaLt
kbchK2f9Ell59Lpvqlzlx4iuX2XrWu2XcO58cHPVunusTwPVCbP1w2xdcfS6
firPhsqngbwZn3/Xoq+8+rapezaQDwHlyKuAcuTTQN6GDYeu+/Sps3p9ESgf
7ZdAngrktdjw1e8tX752fefd73hkq6NHfi2/cP76xees7xy73W2vX33YpueG
1Z955R6n7r2+c/b3v7zPsVdNPoevK8qzPR7o80U+lrGvt+nH/g1jjDH9gDwb
aJ4O/Y4s+uhvfH6Xbfr3ciD/xm6vW3vlT//nIz056wlh5xlZzwbr+Y/Oke8C
zXuy3gzWp6HyLajmSVHOehtUx5/1frPOTyvngV23IjpXzeOrcpU3I7quQDVv
Gz0vz877sDk7rxHt38jybLD+bZWXu0u9cVfng52zno2bNo57X9eTs54N5J3O
8m+o8rl7XPPQ6TeOfl5BuTHGGBWszw3lxkTA1rXSdcvGGGOMMcYYY4wxwaB5
ZHZ9bdW8uarPHdUboLoLVDeC6l5Q3VQWWf4NdB7YeiFV3U50vVC0fyO6H5zt
94/+v662rk10ntUfXe08qOqdnHdhvQGqeY1q3hv2dVnfRdb3jOpzz6pvjL5v
RPtH562a52HY8uj12qLzrDrVLr31ga5Tde68/Zyt71XV/arW41PVCSOfBspV
db+sZ2Pxk+9+2+VPjx534f0byJvB+jRUng3kQ2A9G8i3MFXPBvJFoJz1VLDe
jEcPO3zJwQvWde795OknHPeXayfMVb6OaL8H8nX86nNB/g30ObLXw9jXlTHG
GNMWrH8D+TRWX7vz/EMWf68nR74OlLNeDpV/A3k2UI7mH1XeDNaPkeXTUM2r
susOoBzNk0avj8DO26relyqPPg9Z70uVV/NdVMuz1umI9qhn+TRU887Rng2V
f4Odv8ia13DuXJGjcXVVbv/GdOTGGDM8oDqZrPtMlJtc2M+LvX5UdcWq/g52
vUj0HG2MMcYYY4wxxhgTDVqvGeVs35xq/JAd/0HjOWh8BtVpsHVEaN2ZaFBd
3Gf/fuGLnl44df8Guy4VW4emWq8nen0cVLeDUNXJoOsZ9R2jvuysXFXHklUP
Ez2vwfrG2e9blLPHk9VPzf5OqeqL2NdFeXQ/OPpcWG8D+j5h82j/TLXvN9W6
V+z/L3t/xZ7P6HW+VPuv9n2i+t7I+t7Lel/nPnzymuVL6+fsOm5d6tUlOnfu
PC5H9bqoLnfFRr/E7dOeo/peVd2vqh6YWy+P92aofBrvv3/9e57avtebgXKV
Z+O8M89btnLB6PEV3rOxz/K5V869qNengfJtb7tu1muv6PUnoHy0twF5M5D/
AXokLpy/fvE56zvHbnfb61cfNrGP4onjvnL00d9d17nskvPnrJm5dsKc9Ww8
+nsbHtnrdes66w84ceFT/zqNOTge9v2i8zZZLwe6Hsb2bxhjjDGDjcrLgfL9
X/H5M645vLefjfVyoONB/g12PhF5NpA3g/VpoPlHdl4yOlf5ItA8pmo+tFqO
5vGjt0fzwtHHH33eVMej8mZkeS2ic+S9z8qrreuh8t6r5rmq+cnR9uw8EevN
QPMdqvkRz6c4V+QqrzWbI88GGodH/g003o5y5Kmu5t9gj2fs92WMMe2SVTdl
/4YWVd1mdB2yqr5a5Tlk10dT+Tfs5TDGGGOMMcYYY4yWuHkuNN+K+tfQ/C87
v4zGhdB8PRrPQeM2rYP8Gwi0XhWqo2Pr5di6OJV/I7rOh/VssHUsrGejmh9b
tW5LtTyr3xl936L9sP3FWevjdKlTvxFd/8PWL6HPi/V+sP+n7LwMW1fGXv/s
/QN7fth6tmrfG+z5aSVH7wv9H6H/ly5x972qesVWvj/Z91XtOLOOx7lz57g+
lt0PWx+LPBhoe9X6d9H1t2zOejNQfS/K2brclTs8uWz1rqP7/Pg82qeh8mYs
2eyPPnLiM/3nyKeB8oPetNuJP92hf5/G2D6EH3c2HLru06fO6vUqhPk0QI68
EChXeTMe2OlvdtzxWyOdV778Dy464cCRCfO7N79lrzmXrO3c+P0Zlxz488nn
D275W+99/piRzl4/2P9rI/8y8fbscbK+DvS5oM+9C75+xvZyGGOMMcPJnkcf
9Lcv+u3R/jjswWBz1uOBcnScaD4RzRuqfP6n7rtiy499otdrwebs/KMqZz0b
qnlPNkfeCbavIdqr0HqOzjN7/lvP2b4bdp0LlCNPRfT+WQ+GKld5M9hc1c+l
Wqcjqy6C9W+ofOzV/BvOnStylX8D+TTGzll04/9Zng32ddl87PkIY4ypT/S6
Rap1rNjj6YJ+f6vR+zvC1tOq6gCznhdQHr0uKuvfQM+h6HlZ5cM0xhhjjDHG
GGOMGZ9681+jE7ZfEo2DIVgvBzv+M6iwng2VfwOtA8XWlbF1O6j+BNbDsID9
s+u8sOu2qDwY0evdq3LWL6GqG1HtX1X30sX9yMOWq/xX0Xm0D4HNVf93bM4e
J5uzx6Oqr2O/h1Hu+j3nzp07n95c5cFg96/yZrC+CzZn17Mbfz/9ezBY30X0
+ndz97jmodNvHN2Hx+c7vzDz4+86a3TfHs6RT4P1bFTzaZx35nnLVi4YPS7C
ezaO/tKzu3/+rN4ceTbG9h7079mgfRoXzl+/+Jz1nWO3u+31qw/bNB6DPA8o
R34M1puBvBas72LGzJ9d+9Frnur84kUPj2y//7rmcnR+EMhzghjfy2GMMcaY
qXD74Xv/0dLXj74PxjnyZuz2urVX/vR/PtKTI/8G2n7f173s/CUzev3/aJ4R
zRsizwaaN2Rz1oPB5mge8/onbpq7dqveeUw2Z/0Y0d4Gtt9B5TFg/QaqnJ1H
ZvNq56Ha+c/yV6heF9WZsHm0H4OtW2DrGdhctc4I2l7V1xadq/wb7Hyc5+mc
V8rR/AKaF+B8Gjgf25uhAs8LRPsusrwc6P1yHhJjjImDvZ9kPQbovlflqWPr
ilX+kGhU9Xts3Zpqna9q6xiy65+y163Kv6EaJzHGGGOMMcYYY4zpUm/+Kzaf
OqrxT5SbLqiOjgXViaHxNzRex44/s+OEqnoVdj0XlQ9Z1V+v8ktU81Q4d+7c
uXPnzp07d56Rq/wVWbmq3hV5LdD6cSi/8MALDlk++56+c3YdOpQjP4aq3hX5
Llbu8OSy1buOXgebz1V+DNabseeHj1xzzYdH9+3xOevZQN4MlR/joDftduJP
d+j1Y7D5q/c785mv79rr00D5aJ8G8iRAnwbIkZ/h0cMOX3LwgnWdez95+gnH
/aXem8H6MT705j0PWPTtJzt7venSvR5dOHG++J3HrFjy0JrOiYf8xacu/c6m
fOQPvzjnG2ue6Cydd+B187Zbn56j40TvK9q/YYwxxpg4WP/GZ/9+4YueXtjr
x0Dbn/YXH7zxI783+nkAezmQ3wO9LvL5n7rvii0/9on+vRnId8Fur8qreTOi
fReyPohgfwLrQ2D7ROD6HUnHr/I5tOKFcN6F9WNk9fexfX/V+tRUHgx23e2s
Oo1q6w44H44czYNE+zdU8w6q+YJq3gw2R+8L+TfY+Zqxc2NMi1Tznqn8G9Ge
jWr37WzO3m+j+9UuvfcVqvXyor0c0c8dKv8Gu85plieT9XgYY4wxxhhjjDFm
2Kg3LzbdORoHQ+NRaByJzU0uqM4Hjfux/grWr6Ja/4Udx86qA0HjzNF1F673
cO7cuXPnzp07dz5Wjuowqx0P8lSgelGUo7pQVa6pe4zPUd2mKlfVnar8GMiD
wfoxkO8C5e+/f/17ntq+11+hylk/Bpsjn8Z5Z563bOWC0ets896MfZbPvXLu
RVPPt73tulmvvaLXm8Hmoz0bz9217/w7D9zQecO8p9evWtSHZ+PC+esXn7O+
c+x2t71+9WGb6pKeOO4rRx/93XWdyy45f86amb/m0wj2bCCfBvJOsN6M3U66
7+EHn1vdefSC39xs/yP0+de+9Pa128x8vHPoE1/96wcfmXy+4HNb//FPtl7d
ecXNj8/eZvHEr2uMMcYYgzwYKN/3dS87f8mM3hx5NpCvA+3ntOd+9LZVz4z2
5W222Ytn3nn2+pHR9+XYp6HybCBvRjWfxpYL3nvNfrv077Vgt2dz1NfQil+C
nc9tJWf7sNj5a7aPDG2vOn72ONnjV51/1XGiXNUHl5Wr1hnJqotAOdvHx+6H
rZdwfYXzFnKVh5ydT1F5vFXzDirPRlaO3hc6D6y3ZHz/Sa9fBV0PY18/xpjp
ROXNYOu9Wc8Gu55jtDdD9brRzxfsfT66D1fdr7L3w+j+nPVdsF4R1XMEOk7W
G4Oef+nxHxWkl8P+DWOMMcYYY4wxZtioN/+Vk7fOsL3f4YH1aUTXk0Svk+J6
DOfOnTt37ty58zZzdh0x1f7ZOslW8qz11FTrrLHrr7HrsrHroKn2z9aFqvwY
bI78GGy+54ePXHPNh0f3seGc9WCwfgzku2Bz5MeYt8Mtq/d6ca8fA+XIm8Hm
r97vzGe+vmuv7wLlrDdjw6HrPn3qrNH9fP37NFSejdWfeeUep+69vnP297+8
z7FXbcpVPo27N79lrzmXrO3c+P0Zlxz48035h9685wGLvv1kZ683XbrXowv1
Pg3kr2Bz5MeYcdW8P3/j7j/qLHzpwruX7LxpvGTRhYddvOKFxzpH/O7BJ93+
D5PP0f7R8RhjjDHGqLj98L3/aOnrRz+H8Pmj2/zsuANe6PVyfPwP3znv/qNG
Pw/8v/u9D377lHXPjr6//3/3n0tvOX7k+f79G8inofJjqLwZ1fLodUtVPg3W
s1FtHWG2n0u1n+jjZ9ebYPeD5tnZPPr9qo5T1e9WLWf7K6PrH6LzLvXmC5w7
j8jZeSiVzxzNy7CeDdW8CcpVvovoeQ20f5Szx4/OT45/w14OY6YT9j6Q9R5k
+Teq+TpUz2vsfT66b2e9c13i7ltU/g32uYM9HtbLgf4vWM8GGp8J92yQsP4N
ezmMMcYYY4wxxpjWqTcvVitvBZ8fMz7RfmN2fRbXgTh37rxqztbboP2w20cf
J1v/g7ZX9cs7dz7Muarer5rnoZVc5Z3IylEdIFrPi63nZHP0uqo6z+i6TdXr
7vzCzI+/66zR6zPrfBeq/Nknr//MostH959hbwbrx2BzlTeDzVmfhsqzwfo0
kB+jX2/Gv62+aN/VyzZ0tvrnrR886g19+DHIHHkzoE/jsMOXHLxgXefeT55+
wnF/uXbCHHk2kE9jxsyfXfvRa57q/OJFD49sv/+mui3k2UA58myw3gzkr2Bz
1pvxv299z4nz73yk87Jzl579j5dPPkf7N8YYY4ypxmf/fuGLnl7Y69nY93Uv
O3/JjN78tOd+9LZVz4x+/tlss9fcv/KfNqzq9XL86V/d9sxHT+7fv/HWGTeu
PP6sOP8G8mwMm3+D9WOweVZfEru9ar1g1ueg8lpk+RxQfxC7H3adC9XrVvNU
tH78rGeDrX9g6yJU+/H6Js4HMW9lvkzlM1f5wKPnX7Jy1XlA81lofo2tr7B/
w5h8WI8Bm6v8G6rnrCxfour5TuVL0dYn14dd91Dl30CfI/JsoHEYlX81y3dh
z4YxxhhjjDHGGDNs1JtHq5W3Qlb/oGmLav9fzp33l6v8A2hdeFWfL1rnAuVZ
/bxZ56GVfmpUX8HmqvOftT4Ou/7L5PrK+69LyfKBtOIhQcfJ/j+i65PNVd+T
0d/Dqv2rzhv7PYN8CChXeRiivQ3s9xK7f1TH2EquWheMredkXxd5KpAXgvVI
ROfIU/H++9e/56nte/0SKGc9Fez+2de94VNvfu02J/R6KlCOvBbnnXnespUL
ftR3jrwWR3/p2d0/f9b05/ssn3vl3It6vRlsvu1t18167RW9Po3ROfJjPHfX
vvPvPHBD5w3znl6/atHEOfRmXDh//eJz1neO3e62168+bGI/xhPHfeXoo7+7
rnPZJefPWTNz7YQ59Gn83oZH9nrdus76A05c+NS/TuzTUHk2Fr/zmBVLHlrT
OfGQv/jUpd+Z2Kex20n3Pfzgc6s7j17wm5vtf8TkfRqz77js5/vvs6pz895H
vOLEYzbl77xxwe9ssfcPO3uu+tRf7b1Un+/80otPXfOW73XWvf3uL25ztT5H
r2uMMcYYU42P/+E7591/VK83A3k2kJfj0W1+dtwBL/TmyMvxwNJbjh95vtfL
cf0TN81du1Wvf4P1bFTzY0TnaP1Q1E+B1kVlPRuoH4TNWf+Gqt+K3U+09wD1
nUXnrFeBzdn+L1WuOn6/3y6q9aPZ3B4M5855Lz1bB6KaB0TzdKq6AtW8FZp/
UfnD2fkalKPXVeUqTzs6/6z3nq1/4K5bFWwdrGr71utvTesgbwCbo/tG9r6X
9XVEezxUXkeVZwPdz7MePO19+PQzvj8kbv/sdY6uBxow/oPGi+A4UjAyD60x
xhhjjDHGGGMGlHrzdDl5K+j61jWef/742fmp2OMZVKr9fzlvLVf1obP1Eiov
AesriO5fVnkS2L5aNlcdZ/T7jc7Zvmb2c2HfL6onYeth2LoU1fti++tRjr4H
2LqpyX3PTN0nE+2lyfpeyvI8sH4G1X5UfoloHwKbR69XxdYBst977P7ZXOV5
YPePvBAoV71fNlf5KKJz1jvB+iiQd4LdP8rR/tn8oDftduJPd+j1S6jyV+93
5jNf37XXU5GVI2/GhkPXffrUWaP753D+w+/tdP1jN2zKkWdD5c2AHoxgPwa7
H+TTQPmH3rznAYu+/WRnrzddutejC9dNmCPPBvJpsJ6NRRcedvGKFx7rHPG7
B590+z9M7Kn437e+58T5dz7Sedm5S8/+x8s35fu992fnvv/8Bzp3jPz7ZfNv
njjv7ufOzqKDDr/90Acnn7Ova4wxxhjTClvMnH3Oq7bv9Vccdus3Hzvh9NH3
95tt9t8fX7nNwjWjnwOxfwN5PJCXY+SD3z5l3bOjn6+wlwPlWy547zX77TL1
en60H5QjHwjaHp1/9vjZPgvk32BzlWeD9W9ErxccnavWI249V3keVLmqfzDr
PLD9dFl5l3rz9c6dV8hz6tDy1vVQzbey832qeoBBnYdifR3o/LPz3bH1Ayrq
fW+gfGz/uTHjw3oY2Ps91lfAwvo6WB9CtH9D5VFUPS90ie4L6H//7HU4ueeU
qcN6GlXYU2GMMcYYY4wxxpjhpN74PJe3jm7dbdV63GPPS+LjR/OYquPnjqd1
qv1/1fM/DFuOzhvyXWj+v/jvE1Vfs2q9eHa+Pnr9EdU68mx9hap/OXrdE/b8
qN6v6nNhjxP1Navy6L5ydN6ifQKsPwTth/2+UuXV/AzR51+1fZangv2+Unkk
VP+/yFfAfp+ofAjs9uh40PZsjnwLKEf+BNXxsOcnOkfn4egvPbv758/q9T+g
HPki2O1Vx4PysesDcY48Far9oxx5J6Lzfv0Vqhx5MJ67a9/5dx64ofOGeU+v
X7VInyOfxhPHfeXoo7+7rnPZJefPWTNz8t4MlD+45W+99/ljRjp7/WD/r438
y8S+ixkzf3btR695qvOLFz08sv3+6ya9PcqRN2PxO49ZseShNZ0TD/mLT136
nU35bifd9/CDz63uPHrBb262/xHrJ8y/9qW3r91m5uOdQ5/46l8/+MjE+ew7
Lvv5/vus6ty89xGvOPGYyXs2dn7pxaeuecv3OuvefvcXt7l6Yq/FNRv3f2/n
0gt2vXbVHZvyL27c/tbO0T895YHrfjj5vOvf+EZn9sWXrNpt7cTbG2OMMca0
AvIhbP5n/7HTeSt6vQooRz4H5M1Avg6UIy/Hi2feefb6kdHPn/h1H1h6y/Ej
z/f2m711xo0rjz+r19eBvBkoR/thc5V/g14nFPg62Jy9flDOejlQrvJysOsp
q/qkWA8D64VQeSRYTwXqb1Ktv8zmWd4J1brh07M+tXPnzsfKUX2IKkd1JmyO
vASqepVo375qvlJVT4Jy1qeB8uj6BPZ42HoPtj4BfY7oOuHWARlUXPdrchn/
PpPdfupeBXSfjGD9h6yXI9oDqXp+ZJ+bpgd//xhjDAKN67Lj2MYYY4wxxhhj
fp1q84+tU2+dcdYDz3k8VPmwwa8rgeav2fnx6Pl0NlfVA6jqB1gPBnveon0X
bH80ylV1Baq+Y9W8P9v/q1oPne3zVe0H9bdm9f+y71e1HzZn+7hV692zfeKq
/m5VX7/q/5pd34et21H5GVSemejvT1XeSj0Y651gt1d9L7H/76rvpWifQLQ/
4dX7nfnM13edun8A7Yd9X6y3QXUe0OtGnzdVHv05Ir+EKp+qd0KVb/jq95Yv
X7u+8+53PLLV0SMT59BTQe5HlgM/xurPvHKPU/de3zn7+1/e59irJp9Dzwbw
Zjyw09/suOO3RjqvfPkfXHTCgRN7M1COfBeqHHkzRv7wi3O+seaJztJ5B143
b7v1E+YLPrf1H/9k69WdV9z8+OxtFk+cz7hq3p+/cfcfdRa+dOHdS3beVE/H
+jRQ3vVXPNJ52blLz/7Hyyf2bHS3v7Oz6KDDbz/0wX7zXj/Gbrf/Mr+8s/Oc
+3/yd89G9xsZY4wxxrSHat1VtD3yeyCPxPVP3DR37Va9Poo//avbnvnoyb3e
DOTZQF4O5PE4dd8VW37sE737YT0eKEfv67Bbv/nYCaePfu7F2yMvB6qjVnk5
VB6PrTufnHHaAb2eDZQjLwe6rqK9HCqfBptH+zeyvBMqn0aXqT/XZe3ffgzn
zuvlqM5Hlavqdtj9sHVfrE8D1bewPo1qng3V/Cnrz8/KVXU7Y+dmeqj3vdpv
juZNTGXY+ZL68y7s81q0T4PNWV9fl6zzX+d6GP/8GGNMIKT3GHmw0Xg76+VA
+zHGGGOMMcaYyVFn3G98qnk2WjlvCDTfp9oPztn5SlW/P9qe9XuMPT/LguZV
q8F7GNjrgf182f2rcvY4VetcRP9/oRzN77P93Wy/tspHoVp3XrUfdv101K/K
9rG2su4529/K9iO3kqP3y27Pnh/284ruf1f1ibP+EHb/aD/o+Nm6IPT9w34f
sv4HlZ9BtR9Vznoe2Dzab6DyIbTyezHaD8D246P9sDl6XdoPAPr3Uc6+rur9
RufIz8C+X/b8q/YfnbPXCZuz/odhyx897PAlBy9Y17n3k6efcNxf9rE98GOw
+YNb/tZ7nz9mpLPXD/b/2si/bOrHmjHzZ9d+9JqnOr940cMj2++/bsKc9V3s
dtJ9Dz/43OrOoxf85mb7H6HPv/alt6/dZubjnUOf+OpfP/jI5HPkzWB9Gu+8
ccHvbLH3Dzt7rvrUX+39a/V6yJuB8ms27v/ezqUX7Hrtqjsm9ml88b0/O/f9
59/aOfqnpzxw3Q+zfBp16v6MMcYYY6Yb1O/P9nGgfn/kK9h2iy984NajevtQ
UF3xW2fcuPL4s/r3WiCfxj/89K7/9vE/7fV1oFzl8UBeEeTxQO8LnQeUs3XX
qjpt1teBctbLgXJ0vSEvh6pPSuXrQP9fbM6uH63yaXSp0+/p3Lnz4cvvufCX
9UtLO6NzjR8DUW0dJZ1ng63PQXU1bJ5Vb6Oqw8laryR6XZWxc9MW9b63nU8m
Z6l2PHGonuPYHI23sOMwbG6/hDHGTA/s+CTrK2a9HGg81p4NY4wxxhhjzPTQ
+nhmu+Of0wP252d5DFQ5el/segGsb4Gdh23Ds4HA70u1zgLaHu0fzSOrctYv
gY6TPT/s/DjK2ferWs+C7adWrXePPAPV1k/vd11ydj1xtq+T3U/aOuOi9dBV
67ZH9wWz75c9zuh17VHeBfdlo/8LNlf5XlTfG+g4WU+IKo/2ObBeoKzv7X6/
h9n/I7SfiV6Xzaf6e6H63pN9zwM/ANsXD/vc0fZsTvbRP7DT3+y447dGOq98
+R9cdMKBIxPm0cePfAsoZ70NrM8BbU97D8jzkOVnUB1/9HWYlbPHjzwV1fK7
N79lrzmXrO3c+P0Zlxz484l9GmgdNJVPY8Hntv7jn2y9uvOKmx+fvc3iiX0X
M66a9+dv3P1HnYUvXXj3kp03TJizHgzWp4G8GWyOfBr7bfRjPNC5Y+TfL5t/
88Q569nobv+NzuyLL1m129pqfVrGGGOMMcNO3P0W6gdhfR1sfTLySFz/xE1z
127V669AOfJdoO1VPg32dbeYOfucV23fv08DbY/qtNmc9XKgzxd5OVD+4vte
etBXH+7fy7HurefceNPyOP+Gyu/B+jdUfVuTW0/ZuXPnzrEHQ5XftNE7cV1P
jjwbyFMxth9DBfZgsL4OzTpKqvou3qfB1hFFezbY9SCivRnsOguq19Xkpi3q
/V44bykfPNDzF+vTYJ/L2Ocveza6jO+BNMaYONB4I8qRB5j1A6NxSzTOicZL
4bi6McYYY4wxZshoZbyxleNsHd5Hocqj5xlVOZqvzDqesXMEOv4s8HwuOw/L
9hGz87Ps67LrILDz1OzxsP3arO8C5WzfdL99wWwfLtsfSq87D7Zn+0zZflKU
V+uLTOvHzOqzFn1erfRlZ51n+v9d1O9P96GLfALZ3oYqPodoz4Pqe3hQc9n3
MPm9wb4u6ltH/enROepzV22vytF5QznrDcjKka+g2nFm5ex1gnwOqv8L1f6z
3pfqdVv3Y6C865F4pPOyc5ee/Y+XT5wjDwa7HzZnfRr2bBhjjDHGDDPV5q/7
93igfhbUR8PWM6O6aNb/gHK0H3bdQ5Sz+1ett8geJ3s86H2hdSfR+UefO7pO
kGdD5etAfVtsn5eqn2v8/qY63w/OnTuPzx/a6HNY3uk3Rx4MLo+G91SwOdq/
Ko9dR0lX58auW8Sum8Oup6PyaUSvK6HKNXVTZrAZ1Lpo52yO7v/Rczd6TkGw
z91ZqHwaXfof35jcc9mg4nk+Y0x9WI8u+h1B3/Pod4H9/TXGGGOMMcYYLa3U
c7sevQs/36fyY7Dzg8jDz27P5qp5SZSrjpM9Pygfu283i14/A9uH+6v9THdf
8K9eF/UpH/Sm3U786Q69Pgo2R/6KqfZHs/th+53Z9c1V/baqnO0zVfXfsX15
WTnbD8juhz2erD7rQe0Pjc7Z/mh2HXn0vaHqH1d5UdDxIF8B+v5UeX7Q/qt5
IVQ+B1XfOvt93srvQrXfI/R7gXLUh45y9PsV3eeuylG/PNqefb9sjj7H6NdV
5ez9CXt9qvYf7W1Q5ez1zO4/6/1G7x/9X7N+DNZrsfNLLz51zVu+11n39ru/
uM3VE+cqf8U1G4//3s6lF+x67ao7Jn5dtL0qRz4NlWdjt9t/mV/e2XnO/T/5
u2ez+rSMMcYYY4yGOn1AWTmql0Y562Fg/QzIC6HK0fqJyF+BfBf0eoukZ4P1
n6D3hXLU/8X6OlDOXg9sfX6X/vvp0PbOnTsfvvyeC3/peVjaGZ0jz8ZNa1at
PHnVdT058mys2OiFuL0nP2Djfu7oyS888IJDls++p8+cBfsrkKcC5azvQvW6
1bwZbP0bqkN7//3r3/PU9r3eDNanEb1OEMpRfRS7vSpnj3/s3Aw2qnH2er9r
tfJopu7ZYH2A7PMs699Az2sI9DwYzfT4DIcNnx9jTH1Y/9L05MYYY4wxxhiT
RevPL60cJ2Jw5wGzcnaeEW0ffZya9Qumnw0Xzl+/+Jz1nWO3u+31qw+buF8Y
9QXT/cKgP5fN0esiHwXyV7C5yncBzxvZv4z6x1F/Pdt3HN1vq9oP2w+L+uCi
c7afju3LY9ezRjnbb4jy6H7SYctVfaZsv3N0X7Oq31nlT0Dfn9E564vI2r/q
PKt+X1T941k+B9X3Lfo+R/3gqtdl+83Z7aP71tl+c1XfOvt+VedNtZ+sXHXd
sv+Pqv8jtB82V/2/qI5H9f2gylX3w2g/KGd9F6xfQuuj6H971mvB5tH7/68M
Wx2rMcYYY8ywU+3+zzm7TiLrD2H7pFDOejmQ3wPtH/kuUP8X6iND26Nc5V1B
n0vNen7nzp23nCOfhsqzgXwarGeju//7+s6R14L1YyCvBcpV3gx2nSm2jg7l
0XV0XH0XX8+G8vPOPG/ZygU/6smRZ4NdVygr32f53CvnXhTn6xh7/2awaWW8
vt7vqSZX0f9zIvL7sf4N1kOo8m8gz0a0fwM9l2mf14YN9jz4vBljqqH6HvPv
hTHGGGOMMWbY8PNOLvx8H+vDV/nzkU8ezfeh+UFVrvHe8zm7jsDYx18HtL48
8jlEex5UOXv8KEe+C5Sj86nqX1b5MVT9hqq+16z1lNn+MlWO1llmc1X/Gtpe
dZ5Rv2GWz0TlOcnKq/VBZ/VNR/sKor0Nqj5x1XFGn8/o/3f0PVPt/5f9vWM9
D63n1X5//ysTzx+qfq/Zfvms86963ej3xXpRVNsP6v+v6nsv6/ywrxvtqYh+
XojO/yv6us5WjnNquTHGGGOMiUV3P4f6edk+XzZfsbEP9/a+c7Qf9L5azVEf
FruuMeq3YvuqWJ8G6hdTrTuM9pOVs8fv3Lnzevk9F/7y92Vpz+8LytnfTTZn
fx9ZnwbyY7CeCpXvAnktsnJ2/anodaxYnwZar4pdB4r1bLD1ZqxnY9vbrpv1
2iumnv/weztd/9gNa/rOVa8b6wMxg8GgjtfX+90fO48DeSHQcx/KWW+hysuB
8mgm59lgqfb/YowxZnqof/9gjDHGGGOMMbn4Oagmunk6lCP/fLT3Hs2voeNB
2284dN2nT53V/zygKkfHU93Dj9ajZ3NV37FqP2yfctb69ar9sH4Mdr1mtk9z
sPqhnE81j+5HVvU/VutnrHbe2P5rdn32rD5i9niq9VOj44nuL1b1I1f7P612
nP+V/O9z584r59V+r6OPP+s8oO899vtQtR/V/lGOzrNz564rMcYYY4wZVHDf
LurPRevUs+vFoz5TtN66Zr0A3JeKjrPr97ivJ0f90ZuNyfTnbF8S8mOgXHWc
zoc7Rx6DrONx3s1Vnwvrr3ho4/ft8r5z9nXZ/Ud7pdD2yJvB5uj3i/0dZz0V
7P2AynehypHvAuXIa4G2Z9erQjm6X0I58mmg+yX2vgttj3KVZyOrXo7N0XHG
5mY4qXdf0UaeRdxzH3qOY/2NxhhjTLv4fsMYY4wxxhhjzDAz/fNx/7b6on1X
L9vQ2eqft37wqDc8Kc+fu2vf+XceuKHzhnlPr1+1aFO+4avfW7587frOu9/x
yFZHj+jz1Z955R6n7r2+c/b3v7zPsVc9NWGO9oPO2/h5HNE+DZX/QeWLQDm7
/jLKVf3a0fuZXD+1+86cO3fu3Llz586dO3fu3Lnz+NwYY4wxxrQN31c7dp8p
3v/oeV40r/rEcV85+ujvrutcdsn5c9bMXPuf+aOHHb7k4AXrOvd+8vQTjvvL
tRNuP9G8J5p3Rv226Pwctv6pV3/xqft7ctQ3bS+B80HKka8GXf8qD8Og5uz5
QXm0pwJ97qx3QuXBiM5ZD4YqR78vyLPxt+878oAbnn6oJ2c9G6w3g82RvwL5
KJDXgvVpsK+rytF9BevTQDla9yrav4Hq+th6v6l6NqLr/dgc3X+i7VXv1wwz
9e5nauXRTP/7Ql6O4aSV68TUxNfP9FDtd8GfY1u0fp34ejPGGGOMMcYYEwH2
afQ7rwR9FxfOX7/4nPWdY7e77fWrD5vYR4HqtdjtUT3Yo7+34ZG9Xreus/6A
Exc+9a/5Oft+0fmMZreT7nv4wedWdx694Dc32/+ITT6NBZ/b+o9/svXqzitu
fnz2Nosn9m8gzwbyWiCPBOuFiM7ZdZb/K9XGq5w7d+7cuXPnzp07d+7cuXPn
9XNjjDHGGGPGBvUhovnTuze/Za85l6zt3Pj9GZcc+POR/8yRhx/NG6J8xsyf
XfvRa57q/OJFD49sv/+6/8zRfGiXH3f2WT73yrkX9faTov5W1FeL+ohRvzPq
v2b74lds7Ne+vSdHfeVoe5Szx9OKb4H1DLDbq3wL6HVZPwa63lBfP/LSoO3H
v557/QOstwG9383GRJez/gqUs/93qv9TtP2FB15wyPLZ9/T9uaDtVXn067Ie
DPb/hc3R/xf6vdj5hZkff9dZj/bkyDvBei3Q9myOfBQoV/kuWA+Gyo8R7dNQ
eTaQNwPd/6CcXVerX+8EqgNkc3RfytYZwpxcV4s9fmPiiL9fquUhVNH68VfD
59NEUG2coRWqnTd/XoNNtc/d14MxxhhjjDHGmLagPRtg3grVTUE/BunNeGCn
v9lxx2+NdF758j+46IQDN9WDPbjlb733+WNGOnv9YP+vjfzLphzVj2Xl6PjR
+42GraNTsd9Gr8UDnTtG/v2y+TdP3ndhD4bzYcr/4eA5v9hxpPd6HtS8S53z
79y5c+fOnf86/l1z7ty5c+dxuTHGGDOMoP7HYeNX9wej/xozPux85eJ3HrNi
yUNrOice8hefuvQ7m/wY0Kdx1bw/f+PuP+osfOnCu5fsvGncA3n4Z99x2c/3
32dV5+a9j3jFicdsypHnH/k60LoG4/dL8uu8o35Y1LfL9ueiHO0f9VOjvu+V
Ozy5bPWuP+jJUf/4WRs9AN/tyVX96eh4UI7eF8rR67J996rzgProUR862/eN
+rjR9qhfHh0nel/Ik4A8EirPCevTGN8f0nv8WTm63tj9IB8F2r8qZ/+P2Bxd
hyhnv2fYHP2/oP8v1i+h2g/K0fcM66NQeTPQ/lGOvBbVctazgbwZqnz0/Q+q
A0Q567VQ5bI6Q5Cj/Y/vhTNmOuF9buz9A/Jixfr6VFQ7nlbw/JaZCtXmTZ0P
dm60VPt8fT0YY4wxxhhjjBlO2HkxBJr/Qp4Ktk4M5cg7ocrR66L6MTZvna43
487OooMOv/3QByf2b9inMdz5TZ/9jW23+vnUfQ4nvvxLI3v8oP989gNPPrLf
3f1vP/OC373rkBv7z3/8odOu/8iVcfmtb7jr/z9pSf/5F9fs+KWF501/jo4f
nTf2c6nmFUHHn5Wzx4/+H7vU+d6IzqtdV87Hz9F1q8q71Lk+s/Ksz1f1+87+
jqt+39n9Z33/V/t/VO2/S53/I+fOnTs3xhhjhhH3PRnTP6r50K996e1rt5n5
eOfQJ7761w8+silH3ox33rjgd7bY+4edPVd96q/2Xjrak98734dy5OdH+0fH
yc7PsvO27HoKKEf+ELSeO+qH7YK9Ivssn3vl3It6+3xRXzDbR8zm6HhQv7Bq
e/S+kKeC9WCg/W9723WzXnvFpuOEfcfgc0fXCaqjQPv51fEgzwz6vJAnBHlO
UP8m8nKocpXvAvkcor00Km8MytH+Wb8N8k6gnN2/ysODcuQvQjnyYKD/C9Yv
wX7/qPw8bK7ySrHHib7P/y975x5eRXmu76D1WAl0sxW0YkEuCCKWcEaCfIpy
ST1ARKWIAh5IaXEDNQT8oRSUUkEvga1osASJnLYcSwwiISAYNAqBhHCuIRxD
QggkgAfkJP7aQNZqs/qw8ibvl5lJnvufVZ8uJrNmZq2Z+eZ970+aS88XyI+h
tT6lzwvaOfqdL50jX5k0l57X0P2d9Hwnve5C83ZJl0NI5WPfJ3bp5Qf6zTLj
/pnPCsjR+uPPpkF1e47C51LEDbjtuSlzb+WkcuB+J4QQQgghhBBCSNnRmqdJ
mqO6LzR/E1ofaT0YkeC2cSb35Lb7kbX6ZG37K6Q+Cun7oxcPmBT758D8N9EJ
o+fFBOa3tD83JDnKXv6LnCVNo352zKz7/Yh6ux58z/f/h05+7kCt2UXmlYH/
zOep5+jvStcfbU+Ua3lCtHwm0vV3Kpd+XpRr9ZtLfze0fmdQrnWcaPlwtPa7
7c/lVK7lVXCb90Dr+NfyUbhtv2t9X9D5Wiu3/Xsu/V5reb1snxe0/F3SXPr9
cpuPyHZ+Affc7zBn7t2cEEIIqV6w74mQsoOeM6LnklKfRlJc5Jy0nzab+dMa
r8jZ4M+RP//fCX7de8HLscrcN2deTtiR4H/3wvuzTa23Zk2KXxR8/RvWnDMm
v9XXprBzxvSfLw+eS5c/vng995tH2z4Y/dXU4Dna/uj5Mtq/0ufLqP9Uyyui
NR89ymF/rnB9xL4LsHy03fq1CO8yft1h07Lp/JZ7xgWvT0DfU5Sj4wTtdzSP
STBfB+rvRp4B5D2Qei0iiwp+Ob1gW0Cu5dNAngctj4TUXyH1UUjXX8sv8c5v
xi/95Zdlz9Hyncql649yLT+P1HeEvBBeyaV+DKlfAnmovJKX9XMhH5c0F/s0
LPujpPNzoRxd50hzQiof7MHQ8W/orafdnFyA25O4Gbc9N2XubE7cCY8TQggh
hBBCCCGE2APVQaF6KmmdFaqnQh4Pqa8DvR+B1of8J9w2LlX2XNqfi/oK3dY/
K+0zte2vsO2pqBFRd3ryPUXmm/TePQ92SPTl5/PSHo/aV2jGFr8/KWhe1LnV
+uT6hWZm8XLWljvfV5A7NmrVUZM8beCy/l1S1d+PcunnRblX9pfbcul2sO1R
sZ1X1d8BaY7+rtb6e93n43Wfie3vi1N+J63cbb/D0t9n6fdO63vkVG7bZ+LU
91TLT+JUruUn0fIBXsA992vMmZc9J4QQQqozPD8SUh7Qc0Dkl7iQbzTjuz3y
VY8d/jzsq3/mi0zDnttOTPne9n1W+ZF6QpD3A31etBxpjpaP1ke6/mg/avlM
0HEl9YpIc6mPQpqj5/Vo+3Qq3i/bzYajpxe8mFJ+Xw3K0XJQjnwyaL8gXwfq
a0b91xfA/fLIS4A8D1IfBXo/8k6gv4tyqacC+UlQLl0ftBwtX4TtHK2PdLtJ
c+S7kHozkB9D6s1A3gmpj8JtudQvUdZc6pFwKke/k1rvt+3NyBt7fbMxrYvM
pF1L7hy4rCDo+217NrR8GshDRS8HIbbh85Lywe1AvIjbnqcy182JV3gr66X8
xFmB47bjhv/w14Q0p+pmiFfYPuuLQUfPlx6/IIQQQgghhBBC/p1L15uVva4G
5ajuRerxQPU/0hwtn0iwN/6E+sW05qlH/b8ol87bLu2XRP2e0r5d1Gcq7Vs/
/vboWrXHFJrEGu/s2dxvteM58lfsjv1rp9pPHjWvFq//Ol+e2eXhk8mnj5hp
bf7ycq/HNwTN04tCEqLeO2KeKf67Gb78p5CBG7c1PWLSpu77ZsS4zKD5gLir
BzRNLDCn5g1P+zhlc7mXg9YHrT/aDtIcbWdpLt0v6PNKc+l+t73dtHwv6Hvh
VJ+79Htq+/jR+r7bPk5sfx/RftHy+UjPL055D2yfT7XOm7b9Tra/j9LlaH1/
bf8+S/ejU/4frVz6fbHtJ5Feb2v5f2znUq+I1DeC7oOkfg+p9+Pi2jJn7oKc
EEIIqQ7wPEiIe/DedazUs/HvuO3633s52s5SD4l0P3L/XgBtN1S3gOoH0Pwg
qK8Z9Vmj/vGS9Ub+AeQ3QJ4ELd+CNNfyM0jff2di74Te71d+jtZHK9fanmj9
pR4Mrbyi/grko5DmTvkoUI78D9Ic+SJseyq8nku9GbZz2z4NtBytXAo8noXH
Lfq+XwD/zqDfSen5VMezRKonzt832sF798+E6OH8/XDFci28vv7EbWwaMuHW
VZcFjnOhPGHOq39Z3rPsOfJ4EG/x+1e+/PZ/Xgr0aaAc+TciU9fuf/7Ppccv
CCGEEEIIIYSQsoE8G2heIZRLfR3IB4Lmr0F1Msj74TSov0naJ+UsZR/vRH1h
qL8M9aOhvjapT0OrD1Ha/2jbXyHt25X2wzrVR4/8FdvaLjj7ckSBuTL52lnf
nN9S7nzBoMJmjbofNvdkt3lkyMjtlZZrrb/U+yH1gUg9JFqfy6lca3tqeVfc
lmttN6f2r+3vo+3jzbbfwLbHwG1+J7d5Y7TOj9Utt+1xsu0/0fLwaHlFnPLw
2PaESL0fWrmW30PL14Fy6X2oVn4Bt9UZMa9obqcvjBBCCKkOVNXzIOumCfEu
zt9fMGduI0e+DlTPgOoTXp5w9XMnrs4zdVJy7/v5e35fR78W4V3GrztsWjad
33LPuEJfjvqvpf3IwfqOkfcAeRKQz8EpD0NF/QzlXb5TuXR7VnT7SP0SWp9X
6s2AfglhXlX9D15ZT2l+6A9Lo6J2FpoF8/7aM//G4LnW391+y8R69T4/aq6v
/dv3n7//aLnzPe2PZbf8VaEp6jJ4XMGB4MvX8mZoeTmk70efV+t8p+3f0Do/
Il+HzMtBiBdhvzwhgUiPc3oqCKkIhR0mr/kssSjgOEf5vq0/f2F1VmCecs0V
21Y0K3s/BloO8RZS/wa9HIQQQgghhBBCKgLybEwvrktJNVEnR21fua/8eVKx
T2OzmT+t8YqcDcHrXlBeuVR8vBP1JSF/hdRrgfqtbIPWB/WXofmsUT8d6u+z
Pd+91Hchnc9d2ucr7T+VehWkubQP3WQ+OGXTF4dNow3xI8M7bfPlqF8+9IrJ
a0fszDdDC9c3XfTJDl8+Mj68T9rT+Wbi+X4hBd/u9OXdtw17/YVhh8y6Bq8v
iRqSVe58xZDrG6aeyzN5LW8ZP3vhrnIvJ+fOLSfqFxwyC2p9tzOs5ddBc/S5
0HbQ8oRItzPKtT6v9P3S7SbNtbYzOv5RLv0eaX3v0PZ32/HjVK51vEmPE+nv
Lfrddpv3QOu8Zvt8J82l33fbufT7a/v3TWs5KLe9f7W+L9LvkfR6Unq9iq57
tXKpJ0TqD5HeL2jlUk8Iug9COfITSnOp30P6fpSj+1l0X4w8lhfXinkl51LP
RsW8HIQQQkh1xrt10+g6tqLPKXj9QEhVwfn7GubMK3L/i+oT0PwgYdFbsnac
yjN7pt0Qcvej/r6Na288s+J/kgrMuRpZR//rbr+vA/Vroz70YP6E0n6Gkrys
PgeUo78r7adGOezXlvoZ0N9V8jaorY/Seko9BuLP5dD6S/v94fu1cqn/wfb6
CHOpF0Kaa/krnFp/27nUs+FULv1c0v0o/l0CvzPl9QghL8edib0Ter8f6N+I
mvH9be+8GejfkHk5CPEi3h2fIsQ90LNBiA1+ev+/Qj9/o+xeDpSj5Vx3eexT
qc8G5j/bUrPbx1mF/D56HOTlIIQQQgghhBBCbIDmi/l39OtbyvZ3tbDn2ZDO
U4z6nlAu9V2geZydAvXTSef7tj3fvVZfMMqlfdYod5ufQdp3j7wWs/eOXn5m
Qp4Z9ev6qddnZfvyth+uanLypjxTt05yt0MFu335l0POvHtiUa5J/KHXxqSz
eyotR+uJci1/iFYuXX+v5Fp+Fad8LLb9M+h75NRxIv1eo/e77TiU7het31vb
nhmncq3tU1Vzp37fpO/X+rxOHYda128o17rOlPpDpF4dqT9Eet2Ocun9glaO
7l9QLvV1oPs1aY7uE23nUo8Hui9G99cov/jXmVvK6d8ghBBCKgv31FlXjvfb
PZ+XEGIbe/cvUq+j9L4SLV9636r1HFnq1ZTmWp5PtP5Sb+fFv+54ju5zG9ac
Mya/1demsHPG9J8v9+f3bVhw9u47c0xK60frDP6dP395wtXPnbg6z9RJyb3v
5+8F93Wgfn9p/7LUO4FyqZdA3KevtBxp/z7qT9daf6lnQOtzidfTco7Wx23+
Adv7RXocOuV56NcivMv4dYdNy6bzW+4ZV6i+PtLloPVBOfpdRe/X2m7SvyvN
vfJ9kf4+aHmBLoC9HL/s9Ma3yY0DvRzdmoYNPvnfgV4O5N94+423Z296+SDv
ZwkhhFyCqurZcOr+nJBLgzwb1878S+vZPQN9Gpf98cdb3k47Wub3Iy+HNCeE
EEIIIYQQQkh1xfm6l7LlUsq+HFRfJJ2nWOrNQH1bqM8LzeOM5ptGfWdonmst
pPN9S+cZR32IaN5z1Bfp1Dz1KJf2+0v7Z5HHQJqjfnmU927X4YrCzrkmrOh0
WNcr9/nygh+Hx+RnHjTDn153ePEkfz4idWlOzrMHTdqW2IU31N3veI7WH+XS
7aO1PaU52v4o1/q7Wrnt7eyV3Pb+kn5fnPpee+V4k3pmpP4ZrfOIU+cXre1T
3XLbviPb+8Wp4xnl0us3lGtdZ6IcXfdq5VLvhzSX3i9Ic3S/g3J034Tus5Cv
A92vSXPpfSJ6P8rRfSvycmj176A+HZSjPilpfxZzGzkhhBBCCCGEBCK973Mq
1/JjoPej+2vp82KUa40zSP2i0ufmWj7PC1Te/e+FeUY2mvHdHvmqx47S849k
m1pvzZoUvyi4ryMsekvWjlN5Zs+0G0LuftTfRyLty5Z6AKQ56jd3Kn+v6+/S
Zv493wzu/v9GzF/vz48+Ob3nqvxDZlbM/StjQouCbme0HGm/v9ty28eD1Ksg
3Y/S3Ov7S5o79XmlHgmt/Yu+19L3215P28ezlp9Emmudd5Cn6NAflkZF7Sw0
C+b9tWf+jcE9VD/kvR+RN/uYuerDq3c82yjQy3Hdlyvb1f9boH/jzsTeCb3f
D/RvIC9H1Izvb3vnzdJeDkIIIYQQ4hWQfwPl9G8QQgghhBBCCCHEDtWnj0Nr
nmJpP5Rtz4Z0HmrpvNha83dreTOk857bnr9e2r8szbX6bb8ccubdE4tyTeIP
vTYmnd0TNJf6HK6eeKLn3u9yTN2uUYPHxPv75ac91mJt1ms5Jmp56xb5YQd8
efObB7fcUS/HLL3tshORCcHzyIX5tdI7HTDdQ+Njbk3JCZpLl4/WE30u214C
9HelufTzauVa66/lhfB6jvaj7ePEbbnt4832fpT6QKS/27Y9MNL1qW651n70
Sq7lpbHtFZH6QKS51vUk8ntIr3ulOboOl+bS+wLk65Dep6Bc6vFA9022PR5a
ObqvRPeh6D5X6uuQzs+rNa8uvRyVmRNCCCGEEELcT8Wv59HzTamPQnqfqJWj
+02Ua/1dKWjcQOoXte0j1fJ+SP0eaDu7y9exytw3Z15O2BH/+nR67MxbT/x1
u9lw9PSCF1P8+fi4yDlpP+03j7Z9MPqrqf78kxmdj/z8xlzT49DHr+/IDu6X
sJ2/POHq505cnWfqpOTe9/P3gudo/aXvR/m1y2KGNbntoBlXc1zGzIbHgubS
5Wt9Lq3tjzwD0ty2JwHl0uMH5Vrbwalcun+1PBVaPg3p57K937W+L079Xae+
11reD7R8qd9jT+QjMx98udBsHv7n5/8w2u/lOPbx14mJR4rMA/dkXxV1NNC/
caxH4cgx7fLLmBNCCCGEEEIIIYQQQgghhBDiBFWvv0NrnmKUo34oVL8krbNC
/WKo7wz1tUn9GNJ5urWQ+i5Q7rb56233O0v7u6V+A9T/vjpnwQebF/zjv6dn
Jq7okBM0R96MU28kzZ2dtt883uKpTWP6HvTlMwdNiHip937zVOSNzXafDp6j
5aBcuv5uy6Xb06nc9naw7RVxKpduT3Q8SN8vXU5VPa60PDZS34709xnl0vOC
lkeIefly214Xt+VO+UC0cq3rQ+T3kF73ohz5PaQ58nhI7xeQxwPdj6Ac3e9I
c+l9lpbHQ9oXI82lXg7UL4O8HCiX9tGgvi2pl8Mt/TjezAkhhJDqRe3M2yO+
+DLOjPr8RHjciJSL58fj5v5Bf2l3583Zpc6Xx819227KuvOuwHzkqjfqnO76
dUBub80JId7E3nX7pe+Dyg66j5Pe39nOqyrS57ZOjZNojXug5+NovAKNPyC/
ilvGB6S+jq5rXr7j8tb7THjOiFdaz/Ln921YcPbuO3NMSutH6wz+XXC/B1qO
NL+w/tmm1luzJsUv0l++9O82rDlnTH6rr01h54zpP1/u/HpK95c0Rz4Q6ful
PhOt9dH6vFo+Fi3PjJbvRcuTo+WB0fq8TuXS41nL56N1PEhzp3xNKEcejx1X
3P7Y+d8dNS133/3J0YV+L0fe2OubjWldZCbtWnLnwGUFvvxUesSLG+8/ZhrF
fFOUMz7Qy7Hv61s+3b+a/g1CCCGEEEIIIYQQQgghhBDiBrzb96E1jzCq/0H9
TdL6IlSnpOXZkNZloT441Gcn9WOgvkIp0n5GNE+6U32atn0a0r5p1PeN+s1t
+zQeeKD35si8fWbACzvGdYzNrbRcy+PhVM7teelc6pHQ8p9oLR9tZ63to7V8
qSfHtlfHbcePlsfDdi49X0iXj5Zje/m2t5v0c9n2rrjNE+J1f4ht74eWr8Nt
Hg8tX4dtjwfqc9HqT5H2rUj7WaTz2KJ+FpSj+WpR/8v0/Hozxr1dcf+G2/to
qlZOCCGE2GV4/yPjBnbYVeo8hL0Wd3dO+FPHfoG51vqgv9v1V5ETVjS393cJ
IVUd91y3o/sv5NNA93ekckDjJ1q57fEWNK6CcvS8G42HoPENNF6BjnM0znCB
yrsfD/vqn76IRaZhz20npnzvX5/pxV6OVBN1ctT2lftK+yU2mvHdHvmqx47g
Ho+kYi/HZjN/WuMVORuC51rLQeuJcunytT4X8nhIt4N0+VJ/iO3cbX4S5JNB
uZb3w6lc6n/Q8qhI3++V3Pbx45Xj0/b+Rcfn0Sen91yVf8jMirl/ZUyoP8+4
7IuWPecdMWt2XTvv/rN+/8aeyEdmPvhyodk8/M/P/2H0EV5/EkIIIYQQQggh
hBBCCCGEkGqAA/VjoM8I+TSk3gxU/6OVo74t6TxHqA4K1U1J67KQZwP190k9
GCiXojV/uu1cq19Vqz8a9YOjfnOUS/0P39zWdGBYzD7z/NtT9k5tlRc0f2nL
5Mbzf7XXvLqt5rs9nz+k/n7budZ2kOZx15w692ONfSZ6aWTH7zOC505tH6e2
v21fhFZe3faXNHfb/pL+fkpz9LstzW0vn3n5ci2PB/NL51rXY1q+Een1pPS6
WurrkObofgHltvtKpP0m6H5K2j8i7StBudTXge5zpffLUv+GlpdD2hdD/0ZF
ckIIIaRqgnwaXV7PvT354cDcKe8HIaSqU/nX+YNrzzjabHfFPRvo/o5UDtJx
Hi1fq9b4j9b4DBpXQeMkaNwjdPJzB2rNLjKvFL9/ni9H4xLIC/rZa1ded9VZ
jj/YypGHRLqcC36JVea+OfNywo6U9k64LUd+krK/X+ppkfpPkFdEmjvlG5Gu
p3T5Wp8L+UmQz8Ep74pTfhiveGmcWk/bxzk6DpHfgxBCCCGEEEIIIYQQQggh
hBBSXiq/H0TafyRFOp+yNJfOQySdh1o6z7V0Pm40r7d0nnFp3yLCqf5KqTdD
mtv2bJx6I2nu7LT95vEWT20a0zd4v7nUL4H8GNJ8w1stHukVscdM+D7t2JKr
8h3PnVrPmx/ZNOry3+42/3vDhAdqzgmeV9XtYNs3Il2+Vi79vFrfL6dyt+1H
qdcF5eh3Vfp7i96v5fdYnbPgg80L/nGemJ6ZuKKDfi4973g9t72dbftApNcV
TuVoPaW51OOhdV2n5etA1+FafRzS/g7pfYdWju6DtLwc0vlekXfRKS8H8m+g
/hSpl0PLv4H6X1B/Gb0cZckJIYSQ6gXyb9CzQQipXOx5NpC3EN2X3dL+3JDk
qMAc3Q8SXaTjS7b9rtLxJel4kXTcxikvBxrfQOMSF/8Kc+aeyKWeE/R+5AmR
+kBs+0Oky5HmWusv/VzSXMuXgnK0HNvrL10frc+r9bmc8uSgz4U8Gyi/b8OC
s3ffmWNSWj9aZ/Dv6N8ghBBCCCGEEEIIIYQQQgghpOK4x7+hBerD0pqXWTp/
NMql8xZJ+/JQXZbUpyH1S6D3S9Gqc9PyZkhzaT+stA9ay7Mh9QNo+SVQvnpT
6La+k3aZGb0vC1mXfVh9+SgfXHvovITobDO1fde5g+4+HHR9vJ5r7Re03bT2
i23fi+3jx/ZxazuX+lvclmv5QNDvrTR3m3fCbbnWdkbnQdv7Rcuv4pQfQ3od
Il2+7c+r5euQ5uj6U6ufQnr977Z5V23P0yr1cqDcKf9GUedW65PrF5qZxZ6N
tb5cy7+B+rbQ+1H/F/JvHO/36qdPJ5S9v6x6+jcIIYQQQggh7qfyr+elng10
n2h7voOqipYP2alxKi3vBxpHQuM2XvdyfPbalddddba6jUswZ+5Mjnwg0hz5
RrS8JVqfy7b3o3L8JO75XOX7uxU/3pzybFz4u9mm1luzJsUv8udd17x8x+Wt
95nwnBGvtJ4V/P1aOVr/isHxc0IIIYQQQgghhBBCCCGEEOJFvNs/gup8UO7U
/M6oTgn1wUn76dA8R075KKR1ZVK06tNsf16tvldpn7KWZ0PLvyH1Wtx7dGbL
bh2zzOgZ/Z8/FF1QZfJeo5MbPPe3v5vEGef35l9xpNzv18rdtn3QceJUrnV8
uu34l24HqZfDK7ltX4fU/2Db4+GUD0Tr82r5prT8Km7zllTVHF0XSfsdbHs8
pNfVtudFRfcFWr4O2zm6n0JeDmnfB/JvoH4QLf8GypF/43xe2uNR+wrN2OL3
J/k/r9C/IfVyaPk30LzPyL/hLS8HIYQQQgghpOJoXYe7/3oe+QGk/g3kJUD3
lSgnF0DjwLa9vtLxLpRLx6+k/lg0voTGc9C4jXQcRsvLMT2/3oxxb1d8HOPi
v2LOnDnzcudSf4jt3Cvr6dTnknpIkJfDKV+Hbf8G8pMQQgghhBBCCCGEEEII
IYQQUv1wT32atA9L6sFwKpf6NFAdFOrXk/o3pH4JLe+EbWzPe67V74nm1XLK
v4H67qW5lqfC6/mg2ltrjb51p8md8f5jBe/589Gzjpx/L3a7qRffaf2R249W
Wu627cNcN5d+75APROrl8Eou9Q5p+TqkvgjbHg/bfgnb6yn1bGj5N9y2/d22
/raPK+n8pE55OWzPT+qUl0MrR/0a6L5Jej+4YFBhs0bdD5t7sts8MmTkdl8u
7fuw7eVA/VCorwTNd6zl30B9YVL/Bppn1p3+DUIIIYQQQoj7cc91Purrdwp0
Xyn1Q7oN9FwDPWdB4+TS8W2veJul42BSrywaX0LjPGjcBvlRB8RdPaBpYoE5
NW942scpm4OOq0j9pWjcQ+rluG/74exOGWX3dXz22pXXXXXWu/kFnPcVMGfO
nLnbcuTlQD4KlEv9G7ZB/o3yLSfw80p9KZWbE0IIIYQQQgghhBBCCCGEEFIW
3P8cCtXtSHNpP5fUpyGd39m2Z0PLv+GUj8I2Uq+Ilm8E5Vp9taiuT9pXvuGt
Fo/0ithjJnyfdmzJVeXvc0d9/W7zcqC6TWmu5cf43y9v3p0xeot5Lf6lxKJH
CoPmb7f5WdHSa7eZB+N33VW4+mjQ3Cnvh7Ru1qncqfW0/Xfp8bh0jn73tLwc
tuu0bfs63OaFcKq+3antX91yLV+H1OOB5hXV8nKg63Dp9bzU1+E2/4aWz1Dq
35D2fUj9G9L+Jum8rsi/IfVySP0b0YsHTIr9c8X9G1p9Kxf/ujAnhBBCCCGE
EILuZ9H9r1NIn4NIx8nR+DYax0Y5Gk+W5mjcWDreKB3XQuNX0nEn9Bwcjdug
cZj0opCEqH/sp2eKx0Mygo6fSL0coZOfO1BrdpF5pTif58ul4yFaOfKBIA+q
Vi4dz0E5Gs/RypGvld4S5syZuyVHfonpxT6NVBN1ctT2lfuCezmS4iLnpP20
2cyf1nhFzgb3+jrcDX0dhBBCCCGEEEIIIYQQQgghpDKp/OdKqE8K1edo+Te0
PBuovwz1u6Fcy7OBci3PRlX1cqD11/JvoPo3af8yqrtDfceofg/1j2v1s6O6
RKmXwyn/hm3vBKoXlfo3tLwcTuVa281tuVc8J7a9HNJ6Zq94OWz7OqS/51re
Cbd5NqTnO/o3qmdOL8cFtLwctn0d0vsvdH+H7hNDr5i8dsTOfDO0cH3TRZ/s
8OXofnNb2wVnX44oMFcmXzvrm/NbfLmWf2NfQe7YqFVHTfK0gcv6d0kNmkv9
G8izYdu/Ie3vQP4NlNO/QQghhBBCCCGVA7r/RR5L28zp3Xbj4W8yzYr4G8OO
H/Q/70C51ri91Ndh21ONxpPR+Kd0vAuNX6FxKjS+hMZ/pN5UqZcDjc9ojbfY
zpEPBI3noHEb6fuludQfIvWKIB+IlidE6omV5ra9Ihdw3jPAnDnzwBz5Ny54
NlaZ++bMywk7Ety/IfVySHP6OgghhBBCCCGEEEIIIYQQQgjRxj3+DdQ/JfVv
aHk5pP1lqB4J5VqeDZSjuilp7pR/w22+DqlnA9W5uc2/Ie0397p/wykfgm3/
BvNL51p4ZT0RWt8jrTpkt+VaHg+pl0PL16HlhdDyG9j2XVQ3D4ZTXhSv5La9
HNLrUrf5N6S5lpdDy7+Bctv+Del8rNK+D5RL+zKQZ0PLvyHtp9Dyb6A+hQvQ
v0EIIYQQQgghXmdN/fOths9YZx794OS479733/9NPb3xMfPJBtPgg9/W/vZa
f/7H7XEjrsnIMEfjk+JOvFjky5GvA43DO+XBRuPS6Hmcln8DjV9J/RtovAiN
80i9HGjcBvk6pD5VNG6j5VmV5kWdW61Prl9oZhb7OtYGHS+Svh/l5/PSHo/a
V2jGFn/eJF8u9YrY9sTazqXjYFJ/iDR31mfLnHlVyiuPS3s5yu7f0MqJTdx7
HBJCCCGEEEIIIYQQQgghhJCqBaqrkeZa/o0VQ65vmHouz+S1vGX87IW7fDnq
I0P1RageCfXHOeXfkPo0pDmaR8nr/g2E1LNhu39W6uuQ9oNL+9Cl/g0tL4dT
ng2Uu81HoZVL56eT1sd6BVQPTHSR/m44NV+hlpfDKf8GvRDl+7xa532t5Xtl
v7hte3rFv4Fyp/wb6H7Kbf4NNJ+vtF8D9WVI+yCk86Jq9Smg/gJp34EU1C+A
PBv0bxBCCCGEEEJI9eKVrQ16Z3862Rw6W2vqkLmfX7zvO25e+eW8Q58lDTWP
tvn1j/dsS/XlJf9O6vGQPtdAOfKuIy+Hbf+GdPxKOk6FnnejcSQ0XoTGeaS+
DjTOI/V4SHO0fOnflS4HjV9JvbJovEs6DqblFUE+EC1PCBpnsz3+Jh2XQ55b
5Ou4cVrb9O5rAvPBtWccbba77ONsyONBvwdz7+ZVB3o23ASPW0IIIYQQQggh
hBBCCCGEEFI52PZvSPu8pP4Naf8a/RsXQPVd6P0odxtu64eV+jekXg5UB+g2
/waqb6xu/g0tpD4NrRzVx6J62tI5qsuV5mh9tJZf3vUp63bQ3i9SpN8Xt4F+
l6T+DfT7qeXfcMrL4ZT3wynPQ1XNtfwqbvONSPPVOQs+2LzgH9ed0zMTV3QI
7t+QXifb9m+g+w7b/g2US+/LpF4OqX9D2r8g7TuQzjfqlH9DWv+vhbT+nxBC
CCGEyGife2DJO2u/LnVdddygvPLWjBBC/p2MGqZNozVLTLvice9lvnFvlPfq
/lHzDhvmm25zB63Pb5nsy2tn3h7xxZdxZtTnJ8LjRqT4x9WVPR5onBw9l0Hj
3rb9G1KvLHoOKx2/ko472fa7Io8HGkeS5mj50r+rtRxpfYVtb4nUB4JyNP7m
dR/IL3KWNI362TGz7vf/XM57Qcf9pL5c5OtAXlyUS8fxyufRZc68MvOqA/Jy
0NfhBDxuCSGEEEIIIYQQQgghhBBCiC6ofsMp/waq80F9Z055NlC9kzRHy7ft
30Dvl9Z9VVVs9x1LvRyoH5xejkvnXvdsoOVr+TfKOg+d2FOB6mm1crf93Ury
eCD/Cdq/WvMDolz6fUTfd5TbRvq7atu/YTv3in8D1aVL/QxoOV7JpdtHuhyt
XLo+Up+G9LrU6/4NLc+GVn8Eur+z7d+wXecvrc+X1uFr+Te0kNbtE0IIqY6U
3I+WfiWEEEJIdWBWzZjG0elJpl+xN2Om73ogtM3imaO2LjM1iz0bC3z5y33y
6o//OvHi+z8KmiNfR3hco8YP75xtGtzw4buTJ6/25dpeDjS+LfVvoHFjNB4r
HU+Tjptp+TrQ+BXK0fhVdcul43IoR+Nstr0lyPuBctveD6l3F3k8UC71eCAf
LxonlHo5UhulL46eWfH8xmlt07uvKXuOxgO1cuT9+Oy1K6+76ix9IMzLknuP
sK/+6dlYZBr23HZiyvccb68ceHwSQgghhBBCCCGEEEIIIYSQysEp/4a0j0w6
X49W35yWl0Pa9yddjpZ/Q5pXVZzqR5b2caN+cFQfiPLBtYfOS4jONlPbd507
6G5/naHUy6Hl36iqXg6tXOrZKKt/Q80v4RH/BqzvdZmvo2R/Sf0bUi+H1vGp
5euQ/p6g3G1o+Tqk7/eKZwPVmUtzqc9Bmmutj9bndVtue/tLr1dt+zSkng3p
fKNang2pT0Or/l/q30D1+Vr+DTSfptS/gXKnPBsI5N8ghBBSHaFng5CykNRu
Sv6GlVmlvh/HjTS3u5aEEKJHQp+wYW8OXRvwO9buUMf5A79aedGn8ZYJliOP
h5aXo2TNtPwb6DkX8threZvd5rnVel6sNW+FV3ItH69tTy8aJ0TjeyiX1o0g
jwcaD5R6PJCvA40HSscJtcYPtfy9Wn6P4/1e/fTphIrnyO+BxiGRl4O+juqQ
V32Qf4NeDgluO255nBNCCCGEEEIIIYQQQgghhDgFei4vzaWgugVU54DqIlDd
hdS/gfrFtPwb0v64qurfoGejfDjVpyzts5Z6OVB9IKonRF4OlGt5OaS+Dmlf
P6q3dJtnwzX+Dcs+DbEHQ2k9a2feHvHFl3FmVHHdb4r+53WpfwPlto9bLX8O
fR3ly73i2bDtbUBeMtteDtufy6kcbU/bufS6WnpfYLtOXmveTNueDal/Q1pv
j+5P0TyYUv+GdL5LdN8tne/SKc8GIYQQQgjRQcu/caZmxEPhhl4OQkjl0+Pm
8Zv6D9gS8Puz996U3MsXZgTk9/eIad5t4rqA/Ny29B6DRqcG5FJfB/JyhLZZ
PHPU1mWmZrF/Y4EvR14ONA5fsgZS/wYaH9bycqDc9riu1OPhlPejqubS8Uwt
P7CWB1g63qjl6UW51MuBxhVt+zqkdT5S36+W3wP5OlCu5etAXg4tXwfKL65V
QI78Hlp/1235BeglcDvVw9fhNm+G13NCCCGEEEIIIYQQQgghhBDvgp6DO+Xf
QPUGyL+B6iJs+zdQP5rUs6Hl07Dt5XCbZ4P+jcpBWi+n1X8t9XJseKvFI70i
9pgJ36cdW3JVftDjYfWm0G19J+0yM3pfFrIu+7D68YPqIaV9+m7zaaB8Tu+2
Gw9/k2lWxN8Ydvygd/wbyGuBPBsoh34MsJ7i5Vj2iki9HCX7xbZno6p6OZCf
B+VSLwequ0a/e6ge2+u4zb8hrWeW5lq+CC1/hVYduFPXk9L5IrVyaV261vyS
0jp2aa7lzdCqh3dqXkupfwPVySMvh9S/Ia171wLVtxNCCCGEEBla/g27a0kI
ISEhw5/I+jTjyNaA3x/k30B5s72t9x/PzgzIp6y/6Zom0zcE5FIvR9pnNe7o
m7I6INf2b5R+3lGSo+csUi8HGgdGvnr0fA3l6Dkdeq6HcvR8EPn/bee25y+Q
/l2tz2V7PFw6biwdd5V6idF4qZY3GI1PolxrHBLVz0j9wMjXgcYnnfIGo3HL
6MUDJsX+ueI58nikNkpfHD2z4h6PG6e1Te++JjAfXHvG0Wa7K54jHwj6u9Ic
LV9r/bVy5PFA3hLpckh1wG2eiuqWk/IRfDtXD08OIYQQQgghhBBCCCGEEHJp
UF8Meh4tnYcCPQeX5ug5O3pej+oBtPwbUs8G6keT+jekuVO+Dq3+RPo3qja2
69BQ3R2q65OC6gwRqJ9d2hev1b+P6i1RTv/Gf86lng1pbvvvqvk60PYM4t9A
dcK2vRzoeLN9nKPvl5Z/Q8uzoeXfQLnUd0QuIPVvuO36Sro+Wu+X5lq+C2ku
vc5H9xHSHN2noPsaaZ25lk9DWpcu9WygOnaUozp2aX078mxI/RvIs+HUPJWE
EEIIIcQb0L9BCHGKLl3Gdm6SuTPg9yRl6yvTFp3ZUeY8LvaORXcN2x6QI1+H
bf/GrJoxjaPTk0y/4vH2mb7xcC3/RrDxdql3Go0/a3mbpbl0nFk6/iz186P3
V7dcy3+CnvPa9nig8WTpODAap9XyFaO6FJSjcU4tP7DUGywdz0QeD6lPWDqe
ieqjUK7l5ZD6N9yWO+Ubkfo9qmpO3IDbvBPMqwvIgyHNnVqfEtD5wqn1IYQQ
QgghhBBCCCGEEFK1kT4XRrn0ubOWl0Pq60DP05F/Az3fR/UGqD7B6/4N254N
rdyp/lBUh0N00fJsaOVaoHo8VO+n5d+w7eWQ+jqc8m+U9jNI/Q/0b1zI1fwb
5awHdsqz4XX/htbvhm3PBsq16n6rKk75MWznWteNUr+c1nW1tL5aaznSOm2t
XFrvLc2lfgxpju77pLnb6tKl/g3b80gSQgghhBBn6DSva8OIMdmlrsuOm2MJ
cZ/OaBmYt5pwb8PLl+0KyLX8G7bzEEKIazhTM+KhcBP4PW2fe2DJO2u/DshX
TWn1Yt/1fy9zjrwcyLPR4+bxm/oP2FLmfO+9KbmXL8wIyO/vEdO828R1AbmW
f+PlPnn1x3+deDH/yJeL/RsgL1kDNN4uHSdH49jIC63li9bySKMcefWl769u
uZbnBHk8pL6OU28kzZ2dtt883uKpTWP6lt/joeW7RuPSWj5k5CvWGndF/mHp
eKnUPyz1cqC6IDT+KR3nRHVQKNfydXgl1/q8qP9amrvNTyL1h0hz6fqQ8jH1
wZ7n6h1F29Nt3gnmxC5a3o+K+TGCHw9oOdMfO/PWE39NNVEnR21fuc95bwkh
hBBCCCGEEEIIIYQQdyP1ctj2bNj2b6Dn+9J+K1SfgOocpPM7S+eV1vJ1SOfj
tu3fcKoPFM2PQ9wJqqdCOarLQnVcaJ4m6XxYqA5NWtcnrT9E9Y30b+h4NlCO
/BVO+Tec8mlo5Wj/BjsetLwcbvNsaNUtSz0b0jpbp/wbWvP0VVW0rpe0/q7W
fIIol9YzS3Np/bPUd4GWL72/kNZdS3MtPwaq65bWe2vlUp+GtJ5cy7OB7n+R
fwPlyL9BCCGEEEL+M11ez709+eFAr4VW3vnblzYlDwnMkWdD6t8Y3v/IuIEd
7Pk3QizjtvUhpCoh/X5J/RsjV71R53TXwPynQVlZKQ8F+jdStr4ybdGZHYG/
Y09kfZpxZGtALvVsTFl/0zVNpm8IyKWejbTPatzRN2V1QI78G6FtFs8ctXWZ
qVns2VjgyzNqmDaN1iwx7YrHyZeV+3lBsPF22+Pktv3wtnPb/hCv51oeb6mv
Az23lfo6kJcD1QmgXMvLoeVnlo4no3Fjr3g5pOOlUi+x7Toot9VlOZVL69am
59ebMe5te7nU7+F1Twh9HRe4b/vh7E4ZgdsB5cjL8dlrV1531Vn6OpzNidvR
8mygvHJ9IIQQQgghhBBCCCGEEEKqG155zoueg6N+IvT8HfVPoXoAVD+g1Xcm
7ddDdRSo7sK2r8Nt/g00Tw2qk0Hz3RB3IvVvOOXlkPo3UH2alpfDtn9Dy8sh
9Se4xb+h5dlA3oySz7um/vlWw2esM49+cHLcd+8f0/NpeMzL4RX/htTLIcX2
/IC2/RvS+ltpXa40R7/z0vper4PqhKX1w7aRejak/gppfbI0d9t8hW7L0X2Z
NJf6NKTeDK36cDSfo3SeR6l/gxBCCCGkumDbm4Hyuzsn/Kljv7J7NqT+DeTZ
QLmWZ8Mr/g16OQgJRMvDI/VvrJrS6sW+6wM9G126jO3cJHNnQO6Uf+P+HjHN
u01cF5AjLwfyb0i9HFL/htTLUbIGpZ8vlOTIg41yNK7ulVz6nEv6/Etr+VK/
t20fuDTX8n6j5wLIsy0dz0fPkVH9AMpRHQKqW0Dj7ageQ+qj1vI8S73NaFxa
6uWQ+pC1PMbI1yH1eKD5hrRy9Hel649yrfXR2j6obg3lqP4tevGASbF/Zl7d
kHpIbpzWNr37mrLnyNcxuPaMo8120+NROblXqKqfSwt9/4ad5RBCCCGEEEII
IYQQQgghF3DbPAjoeSt6Liz1cqD+KfR8H/WLoboC1B8n7cuTzqMtnSdFy9dh
278h9WygHM13g3JSOWh5NqT+DZRL/RuoHgzVj2n5N1Cdm9s8G1r+jQAfhUP+
Dds5/Lwe92kE82ygemDb/g3bXg4p6HtaVf0bWvPiSXNpva70PCLNvYL0es82
0rpiqWdDWm8szaUePy2vhdRT4ZVcy6eh5dlAudSbQc8GIYQQQsh/xinPBsql
Pg1p7nX/htvWh5DqQKsJ9za8fFnl+zd+GpSVlfJQ2f0bcbF3LLpr2PaAHPk3
mu1tvf94dmZA7jb/RmibxTNHbV1mas4dtD6/5QLfePjLffLqj/868aKX4yNf
3qv7R807bJhvuhW/P9mXS/3e2uPzUl+H1nh+WT3twd7vNh+Ilt/btg9Ey+Oh
9TxC6uVAOfJyoHF7aV0B8nWgOgdUFyH1ckjrQ6ReDpRLx7elvg6tcWCp9xjl
Wr4LaW57PFnLT+KUDwTVm3nF14HWR7qe5NKkNkpfHD0zcLtp5cjvgbwcUl/H
xb/C3FN4ff1to7V9eLwRQgghhBBCCCGEEEIIcSde93Kg5+bo+TuaX0PaB4f6
76ReDqmvA/Unank5UB2Iln8D+TRQHQuqe7HteSC6SOuXUC71cqD6K1Svhfq7
tfwbKJfWvznl37BVV6nmhXCpfyPg87rMm6Fdx2vbvyHNtfwbKJd+T237N9Dv
ktSbgZajtXxp7hX/hte9HF4BXT9L/RvSumKtOmSpjwLdv9jOpf4K234M2z4N
af02PRuEEEIIcTvII4HeL/VIoOW7zafhNv8G6qMf3v/IuIEd7PXX079BiPtB
Hh6t3w30+zBy1Rt1Tnctu38jZesr0xad2RGQS/0bPW4ev6n/gC0BOfJvSL0c
yL+R0Cds2JtD1wbkyL/R7lDH+QO/WnnRs/GWb5wceTlQnlHDtGm0ZolpVzze
vsyXIy8HyrWeL5R8Quk4v1dyp55H2PaN2/aBSL0c6LkGeo4g9XWg5wJo/F/q
5UDPndFzbVTngLwcUg+21Msh9VpLx9VRruWd1vJySMd7pTka19Vavu3c9vi2
Vl4jou705HuKzDfF65noy7V8Hej9Um+GNJeuDykfWj4WqZfjvu2Hsztl0L/h
bE6cxfZ+4fFDCCGEEEIIIYQQQgghxFs45eVAz1tRjp7boufy6Pk+qgdA/XRa
/g2plwPl0nlSUF2HU/4N254N+jcqB7Tfpbl0P6J6Ki3/BqoTk3o5UH0aqmfT
8nVo+QeqvX8jSP1q6e3gNp+GW30dtufj0zr+teabk9avSr0cWrlW3ayWf8N2
/S29HN4CXT9L/Rvo+l86f580t+2XsO2pcKpO2HYdNT0bhBBCCHE7qF9bmmv5
JVB+d+eEP3Xs5x7PhtS/Ic3RdtbybEjz9rkHlryzNrC/XprTs0GIPaS/29Lf
E/S9XjWl1Yt91wd6NqT+DZRL/RvN9rbefzw7MyCX+jdQLvVv2PZy9Or+UfMO
G+abbsV5si9H/o3ambdHfPFlnBlV/HdT/OPz4PmF9P1az0eqal5yBEifazjl
8ZC+X+oh13p+gZ4vbHirxSO9IvaYCd+nHVtylb6vGz0vkHo5UJ0DqpcYkbo0
J+fZgyZtS+zCG+r6czRPCqrfQPOwaHk5tMbbUV2N1MvhlHfadm7ba207R+P2
Wt4PNH8TqivTyp2qi6uq2N7vWn4V5OWYnl9vxri3A/Mbp7VN776munk5nKKq
fi6v49R2dtt+5/FGCCGEEEIIIYQQQgghpHxoPX+UzneAnseh57zoOTXqs0N1
AqiuANUhoFzLy4HqK5B/A9VpVDf/Bj0elYPt40HLv4Hqu6ReDvo3LiD1KpSu
Y3RbvWWwOszSdYxuXU9rXpRK8nXYrl/V+r5ofX/d5uWw7d9wCnoz3IlWPbBW
3a/X6129kqM6TKfm7yOEEEIIqWxaTbi34eXLAvusveLfQLnb/BtaXg6tfvkz
NSMeCjeB+chVb9Q53TWwjx69X8u/EUIIKTNav8/SXMu/0aXL2M5NMneWOXfK
vyH1cpzblt5j0OjUgBx5OaS+DqmX4+U+efXHf5148f0f+fKMGqZNozVLTLvi
8fNlvty2r8MzudTT7tLnHW7zdWj5N6Q58n5r+bqlHm/0XEDq5UDPwVEdBarH
kHo5UB2IlpcDzUej5cGW5lIPttTLYTvX8ni7LZf6vaXj/NL5m7yeV1Wkz2Wk
203Ly4H8G6mN0hdHzwzMj/d79dOnEyru5fjstSuvu+qsbV9HVYXboXJwmx+G
+50QQgghhBBCCCGEEEJI1UDLv4Fy9DwOPeeVgp7vI1BdgRRU50AujdTPoOXf
kM6DQy6Nln8D1VNJ67Kk/eNS/wbKtfr3tbwcWvV+bvdvoPUJlqM6RulypPWZ
FX2/2zwhTtevSutRUf52m58VLb12m3kwftddhav1v7/S3xP0u4TqXaV1sLZz
QsqCtL5Xq95Vy6eB6lFt+yWkuVPribyL9GkQQgghxKugvmnkbfC6l+Puzgl/
6tiv8n0a6O8in4b0c6H9IvVvaHkz6N8gNtD6HbC7lvax7dPQ+j1B3h6pfwN5
NqR5XOwdi+4aVvp5KfZySP0bUi+H1NeB/Bte8XJIc894PKReDsu+jpIjwCnf
uFPPNdD8AtLnFMj7jXI0nwJ6zovma9DycqB6gGmPtVib9VqOiVreukV+WHAv
x4jUpTk5zx40aVtiF95Q159LvRxoHhYtL4fUjy31dSCfttSzjXI0Lw/Kpc8R
nMqRb0Qrd5uXQ+rxtu0Pt/1cQ/p5bfvhtdDysUjrEm9pf25IclSg7yJ68YBJ
sX8ue478GzdOa5vefU1gPrj2jKPNdlfcy3FpXwchboZeDkIIIYQQQgghhBBC
CCGEEKfQ8mlIczSvDcqRr8PrSD+v1vaX+jdQnRWqy0J1XKhPHPWtS70cqG7N
Kf8Gqt+zNT+X1zwPqC4RvV8r96pPo7L2l9bxKf2+SOtXtepa0e+MtK7VKc8G
/RtVG6/45aT1pVr1il6p55QuH71fuhxCCCGEELeD+qBt517xciDfhdTLIfVp
SHO0/tJ+eZRr+TdClKCvg/wrtj08XvFySNfftn9Del7Q8m9oeTmk/g2UN9vb
ev/x7MyAXMu/cX+PmObdJpbuKz1uEvqEDXtz6NqAXOrfmFUzpnF0etLFfKYv
1/JyoLzaeTlc6t/Q8ofbfn6Bctv+Dak/XPp8QerlQM+dUS6dpwM9T0dejoIf
h8fkZx40w59ed3jxJL9/Q+rlmL139PIzE/LMqF/XT70+K7vcOfJ1oHxkfHif
tKfzzcTz/UIKvt0ZNEdeDmmu5etwWy71cmgtR+r9sO3rkOZavnSv5NLtr5Xb
9tKj50rIyxE6+bkDtWYXmVeK3z/PlyP/xm+iE0bPi7Hn37hv++HsThkV93Kg
nBDv4jYvB/0ehBBCCCGEEEIIIYQQQgjxLsjDgOpbtHJpnYzUR4GWX1V9HU4h
9W+g3HafuJZnA+Wo31+rHs+WlyNYXlZPRbD3S/8u2s62P291928Eq3f1Sl0r
+j46BT0YhLgHLT8GIYQQQgixi1P+jeH9j4wb2KHs/getPnHbvg7bue3tgPYL
ys/UjHgo3ATuX5Tb9mPQv1G1kXowqqqXw6nfE6lnQ/o7IPVv/DQoKyvlobJ7
OaT+DZQPfyLr04wjWwNyt3k5zm1L7zFodGpAjrwcbvN19Or+UfMOG+abbsXv
Tw6aa/k6QlyG0/4Ntz2P0PJv2PZyIP+G1CuO5llAz4vR/A4PPNB7c2TePjPg
hR3jOsbm+nLk5ZDO6zHtsRZrs17LMVHLW7fIDwvu5RiRujQn59mDJm1L7MIb
6vpz5OVAedsPVzU5eVOeqVsnuduhgt1Bc+TlWDHk+oap5/JMXstbxs9e6D/P
IS8H8nVr5aFXTF47Yme+GVq4vumiT3YEzaUeD2nuNo8HygfEXT2gaWKBOTVv
eNrHKZuD5lq+Dmku9UJo/V3muvsFeTmkaHk5fpGzpGnUz46Zdb//Z/6eL0f+
jen59WaMezswT22Uvjh6pj0vB3o/IcR99yHOUF38ISXrXdZXQgghhBBCCCGE
EEIIIYT8J6R+DKdyKahuh1RP3ObfmNO77cbD32SaFfE3hh0/WHleDuRbsO1h
sO3fkH4uVOdpzdchnFcupJLQ2u9uq2slhBBCCCGEEOIunPJvaHk5bPs6qpt/
Q+rl0Oq7t52HkCqBbd+FV7wc9G9cyJ3yb6Bcy7+h5eW4v0dM824TS/eDyr0c
yL+Bci3/RogQr3s2pGh5OUqWR//GBbT8G9Ic+TekXg7k30C51L8hne9Dy8tR
8OPwmPzMg2b40+sOL57kXi+HbV/HyPjwPmlP55uJ5/uFFHzrP89p+Trc5vGw
7QPR8nLY9njYXh+ncqkvRSvX2i+2QV4OqX8D5b+JThg9L8aelwPlhHgX798/
ECegZ4MQQgghhBBCCCGEEEIIcQJUx4LqVaQ5qodxClTng+qOSNXGdj2eU/4N
p3JUT+iUf6OsXg7bng1xrlzXatu7go5z23Wt0vpVQgghhBBCCCHuwm1eDmlu
29fh9RxtH6l/A+X0bxAbuM2T45XcbR4e5N+QejakuZZ/Iy72jkV3DdsekEu9
HFJfh5aXQ8vX0e5Qx/kDv1p50afxlm88HPk3Qki50PKTlyxP+jzC9vMFaY68
/dXNv/HSlsmN5/9qr3l1W813ez5/yJdreTkiF+bXSu90wHQPjY+5NcXv35B6
OaR1C1L/xpdDzrx7YlGuSfyh18aks3uC5si/Ic2lXg7bHg/k65D6N2znyLOh
5QNxyteBlmPbX6H1eZ3KpcePU/sXeTkyuzx8Mvn0ETOtzV9e7vV46euwsnP8
7dG1ao8pNInFy/f7zlBeI6Lu9OR7isw36b17HuyQ6MulXo5b2p8bkhxVdi+H
NCfEPaD7EKdyQgghhBBCCCGEEEIIIYQQ4ja84t8gxAaoPtAp/4bUR+EV/4bW
dqhq/o3y1sHa3v5O1bUSQgghhBAvwfm5CKnOOOXfsJ0j74RtH4XbPq/tzyXt
xw8RgpaP1ke6fHJp3OaXcCoPUcJt/g0t3w7ybDjl37Dt60BejuFPZH2acWRr
QC71b0hzqa8D5ci/EUIchf6Nij2nQLlt/8bg2kPnJURnm6ntu84ddPdhX67l
34i75tS5H2vsM9FLIzt+n1F+/wbK0TwaKEe+DlSfgOoZRqQuzcl59qBJ2xK7
8Ia65fd1tP1wVZOTN+WZunWSux0q2F3uHHk5Vgy5vmHquTyT1/KW8bMX7gqa
u83XEXrF5LUjduaboYXrmy76xH+eQz4E6fulue3lu81HgXKph0TqOZH6T6RI
968019o+Wr4OlCNfx+7Yv3aq/eRR8+rAf/ox/H60os6t1ifXLzQziz0b/usw
5OU4n5f2eNS+QjO2eDlJ/u02+bkDtWYXmVeK83m+HHk5fhOdMHpeTKBPQ5oT
4h7o3yCEEEIIIYQQQgghhBBCCCGEEKeoqF8i2Pu1fAuoblBaV2nbC1Fh/4aW
r8P2362m/g10HBJCCCGEEEII8TZO+SWQh8ErudZ2CFHC9v7SWk9SOVRV34Xb
0PJmSHPk59Hy6kj9G6umtHqx73r3+De0vBxSXwfKka8D5ci/IfVyhBBXUt7n
Duj5lPT5gm0vh23PhlP+jdWbQrf1nbTLzOh9Wci67OD+DZRr+TekXg6pfyNy
YX6t9E4HTPfQ+JhbU/z+jeY3D265o16OWXrbZSciE/T9G1Ivx5dDzrx7YlGu
Sfyh18aks3uC5si/Ic21vBxS/4aWr0Mr1/IwaHk53Jajz2t7v2gh/bu2j0Mt
D4mWryO9KCQh6r0j5plin4b/+gz5OvYV5I6NWnXUJE8buKx/l1RfLvV1SL0c
0pwQ90D/BiGEEEIIIYQQQgghhBBCCCGEkPKhVQ9p29dhzcvhUv+GVh2sln9D
qw4W1a/Sy0EIIYQQQggh5J+gvm/U3207R33iWsv3utfC6+tf3aAHw1vY9m+g
fHj/I+MGdqi4l0Pq30D5T4OyslIeco+XQ8u/oZUPfyLr04wjWwNyqa8jhHgK
7ecRUj88eh4k9XKg5wu2/RuDam+tNfrWnSZ3xvuPFbwX/DmFlpdD6tlA+Ya3
WjzSK2KPmfB92rElVwX3ciDPxgMP9N4cmbfPDHhhx7iOsbm+HPk3tLwcq3MW
fLB5wQETMj0zcUWH4F6OaY+1WJv1Wo6JWt66RX6Yvq9D6uVo++GqJidvyjN1
6yR3O1Swu9y51MvhFV+HV3LktXDbekpztN+lx5UW0r8rzaXbQer3QMcJ8nKg
3LaXY3fsXzvVfvKoebXYp7HOlyMvx/m8tMej9hWascXvT/J/XuDlkOY1IupO
T76nyHxT/HcTg+aEuAf6NwghhBBCCCGEEEIIIYQQQgghpLqB5tXyin8D1X9a
83I45PdAn6tse9ke0rpZ2/PHEUIIIYQQQgipXjjl2dDybwT/hGXDK14L6Xqi
fv9WE+5tePmywBy9X2ft5d4D214LreXTp+FObO9f6fEs/d5peZPQ7+2qKa1e
7Ls+0L+BvBzS9zvl8bDt94iLvWPRXcO28/tOitH2b2jl0ucOWp5wp/wbg2sP
nZcQnW2mtu86d9Ddh4PmUi8H8m/EXXPq3I819pnopZEdv8/w+zeQl8Nt/g2v
eDmkvg7k35DmUv+G170cWp9XmmvtL2lu+/hBy9c6zm2vv9Rjo3X8Iy/HgkGF
zRp1P2zuyW7zyJCR/uuwbW0XnH05osBcmXztrG/ObwmaIy8H8m+gfF9B7tio
VUdN8rSBy/p3SfXlyMtx/O3RtWqPKTSJxd6P1ZWWIx8IygmpfOjfIIQQQggh
hBBCCCGEEEIIIYQQr4PqCVH9HqpL1PJvOOXlKJ1b92mAXLLv3AzaztJ6V606
VeSTQXWnCOn7CSGEEEIIIYS4C63+btveDKfwiq8D9fUjP0DlrVnFsO1VoGej
auOUf8PrXg7p+23ntr0fyL8RQogA5AO3nUu9H1peDql/Q/r8QvpcQ8u/seGt
Fo/0ithjJnyfdmzJVcG9HMi/YdvLEbkwv1Z6pwOme2h8zK0pleffQLlt/wbK
pT4Br+B1n4bUR4GOE+lxpZVLj0O0nlrHuVN/17bfZmR8eJ+0p/PNxPP9Qgq+
9V+fSb0cJvPBKZu+OGwabYgfGd5pmy+XejnSi0ISov5xPnum2GuR4culXg5p
7jaPB8oJIYQQQgghhBBCCCGEEEIIIYQQQpB/A9XdoTpDtByU2/Z4aPk6Std5
avk3amfeHvHFl3Fm1OcnwuNGpPjysu+5C2TUMG0arVli2hX/3WW+5Wjl4XGN
Gj+8c7ZpcMOH706evDro5yrvvHho/2rVtUr9G9L54GznhBBCCCGEEEK8Aerj
dmZtqh9SP0Dlrdm/Q58GqQhOHT9aXg4tX8eZmhEPhZtAXwfK0e+zV3Lk5ZD6
OkIIsYCaz1wpL1kv9DwCPVdym5dD67mGU16OBx7ovTkyb58Z8MKOcR1jc4Pm
yL+B8tU5Cz7YvOCACZmembiig76XQ+rrGJG6NCfn2YMmbUvswhvq+nPiLFo+
Dak3Ax0P6PiRHodVNUfbDeVo+2t5ctDxgI6fFUOub5h6Ls/ktbxl/OyF/utX
dBwizwzyb7jNy7E79q+daj951Lw6cES9XQ+uK3eOfB1u83LQ10HcA7qvk+aE
EEIIIYQQQgghhBBCCCGEEEIQqD4Q1dehukFpjv4uqmOU+jq0vBxuwbZnQ5r3
6v5R8w4b5ptucwetz2+Z7K93BV6Oks+B5q1z+/YnhBBCCCGEEEKIPWz39bvN
v0FIRXDKv+GUl0Pq60hqNyV/w8pA/wbKka+jfe6BJe+sDfRgaOW2fR0hhFQi
Wt5yrbxkvaTPI1COnkMh/7z0eZnb/BtafnLk5UD5zEETIl7qvd88FXljs92n
DwbNIxfm10rvdMB0D42PuTUlp9y51NchBXkAiLdA3gzp8aN13FbVXOrJkfpw
0PcR+TekOfJySP0bI+PD+6Q9nW8mnu8XUvCt36cm9XIg/8aAuKsHNE0sMKfm
DU/7OGWzL5d6OdD7ka8D5ci/4XUvBz0exD3Qy0FIWeB8SYQQQgghhBBCCCGE
EEIIIcQGWv4NVK+I8uoC8mC83Cev/vivE02/z0+Ex434yJfPqhnTODo96WI+
M2je7lDH+QO/Wnkxfyvo+0PbLJ45ausyU7PYv7HAl5fXy0EIIYQQQgghhJCq
g1Z/vbTfX+oNkH0qQqoWbvN42PZ7DO9/ZNzADhX3dXjFyxFCiAuw7dmAOfB+
lKzX1NMbHzOfbDANPvht7W+vPRY0R7535OVAz7+k/g2tHHk8BtceOi8hOttM
bd917qC7y+/3QD5/1L8Wd82pcz/W2Geil0Z2/D4juJfjgQd6b47M22cGvLBj
XMfY3KBejlNvJM2dnbbfPN7iqU1j+pY/J6QioOMKHc9uy6XfR2ku/f6uzlnw
weYFB0zI9MzEFR3K7+uQejl6t+twRWHnXBNWdDqs65XBfR1tP1zV5ORNeaZu
neRuhwp2B/VyrBhyfcPUc3kmr+Ut42cv9F+nSr0coVdMXjtiZ74ZWri+6aJP
dpTby6Hl65B6PJCXY3fsXzvVfvKoeXXgiHq7HlynnrvNv0EvB7GH1L/B+0lS
PqS+PrflhBBCCCGEEEIIIYQQQgghhJDqS0KfsGFvDl0bUI99f4+Y5t0mrgvI
K2/NCCGEEEIIIYQQ4jVsezacyv/zpyWkbFTV48pt31Opr6PVhHsbXr6s4v6N
MzUjHgo3Zc+1vBwhhBA11tQ/32r4jHXm0Q9OjvvufX3/BvLJSz32TuXI1yHN
nfJ1SHNCKoL0eEa59PuilbvNt2Pby3H1xBM9936XY+p2jRo8Jt7v35B6OaS+
Dql/o/u2Ya+/MOyQWdfg9SVRQ/zXl1IvB/JvmMwHp2z64rBptCF+ZHinbeX2
cqBc6uVA/g3bXo6izq3WJ9cvNDPTe/c82MFfP7GvIHds1KqjJnnawGX9u6T6
cqf8G2h90OcipOLQy0HKBz0YhBBCCCGEEEIIIYQQQgghhJDqTpcuYzs3ydxZ
6vknn7cTQgghpKpTcr1T+pUQQgipnnjds+GVPIQQF9P525c2JQ8JPG6luVP+
jeH9j4wb2MGel4OeDUKqLlL/BsoH1d5aa/StO03ujPcfK3jvSNAcLeftNj8r
WnrtNvNg/K67CldXXo7WE/k97j06s2W3jllm9Iz+zx+KLvDlg2sPnZcQnW2m
tu86d9Ddh4PmTnkJSPVE6zj3Si79Pkp9HcjLgfIHHui9OTJvnxnwwo5xHWNz
1b0c0x5rsTbrtRwTtbx1i/yw4DnydSD/xpdDzrx7YlGuSfyh18aks3t8edsP
VzU5eVOeqVsnuduhgt1BvRwol3o5Qq+YvHbEznwztHB900Wf7Kg0X8eAuKsH
NE0sMKfmDU/7OGWzL08vCkmI+sf36pli70RG0Ny2l0PL4yHNpZ4NtB3QdiOE
EEIIIYQQQgghhBBCCCGEEEIIITKk9eGozhzVq2vNOyn7VPZptrf1/uPZma5f
T0IIIYQQQgghxA24zWtRVfMQQlxAl9dzb09+uPL9G27zctC/QQgpQerlkObI
B2I7l3pFtHwFUj8AyldvCt3Wd9IuM6P3ZSHrsg8HXc85vdtuPPxNplkRf2PY
8YOF1n+3k05l3X7gff/54tZmGya8/3+Fpt/9V+b9mOPvj5+TWn9t91WHYR6x
OTwsdZa/z77ouqzDX4wrMK9+umtOu8b+9/cZ/cy0v3+bL14+yrOHJBTctPfv
vnzngdBnwvYcdd357pVfzjv0WdJQ82ibX/94z7aSvnf/efmP2+NGXJORYY7G
J8WdeLEo6PdC6qtxKnfq+yj14Wh5OSIX5tdK73TAdA+Nj7k1JbiXA+VXTzzR
c+93OaZu16jBY+L9/o2CH4fH5GceNMOfXnd48SS/f0Pq5Zi9d/TyMxPyzKhf
10+9Pis7aN5927DXXxh2yKxr8PqSqCH+61Hk5UC5lpdD6uv4KWTgxm1Nj5i0
qfu+GTEuM2judV+HVo4+F9puyH9CCCHEnSC/GT2BhBBCCCGEEEIIIYQQQggh
hARHWsd+d+eEP3XsV/a6dFR/Lp3HFi1H6t9AdekjV71R53TXstexe8XvQQgh
hBBCCCGEVGfc5rWw7bvwynoS8q/ct+2mrDvvCjze0LildHxSy7MhzbX8G8h7
HEIIIUFAXgvU1++Uf0Pq5UA58gBo+QHQcpCXoPTnQn6G0DaLZ47auszUnDto
fX7LBb4c+dvReQGdT98de8Xg+U/53/8/L4xPqDO0CPou5rT+6Lmhv/P3u9du
Pzf62duxTwP5N6S51L+BPtf9g/7S7s6by37eR88Hhz+R9WnGka0B+blt6T0G
jU4NyF/uk1d//NeJpt/nJ8LjRnzk24+vbG3QO/vTyebQ2VpTh8z93J+X09eB
cuR1sf09Rb8ntr06yHuD+kmRl+Ob25oODIvZZ55/e8reqa2CezlmDpoQ8VLv
/eapyBub7T7t93KszlnwweYFB0zI9MzEFR3K7+UYkbo0J+fZgyZtS+zCG+rq
eznafriqycmb8kzdOsndDhXs9uUrhlzfMPVcnslrecv42Qv9169SL8fI+PA+
aU/nm4nn+4UUfLuz3DnydaAceTmQL0Lq60A58ld4PUfbDW1ntF8IIYRUDlLP
htv8G+j6durpjY+ZTzaYBh/8tva31x4Lev1MCCGEEEIIIYQQQgghhBBCvA2q
B/vNsuSDST8PrPuKvi78b3/8pb/O5ZOke//+evtjpkdsn2PtswLrt7v+KnLC
iuZlryuT1rG7bX5J6ftRHbvUvxFCCCGEEEIIIYQQ11NVPRu2qaqfi+jy8ION
70kqCByffDDk+NsdzgbmaPwTjWdKvRxa45ZSzwbyA2v5N6R5CCGEBEGr717q
B7Dd16/V719Rz0ZJXrpfLDyuUeOHd842DW748N3Jk1f7+sXSPqtxR9+U1QG/
53Gxdyy6a1jpPmb8+4/Op0mnsm4/8L7/OdetzTZMeP//CqHvIvqD7g/nxfq9
E3Peir8ttdsh6OVA75fmyMtR78knf//mM/6+/A6Pxf4i4uEj5qeDf5n/aAO/
l2NiXM87P7r+qEHXJ+j6AW3PLl3Gdm6SuTMgR16UhD5hw94cujYgR36VXt0/
at5hw3zTrThP9uXoOCmvx2NN/fOths9YZx794OS4794/Vu689PEcLEc+EJRL
v+9Sf87g2kPnJURnm6ntu84ddLff14G8HC9tmdx4/q/2mle31Xy35/OHfLnU
y3HqjaS5s9P2m8dbPLVpTN/gvo5pj7VYm/Vajola3rpFflhwLwfKbXs5bPs6
Qq+YvHbEznwztHB900Wf7AiaI/+DyXxwyqYvDptGG+JHhnfy/35JfR3SHPk6
0otCEqL+cf54psY7ezb3y/DlyIOB3i/N0fpoeTbQfkH7Fx0nhBBCLo2WZ8Nt
/o2Kgq6TnV0rQgixzXHzn18JIYQQQgghhBBCCCHEPaB6M1QPhurcUD0Y8myg
HNWxo3p15NmQvh/Vt6P3a+VoPUMIIYQQQggJgHUIhBBSVXHKj0FPBfEiaB55
NG6JfMJofBKNc6JxSzRPvdS/gcYPnfJv2PZs0L9BCKnqOOXfQO9Hyy/tE0A+
hJf75NUf/3Wi6ff5ifC4ER/58nPb0nsMGp0a8Hv+06CsrJSH/l7m8xHyXyFP
BfJgLBj4y/PnV/v7rW/+v3Hj6j2RZ/b/Ov9vdQ/5+7PfTf7D3uf/kGvqnfy4
f3gtfx66qXvHNSMPwhwtX+rlQJ8LXbeg6w10PYD8/ClbX5m26MyOgBx5OdD+
bXeo4/yBX628eDy85TsekK8DHT8ZNUybRmuWmHbFx9syXy71e4i9H0H6HKV+
D6m3R/p9d5uXI3Jhfq30TgdM99D4mFtT/P4N5OVofvPgljvq5Zilt112IjLB
7+VAvo6rJ57oufe7HFO3a9TgMfH6vo7Ze0cvPzMhz4z6df3U67Oyg+bIt6Dl
60BeCGku9XVIPR7Ig2E7l3o20HZAng1CCCEXkPr9pD6x1ZtCt/WdtMvM6H1Z
yLps/3VLdfFsoOvV2pm3R3zxZZwZVXydnBI0L+/fl17HEkIIIYQQQgghhBBC
CCGEuJ0//umdG4tu8c8bNbpl55tSr9hm8mPmjfpumL/e6da296xOKMoyA6e2
O/hdaLq/Luu68w+sWLDf7Gic2bVJf/98I7kNcuZet3IfrjcTzscUfV343/74
S39d3CdJ9/799fbHYB279P1SLweqN0P17Wg5WjmqiwshhBBCCCGEVFGQL8W2
R0Vr+VXV91JVPxepqrjNj0EvB6kIqF8V9aVGbA4PS53l74squi7r8BfjCuD4
pNS/gcYnq6p/w22eDXo5CCGkcint2SjJp57e+Jj5ZINp8MFva3977THoMUC+
BeRtGLnqjTqnuwb6H9D5Dj0f7Hf/lXk/5vivE+ak1l/bfdVhsTfj1NXvj/18
dYYv/+6Hesejph2Az1UjP3219m/a+z/X+JzW7/7XGzlwOeh5q5aXA123dP1V
5IQVzct+nXCmZsRD4SbwPNuly9jOTTJ3BuTDn8j6NOPI1oB8770puZcvzAjI
ka8joU/YsDeHrg3I0z6rcUfflNUB+ayaMY2j05MuHm8zTbDctt8D9T8iX03J
J0F9juj7iHwdUg8P8nJIfR1x15w692ONfSZ6aWTH7zPyfDnydZx6I2nu7LT9
5vEWT20a0/dg0FzL14G8HAU/Do/Jzzxohj+97vDiSX4vB/J1tP1wVZOTN+WZ
unWSux0q2B00R76OFUOub5h6Ls/ktbxl/OyF/u8t8nKgHPkipLnU1yH1eCA/
htSbIfVpoM+FtgPazmh/of1LCCFu45vbmg4Mi9lnnn97yt6prfzna5Tb9mxI
/RtaXg6ph7C0LxFd1yFvG7rOlObo+vNS+9xJKuqZRJ7GyvsE/xl0XCF/nTQn
hBBCCCGEEEIIIYQQQoifA89fXtDmuS984+h7rolN3/PV16bPEyGbju1a4ct/
yDrUoWHSZtPj/k/m/zF5uS//eEmnbj3eyjRRzz/w3ZAfV/ryiCun3Pbtni1m
5xMrvlh2j79OqfdSc7TjSzvNx10uv+b1n77y5X+b0mf575bvhjmqE9Oq+0I5
msdK6uVAy0F176gODdXDo/ejHNXho8+F5usMIYQQQgghhBBCPIvUP+OUr8b9
0HdBvAjqV0X+jTmtP3pu6O/8fVS128+Nfvb2fNhvi8Yn0Tibln/D9jgk6kfu
/O1Lm5KH2PNvDO9/ZNzADu73coQA6PcghJDKAXkS4mLvWHTXsO1l/r1F50fk
0UL+CqlPo+vHf/jwt0vW+/JVg/63xmexe+HzU+TxkHo50HK0vBzo+anUy4H2
F/KoSH0dPW4ev6n/gC0BOfJ4TFl/0zVNpm8IyO/vEdO828R1ATnyfkj9Hloe
D+jrAP2bJWtW2odTkqN5yVH/I+o/1ZqPHvUVIl8H6v+dOWhCxEu995unIm9s
tvt0cF9H5ML8WumdDpjuofExt6b4fR3I42Hb1/HlkDPvnliUaxJ/6LUx6ewe
X468DVJfR/dtw15/Ydghs67B60uihmQFzUfGh/dJezrfTDzfL6Tg251Bc+Sv
cFuOfBroc6Htg7Yz8qug/Sv1txBCCPJcSc+n0vMsytH6OOXfkHrDUI6ui6R5
aU8a8nKg60N0PSm9zgxxGOSFQ3lZ/RsluW0PjPR4Q9e96Hun5eWg38MuaJwB
3V87s5aEEEIIIYQQQgghhBDiHZDvAnkzVt8/NL5dg898+dqnDl87tfl26MdA
77/wX4F9JcjLgZaTHzNv1HfD/PVFt7a9Z3VCURasK0M5mqep3pNP/v7NZ/z1
Cx0ei/1FxMNHYI7q2FHdO6oTQ/XzKJf6QFCOxuFRjtYHzdeJ+gtQ/R6qA0T7
HXlg0P5FdX0hhBBSRUF1tmg+vpStr0xbdGZHQF45a0tI9UA6nxEhpKLQe1A9
ke5f2z4NHm+EVCVQ36t0Xngt/wbs5xV6gJGXQ8u/0eX13NuTH7bn35B6ObR8
HSGEEELIv4DOp+i8j7wW6Plm0Z8ervXxuC99edTTR/829vpss/vZfr8d3vNz
Xx63pyD7upl/h8/d0PUJ8ontaJzZtUl/vy8it0HO3OtW7oM+EOTlkD6/k86b
gK5bkAcMXQ+g8/6ZmhEPhZvAfNWUVi/2XR84zzWa/xp5XZDfo9ne1vuPZ2cG
5FK/B3ouoOXxQL4ONO856vcsWYM19c+3Gj5jnXn0g5Pjvnvf7+so3Tdakkvn
K9fqZ0R9viiX9hc/8EDvzZF5+8yAF3aM6xib68tt+zpQjvwMUm8DyqUej5w7
t5yoX/CP369a3+0Ma/l1uXPku0B+DKk3Q7o+Wp4N2/sLeV3Q8YaOW0JI+Ql2
PkWeK+n5UdrXr9V3L/V1SP0btr0cWrnUs4E8EqV9aMirhq7r0PVhaJvFM0dt
XWZqFr9/QdDrRqmvA15PBvG/Sa8n0XaTXmciX5zt4xB9T+nN0AHdZ6H7NeR7
ROPeyI8treNFdc7l+cyEEEIIIYQQQgghpLJwqo7dK/X2rMOv2jh9HAX3XSD/
BvJ1fB75361Ohqf48ismvHP294/uEPs30CtaH/R3Ub0ZqitD9WzIF4HGpaXz
Tkp9F6iuDPkuUI7q+lCOtgOqx0P1cmg7Sz0bqG4Q7Xe0nigPIYQQIei5p3R+
PVSXi+p+Ub0ues6L6hZQPS16/ov6p9B5ENVpoxydL1CO/m4IqQDV734E1clo
1bHQs0GIW+D4TNWA43KEkMoHjVOh/lPUZ4rug5zyb6C+YKl/A+W2/RtOeTlC
CCGEkEoE+efRc1I0bwLyYyBPvtbzPuQPQcuRejnQc1t0XSS9zkHXLeg6ROr1
ap97YMk7awPH4dH4PHougHzayOPR4+bxm/oP2BKQI4/H/T1imnebuC4gRx6P
doc6zh/41cqLzyPe8t1fS/sxtfsrUd+xdH5zaR+llsdD6uuYOWhCxEu995un
Im9stvv0QV9u29eBPAzI8/DlkDPvnliUaxJ/6LUx6eweX67l5UD+CpRreTzc
5tnQ2i8oR8dD85sHt9xRL8csve2yE5EJ/uPn1BtJc2en7TePt3hq05i+B4Me
t+j4RNsBrSchbgSdr89tS+8xaHRqQI7Op8ifUPIv0XlQ+pwUndds+ze0cvS5
bPsQtJaDrk/Q9QzKSx8P6LpL6t9A14FSXwfyb6D1QdeH5fXSSLen9HoS5eg4
IZcGeVRKe2bQcYKON3Q8O+XfkM67h54vBN+ihBBCCCGEEEIIIcQ5nPcO8JWv
fMWvyMvhlH8DvSIvB/IzSOeHQvVmyNuA6rtQjvwYqH4M1eGj5cD1BPX/qM4N
1eOh/gJUX4e2s9SzgY43aV8D2r/oOEHrg47DEEKqHM6fn4K9ovPOH//0zo1F
t/j9EqNbdr4p9YptBtUto98rVPeLPEtoHj1pXS6q70V9Q+i5LZpHD70frT96
novOX+j3Fp130PkF5dK+M7Se6Pdf93rGbVT+91HqUUHHIaonRz6Zkv+F6q5R
PQz9G4RUd2xfv5BLw+1MCLEHGv9E94+ojxXdR0j7WJ3yb/SI7XOsfRb9G1Iv
RwghhBDiAtBzW/TcTfr8Do3HoueGaLxduj5o/FD63BY9P0XXV2icH11HoX6o
rr+KnLCiedmvi7SeIyDvN/J7II9Hly5jOzfJ3BmQo+cLqF8YeTxQnxryeGj1
aaJ+5MryeEjnSZd6PKT9zsjX8cADvTdH5u0zA17YMa5jbK4vR74O5FVA+dUT
T/Tc+12Oqds1avCY+P1Bc+SLkHohkK/DKzn6XMibgTwY0u0sXT7a78ibgTwb
KJd6WtDnQu9Hnwt9L8oK8ieg57PS5ZPKAZ2v0TgGOi+fqRnxULgJzNF5Fp1P
UT849BIE8Q+gvnXkm9J6Top8U7b9G2g9pf4NLV+HdDlov6D9WFYvAbpeQp40
dByi6zr0HF96vYeOc3i9F+T4L70dSnJ0vYe2J7oOJBdA33f0+yD9vqDr7dL7
C13/o+MKHefIT4h+t6XzMaHxdnR/iu5nS+8HQgghhBBCCCGEEOIEzvdb8pWv
VfeVXKDs2w3VmyF/AspRvRmqK0P183Naf/Tc0N9t8+W128+Nfvb2fOiFQB4J
tHz0fpSj+jT0uaTeEqlPA/UvSPt20edCOarrQ/WBaH0u7d/g70P1xOnzRvV9
RX1S0v4p9DuAfidRfa+0jhf1N6E6XvT+3yxLPpj087L3Q6HlIH8UOn9J5z2U
nhfQ++G8h+A8iM5ryO+E+vJKthNf//MrOj+i4yFECVT/U/L/S/0b0vooVK9F
SPXF+d8jd79WN7g9CSG2sXcdi+5T0PiYdD53qX8DeTa87t+Qzi9v279BXwch
hBA3g8ZL0fg2up6Rjsei54Doukj6fBYtX+oDQdddaDwfjTMjjwfyoUk9HtJx
fnR9FeIQqH8c9Zchr7LU44H63VC/J+qbk3o80Lzw5Z1vHY1XS/s6UR8u8nWg
cWwtX8epN5Lmzk7bbx5v8dSmMX39/gTkYUDehmmPtVib9VqOiVreukV+WHCP
B/InII+EV3L0uWx7NtD70X5B+xcdD8izgY43Le/KiiHXN0w9l2fyWt4yfvbC
XUG3G1qf0v4c1LeLvEPIw4Dur9H5CNXDhBBVkH8DjQ8g/xUaN0DnzR43j9/U
f8CWgBx5XdBzUuQlKPmXyD+A+tmlz0/d5t9AuW3/hlaO/F3o+qH09Qa6PkHX
M8iPIfVvaHk5tK7T0PYJIWVC+v1yi3+jJC+93237N5D/UOrfQOP56H4TPV8I
IYQQQgghhFQzWIdJCEE4XUfPV77yla+V/ep17G0fVD+PvAqoD1fq60B9vqge
DNWPoeVI56tCOarHk9bFoRxtT9QXL+1/R9tB6gNBxwPyulz4L6e/92551cLp
z8FXr74iTwL6/ZH6mlAdsnSePqmvCdX9ov4s9H6p9wn93krPI+h3Hu0vlGud
d9B+p2fDxishpPrg9O8Nf5e8AfcjIcTp80DwVzR+iO4vtPy99G9cOpf6N7S8
HCGEEEKIi0HjnChH47To+gflaDnoegnl0uezaPwZjc9Ln8+i/mU0rq7l8UAe
bOl1oNTvgfKuv4qcsKJ5xa/T0PVVUrsp+RtWBvaboz5l1Kem5fFAffFOzdsO
+0bLOW878nVI+6mRrwP1S6K+y7hrTp37scY+E700suP3GX6PAfIwIG9D5ML8
WumdDpjuofExt6b4PQO2/R5O5Wj9pbnUWyJdH7Rf0P5F/hb0d9t+uKrJyZvy
TN06yd0OFfi97lL/BloOOh7QcVtW/0azva33H8/2n19KcvR7iPxLaNwAPedF
z6ml89E49fxU+nwZrT+6ToDnd3A+lZ4fUT81On8hnxV6PzqvoT5xdH4p+ZdS
HxTyP6B+eeSDcpuXA60P+rzIf4VytBxpjs7jf9weN+KajAxzND4p7sSLRWLP
BjpOkO8CXS8hPwzyFaD3o+MZeWbQeiL/TDAvB7mA1veL/g2ZfwONq6PxfOSB
RPeV6D4UndeQJyqEEEIIIYQQ4hG8UrfpfN1Y5b4SUhGcPn75yle+8pWv1eUV
PZ+V1qGh96PnvKiPW2teKvR3bedoO0jrAG1vB/Zf85Wv1ecVfa/R74D0d17q
d9KaTxD9TkrfT09FdX4lhBAp/L0i/wqPB0K8i9PXoe59ld7fafk3kI9Rq+9S
y7+B+oCk/g2plwPNM6vl5QghhBBCXI/z10nBXqW+ZTTeLs2lz1vR+LnWPAta
Hg+prxv5PdD1ZPaQhIKb9vrznQdCnwnbI7/OfDDk+Nsdzpbd44GuA9H1ntTj
gfqXUb8Y6muOi71j0V3DtgfkPW4ev6n/gC0BOeqvd6rPtLwej9J9uyU56meU
9l9LPR6oTxP5EJDPAeXI7+GVHHktkAdD6utAPhPp+kj3C/JpIG/GiiHXN0w9
l2fyWt4yfvZC/+9R6BWT147YmW+GFq5vuuiTHUGXg/wbqI+4rP4N9LuB+m3R
/Tj6/UfnHa/7N6TPqdF4Djrvo+2GzpvofIfOX52/fWlT8pDAHPmm0HkN9Wuj
4wqdX9B5BHkJSv4l8nIgvxPyTmidF2z7OtDy0edC50fpeRNtT5Qjn0BpHxfa
v1LPBvKJoeMN+c2QlwBdLyG/h+3rJZSj3/mQaor0eyTN6d+Q+TfQfRw6ryGv
F7qPQ/dH6PsVQv4FPu8mhBBCCCFuwPnniHz9T6+keuL0ccdXvvKVr3zlq7df
pfVpXu+Dlno50HPzqrp9+MpXvvKVr3yt/FdCCEHw94TYgMcVIRXH6evHqvMq
9W+gPg76Ny7k9G8QQgghWjh/nVRZr9K+WqnfQ8ubLfV7II/HjsaZXZv09/cn
5jbImXvdyn2wL7jeyY/7h9fyX0+Gburecc3Ig/A6E3k/bPs9pNer6PoTXWei
60bU74yuA1G/25maEQ+Fm8A+aNQ3jfweqM9O6vdAfXxSjwfqn5XOF1/yl1Bf
NupzRH3EqB9Z2se9elPotr6TdpkZvS8LWZft7+NG/d2oX9upXNonjjwkyIOh
5c345ramA8Ni9pnn356yd2qrvKA5Wk/ku0B+jNl7Ry8/MyHPjPp1/dTrs/zf
55w7t5yoX3DILKj13c6wlv7v58j48D5pT+ebief7hRR8uzPo8qX+jdLHM/oe
afk3kK8JeTa87t/QqgtC53c0boPOg8hbJR33kJ53kFcK+aPQ+QKdF9Bx+8rW
Br2zP51sDp2tNXXI3M9L7R+5rwn1y0t/z7X6+qW5ljdDmqPtjPLS52UtzwY6
fqSeDWmu5TGTXv9I8xDyb3jVv4H2b1X1b6DzHfJvdOkytnOTzJ0BOfp+hVRp
3Pb8mvVjhBBCCCHkX3H+OR9fbb56Hae3H1/5yle+8pWvfOUrX/nKV77yla98
5autV0II4e8GcQM83kh1wOnrvur7KvVvoL4Vp/wbqP5W6tlAOZrvFfVFSuc9
p3+DEEIIQTh/neTWV2kfLrreQ7nU4/F55H+3Ohme4suvmPDO2d8/ukPs90Ae
j4+7XH7N6z995cv/NqXP8t8t3y32e6C+bOT9QB4Pqd8DzbNc78knf//mM/5+
rg6Pxf4i4uEjsN8ZeTzQ9ar0uhTlWn6PpHZT8jesLHufNfJ7oD644U9kfZpx
ZGtA7pTHA/X/vvLLeYc+SxpqHi1+f6ovL1kDad+xtK8Z9VNLfSCoD1Sao35z
aS71eNjOkcfjyyFn3j2xKNck/tBrY9LZPb5c6t8IvWLy2hE7883QwvVNF33i
9xEgL4ct/8bLffLqj/868eL35SPf8Yy+j+j3Ad2/O+XfKPn7lf2qNf8O+lzo
vInOa+j8hc47aBwD5cP7Hxk3sEPgclCOfFDI74T6xGfVjGkcnZ508bid6dtu
vbp/1LzDhvmmW/HvfHKFf7dRXzz6vUV991o5+v2ULgf19U89vfEx88kG0+CD
39b+9tpj5c5L+wHQ9ke+LJSj/Z72WY07+qasDjhO0HUCytHvHsqRx6PZ3tb7
j2dnlvn9aH0S+oQNe3Po2v/f3p3HVlUlcBx/SspIhi0qLogGMdpRydgqSwcM
12oaERWKRgSC2yjqFCnraCS4ESZQEuLCloiKC40sDlTWFgUHbAFRNkWqtRRo
KZSmPCR0UERlRpnex7T+ag+9r+fe976/fz7JSVPeu+/ec899en6tM67WOWrc
9Pio16/6c0JxGtPr0bR/o/a8pK4jv/VvqOcX0/4N9Zyl+jdU/7bqE1PXhbof
qeegkC/D/391KhwHQgghJPZi67/nEG9j/7/PoReSU7H9OSAiIiIiIiIiRktC
GhLb5ynXRXTD8SGEkPpj+76EDdW0fyP8zJ1tlk1c744PfbBq0YR2xcb9G2of
h9/6N1TPhq3+DdP9j/RvEEIIISr212FB07TfY+iwPtWZP33gjvdsPu3qoyWf
y34PNe5Vv4faf63Wt6r3w7Tf46Jjyx5IahNZD7fe2rfHR0/vk/ud1X5z0x4P
0/WzWg+r/Whe9X6ode/hnNmr30hu+H7tH1r1vCPJaXi/h1c9Hmofotr3qvb/
qh4DtS9S7RM33Y/8/BcdBxavftE5cKLNrMzsjyPjv7PfvPb+6Jpxr/Zfq3G1
z9SrPhA1rvbDDm87Yl7O6GJnVve07IybTusJKVvw5vYFpU7otW1L8lLKIvNU
t5SEQ73KncTw8cS05nvccdWPoXo2FmQcuuaKvged1OIu/TOfjswL9G+Y9W+o
+07Nv9/UmvZvmN6X1f1RHTf1fY66v6j7hfreQ83z6nsPtX9Z9TWp81DN22q/
uezlEPNnzW9U85jqr/CqNyna47Vfv7yPiHF1P1K9VWpc3R/VuNovb9onoMbV
+ab6KNR6QO3fVz0A6vWovg71ftXPq9+vXo9aX6n+nBBpUNT1qOaN2vOPuh69
ul7Uea7W4Wo9oL5vnzEhYfj8IZH5/4lRk3LOGxGW96Oe25MSC96OrJvCLYsO
5k+slH2J6rlGXY/qelH3I3VfU+9LPT+q+3jN70O0LyGEELuxfR/A6Goa268X
o6utxOr78iq2zwtERERERERERL9IYju2zy/0RtPYfr3MM6QpEqvnp+3rNVrH
0/brwngxVvs3THs2gtK/ESKEEEKIR7G/DguaXu0Ljvb+YjVu2vuh1sOq98O0
30P1eKh1tWmPh/r7zqqvQ63DizNzKtvvjowXlrZ+KLFEr8/VPjKv1u1qf7da
b6v9bmrfn1c9HurvvKv9qqb7ZE3/3r3aR6n2m6t9wabjrbv8863xXyx3Wv26
b32BO656G+Q+d9EH8ns9IWr/e+2/C18zrvaxqt6PDv23jm927y7npQsm92k1
t8Id79xhePLOi8qcpVeffSQ9J9Jr8WTB0rKyv+5zNn0+c+EFF+51x/My211e
8ON+Z3/yZZPeWRg5L1XPBv0bZv0bar9qUPo3TH9ejas+q7Rlf3v33sWfuOMf
Zrx01r9m7pbHU32foz5H0+9J1Hmi+kVVL8fJjKKitXc0vJdDzatq/lTnv+qL
ONO+I9N5zHRc/f7aPUum+/fV8VHj6j6i7lPqc1Hj6j6rzge1717d39XPq9ev
zjf1OtW/q8bV+/Lq/aqeAXU9qvWY6feuIXJGUdevuh7VelKdn7b6N9Rzimn/
hnruUO9XredVT6B6flGvUz0PqufTmt+H6F8JIYTYje37ACLaX3f57fWYxqvf
b/vzQURERERERESMF8mpRPu48fk2TWxfTxgMCSH+j+15AoOq2pcRq/0bpj9v
q39DjYcIIYQQYin2123YOKPdBzJ0WJ/qzJ8+cMd7Np929dGSz6Pe42G6bzp9
9Qttb+u+zR2fVHbDjHOnlMl1u+r3UPvX1DrftPfD9LlgdMukRSMviaznV+Te
8lVW98Ny/a/2wan1vFqfq/3gal+h2peq/i682t+qej9M+0DUflvTcbWfV+1P
3H3L2vJmC7fUGTftFVH7mlXvh2m/R82/pHo5VE/F91Nys9/ZtNe557ohW5+7
b1/kOu+WknCoV7mTGD6emNZ8jzveOuHFdU8WVjgjDn3yp/dWRD4nr/o3mjpB
6d9Q83bNv+8XverlUP1Upvcd1Qel5u3bQ9++knKi8X1KqqfUtGdJ7QdX85vp
fKX6H1S/hNr/rnot1Dzm1bh6PWpeVe9X9UepcdN9/Wpc3XfU56vOB9Nx9XrU
/UudV2pc7vcX863p61frENVLpq4vdZ2qdZSaB9R6T60/Q8TTmM5v6vxU59vh
nNmr30hu+Pmg+jfUfUc9j6jzRz5HiPel1tvqfqRev3rOqhg7b3z1mMjx79Q1
dU1OuMh4PYDxoFcJ+usnhBBSf2zfrxDRv5Jghc/xzGL7OkNEREREREREbKyE
xEO4Xgghfovt+z/6Ra/6N9Q+F7/1b5iOR7t/I0QIIYQQ8mvsrwuxcZrud1b7
vkc+M/3i8GWRfW3PJvdqX5Cww/k4/fzrjyWtdccTJk8/8fjdO+W+crVvy7TH
Y+eV29KueiCyH7a8Y1l2yw/2yP499Vyg9mur5wW1716Nv7D6m7ndrow8Xwx+
9qFXvzqq+0DUc4faH2fa76H2m6vnCPW8YLoP3XR/uuoPUfsi1X5b9fe+o903
ovYdq/3Lah90223X9sxfP9sZ/+t+85rrLPK8NvLL2U+22LLFqZqTO/vIU2F3
fHjbEfNyRhc7s7qnZWfcdNAdT19Y0WbzjaVO39ZzxnZaW+aOd333w6uOtd/v
XHjeqt4HKne546o34+k5SYM3PVjhTP35/lDl0cLfHe+7Y0zWqDEHnI0dsxYP
zYwc9/WZP8w48l65s+S7AZ/lnihxxzt3GJ6886IyZ+nVZx9Jzyl1x1WvSO0e
ErVPn/4Nb412f5TpfWfZzc1aZJ3c4I4vmjZ45aMrd8l9xGq+VfOq+n5G7ctW
8636fkbNh2oeU/vHVa+RaR+R6p1Q42pfvOm46b9r2nehjo+az09mFBWtvaPu
/G/aI6H6Ikx7JIzvg4afu2mviOn5pvpG1PFX6wG1rlD3d/Xzav1j2qug1o1q
XlLzmFqfh4gvU5yZU9l+d+R8KCxt/VBiie7rU88F6j6l/ruDaW+Puu+oHkL1
PKXO25rfh/Gordh+37F2PAkhxG+xPR8jIusWQn6J7esMEREREREREeNX03j1
ewghhBDin9hej6DfpX+j/nGv+jdChBBCCImz2F/nYWyp1u2mPR5qna/2p5cO
a1bZ5eF8d7ykxczNJRu+ls8FqvfDtN/DtPcjffULbW/rvs0dn1R2w4xzp5QZ
j6vnF/X3sk17P9T+O9PnIDWu9rObjnv1PKX2y5v2Fqr98moftNrHrXo53m41
9srRm3P/1yPxVq3rLxT66NKfr//7Gxudu988NrH69cPuuOrfUL0WA7ulJBzq
Ve4kho8npjXf447nZba7vODH/c7+5MsmvbMw8n5UL4caV79H/btryha8uX3B
f1/fa9uW5KVEekI69N86vtm9u5yXLpjcp9XcCnc8Wv0b6vwx7d9Q80bQ+zei
rWl/lDqeap5X+517bk9KLHg70icQbll0MH9ipZwnvZr3TL//UX0Cqp9B9Xio
/gfVR2TaO+HVuHo9pr0W6jiongc1z6vjf3NW+bWr7mx8n5W6H6lx054W014p
094Mdb8z/VzU+aw+F3V81PWlejbUesm0Z6NwUF7+8tRIv9bApU5Vj3GFcp5X
817N6/VGEm9R63nVQ6jup01zfmJs6LfYPh7xIiGEeBXb8xkish4gvx3b5xci
IiIiIiIiYlNLCCGk/jCv2o3t+yT3WX/F9ucZ7xJCCCGEkGDF9voR0RtN9197
1fuh9kuq/Wiq9yPa46b9IaofQI2rPhC1X0+Nq/2qav+76jdQ49HuIVF/31zt
51X7qdU+YrVP+dZ+Yzv3nrqxzvjzX3QcWLz6RefAiTazMrNrzsfI8/stVW8l
9+5R5Dz7xgPDDoyudMf79Bm4PX3/HueRUTsn9phZ7o6fM/XIXbury5wL04YO
f27OXnd8feYPM468V+4s+W7AZ7knStxx1afRd8eYrFFjDjgbO2YtHppZ9Ls/
39T9G/06TNr6wCOf1zme9G/4U9N9vuq4qflc7ZdX85jpfKV6PNR8peYlNf+Y
9sHeHvr2lZQTDe8jMu2LiPa46lVQ/STqfanjIK930ZeiehtsjavjY9rTYtrX
4VXPiWmfifoc1eel7u/qelTrH9OeDbVepcfgdEmwYvt8QURsqLbit9dDiB9i
ez5ARMRg67fYPh6IiIiIiIiI6F9JfIbz51Q4DoQQEqzYXjf5XUIIIYQQEtux
vd5EDIZq/6PpuFd9IB+nn3/9saS17njC5OknHr97p9ynb/rzpuMVY+eNrx5T
4I536pq6JidcZDyu+kNMf17te1XjqvdAjav9tqo/xHS/vNov3L28dPH0dXX3
O1+z+4a93xZvqzO+5SynyxUfLXa6dfnzT6k7ltc6r+v2UdSMf/rydf0H9Cxx
Jv970+HFf6io9Xv9k++n5Ga/s2mvc891Q7Y+d98+93U2tn9DHc/cbtMqPv2g
7v5xW/0baj6p+ffRTDVvq/6l0mHNKrs8nO+Ol7SYublkw9ey7+ixWd32Vbfe
7I4/0fLnPnkL9spxNc+Yjpv2Gpn2Ean+ENVjcHLfP+bf3TEy702dfddf3m9X
ZTyufr96PWpcvS91HEx7n9S4Ov5efV6mfSymPVGqB6PX0XFbV2U2vjdD9aWo
3hj1vtR5oo6b6tVR16maB9T6jZ4NbLhBj+3jhxiPRju235/fj49X4TiQ02P6
OXr1udu+XhEREW1qGtuvFxERERERERGxtsSfsX1eNPV5EpTXqWL782nocfDb
64nVcNxIPMf2/Mc8RgghhBBC/Bjb61lErE+vej+8+j1qXO0/VeOqh8R0XP1+
tY9ejaveErXfVvV7qH3xav+v2l+s9i8//eGU846n1e3lCMV43sqY3HPcwL3O
kPSLr9l1PNK/MbztiHk5o4udWd3TsjNuOuiO1+7fGND3/c4pn853emdnfFKR
vMq9vm7tN7Zz76kbG3ycb1u+al/uH+t+Ll71bxQOystfnrrOHR+41KnqMa6Q
/g3LquOv5pNo9x2p+ce0v0j1h6hxdd6a9o14Na5ej+n7UuPquEV73LSnRfV4
qPuO6jmZMSFh+Pwhkd6hJ0ZNyjlvRFj2daj71+iWSYtGXhIZX5F7y1dZ3Q/L
32/am6H6SdR8qz5fdX9X6wG1DjFdX9UcJ0RERO/1KrbfB/pLUn9sfz6IiIiI
iIiIiIiIiIiNlZDTE2/nVVDel+15wi/HgRASvdieV5hnCCGEEEKIH2N7XYyI
QdKrvo5ovx6v+kZUv4fan6v2U5v2coRIozLyy9lPttiyxamakzv7yFNhjuf/
xf48Eq+azpO2+o5Mf79XPUhe/btejXvVE6XG1XFQPTyqp0X1S5j2dageIXWf
uv/W5vt/KouMzy24dF3fDw8a92ao16n6VdR9Vh03dZzpNUJERER/Sk4l3o6n
7fMOERERERERERERERHR7xK78dvny/lDGhPOE0IIIYQQQgghjYnt78kQEe2r
+jrUfuoQIYGN/esNEc3vO6oPqnRYs8ouD+e74yUtZm4u2fC1s+zmZi2yTm5w
xxdNG7zy0ZW7nMdmddtX3XqzO/5Ey5/75C3Y63x/zusTPl6zxR2v/u6ib4e+
WirHVW+G6gmpGDtvfPWYAne8U9fUNTnhItk3ovo01HGL1ueEiIiI2LSSYMX2
+YKIiIiIiIiIiIiIiIhmkjMLx58QQgghhBBCCCFBie3vnxARgyohfkisnv+2
r2/E+HLwoNDWw9/kudf3d0UHUi7P3S77OlTfRfiZO9ssm7jeHR/6YNWiCe2K
jcdVH4h6PfX3XNk/voiIiNhUEtKUsX2+IyIiIiIiIiIiIiIiIp5JbL/eaL0v
EqxwPhBCoh3uX4QQQgghxM+x/b0LImJjJSQeYuu6sH19I+Iv9rt1xfyRq1a6
1/eyxTf27vfyNmfkM9MvDl+2xh1/NrlX+4KEHU7hoLz85anr3PGBS52qHuMK
nYqx88ZXjylwxzt1TV2TEy6S46Y9G6onxPbxQ0T8bWM1to8rBkNC/BDb1wEi
IiIiIiIiIiIiIiIiem/Qw3EjhJDYju37JPcRQgghhJDoxva6DBHRLxJCohfb
13esXe+2jx8Gw1gNx4GcHtvXGSJiUCWkMbF9/iIiIiIiIiIiIiIiIiIiBlVC
CCHk9HAfIYQQQgiJ7dj+HgIR0S8SQqIX29c34plICCG25yFExMYa9MTq+7V9
XiAiIiIiIiIiIiIiIiIiYnxJCCGEEEIIIYSQpo/t7wMQEdGOJFixfb4gIvNq
tMLxJLEU2/MQ2jHosX38giqJz9g+7xAREREREREREREREREREeuTEEIIIYQQ
Qggh/o/t7w8QERERETF+JfUn3o6b7fMRETFetBXb7xsRERERERERERERERER
ETFIEkIIIYQQQgghJPZi+/sGRERERETE2gY9to8fIiIiIiIiIiIiIiIiIiIi
IiIiIiGEEEIIIYQQEi+x/fyNiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiNjU
EkII8TbM54QQQkjTx/ZzFSIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiYpAk
hMRebM8rGGwJIYQ0TWzP94iIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiI
iIhnIiEkuLE9fyAiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIi
IiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIi
IiIiIiIiIiIiIiIiIiIiIiIiIiIiIiIiItrxP33NR5w=
     "], {{
     0.5, -90.27272727272727}, {720.5, 90.27272727272727}}, {0, 1}], 
    AspectRatio -> NCache[
      Rational[1, 2], 0.5], Frame -> True, FrameLabel -> {None, None}, 
    FrameTicks -> {{{{-50., 
         FormBox[
          RowBox[{"-", "50"}], TraditionalForm]}, {0., 
         FormBox["0", TraditionalForm]}, {50., 
         FormBox["50", TraditionalForm]}}, {{-50., 
         FormBox[
          RowBox[{"-", "50"}], TraditionalForm]}, {0., 
         FormBox["0", TraditionalForm]}, {50., 
         FormBox["50", TraditionalForm]}}}, {{{60, 
         FormBox[
          RowBox[{"\"60\"", " ", "\[Degree]"}], TraditionalForm]}, {180, 
         FormBox[
          RowBox[{"\"120\"", " ", "\[Degree]"}], TraditionalForm]}, {300, 
         FormBox[
          RowBox[{"\"-180\"", " ", "\[Degree]"}], TraditionalForm]}, {420, 
         FormBox[
          RowBox[{"\"-120\"", " ", "\[Degree]"}], TraditionalForm]}, {540, 
         FormBox[
          RowBox[{"\"-60\"", " ", "\[Degree]"}], TraditionalForm]}, {660, 
         FormBox[
          RowBox[{"\"0\"", " ", "\[Degree]"}], TraditionalForm]}}, {{60, 
         FormBox[
          RowBox[{"\"60\"", " ", "\[Degree]"}], TraditionalForm]}, {180, 
         FormBox[
          RowBox[{"\"120\"", " ", "\[Degree]"}], TraditionalForm]}, {300, 
         FormBox[
          RowBox[{"\"-180\"", " ", "\[Degree]"}], TraditionalForm]}, {420, 
         FormBox[
          RowBox[{"\"-120\"", " ", "\[Degree]"}], TraditionalForm]}, {540, 
         FormBox[
          RowBox[{"\"-60\"", " ", "\[Degree]"}], TraditionalForm]}, {660, 
         FormBox[
          RowBox[{"\"0\"", " ", "\[Degree]"}], TraditionalForm]}}}}, 
    ImageSize -> 720, PlotRangeClipping -> True],StyleBox[
    RowBox[{
      RowBox[{
       "NOAA", " ", "coral", " ", "reef", " ", "watch", " ", "satellite", " ",
         "nighttime", " ", "sea", " ", "surface", " ", "temperature"}], ",", 
      " ", 
      RowBox[{"July", " ", "2010"}]}], StripOnInput -> False, FontFamily -> 
    "Helvetica", FontSize -> 16]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 1}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2}], "]"}]& )]], "Picture",
 CellChangeTimes->{{3.488207661935028*^9, 3.488207696287945*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 "A lot of geographical data is stored in ",
 ButtonBox["HDF",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/format/HDF"],
 " format. The dataset we will use here is from a government website and \
contains satellite sea surface temperatures at 50km resolution. It \
illustrates the increase in surface water temperatures in the oceans of the \
world and is used to analyze the bleaching of coral reefs. "
}], "Text",
 CellChangeTimes->{{3.488207516135673*^9, 3.488207562529943*^9}}],

Cell[TextData[{
 "The files can be found at the National Oceanic and Atmospheric \
Administration website: ",
 ButtonBox["coralreefwatch.noaa.gov/satellite/hdf.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://coralreefwatch.noaa.gov/satellite/hdf/index.html"], None}]
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["HDF: Importing the data", "Section"],

Cell["This imports the entire .tar.gz file from the NOAA website.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Import", "[", 
  "\"\<http://coralreefwatch.noaa.gov/satellite/hdf/data/clim_oper50km/data_\
files_hdf.tar.gz\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"data_files_hdf/january.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/november.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/august.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/june.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/may.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/february.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/july.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/october.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/december.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/april.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/march.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/september.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/max_month.interp.hdf\"\>", 
   ",", "\<\"data_files_hdf/crw_operational50km_monsstclim_mmmclim.hdf\"\>"}],
   "}"}]], "Output"]
}, Closed]],

Cell["\<\
The file we are interested in, the July data, has four elements.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
  "\"\<http://coralreefwatch.noaa.gov/satellite/hdf/data/clim_oper50km/data_\
files_hdf.tar.gz\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<TAR\>\"", ",", "\"\<FileNames\>\"", ",", 
     "\"\<data_files_hdf/july.interp.hdf\>\""}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CRW_SST\"\>", ",", "\<\"surface_flag\"\>", 
   ",", "\<\"longitude\"\>", ",", "\<\"latitude\"\>"}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
 "We import only the raw data from the first element, CRW_SST. \n",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": sea surface temperature (SST) values in units of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"100", "\[Cross]", "\[Degree]C"}], TraditionalForm]]],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.488207281689706*^9, 3.488207306455617*^9}, {
  3.488207346394644*^9, 3.488207369658105*^9}, {3.488207437059844*^9, 
  3.488207470177656*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hdfData", "=", 
  RowBox[{"Import", "[", 
   RowBox[{
   "\"\<http://coralreefwatch.noaa.gov/satellite/hdf/data/clim_oper50km/data_\
files_hdf.tar.gz\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<TAR\>\"", ",", "\"\<FileNames\>\"", ",", 
      "\"\<data_files_hdf/july.interp.hdf\>\"", ",", "\"\<Data\>\"", ",", 
      "1"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   PanelBox[GridBox[{
      {
       StyleBox[
        StyleBox[
         DynamicBox[ToBoxes[
           FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
           StandardForm],
          ImageSizeCache->{349., {3., 10.}}],
         StripOnInput->False,
         DynamicUpdating->True], "Panel",
        StripOnInput->False,
        Background->None]},
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"\[LeftSkeleton]", "668", "\[RightSkeleton]"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}], ",", 
             RowBox[{"-", "210"}]}], "}"}], ",", 
           RowBox[{"\[LeftSkeleton]", "329", "\[RightSkeleton]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}]}], 
          "}"}],
         Short[#, 5]& ],
        Background->GrayLevel[1],
        BaseStyle->{Deployed -> False},
        Frame->True,
        FrameStyle->GrayLevel[0, 0.2],
        StripOnInput->False]},
      {
       RowBox[{
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
             StandardForm],
            ImageSizeCache->{62., {1., 10.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 41, 23089438687842782356, 5/2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
             StandardForm],
            ImageSizeCache->{67., {1., 10.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 41, 23089438687842782356, 5 2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
             StandardForm],
            ImageSizeCache->{104., {3., 10.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 41, 23089438687842782356, Infinity],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
             StandardForm],
            ImageSizeCache->{92., {1., 10.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>FrontEndExecute[{
            FrontEnd`SetOptions[
            FrontEnd`$FrontEnd, 
             FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
            FrontEnd`FrontEndToken["PreferencesDialog"]}],
         Evaluator->None,
         Method->"Preemptive"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[1.2]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    DefaultBaseStyle->{},
    FrameMargins->5],
   Deploy,
   DefaultBaseStyle->{Deployed -> True}],
  Out[41]]], "Output"]
}, Open  ]],

Cell["This gives the dimensions of the array.", "MathCaption"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "hdfData", "]"}]], "Input"],

Cell["And here is a quick visualization.", "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ArrayPlot", "[", "hdfData", "]"}], ",", 
     RowBox[{"MatrixPlot", "[", "hdfData", "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1024"}]}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Import local copy of file", "MoreExamplesSection"],

Cell["Here is the metadata available from this file.", "Text"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\"", ",", 
     "\"\<july.interp.hdf\>\""}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.488206029772608*^9, 3.488206041073305*^9}}],

Cell["\<\
This imports only the raw data. Click on one of the buttons to show more \
output.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"hdfData", "=", 
  RowBox[{"Import", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\"", ",", 
       "\"\<july.interp.hdf\>\""}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Data\>\"", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.488206050559252*^9}],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "hdfData", "]"}]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["HDF: Values in the array", "Section"],

Cell["The minimum and maximum values in the matrix.", "Text",
 CellChangeTimes->{{3.427119141302135*^9, 3.427119162238214*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", "#", "]"}], ",", 
     RowBox[{"Max", "[", "#", "]"}]}], "}"}], "&"}], "[", "hdfData", 
  "]"}]], "Input",
 CellChangeTimes->{{3.427034971688078*^9, 3.427035007254537*^9}}],

Cell["Visualizing the distribution of the values in the array.", "MathCaption"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Sort", "[", 
   RowBox[{"Tally", "[", 
    RowBox[{"Flatten", "[", "hdfData", "]"}], "]"}], "]"}], "]"}]], "Input"],

Cell["", "Space",
 FontSize->16],

Cell["\<\
If we gather the information into bins it will be easier to write a \
meaningful color function to apply to the array.\
\>", "Text",
 CellChangeTimes->{{3.427701734047071*^9, 3.4277017689897823`*^9}}],

Cell["\<\
This gives the bins and counts. There are many zeros.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"hl", "=", 
  RowBox[{"HistogramList", "[", 
   RowBox[{
    RowBox[{"Flatten", "@", "hdfData"}], ",", "100"}], "]"}]}]], "Input"],

Cell["\<\
This zips together the bin delimiters and the counts.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"labelCnts", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Most", "[", 
      RowBox[{"First", "[", "hl", "]"}], "]"}], ",", 
     RowBox[{"Last", "[", "hl", "]"}]}], "}"}], "]"}]}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["HDF: Creating a color function", "Section"],

Cell["\<\
There are really a small number of bins that we will want to use. Let\
\[CloseCurlyQuote]s delete those bins with 0 counts.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"nontrvl", "=", 
  RowBox[{"DeleteCases", "[", 
   RowBox[{"labelCnts", ",", 
    RowBox[{"{", 
     RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Length", "[", "nontrvl", "]"}]], "Input",
 CellChangeTimes->{{3.427298494756501*^9, 3.4272985018731194`*^9}}],

Cell[TextData[{
 "We will write a color function that takes values between 380 and 750 and \
rescales them so we can make use of the ",
 StyleBox["VisibleSpectrum", "MR"],
 " color function in the ",
 ButtonBox["ColorSchemes",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{$InstallationDirectory, "SystemFiles", "FrontEnd", 
      "Palettes"}, "ColorSchemes.nb"], None}],
 " palette."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rs", "[", "x_", "]"}], ":=", 
  RowBox[{"Rescale", "[", 
   RowBox[{"x", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3100"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"380", ",", "750"}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
Here then is a color function that makes the land black, the sea ice white, \
and the oceanic areas colored by temperature.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"colFun", "[", "x_", "]"}], ":=", 
  RowBox[{"Which", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x", "\[Equal]", 
     RowBox[{"-", "7777"}]}], ",", "Black", ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"-", "300"}], "\[LessEqual]", "x", "<", "0"}], ",", "White", ",",
     "\[IndentingNewLine]", 
    RowBox[{"0", "\[LessEqual]", "x"}], ",", 
    RowBox[{
     RowBox[{"ColorData", "[", "\"\<VisibleSpectrum\>\"", "]"}], "[", 
     RowBox[{"rs", "[", "x", "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.428242898595737*^9, 3.4282429075530243`*^9}}],

Cell["", "Space"],

Cell["\<\
We will need some new tick locations to reflect putting the Pacific Ocean in \
the center of the plot.\
\>", "Text",
 CellChangeTimes->{{3.4272986877540216`*^9, 3.4272987376574697`*^9}}],

Cell[TextData[{
 "Some new ticks to insure the tick values range between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "180"}], TraditionalForm]]],
 " and 180 to follow the usual cartographic conventions."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"xTcks", "=", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"660", "+", 
        RowBox[{"2", " ", "x"}]}], ",", 
       RowBox[{"Mod", "[", 
        RowBox[{"x", ",", "360", ",", 
         RowBox[{"-", "180"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "300"}], ",", "30", ",", "60"}], "}"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pos_", ",", "lab_"}], "}"}], "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"pos", ",", 
      RowBox[{
       RowBox[{"ToString", "[", "lab", "]"}], "\[Degree]"}]}], 
     "}"}]}]}]}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
HDF: Putting it all together\[LongDash]the final image\
\>", "Section"],

Cell[TextData[{
 "This puts everything together, the color function that indicates the areas \
covered by ice, the dark areas for the land, and the surface temperatures for \
the ocean areas. The ticks are also correctly labeled since specific tick \
information takes precedence over listing the ",
 ButtonBox["DataRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DataRange"],
 " as All."
}], "Text"],

Cell[BoxData[
 RowBox[{"Labeled", "[", 
  RowBox[{
   RowBox[{"MatrixPlot", "[", 
    RowBox[{
     RowBox[{"RotateRight", "[", 
      RowBox[{"hdfData", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "300"}], "}"}]}], "]"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"colFun", "[", "#1", "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"DataRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "90"}], ",", "90"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"xTcks", ",", "xTcks"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"10", " ", "72"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}]}], "]"}], ",", 
   RowBox[{"Style", "[", 
    RowBox[{
    "\"\<NOAA coral reef watch satellite nighttime sea surface temperature, \
July 2010\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "16"}], 
      "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4882076663320103`*^9, 3.4882076664338408`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Time-Series Data", "Section"],

Cell[BoxData[
 GraphicsBox[{{
    {Opacity[0], PointBox[{{0, 0}}]}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.7]], {}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[Opacity[0.7]], 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9eQd448dxr/KS58SRi5zIthTVK9JJ1wuPd8cjj72TIAmQINjQARIECHaw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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0008214676889375684}}, 
               AspectRatio -> Full, ImagePadding -> None], {0., 0.}, {
              Left, Bottom}, {1., 0.0008214676889375684}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{1., 0.0008214676889375684}]}}},
           
           ImageSizeCache->{{22.795806315430887`, 33.84642592982402}, {
            115.43553195283275`, 121.42244336008912`}}],
          StatusArea[#, {1, 
            Rational[3, 3652]}]& ,
          TagBoxNote->"{1, 3/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["3", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[3, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9WgdYm9fVdtK0Teo6sRPHcbziEU+MDRhszDBbDAlJIKGJQAvtzRRbgMTe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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.000547645125958379}}, AspectRatio -> 
               Full, ImagePadding -> None], {1., 0.}, {Left, Bottom}, {1., 
              0.000547645125958379}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{2., 0.000547645125958379}]}}},
           
           ImageSizeCache->{{30.82955272502631, 41.880172339419445`}, {
            116.426806224337, 121.41808049584124`}}],
          StatusArea[#, {1, 
            Rational[1, 1826]}]& ,
          TagBoxNote->"{1, 1/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9eAdcm+e1t5u2t03T3tukSZ04iR1PjFlmCxAgCe299xYSEgKBBgIEiA1i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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0016429353778751369`}}, 
               AspectRatio -> Full, ImagePadding -> None], {2., 0.}, {
              Left, Bottom}, {1., 0.0016429353778751369`}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{3., 0.0016429353778751369`}]}}},
           
           ImageSizeCache->{{38.863299134621734`, 49.913918749014876`}, {
            112.46170913832002`, 121.43553195283275`}}],
          StatusArea[#, {1, 
            Rational[3, 1826]}]& ,
          TagBoxNote->"{1, 3/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["3", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[3, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1dwdYnNfRrlOc4hrLsqwuISEQvbOwbO+998L2DrsLLL33XoQA0RESIJAQ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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.004654983570646221}}, AspectRatio -> 
               Full, ImagePadding -> None], {3., 0.}, {Left, Bottom}, {1., 
              0.004654983570646221}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{4., 0.004654983570646221}]}}},
           
           ImageSizeCache->{{46.897045544217164`, 57.9476651586103}, {
            101.55769215177331`, 121.4835234595594}}],
          StatusArea[#, {1, 
            Rational[17, 3652]}]& ,
          TagBoxNote->"{1, 17/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["17", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[17, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyNegdU21eyt3c3+77sbl6K7Ti2YzvuDWMwzfTeJYSQBAgVBAJVJIQKAgkh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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.007119386637458927}}, AspectRatio -> 
               Full, ImagePadding -> None], {4., 0.}, {Left, Bottom}, {1., 
              0.007119386637458927}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{5., 0.007119386637458927}]}}},
           
           ImageSizeCache->{{54.93079195381259, 65.98141156820571}, {
            92.6362237082351, 121.52278923779029`}}],
          StatusArea[#, {1, 
            Rational[13, 1826]}]& ,
          TagBoxNote->"{1, 13/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["13", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[13, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1eAdcm1eyrzd3797dzW6qk93YjmPHXsfGJca4YJveO0KAJCRUEEIV9YIQ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                    "], {{0, 
                    319}, {11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.007940854326396496}}, AspectRatio -> 
               Full, ImagePadding -> None], {5., 0.}, {Left, Bottom}, {1., 
              0.007940854326396496}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{6., 0.007940854326396496}]}}},
           
           ImageSizeCache->{{62.964538363407996`, 74.01515797780115}, {
            89.66240089372235, 121.53587783053392`}}],
          StatusArea[#, {1, 
            Rational[29, 3652]}]& ,
          TagBoxNote->"{1, 29/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["29", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[29, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxtdwdYm0e2trPZ/bfvTdl1irPpiRMnca+ADZgOpsl0kBAgAZJANIGQRAfR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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.022727272727272728`}}, 
               AspectRatio -> Full, ImagePadding -> None], {6., 0.}, {
              Left, Bottom}, {1., 0.022727272727272728`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{7., 0.022727272727272728`}]}}},
           
           ImageSizeCache->{{70.99828477300343, 82.04890438739658}, {
            36.13359023249306, 121.54723703477171`}}],
          StatusArea[#, {1, 
            Rational[1, 44]}]& ,
          TagBoxNote->"{1, 1/44}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "44"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 44]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFWAdUlUmWRrvtadu2TUhQQBQlGUBEkZxzzpkHPHg8clCSoIAiSjDQgglR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                    
                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.03258488499452355}}, AspectRatio -> 
               Full, ImagePadding -> None], {7., 0.}, {Left, Bottom}, {1., 
              0.03258488499452355}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{8., 0.03258488499452355}]}}},
           
           ImageSizeCache->{{79.03203118259886, 90.082650796992}, {
            0.44771645834021, 121.42853561284285`}}],
          StatusArea[#, {1, 
            Rational[119, 3652]}]& ,
          TagBoxNote->"{1, 119/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["119", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[119, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFWndYVNe2J+pNN4nG3lAUUQSVoIDSi5QZhjI0qcMAg3RkqNIEBBEVsZBE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                    
                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.03504928806133625}}, AspectRatio -> 
               Full, ImagePadding -> None], {8., 0.}, {Left, Bottom}, {1., 
              0.03504928806133625}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{9., 0.03504928806133625}]}}},
           
           ImageSizeCache->{{87.06577759219428, 
            98.11639720658742}, {-8.473751985198007, 121.46780139107376`}}],
          StatusArea[#, {1, 
            Rational[32, 913]}]& ,
          TagBoxNote->"{1, 32/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["32", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[32, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFWAdYW0e2JtndvM0m2U3PlhTbcbJxA1dsXACb3nsRAovee+9FdBAIEF0U
gelgiqkCBOpdQgIMriR2iuNkN9mULW+/3ed3rgaur3HePn//N5575p8zZ86c
OWfE3sA419Bn9fT0kn4JjWtA2sXExIAMt5/Dx6WM5JDAn0HH5Bk9vRfgf6zf
d21pcJoHbe8Ep39yeWCKCy3qDEwv9U9xBmeWAUDAhDO8x4TpJUQYnl4emsXI
AzPL/dNLQ1NLaAjHyAwXADRMz+QidLApU4+ZMIp9XuOMTC0PTy7hhMFJDgKS
wNDVaS7GmV4mclB7dZaHVsE+Z5aJq6AOjMJafVMczE5op7floHZkepsGgCUA
+Oq4HIA2goA0E0eHprg6LKG5uJwAHgC8vb3rqSdGdRbyMYLO4dgWJpeI3sA3
grsFt4FoDHKCjskhzsVN3d4CbH+Kg3sMAUzadQQD1xZ3LYQTiHOJC+0iPPae
Tvn/S3jahl0EFAbQ4g4hLo2W2BUn+HnhOp8mEDu4J3UA+U8Y83SfeARoxV3+
x4MZj1V8FA9jAAwBYddEOIjH23yKQAwPomE7WELYZdKO5UtEAlE5vgtwAvLD
zl0mzsKDCtG4hP62BOeAZrR3NHR1FiTc0RkeOjg4FOgDsDs4szwKQ7Pcsbkd
iQ6IgGFnFBGIGJvlY+0cAToJkYBBNzTO5gOInO3RJwnIcsDoHAacgEYxDU/O
2tZDsGGX5YjwePU53q7toM0iOb7Z3Ws9uQRuzPic4DFwIRG6oV0aYF/XFoQT
8wIMbOG1eRG0WGdHOMbmT3HEGBYlaHRsnnttUTTJwT5B7cQcRphekiDa5KJo
iiNE/MkFMdIzwxEBpheFgKkFweyCeJotnGaLphZEulnC2SXx7BK0wjmOAMDm
iOcWJUDDmDCFI1zgihd5EgB05pdFc8sSNlc6tyybWxTNLvLZS8IlgWRZKIWW
wwemaIbLZ3PFwIGheQ6fwxXxRFKuULLMx8AVSBeFYh1fBkOAJf42AcATyvgS
BU8swyQCHUAokgqlCr5YxtfJoY8RxDKuSIo6ALFcBXKBRA4EaIlAcolUKRLL
xRIFtNCHDgCGcOBDCIhABBLK5GrE/A8EtBZRFd7B5VKZCoBzcCGuB30+ViJX
ASRSlUy+opPIZXKlXK6USGT4FLGEaLxMKlMAgInW2rVBnf4nCMR10SciiHeW
IMgfG4/2i+/xaQIuwb0qlTz+JNJ0RsoQQSZVbZOBIFZg0O0aWSsSK4QiHRMk
2BQl7gTYo+50lPih6GYpd50U8URwM4gEFBK4QpFMSfQSSFBogRyLH5EMfRJt
QBGLwg/1sU8RBrQoxCoAH+KL5BD/uBALZvH2J4pq7HaI5AKxgr8jXxKIAVxd
h4tfIt0QdndEMiJhWTe6DJ+6ywi3Fe4sDvQJ8iXethzuMggRoE/8RHzi0AJX
iDpEJuogyfyyAHGgxckLS4LF5W0he4mP5MAEYPJlIRAwjo4wx+Fta0DCHQK0
wGcv8gCLHD6GnRXRohifi3EQGX1uS5Aly0+sC1kL9Yk2Y0ssbcvBEpywvcQO
gbgFJMc3C7kOLYS8h+S4PwFwvttJTyB9fCJCKQCOElosluD0RXKE7UPXAeVD
FDYQXRBjPL4Y0bCgEspgolCihHDdleJ0fZXuvmxf511XGFpcCJAr4HM7M6AO
logIQqVqBaBQqgFYR6XEoPvEoAKZWq1ZgVapVgGIHSSHlkhAfVwOWNFqAPgn
UU7UgOtBfHwK/gnQrGoBxA6uZ9daeIdoIRG7hD9pLVFOpP0HAlHhTy60azmi
H/4vbUT3Is+jz6fXIhJ+Ej+pAde8C3D6TwuJU54m7FroaajVj+ei6UQl2Omv
7AThDmCKSgWkx58/TdCpkisVqIUgRzEsxxbAJPi60If4fxroChBvBw4kRNg1
hF8uIgFaYqXGoKuJ+N1EL5MnXh1irJKi1wgkBOhs5wddzUIdYhGEPl56UM16
ojzp5Hh9QcBqCuEZhmUhwXYZ2oYI8pIMf7BxsSnSZSJBIMVehlCedICctpMV
oRVh9Ysnxh+KCE/WGuyBChKcwOEJ8eqD0u/csojNQ4kXU7uoI2wXPp54u+Tx
8CFsXTzHopyMv11RNoY+uA6ge5JhDhSK5CJdgkWPSUi2eLTsxACCCsUPAOUl
7LbCfdWuYSlIo4HAQy38A4l2bRUXrq5qtFrgqrRajAodnXBV11+BFka1OgZB
uKrd+QcyTKFu7tradRjSravF9e/QsNloLUyZzirERMp3FtoGvsL2ojo++kRy
lFeREJu+ui2BraEpKOuinLOiY+BJDA0hIHfhKZqYBp/O88QEhSoOsdYQMhVW
rB4T4AO7zvInMgwqZyql7uw0iINnG2Jpg/NVKLWIgw+hs94JBg0iEDMJkYCC
5HGtfIqg06BBZXQnoh5DqdLiBF2+2pZDZkCQKzTw8wFaFIpPE5QyjVqplSjU
IpVGrsbkoE2m0kiVyDCNQrsiV61j/tKoxDLNtlAHpEooU8og38o1Mqkanvlo
CAxDwPoKTL9crVWpV5Wax9NxwsNvvoQYkMi1Ss0aWEskoI4dKfD+l59p129K
JFiEo4mgEAEI7x12MrX3vr51+8bN2xIRZEeNYmWViAvmnh+edDlr6a5YUX/y
yRbYs4tzc+uWiW3oa0cdDwJHI//s5ldwxxVrG0rtugxOULO+vnr3h68fxkTk
G17wOXbeVaiS3757B36zgNNUmk2VchUcdW2cU85otw2IOG1DueBEmli4trF+
fU17BzYOP9w2NHfKaQy9tyxfOBhpTc44fNrDIzCcyeoRCaRwq9Y370xNj7W3
daeUNriE5CtXV2m1PUcM3UISsxjt9XOLnK37Xw9NS8bnF5fFSvDzMof7ycMv
MwtqzV1IKaWV9LbugdHRtsEx1vBEZX17NbMnq7w+Ib80v7I2JpNq5h6aVFSd
X00PS6dmUesyC0o9gyKSiipj82otPOIo0dmJ2SUxmRXWPom9o5P9Y9fqmV1N
rP6a5ivJOUWOvqlH7EKqmmvqmtopKVTZ6qZyfVOxemP15r1xNp9W35WcTyOn
Vrb29WXnFeVU1HBl6gU+FAi5XLvZPz5b2zxAraq9nFI8tSwqK6/qHxlbFEBd
UAhlKtXqxuD4TDmjrbCqMTyjqntktKW1Iy23jCtRwagIPLt+g9V/tZjRWFjb
FpxQNMVezCusPmvtwZMpQT9UGfXaZtfAaGl9G7WmJTazbHZJaungb2BqvQzl
TKrgSyDw11n9Y+W1HYXVdfm0Vo+ABP2z1qn5VIFCBaMA6cr1zr7RcjqT3tQa
Gpe//5SFX2R830A/aAAb+BKFfOV6a9dgPbOXSmv+8LRJUHRSe/dACb1xCX7Z
yZRQ3aSaNWb3UFPX0EU7r2OXbKXajdrG1pLaJq7uDxfAESlXr85wzJy9DS85
ppTRpzj8RmZnEZ0B9otlaviBcO/Lb0LjMw6eNqlnjcTll43PclraugpptQKp
GuoRRFfP8KShqW3HwERFfUdMVtHMAq+vfyS3lLYkwH4eypRrV6cWuwanalq6
CyobUooqx6fZ4xMz+aVVYsUKbAFqn3LtJqOtt4TeXNXUFZ1TNMFeBGdmUEt5
ul3AImK1traZVdXYWUxviaOWjc7Nzyxxs0oqwEKod0o5ZEUt6K9t6CiuaUzK
LxmamIUKmEMtkWIZBpIjlDxtdROrrrGzjNGSmFc8ODoF3s8vLoOLBlkCLgkQ
Khs6gFDZ2AYaeofGtaub1NIK7DJit0iNCDX17UBILSy/MjB6feN2oY4AzyEg
QFKqgNhmtJTWNacXV3b1jdy4uVVUVglyeCwBAapzaW1rTQMT/J9VQuu4Mnjn
7v1Keh3YgAhQwYFQ29gGGoDQ2tl77/6D2oZmiUKJE8rqmKABdgGERmbXp589
ZDS1Yr+JwAbNulCirqhuKodt1jFzi6sYHd2f3n/Q2tmNJUO5Em76Ml9WWt1Y
0dQJCyHC/XtfdPb0654NMtgjECpqWyqbWaU1LUCoa+/6eOtTuBe6R50cluDw
paChqrkDI5RW13R03b1zb2J6Tvf2wAjw/impaqhuAkJTXhmd3s66fXOLDe8h
7HUnhyzKXhKW1TZXNbZDm1dRU8XsuLl5hy+QgCfFcsiXaxBCEMM0RgsQIEVU
trbf2LgNFuoegRLIh4hQWddcXtcEhIqWts3rt+CYBFKlUC6XazRTC7xiejOt
obWC0VpAq6tgNEsgkWrW4OLwpWDlKoRxcXVTZX0LEIroDUCAGAP5ou4BCUuM
Tc2X0VvozVg8gLeBKVVpVdr1Bd0fLmTq1cHxOYjYynomTKfSGmCzEM+atRtA
AIhVaz1Xp/KrGmBuQWV9XnldcXWDQIElDY5IOs+TwL27MjqVR6uHmAFTQQNs
li9bgZwABPChULHWP87GNNe2FlU3gRKICh5UsZVVuN3zyyKRDGyYL6Q1QFiW
1jLzqxorGph8hQYIC3z5PE8GGnpHp8HIEkZLcR2TSmukNTH5SrVMcwMIbK5U
R5gFP5TWtxbVtpbUtII/RStavkwL04EgkK/3XJ0pqmoEJ0DtyK+opze38+Qr
YtX1Bb6SzZUjAuZJHaG4Co6VKV5Z50pWFgWqeZ5CqLjeNzYHoUJraq9qYJXX
ttW2dorUawL5KkeoxAnldUyIByBAdahjsiDvgQ1AADt1hJnyuhZ6aweMQhIA
DTLtOmjgidTAAWMgk8M51jA76S3dwGlkdfPlKpFyHZI5ZHuZZgM00GAiq7e6
uau6ntU5MEGjN6oUmiWRAnwOy41ML4Ib69sGa1t6apk9kO0lKtVlSoBAroF8
DhqGJudBzuzor229UtfZT29laTduPfzzX2A6EKDiDE3O1Xf2trP6W3uHy5s7
pxZEGzc/gasNBCgWUKxHZxebugeaOgZa+8eq2zq9yJfnZtjfff+jQrMBaRC0
jc1xgADTW/pGukaupWflu7l6lZVViBVa5co6ECCqG7t6WUPDXUNjjI6eKY7w
z3/5e1Zmnlp7Q65aXd28PTnPbesd6hoYb2jrucbhdV+bWBBhF+LW3S/QC2de
KGjrHRmenoUTz4ME0tTW0dsxx1uCUlXb1HATLvLiUu/4FB3qTWcvlV5mZW99
ysDAyOiIsZV5SnbKwz/9wBbKh6ZnGd3M99/Zm5CR9eOjf6ZkpH908I/WLvb3
vrz35+9+hKjuG5uCjMFk5Jvamphamjc0VqdQM9Lyc0QKWXRM3PDkDOQQf18X
0qV9gUFuR8+cPXJw7+svv2Tv4VrX1OrtQ1q7cbu6ttHa5OypD95MSgnz8XF0
sr8AL68ierkHxX/z9tatjz/18PI0OmdodFL/wMG3HV1sndzcX3jjJWc/95q2
tvWbH8P9ik2INDT44IOD+/d89JrpRYOQQJI/hWx2/qCZyf7QKLv6xoaTp953
czz2wpu/1j94yPDom35+Fna2lheM9jjYH9E//oe3fvfiiWP7nC0OnDY6bKh/
6L3fP/fya88+//zzr/z6+ff3vmFw9KDh6QP6h942PfX+kUPv7nvn95fJnsmp
SbTKmtGRMWpB3suvPK+vv++S6QFT42N7978WERlSXF7h6UMmk0kbN64PDvQ9
+3O9D/a/d+r43g8P/PbAkTcZzJoX33hV71m9F379C6lcwuroeu6550xMz4Bn
Ptz/1muv6pXWVH5w4PCePXs+Onzkxu3VK90dL774ov6Jd95575WTxw7+8hd6
cek5bcwuRkVlZ3d/B4vR3FzzzDPPHDf86N09fzhlqP+z5/QySivOnT75uxee
fUZPD6Z3MOv37Xl9//7fvvzyc2++9areM3oR0QkR0eQRxun4hJS2K20dV9qf
fVbPxcExMiTq6uDA5598oZCLogNjKitq7ty72zcy0NzessCZf/Tv/3n070d/
/fH7v/3jr7qKWdDdN7h16+aVK11V1eUlxflt7U1ff/PgNpzZN1+oNNczcqka
peCff/2+uYVRW0MTCngbG+t/+ubrbx5++81fvv7+qwckZxf2omCGfa17oKO1
rem///vvf//hx6++ePDwi3v379787sG3hmcPC8UiqLf0xupGZsPf/vHDndub
9+/d+Xjr1hdfbN29+8Dayv7Rvx49evTv9s7WisqSf/3rn/c+3Xrwp88/2/rq
zz9+dvfeJ+EWxwau9rX3jAz0DdfUNzz86vPbn9z8+PYN0P/915+vKDejIsM/
/+QzeDYMzA33trf++MN333358MuHn33+4LOvv/1eIRVEJiU+evS3tdtb5RVF
MSHebdUFdRU5dfR8Rn1JTWEmbNzR0TEu3NPf17m+iTU9PjMxMtnH7Oxtrhtk
MRm5MUW54Yzqin5aQgXlZKLju5nBhzK9D5aEnshzfWuwJHFGssJktVa39Xbn
+rLybMUT9VfL0me6anor4vrpAcPt1AWhrI5Gozd31aeQGiM+1Gw+0N64v/7x
5wLl9VtbXw0vc9hsnvLGhlqjEIs149cmxgZbZtkj89yZ2aXZxQX2wFCbYJIr
VgvE8kWodKKNu00Bf2C4vcYIeLvG790a8u8aQw6NTk3R6qqzC3Lamwr6Y84x
85yZmRY9+fasBKMrKeaM4Hd5An5//0RsMnWAVdXs/tKkSHSNzZuZ4U6Mz/XP
TPI5QijkcxLh+Oz41bGRnubmsckp9uSsTCGXKq/zVlaF6hX12sbaqnpzc1Oq
VnM1dwfK3XqKXDoryMM1Ab0Ffqwid7CT1d2ZSy0eGuzpKw/oyTUZybEYptqP
UW1GCyyHIg8vXSkWqa/DKbe0MYYKzNijA4OMspEm6sJQa19XJZtFmxu/Mjo5
28HqbGlh9lcELqhUktWNBbl2Fp74G3eE2psDk8ODQ939kxPd3d2soe72XEp3
cdhIQ1JXbSbsa6KjiVFM7WW1D0+MtbS29QyxFuc5gqW5+7c2+6+w4Jfa1rcP
hltZ3/74zd/+/v39O3fmFyZrKnJ7Oqo7mfSa4qS24hRGSWpvW9XczNCdrdsq
mbQjPzXY8NWLL+mluphkBFgk+10IMT1y+oNX3C581FiTWhrklnjhUHWCVayj
kZ+lIcnaMOmyQ7Cjke/ZY2QziJDj2U76yaTzqS6niwItkym2kSQLf9vzIdaG
6eEu+Zctssnna9JINYmejLTAmiSP5vzgtDCHKIpVLMm8PoGc6H++JMw61cEo
K9A8xtm4KMI9xv1Uso8ZNdSlLN0rP8gj3dcqh3Ih2dUozN0iy9/O08TAw+RY
WbhTdbxtrLdpYbhDeWZYMzWyOsqhOpaUFWoX5HE2O96nJMytLMqhKTssP9Sj
JNqvvYFanxOVF2wTZX2qMsbD3+yYx8kPksJti7J8kr1t/awMEqI8SqlxycF2
FBfzirKE2HBvhzMngvwdwoOcXSwvOZ8/4Wt6PBX0R3omhlDSEwPTo/0dThx3
tzV2PHZi/8u/OWNwdN++3+q/+atAe+P0SIqnuWGYp32ol3NGXgLJ2aogL9TX
w8Ho6KFT+982+WhfbqIPvSQtOTYwMyakOC25oCAlLsDd2vg42cWaRHb0dTbP
ivPysTxnf/pDp7PvBdidsDHYY3LkkOeFM0mB5MS4SLKrjfGeN+wM9sZQzL1P
7M3yNb18dk+4vw14uzLeI9nfmmJx0sP8aIy3WYy/abT7mQT3kwlB1pV5cZc9
7bzNjYJdLlVkXS5LCaaYG5Gsz8RHkGIpWDWl+DvanTlgrv9+VIRvXlrgcGtJ
cqCnv6uVzaWzB9574/VfvXBk7ytRl40jfUzjQ30CyS5VScEUF8sP33711Z/p
nTqy78z+d6wM3nc5+1FhnHtegtcf3/1NvL2pi/Fpg31vG33wR+NT+l4WBjbG
hw+88l8XPnw9NcTm8sVjJdEuuUmUaF8HbwtjMCaOdAkSoK+VobvZiViPi5lB
LvQUn4qs4PQg5/gQt3SSRZSdYYzz8cIwl7RQz5xYr6xA+1SvcwUxHkXx3tQo
cnNheGm8S260Z0K0Z6KvRXG8R31RVE6ITVqQXVaIQ5KvbXaYfU6wY11BTD01
tiHFvzrRtzCBnB/tnhLhlBxqVxDlmRxsmxRgl0K2L/CxoSV6tZbE0OKDwatp
FKu0CKcwb7MIN+NYX0sP0yMBxgcrk90LYzwqUyIr4nwTyGbhnpe8zx1JDnCm
ZgfnRvkURXkM16eUx3gk+TkVpJDzYt3B5gh3s4IUCjUhIC/Ii54bWUYNLM32
zYtwSQuyjfS9mJ5AyQxxTQizz4j0KogjlcSTSuAKhLvUpvtEWR+PsT0ZF+oV
6nI+xMogxc8ixdc4g2ySHWAPe6dFOkLYx5NNXe2Pk630Kc7nLjudhytQnhNW
EGlXmeiWRbGpLAqjWBwOOvNRMsWcTL5IdjVromfWFyakuZqke1+M9zHLDnWK
tDpBMj4QZHP07O9fsjc/nRbqmh3oFud+Mc7PIoZsdtn6mNfFw75WJ70sDztf
OBwd5JoZ7JDgYw20mBBH8JLr6X1O5sedLh2nmBt4OZ0PJdnEB9iGeVl5mp7w
sDC0Nz3qpv823Ny05IBU10uXDu7xsTEJ8bYmu1m7WZx3tTb2cbKJIV0MtTnd
mBVelRN84cRB67MGod4OsSH+gb7OFD/HsMteGeBPkiktzTs3zjXA3Pqyl1Vm
WniQr6e35ZkQH+uIEBI4MMrDuKYgMNDbxO68kYeLZRDJITseLppfRqhXKkRR
qGuo26WMCNcwz0uO5045X9SnOJ2hxfv0FMU1ZAXTEjxDvc6Gk8wjSKZJFPME
smVyhEdOkC09xrUzL7QpI4CR7O1jZ0hyMPGyPBnkcCrJzzI1yqM4xL4syLIq
1rU8wrkw1Nrq9EF324tetkY+NgZpgQ5FWdGpIS5JXiZ5QQ6ZkS7JIY7etiZ+
zlYUtwuh3ufy4rwL4siRnsZx7kaFITbpl83CPC5kx4bkRIdkRPvmJJDL0qNK
koKjSXaJAQ7lCR7ZftbBLmb/C77CADc=
                    "], {{0, 319}, {11, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0495618838992333}}, AspectRatio -> 
               Full, ImagePadding -> None], {9., 0.}, {Left, Bottom}, {1., 
              0.0495618838992333}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{10., 0.0495618838992333}]}}},
           
           ImageSizeCache->{{95.0995240017897, 
            106.15014361618285`}, {-61.011288374923055`, 
            121.61967633847976`}}],
          StatusArea[#, {1, 
            Rational[181, 3652]}]& ,
          TagBoxNote->"{1, 181/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["181", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[181, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9WAdcVMfWxxZNM8ZEEzUajWJBLKAIKE2K9N6WsvTeewcB6UsTEFSaBRQs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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.050109529025191675`}}, 
               AspectRatio -> Full, ImagePadding -> None], {10., 0.}, {
              Left, Bottom}, {1., 0.050109529025191675`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{11., 0.050109529025191675`}]}}},
           
           ImageSizeCache->{{103.13327041138513`, 
            114.18389002577827`}, {-62.99383691793153, 121.610950609984}}],
          StatusArea[#, {1, 
            Rational[183, 3652]}]& ,
          TagBoxNote->"{1, 183/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["183", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[183, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyVWHdYVNe25yX5kptq1CiiFOklVJXe61CkDjC0AWaGMsBQBoY2dAUBC8Xe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                    "], {{0, 
                    319}, {11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.06736035049288061}}, AspectRatio -> 
               Full, ImagePadding -> None], {11., 0.}, {Left, Bottom}, {1., 
              0.06736035049288061}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{12., 0.06736035049288061}]}}},
           
           ImageSizeCache->{{111.16701682098055`, 
            122.2176364353737}, {-125.44411602269903`, 121.48261937232323`}}],
          
          StatusArea[#, {1, 
            Rational[123, 1826]}]& ,
          TagBoxNote->"{1, 123/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["123", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[123, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9WAdclEfaJ3ff3ZffZ3JJzMVYEDkFFGwoCEhHel/awsIusEtbYGlLkSId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                    "], {{0, 319}, {
                    11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.06078860898138007}}, AspectRatio -> 
               Full, ImagePadding -> None], {12., 0.}, {Left, Bottom}, {1., 
              0.06078860898138007}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{13., 0.06078860898138007}]}}},
           
           ImageSizeCache->{{119.20076323057599`, 
            130.25138284496913`}, {-101.65353350659714`, 
            121.44079890431681`}}],
          StatusArea[#, {1, 
            Rational[111, 1826]}]& ,
          TagBoxNote->"{1, 111/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["111", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[111, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1eAd0lEeWruft7JnxGXudMQ5gG2ywCSYnCSFAEQHKOaGMspBASEI5t1qh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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.06407447973713033}}, AspectRatio -> 
               Full, ImagePadding -> None], {13., 0.}, {Left, Bottom}, {1., 
              0.06407447973713033}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{14., 0.06407447973713033}]}}},
           
           ImageSizeCache->{{127.23450964017141`, 
            138.28512925456454`}, {-113.54882476464806`, 
            121.43026500134872`}}],
          StatusArea[#, {1, 
            Rational[117, 1826]}]& ,
          TagBoxNote->"{1, 117/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["117", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[117, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9eAdYVFnStjPr56jjjKKjmBAVMWAAFVFEouScc840OTY5NnTTDd3QTZOT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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.06982475355969332}}, AspectRatio -> 
               Full, ImagePadding -> None], {14., 0.}, {Left, Bottom}, {1., 
              0.06982475355969332}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{15., 0.06982475355969332}]}}},
           
           ImageSizeCache->{{135.26825604976682`, 
            146.31887566415998`}, {-134.36558446623727`, 
            121.52188515055411`}}],
          StatusArea[#, {1, 
            Rational[255, 3652]}]& ,
          TagBoxNote->"{1, 255/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["255", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[255, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9WAdY1Ue2JzHNmIgtUtQIIooxNAUFKdJ759Iu/XLhXkB6LwKiICiiRg0I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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.04791894852135816}}, AspectRatio -> 
               Full, ImagePadding -> None], {15., 0.}, {Left, Bottom}, {1., 
              0.04791894852135816}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{16., 0.04791894852135816}]}}},
           
           ImageSizeCache->{{143.30200245936226`, 
            154.3526220737554}, {-55.06364274589757, 121.64585352396702`}}],
          StatusArea[#, {1, 
            Rational[175, 3652]}]& ,
          TagBoxNote->"{1, 175/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["175", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[175, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFWHdUW9mZZ5LZ1N3N2cmUTOKxx2OP7XFv2MY2xoDpxjQhJIqEqBISovdi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                    
                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.06380065717415115}}, AspectRatio -> 
               Full, ImagePadding -> None], {16., 0.}, {Left, Bottom}, {1., 
              0.06380065717415115}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{17., 0.06380065717415115}]}}},
           
           ImageSizeCache->{{151.3357488689577, 
            162.38636848335085`}, {-112.55755049314382`, 
            121.42590213710082`}}],
          StatusArea[#, {1, 
            Rational[233, 3652]}]& ,
          TagBoxNote->"{1, 233/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["233", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[233, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyVWXdQnMmVZ29t367WXq+ykECBDCJnECBAM+Q0ZBjSwDDMAMOQGRiyyFmg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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.054764512595837894`}}, 
               AspectRatio -> Full, ImagePadding -> None], {17., 0.}, {
              Left, Bottom}, {1., 0.054764512595837894`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{18., 0.054764512595837894`}]}}},
           
           ImageSizeCache->{{159.36949527855313`, 
            170.42011489294623`}, {-79.8454995335037, 121.5367819177701}}],
          StatusArea[#, {1, 
            Rational[50, 913]}]& ,
          TagBoxNote->"{1, 50/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["50", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[50, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJydWXdUm0e290uym2Qdd2zjggsudJveMb13IRCSQEIIAQLRwVSB6cWAwYBt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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.04134720700985761}}, AspectRatio -> 
               Full, ImagePadding -> None], {18., 0.}, {Left, Bottom}, {1., 
              0.04134720700985761}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{19., 0.04134720700985761}]}}},
           
           ImageSizeCache->{{167.4032416881485, 
            178.45386130254167`}, {-31.273060229795647`, 
            121.56814726877491`}}],
          StatusArea[#, {1, 
            Rational[151, 3652]}]& ,
          TagBoxNote->"{1, 151/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["151", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[151, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1WAdYXEeSxt50t75bWc6WrGRZkiVElgARRAaRc9QwMOSc48CQGRhykEAB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                    
                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.050109529025191675`}}, 
               AspectRatio -> Full, ImagePadding -> None], {19., 0.}, {
              Left, Bottom}, {1., 0.050109529025191675`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{20., 0.050109529025191675`}]}}},
           
           ImageSizeCache->{{175.43698809774395`, 
            186.4876077121371}, {-62.99383691793153, 121.610950609984}}],
          StatusArea[#, {1, 
            Rational[183, 3652]}]& ,
          TagBoxNote->"{1, 183/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["183", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[183, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxlWAdY1Fe2N7ubt5vN7pdmVIxdkSIIVhQVFJWqdFBg6L0OvQ/D0IsUlab0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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.03450164293537788}}, AspectRatio -> 
               Full, ImagePadding -> None], {20., 0.}, {Left, Bottom}, {1., 
              0.03450164293537788}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{21., 0.03450164293537788}]}}},
           
           ImageSizeCache->{{183.4707345073394, 
            194.52135412173254`}, {-6.491203442189516, 121.45907566257799`}}],
          
          StatusArea[#, {1, 
            Rational[63, 1826]}]& ,
          TagBoxNote->"{1, 63/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["63", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[63, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxteAdclFfWN9m82TfZFDVq1ChWpBcVlSICooAovUmv0jsMbWgzwNB7EQUE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                    
                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.04107338444687842}}, AspectRatio -> 
               Full, ImagePadding -> None], {21., 0.}, {Left, Bottom}, {1., 
              0.04107338444687842}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{22., 0.04107338444687842}]}}},
           
           ImageSizeCache->{{191.50448091693482`, 
            202.55510053132792`}, {-30.281785958291408`, 
            121.56378440452704`}}],
          StatusArea[#, {1, 
            Rational[75, 1826]}]& ,
          TagBoxNote->"{1, 75/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["75", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[75, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxteHdUm0mWr2fenLN7pnumgztMt9sZsI1xzsY2DoCJJieRQWCTQRIggRBI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                    "], {{0, 
                    319}, {11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.03285870755750274}}, AspectRatio -> 
               Full, ImagePadding -> None], {22., 0.}, {Left, Bottom}, {1., 
              0.03285870755750274}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{23., 0.03285870755750274}]}}},
           
           ImageSizeCache->{{199.5382273265302, 
            210.58884694092336`}, {-0.5435578131640426, 121.43289847709073`}}],
          StatusArea[#, {1, 
            Rational[30, 913]}]& ,
          TagBoxNote->"{1, 30/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["30", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[30, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyVeQd0k9eyrilpkADulouqJSQXejgUBxuMG65Y7pJlW+7dlnuTLVmWLMu9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                    "], {{0, 
                    319}, {11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.018893756845564075`}}, 
               AspectRatio -> Full, ImagePadding -> None], {23., 0.}, {
              Left, Bottom}, {1., 0.018893756845564075`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{24., 0.018893756845564075`}]}}},
           
           ImageSizeCache->{{207.57197373612564`, 218.6225933505188}, {
            50.011430033552514`, 121.60831713424199`}}],
          StatusArea[#, {1, 
            Rational[69, 3652]}]& ,
          TagBoxNote->"{1, 69/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["69", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[69, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxteAdY21eyr/feu5tk106ITRMSAoEEQqKDcaF3UwxYCBCmdzC99w5CAgkh
0ZuNcYm7wTa9F3UhmntJ4iR21tls9t23b9/3bsnmzV9/LLPZ+33zHeY/5zdz
ZubMmXMEITGXlvovBw4cKPwYBlpCqXtBQUJ56L/Bh0d5UUrivwLj+psDB/4A
fxF+YW1zfk2+IpKtSxUrIsWKcGtFsrMq3RVLNmTyTbFEsSzeXFiXrUiUq6LN
VdH28vrmunRjTSpdkyhF8m2RVLks2V0Sba3JtsAIfK6LFRL5llCqWBIpV6Xb
QtnWmnh3Tbwlkm+uSeQiuRIwABBJQWVnXbINRoRSRBGRiBFal6qWkMjFih2U
BzdUlpWr4g2gNcSrjVXppli2CcutiuWIULwFIxKITAa6iHuSh0KZEiyA84sS
2aJYCaEtCjfB7JpYti6UAi2I5ItiBdCSWAYE6iprKIE1BaRlTSRfFSoWhXIU
gBI6uyJUqsEAQDAiCFyh4kGyAUlYFElRt1EAOrWwrpgXAikXREh6QQWsza3L
VUIFzM6tb+yRUIkI1+Tza9LZNRnQh6l/BMytymbWFLMq2geQo6SyIAfAzD8C
UJszq9L5tQ0gmJ1els+sKGZXN6ZX9pabXIalFTOrcpDAOLkkmVqSoYCpZTGM
oKLipUDTKxIAzCyBP4rpJenkghA+1QBkXBTNLMtmV+QwTi1KppfEwEwvyhA7
KgIVUESES1KUQcBLckR9SQoqKi3p1AJCqGRyQQwW0ClErhon5yUTc2LgJ+ZF
D+aE8ImqAN2fEaoAsnuzwgcLItQCqoICUAa1AAQMSg9mRYjN9xJ0Vk0w+2Ae
mZreN4UI3xOsCwDUAmpqPwBmUQAyTq8j4z7dD7QPsB+j/rw3tw7j5D4JOnvv
vc3xufX7cwhgz6V9ACDEwrwQyQzw82JgxmfWYQSV/aSWw4jSP/Nj02tqCUog
QUn9qdZSq6Czama/2f3qd6dWUdqvqBaqkcCjs2qhGqO2+SvLasydyZU9V2fX
9juwNzu1DACg/Zb3r/vPnvxKiC7xT7B1Fe0hb08s718CBdyZXFMv/StSm90P
UOv+yo1fEYSpBnzAT//Pq4xNC1FXgRmbXB2f+ofwf71fUwghDCwxswqEpHR2
3+d78K+qCPlUwdS7/D8ch/c1iWrtP7B7R2x+j1DYzIJE3WHQsw89ao+AXxDP
LYsWVmTQMGdXoMOIEVK1JrQFAUGzhSkYkfa1ijQ9Vd8TTa+IppeE0KuX1mWL
qnFhVQKfc6pxdkWM0tK6ZFUoW1mXwri8hvAgWRYCXoJcEGtS4OGSAjncPgBD
R0RFdUPBLCpECfkUydBxj1GB0csRrku11t5tBWbFCME1vS6Rw4hciBL5qgiu
dbjyNlAhjGKJTCSG8QMMRpEMAcCIMFKFcB+BRIgKZRtiuVIqU8KIkkS6ASRS
yYFQdZCgn/DYADCKAQb9VBN8ohKZVCmFl4lUiZJctolOoaSQbwEhwn2APYl8
U67YQgmVAG1sILSnhU5tbKtpQ7Gt3NpUKreAQUi5s5+Um7ubWw8Vyg0gxA4C
3NxQbik3doCAAQmQQqFEJja3N7e3gDbeW1O+l2xt7Wxv7wIhqK0dIJhCZoFX
AdRCxLhKvrW9i9Kehfefe1pqC9uIbcT8zkOUVG7vs4wC3isiAMQxlTWVIhDq
IbooADaVSNTqpVELOzsPUQe2VQwkBIS7jx6KxFJEghiGJWD2McxCRT1+8gxN
FwB2dh8pYAuUG48ePwUcfEqkcpl8QyKTPnryeF0ohqWlMsXUzDTYARiYgmoZ
G7+PZubmrTtgdmFxeWjkAphFw7964/bDR08gqLn5xVu3xx8/ebGyun73/r0n
T1+qdm2nq2/wzr2JZ89fAj80fPHVl9/MLCyPPZh4+uzL1TUx5BnqvLN3oH9g
6MXLLweHRu4/mJ5fXjs/egk+5xeWwHN4wb78+lsAwCpfXLt16fK1Z6++vj1+
b2lleXJ64unzJ2g5vXz1urt/aOzB1NLa+vLKGri9LpFuPXyk2spdAEAyHz59
kVNQ/O7PP90du7e0vDoxM7sqEkMqIC0wQrrAT4lio7GFBRZ4HYLRq1+8+Opr
mAUjkBnAQLqePnsBjhUUFkOksJZ0Q7n78DFEB1NIMWzBS1727ocfL4yM5haW
PHuFRAEAcAAAoLKJVMEOZP5PP/5U09B87frNl6++guRDwYCHsMTi0opIIgYk
UkiPnpZXVIHCg4kZuWIbmgOYevjw8fTMHKT9xs3bk7MLLSzO7Tv3Loxchl1D
tm96FtrI1vYjSO+Tp89nZueHL45yuHyhSAa+QamAk+ASEv7kNNTAd2++v3L9
RkrqOUggWipgGWIEXaFIcuv2XfBnRShJTkmbnJoBwMPHj8A9NCGAhMBh6/nd
fXNLy76n/AGAVKNE/GBi6tWXX6+uCWEVCPz86JWrN27y+B2QHCg/tMghe9uP
Hl+8cq2Byb545WpBSSkkbXp+AcpjTSy5NTY+OTu3uLo2evU6i8O7NXb39Zu3
N++OKXd2YWfvTU4Bv7ACmzgPBfPdH/80u7gwNTfP6+ySSGTLy6vgIUQBq0DG
IBZI+JMnTx4/fvzlV6/hLMCeIpUv3UA3FzkXG5twwGQyhaoNKsBD6EsAgI1D
Achxk2+hvQjVVU3toO0OsqoyghxqIHVT3dczAa+EapEpN1XFgIBhBDsorypj
pXxzCypQurGFdm9U9wMGfoVJFSDfevgE6fMKtNnu2YHl4NTCr7wJuDUV23Bw
0OYP4cDqyG9M2Sb8uAMGQpibXwYAehGoASqf9/q/Ymt3LwRQAQAQ2url4OHm
e8vqi0Ox/wZBnUcuHRUSxj1GfeNsIL7BiE6pAeqo4daDWZlyey8D7zHqJSBd
6B0nlyOkzjPqMCQKTZpKF8k8gpGqbj0kaRsoIWHCLis2oCQkYsW+Ow5+CMvQ
LYZDh/RJCFCygZDKAcS4KmS0SCB8xA1YVKxQ4VV3qwqMGgEATKEWAADXN+K8
UIbkSiwHGJw15AYXyeGcQgaQB8kaOIT8uockLK8I4Rc0+l8CYFDAwso68Eur
YsgV+kgAFWR1xeaqWAY//+GNAZ0BefOIpHNLq+jDA30qqKJGEg6S22NwhlYW
loXoO2RpTbS4tLayCr9ZFu5NzkC7Hn8wMzxyZfD8JbAAmwKwxVUh9ITldTGA
ESHcZduPN7YeoUJYDuwgIagYcAzkoDU9v4S+wVT/A9lAn08gQZ9n4A+suLgm
hlcTvM0WVkXAAwZ9rQEAVIQyJao1vyKEEQgwwIMKzMInqgUSGJfEspmVdVQd
5OiTT0ViFUng5QnPP5jaE66KEa11yfy6GAh4tTUUA56j1maW4We1aG5NtIdX
AcDDPVdFqpfqB4DKzgoA5Kgb4C08aFUP1z1nllWrg33Ao4B51bsUJQCgKULo
/b9NEC0h4g8qgcfkXtqhGFTvw1UJTCFLwBRKK8ibUy5EX4OKTbRs0Nep+o2q
On1bUuWOSLmNAj68NlXj3ineAMwHgPrludeU4Ngqt+WbO6jWB8X3pxiZVTXP
XwHUGAAgr6PNh+rZ/Y0CaGMbmvAmPKLQxy3aTNQE6lCTm1uPoNF9aB3vZ8Ex
UJcrd4He/fATupxaEWZRAPBvf/hzbVOLuomBBC5W9C0BSfjpf/+thcMLZUSh
Wu97OHJHwDEEy71DF4LpEbzefggBtQ8hwyMKAN//8cerX9w84e7J5nfy+wch
mfKtXTRvAHv8/BWUxGlaGKtD0N7TV89uk2xsS1Wz4MajZy93n74IpNEaOW39
Fy9VNDQ1t3LhAIKTYHn34dNv3r5LysgoravldHeBbkNLa2tHhxx5cD6EHvXd
m3cFhaWZuXlDo6NVzU0wy+vqZba2yTZ34Xx9/+NfmtvaQL17cLC2samljdPU
2soRCBpYLCizt3/6S0VtA43B6Dt/HiR1TCZcuI1sNvD83t43qpAjYxMEgwOg
BXaAYOmOni42j8vv7YZOE3iGjizHa69ltbTx+TDbwuXyu7vYXE5rO/dMZBSz
vQN8BjmTw1FTZ29PM5sFVMNktXV217e0sNrb2TweLM3r7gYG/OR0wNjawuM3
c3kAAC0uX9DMbu3q62/jdYCko6eHyWmtZbfCEu1dXeAbTEHgoMvmItbAZhuf
18hqq2pogE9QgRVb23nwIAQMmOJ08OuammHTwWdwHojVDm7z6puZMHb29sEb
Bnzg8LtAF0LgdnZWN9YDDNaCsbS6srC0hNcpaGJzwD4kDbLUwGIingwM5BQV
1bc0cwQdTa2s+mYWAGBWBWPCcpDqkqoqyGFRRVltYwMAwBnUKzBYUVNb09DY
0dVdUlHZxmtntrLZ3A4WhwuBwwhRQAgwCyPg+d09EDWzFfIuAGFlbR343NXd
W1ffyG3vAJuwp+2CTi6/i8XvgCia2rkQGvBguXdkmC3gwYpdwwP9gwOwrYKu
zqHRkdbW1vOjFzv5AhAODA329fTClnUN9HG6BYKebsFgX29/X8/QQF9fHzwC
B85f6O7p44Fs9OLIjeu9g0OXbt+6cOXKhes3bt69Bw/CL+6Oj09MX7k7xm0X
9A6eH+gbPn/p6sjFqwOjV0YvXbt0+frY+EQHr6u6oXlOLFxWyBbX14GZE67f
X1u+PTU5Pjtza/rBpetXbk+Oxwb6h7m7hZ446Wdv52tl4UI19aVSPIjEo/oY
F0M85eDvzQ8csPnNb5x/+7HtgQMev/+D0+9+5/nbj4MOanh+9FG4prb/7//A
0NaJ0tNNMTRmfPZJOgEbqYOJ0tNOJeDOanyeoa8fo/lpNFYrEXMkx1g/+sih
PJJRuq5ODg5fTCImffZZkYnROYx2HsYgT1u3hqSfceRwhZlJHl6jhKBXbWF0
TkOjkWyco48pwxgU6ek1mhHyD2uwKSaleI0K/BEOxaBQS6uJQijTxdTidWoJ
mHYL0wqtQ53WlDpDQg0O021hXobRYZoTq/G4RkM9tqFer4VFte6n3fZUlrFp
PR7TaW9ZidFup5BryYRqomEDAdttQanS+azTnMQl4Ftw2n025HqtwxwLKpOM
byMbNRvr9duRmnW1usgmbSZ6zUa4flsLpvZhAdm8xRTTZmzYhsX02lLq9Y4I
zEhtZobN+ocHqIaNWFyHKYFFxoEDzRhtvpV5k672AAnPN9VrwB4WUI0asboc
Y8Nmon4jEc/Da1+0t2Ib6neTCV2mRmysXr89uRmP4RIJLUQ825TYjvt80NK0
UR/TbmbQSTFl6+IGLIlMPJZnYggrdpoQ2ARNwVFLJt6gzwzfbU1swukPWlJb
AEDEA4BtjGcaavY6WHHw+v0mBgIL43qszoCtGddIr93IkGNGZJoRW/W0h63N
Wg10+qgmfVZUJlar38qog4TlGRO4ZqbtJEIbBtNvZ8U00O2nGPdbENh6nw1Z
kXlG+h3GOA6V2E4m1uGxfbZEjv7hbip+yJLA0dU9b2vVbaTfQtAaplL5ZuRa
LPa8g0W7gS6PqDdkTeRi9YZtzduNsV1g09aCZ2pSr4ftszKDVIPbw7bkes3P
B2yo7QQczxgzYGPRY2HWiMEMgcTQgE8yGrKzgJQOWlM6iAQIpMeKwjPTb9bT
7Lc04cGmGEGiiLXaR3qoJK6psUAP02ZuwjbWadXX7TU3aiXoQ0Sw4/UY7UGq
KYdI4OB0IcxWkn6jlmaXGaHVGN9mhO+yIAIzRCXBEixjbA+FwiIZNuvodZFJ
LEN9LtGQTzWAbbpkbcYh4SGuTiq5xcSgHqstIBmy8bpsI2yXBbkJqztsbtlm
gm/D6/SamQsoBm0GWl2WhjxDrS5j7KA1mYPT67UyZxH0YEMh832mBi0GiFfI
9hkTQJepr9dnToEoWMaYPktrtpl+E+4IhAkGO8gGnTbkJn3tTnNTJgks44Yt
qPVkYrWeFhSMwFAb6qHHmtiA1e60MGMa48Gri7ZUPolUp6c7YGnJQjJJGiCb
NmGODFuYcUnEFgPNUQf7HjIW9rfbjtJC0IfkdFmYtOp+OmJtBHhwcvSkDZOE
q8N+ft7KhGOoyTHR7bQkVmGOdJlTWUQTlgF22MaGTSE262kMWZnDpnOJeIG1
cbm2Rr+FRSPRqEEXN3TSBsKBKLrNzTi6WDZRT0AhVGsdhjqpN8bW62r12Juy
qMZsHW0kfGM8FECvuUnlEY0LlpRaI2ytod6QjRmbTACmk0qB8haY6rMoRlXa
moPmpAYsrlLryMgxuxYrUqOeNuQW8sOi4vhkUoXm4X4bch7ucIO+Vr8tFSq/
DY+BnDfjdHspxm1k4xJd7fMWZsV6Wjk6h3rtreB0M/FHLtuYN+J0+BQS19yk
5ODBbitqDQ7L1NO9aG3bQjRoN9IaPmbWhMNwKSSosczDB/tsrfM1D5YRNPrN
TVvMDOp0jnBNCE0EHIdC6DA1ztbS7Lc3h9YH52XwpF0rdAwdbY6ZMVQUj0xg
mxhmHzky6GCZrPV59eHf95ri2ERch6GBwN68BYsRmBLYVOM8TS1AFlPJgtCo
ztMMLgnHhz1ysASXBqzMAJCrpcnGawsSoh/99e/yl287SPpQwF22ZvW6mnAA
W8kGRQZ6rXjNrpTsy3fGqk7gWIY6cBwEFqQa3SPDDhZQ6uVEAxZO4zyTeW9q
bDzOtMlAh29sBPmp18f2H7Os09cpN8DX6hwcEnTce3B3PMOqRl97kEyFLg2Z
EViZQVOtJxgXa/zuUu/grS8uT5W4VGFwHVRCN8UQerLAhlqBwzWYkWoO/XZ8
8NpgJ/P+ObsmHLbdmsyjGMFBGLS3KNbDVJkS6z77aObudG9LxXKpG5OAqdHX
gUPKNsJ0WxlDe28gk6u1D60tLY4wM+dKnKGcGsiGdcb4VgMMtMdKnHY9LIHV
Eq7vXKjJXueH1BvqwCloNsCySAY9Nma1up9DRBUkQ7H08Z2qhC2BXxMe0041
aSJg+WQjOLkVGI12c+MGisnu22+WJq6/EE5VYTX7rG0a9TTbTbA9Ry2LNT+F
c1dtol8eGVQSnVFZXFqHhb2GJfT4xprd1uQSfUyPnWWlgSZP6zBN+1PMgQO1
OB0ulKU+9HZ8p61ZjQGm56h5ru5nV13N6QZYqp5RBVarg2RQR8DCFgOV4DR7
j5rDeN/JwQGj5YInQPK5Nia1WAyfTGyzIDWQDM8fsy411Jl1tD2hcTCSiK83
0Bx2tuCYEAYdzLvtyFBRnXakGkPNy77HYz86VG1hnnToYKGuVuyhg1lwWX+u
wfj4k8zPNeI++9Tjsz+kEI2qPNyKTA0yTXRqjls2nzDPszHKtiI2Opjn2Jpm
nbQrifbODw9geTgITjtz/ZyavO3ag535oT5Vnta1nsebg07k0xxyvBz64oNH
suit0d7dib5tiT787LAmukslw6s+0bswwa+R5l5K82AmeLXEerQwvCrCHLNP
21fSvYvDPTJoHrl0z+Jwd0FOIi8ztC3WrzsvlpdBL6e7DzXk9xWlNiQECbJT
Rlnl7KKkxoyQ+oxgTklCXdqZzEj32rzImqzwnEiX6iT/5uLUygjfuljvqmhP
VkJIZZRPeZxPU0JAXoR7+lnXQoZzQXhAQ1IwvzKJmx3ekBQkKE+60JjZVhpd
mRF6uT77Ul12aXRAYcypgggvUCmOPpVzxr0oyrsgNTDS72RykHsiw5lx0qg0
Lag8NqDyXEjDORorPTI/zjc1wo3bXNHV25Ed63uhOrk6IygzxoOVR+8oiRJU
JScE2sSGHrt4nhfi554V49RcxIgJtI71O37WxTrGxSzG24zuRaW7kSMdjekn
8Il+djRPk5q4gMTAoyUpfvkxJ/MY9uUJ3qlnnLKi/AoY7nmBTrHBJ3OT/NLC
nOmuFLq7tbctIei4cchRozNHTQNtMWEniE6WhGSaU2GUe164a1akf8ZZ3whP
cmm8e3aEa6zPyXyaS264W1OCe0+uTy3dJtnNJM3XsoxuXRlmXXTaOtLHpOC0
baafZWKQQwbNLj3YhuFiddbVPtyRQjtqmuzpcva4ZZqfa2zwqTTXowmepoUx
DmXxLjXxPuUx3ufCPGIC3GmeTmGBzskRPtG2erV0+5RjWulHtdOd9dN8CdkB
pHRHvXAHgrX2Jwxb/auj/dcuXlubfzB359qt4dGrg73M8sKr/J7L/d29gr7L
w5dfff/vr7774eW3f3769t2zN2++/eNP7/79r+/+4/9988Oft549Vbx8dvvG
xfF7I+P3r42NXR67ff7OjYvz03fv3rr04NaNuzev3bt3o8r9k1TSb+ucP270
/F2Ro0ZF4Of1IYeKHD6qOHWoxkOjyvFfR8tPX6o6c6me3l0Q2JPu0x3r2hbh
PpAfOtaYxU1KGS49d3Niam55fX5FvL6hWJYplmRbisePxMrHDxZWhVsPZ0Xr
/YM9dyfv3rk3fv/enevXrg5eGLnyxejo4OjFCyNf3AIfHnz7+rvXL77/9vU3
X73+8sXLr1++ePL8xePnX776+vW3379+8/XLZ7/8/PMvP//977/88vMv//nz
z//1C3C/wIAwKvaXN9998/aP3//w45/e/fBm5+G2VCrf2drd3lWKxKvKhzvf
vH3zYPJ+/4ULExNT01MTX9y+PjEzP373Qe/gQFd3x9VbN67fG59bnr8/t3D1
yo3bN+9Idzav3hkbH5s4f/ny7u4u/CSfX1l/9/b1//0/f/vm5dd/+8tf/vq3
//Xff//5v//zv168ev7i+Vc//PAj/JR+++b1rZtj9yfndp88nZidBGcePXs+
NHIhOz35+baMXVd6oSW7NoXOrcvt5ZT01qa1F8b2NeYUR/swi+Jbc+m9VQns
DM/WtABmcQS/MbYx2lGQ5tuS6s2Od+NlBTWEmY8U+uckBga7O4S4Hkth+Kb4
Hy0LdauJ9yoPO9qR5c/O9KtP9Mxg+ESf9gl0cU4O8swMPdaceaozNyw90KGQ
7lob7ZIdZFt91qsuPagq50xRlHNzokdbijsz1iuddrIw0j/V92huqGNNjFNd
olvbuYC8sOO1sa7NSW654cero4LTTjlEeVvXx3jm0U7mRx7rKI/gVcaXnPWu
ifOvyQ1pzKVnh7glOpE4hWE157xz6I6nrYgncYeTQp1qisPL4wPpTrZp4YHl
WdFDrSWVcb41yaF0dzvaSesQJ5uzns6uhngvK0pSGsPL0TbO83hK8PGa7Kgb
g6xObmFlJj3K+1h+wpnGnKhcxqmEAPvazFBWeXJbdUFFRkRxekRdXgK3OrWl
OpldnthRFttbFXeVX1QY452fHJoa7NyUHVOWFpEc7JQfHVCdcaatKBlaMTM9
MCPOJzPcG7piQbp3c3Fo3lmPMN+TJSlnanPOQtODttCYH5MVeaosCvLgVZ4U
GOVuG+Pj1pQTkUZzjTvtnnTGs70ktjo3rCohkJXGEJQmdtamjXCrhuviK856
Z0V4nIvyqco7mx/lVRbrWZcTXpzglxRk11Ia35oXJiiLKYr0AUC459EoL4dy
ukewPfXIvx2I8zxWFu4f425XnEzLCQ30c7RMDfHMivburGNUpgYwPOxz4r0T
aI7BZiahztb1qaGFKf4QEf04JfOMBz+fUZ9Oi6EfZZXEliaEx/lTS6PdMyO9
q7No8f62DG8HbnFkVoQX3YNSEuPaXBiVdsbpHMMrItgDclieEVKSElOUdMbF
wsRa53AJw629LqUhJbSQ4VmWRCtLpcXTjjUUJFZkMo6Zkz2szVMDXYszguvz
oktjvASQhCR6VrQnrzIxI9zb2/GEs4P1CSolxNWqv7GYmR1Zdy4M4sqJ8K5J
9c+K8HGyoFAIunZkyzxGICs9mFcWCZ02I8iRmRnSmnumMNEnk+7RW3+uMjue
WxDWVhjMq42qiPfjFSe3ZYUwz9FK0wPKIr1HKlJq0s80J7u3pIaVxPhl03zr
c4JyIz0KYvzP+ljE+ToWxJ8qSfApCnY662KbGeGQznAtOeeWFegc6ePm42B6
zsWRlU1rLg1piXcdzE9oyjxdFhOYFuDclhHTmJdQXRKZSndpSPNrzae15IZe
Y2bWJvuVpoanhTs15gULGhKK4r0Tve3y6Q5lce61SQHNqb6sjNMdJWlNmR7F
Z2yKQj2iTzvkJgXkMk7kwDUU5pIXdqwuwassLiArxofmYRfgYJdGc89geMWE
uNFcHd1NsMWxrl3FjNaquMAT1LQA1yR6cFbG2eq8tDh6kLOdTZiHPSeH1pZ2
ui7Fv/0cjVPHgMpJ9vMoS4nIYDjF+5wojqOzikIrw1xqz50ujXDpakpsb8nO
T6WlhZ4sivdtq0iFe7Y47TQj0CE20ieYauBKIiaGumVFnogNOEkPdGV4H/N1
tT3r7WatqYH95CN4A/jZUqiHDp0wxUb7nAjycTxpR3U7ZhtoTznrZhMb6HGe
kyxoikvxcs6IikoM8DzjedzX5USI01F4GIwK8tvLkwea0y92FLQXRXY1ZBWl
RqWdpaX4e6YGu7emB19sSWzPCklwt490sq+JO91cTC9IC00K9Al0pEZ7WlQw
nHuzAgfLohtTGRkBnpEO1pmRnvmp/jEnLMDz1NMncmlupUEnG9NP/383ybFP

                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.025191675794085433`}}, 
               AspectRatio -> Full, ImagePadding -> None], {24., 0.}, {
              Left, Bottom}, {1., 0.025191675794085433`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{25., 0.025191675794085433`}]}}},
           
           ImageSizeCache->{{215.60572014572108`, 226.65633976011424`}, {
            27.21212178895486, 121.5079712565408}}],
          StatusArea[#, {1, 
            Rational[23, 913]}]& ,
          TagBoxNote->"{1, 23/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["23", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[23, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFemdYm1e2rqedmymJY9PVC726YGzHFRtjjMH03sE000TvRhRJqFCE6LjE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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.020262869660460023`}}, 
               AspectRatio -> Full, ImagePadding -> None], {25., 0.}, {
              Left, Bottom}, {1., 0.020262869660460023`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{26., 0.020262869660460023`}]}}},
           
           ImageSizeCache->{{223.63946655531652`, 234.69008616970967`}, {
            45.05505867603128, 121.5865028130026}}],
          StatusArea[#, {1, 
            Rational[37, 1826]}]& ,
          TagBoxNote->"{1, 37/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["37", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[37, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxteAV4lFmWNuPWA8SlXOICwSVAsBjElRC3iru7liSpSklSUaDRxh2SEPdU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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.017798466593647318`}}, 
               AspectRatio -> Full, ImagePadding -> None], {26., 0.}, {
              Left, Bottom}, {1., 0.017798466593647318`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{27., 0.017798466593647318`}]}}},
           
           ImageSizeCache->{{231.67321296491195`, 242.72383257930505`}, {
            53.9765271195695, 121.62576859123348`}}],
          StatusArea[#, {1, 
            Rational[65, 3652]}]& ,
          TagBoxNote->"{1, 65/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["65", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[65, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9eQdYnNeZrmJ74+zGa0uUganMDAy9qCGhgpCQBKL33nvvZegMbZjemKE3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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.009857612267250822}}, AspectRatio -> 
               Full, ImagePadding -> None], {27., 0.}, {Left, Bottom}, {1., 
              0.009857612267250822}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{28., 0.009857612267250822}]}}},
           
           ImageSizeCache->{{239.70695937450733`, 250.7575789889005}, {
            82.72348099319262, 121.56641788026906`}}],
          StatusArea[#, {1, 
            Rational[9, 913]}]& ,
          TagBoxNote->"{1, 9/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["9", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[9, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFeQdUm1e2rpO5a715SSa2aRJIQh3Rm3HcjTFgY8CAMWCK6b0X05toklBF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                    "], {{0, 
                    319}, {11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0104052573932092}}, AspectRatio -> 
               Full, ImagePadding -> None], {28., 0.}, {Left, Bottom}, {1., 
              0.0104052573932092}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{29., 0.0104052573932092}]}}},
           
           ImageSizeCache->{{247.74070578410277`, 258.7913253984959}, {
            80.74093245018415, 121.57514360876482`}}],
          StatusArea[#, {1, 
            Rational[19, 1826]}]& ,
          TagBoxNote->"{1, 19/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["19", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[19, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxteQdUlGfatpvs7v/9ySYifWCoQ1MUW+w1KkUBaSqCUqUXQQWlwwxTmBmm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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.012048192771084338`}}, 
               AspectRatio -> Full, ImagePadding -> None], {29., 0.}, {
              Left, Bottom}, {1., 0.012048192771084338`}, {{1, 0}, {0, 1}}], {
             
              Opacity[0], 
              PointBox[{30., 0.012048192771084338`}]}}},
           
           ImageSizeCache->{{255.7744521936982, 266.82507180809137`}, {
            74.79328682115866, 121.60132079425208`}}],
          StatusArea[#, {1, 
            Rational[1, 83]}]& ,
          TagBoxNote->"{1, 1/83}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "83"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 83]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxtVwdYVGfWNrvZ3WQ3q1EYmN5hhiYqNlBUkA6KICJNulQRAUF6GQamMoWh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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.009036144578313253}}, AspectRatio -> 
               Full, ImagePadding -> None], {30., 0.}, {Left, Bottom}, {1., 
              0.009036144578313253}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{31., 0.009036144578313253}]}}},
           
           ImageSizeCache->{{263.80819860329365`, 274.85881821768675`}, {
            85.69730380770537, 121.55332928752543`}}],
          StatusArea[#, {1, 
            Rational[3, 332]}]& ,
          TagBoxNote->"{1, 3/332}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["3", "332"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[3, 332]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxtdwdcnFeSp2/3ds874yBEpnOmCcpCERBCApFzzqHJiCCyEE1uOgdoslB0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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.01067907995618839}}, AspectRatio -> 
               Full, ImagePadding -> None], {31., 0.}, {Left, Bottom}, {1., 
              0.01067907995618839}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{32., 0.01067907995618839}]}}},
           
           ImageSizeCache->{{271.841945012889, 282.8925646272822}, {
            79.7496581786799, 121.57950647301269`}}],
          StatusArea[#, {1, 
            Rational[39, 3652]}]& ,
          TagBoxNote->"{1, 39/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["39", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[39, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1eAdYnOexrnPje5MTn9iWBOyyvbIsRUKoV3rvvS9FdBBdEp0FFrb3ZXdZ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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.007119386637458927}}, AspectRatio -> 
               Full, ImagePadding -> None], {32., 0.}, {Left, Bottom}, {1., 
              0.007119386637458927}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{33., 0.007119386637458927}]}}},
           
           ImageSizeCache->{{279.87569142248446`, 290.9263110368776}, {
            92.6362237082351, 121.52278923779029`}}],
          StatusArea[#, {1, 
            Rational[13, 1826]}]& ,
          TagBoxNote->"{1, 13/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["13", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[13, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxtVwdYnOeRVnJ5cr7LpagBy/a+dAFCiCaKEB0keq+iiN57L8uyvcPSUXFT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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0038335158817086527`}}, 
               AspectRatio -> Full, ImagePadding -> None], {33., 0.}, {
              Left, Bottom}, {1., 0.0038335158817086527`}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{34., 0.0038335158817086527`}]}}},
           
           ImageSizeCache->{{287.9094378320799, 298.96005744647306`}, {
            104.53151496628604`, 121.47043486681576`}}],
          StatusArea[#, {1, 
            Rational[7, 1826]}]& ,
          TagBoxNote->"{1, 7/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["7", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[7, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1dwdYlHfWr5u9uzebYqHPUKb3Gbrls3exIKCC0ix0EJTeex060/sMVezR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                    "], {{0, 
                    319}, {11, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0035596933187294635`}}, 
               AspectRatio -> Full, ImagePadding -> None], {34., 0.}, {
              Left, Bottom}, {1., 0.0035596933187294635`}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{35., 0.0035596933187294635`}]}}},
           
           ImageSizeCache->{{295.94318424167534`, 306.99380385606844`}, {
            105.52278923779029`, 121.4660720025679}}],
          StatusArea[#, {1, 
            Rational[13, 3652]}]& ,
          TagBoxNote->"{1, 13/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["13", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[13, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1VwdUlNe2zrvvrXeTlxuj0qb3PkM1Go29Y0UQKSJNQVFABEFBehvqwPTO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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0016429353778751369`}}, 
               AspectRatio -> Full, ImagePadding -> None], {35., 0.}, {
              Left, Bottom}, {1., 0.0016429353778751369`}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{36., 0.0016429353778751369`}]}}},
           
           ImageSizeCache->{{303.9769306512707, 315.0275502656639}, {
            112.46170913832002`, 121.43553195283275`}}],
          StatusArea[#, {1, 
            Rational[3, 1826]}]& ,
          TagBoxNote->"{1, 3/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["3", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[3, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1VwdclNeWd1/e7uYlL7FQhum9w1BsWXs0WEBUihTpQ5Peht57h4EZGJhe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                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.002190580503833516}}, AspectRatio -> 
               Full, ImagePadding -> None], {36., 0.}, {Left, Bottom}, {1., 
              0.002190580503833516}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{37., 0.002190580503833516}]}}},
           
           ImageSizeCache->{{312.01067706086616`, 323.0612966752593}, {
            110.47916059531153`, 121.44425768132851`}}],
          StatusArea[#, {1, 
            Rational[2, 913]}]& ,
          TagBoxNote->"{1, 2/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["2", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[2, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9VwdYVFf2d2uSTVUp0/ubPhSRqGvUVVGxoCKo9A7SOwLSQToMM8wMUxmG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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0016429353778751369`}}, 
               AspectRatio -> Full, ImagePadding -> None], {37., 0.}, {
              Left, Bottom}, {1., 0.0016429353778751369`}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{38., 0.0016429353778751369`}]}}},
           
           ImageSizeCache->{{320.0444234704616, 331.09504308485475`}, {
            112.46170913832002`, 121.43553195283275`}}],
          StatusArea[#, {1, 
            Rational[3, 1826]}]& ,
          TagBoxNote->"{1, 3/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["3", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[3, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9WgdUlMe3RwFFEERhgWV77wtL01hjQ6WICoJSpHeQLqAoKAhIX2AXWHbp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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.001095290251916758}}, AspectRatio -> 
               Full, ImagePadding -> None], {38., 0.}, {Left, Bottom}, {1., 
              0.001095290251916758}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{39., 0.001095290251916758}]}}},
           
           ImageSizeCache->{{328.07816988005703`, 339.12878949445013`}, {
            114.44425768132851`, 121.426806224337}}],
          StatusArea[#, {1, 
            Rational[1, 913]}]& ,
          TagBoxNote->"{1, 1/913}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "913"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 913]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx1WQdYlMfTpyOISD+u9144QNBYYgGMBRWxgAjSQgcVQUEELKggIL3Xo4rl
b2JiBRudu6M3EXtNLLFrojHxm/deOIjJd8886+zsb2dnZmdn90WqzxZnfzUV
FZWIKdA4e0ct3LbNe+caDegs2hnp56MOzHxVFZWp8C/C1zd1AZ2/Kr/Q2Ant
uSsylKALdPayFO3C0L8JADB05lIHCoMWCB1SzkLlytH/5FHwV0OgFtWA8pNh
SoByCvBo9+yVDqBzV6VAZy63ozwiVGBOXxyTnG+UASnB0E5eAnUKpiOkmAWE
LoF20fbni62nL7UhTEMbilHSGKBhbBSln+pblcivVKGMEjBZoXJdME8p//eK
/znx3zagXRiaZBIolylXGTMM/KofUwUYoLHwXuyYWLR+wpiJdesnzDjT8HXc
EHn9hD1nL40B0A1F5eisMf5i2+kGJCaoBnQ6ACai14Cs+A+vG9rByInta2hX
KkRnnbskBQIH0fRAFU4ALrefu9wBhE4E5FgOwCoXWv+hvGGcUAcVlsAoMmVc
ggonR2lykAGMxLO+bfLuKF1DcnUcgCbG5PyZ7DIy8ULr5P1VRhLdu7Gw14/B
xrZJ4fipCy1AgFECfmpogcRGkAp/UeXo6FemTkhg1vkWFPafgLGlL4wZo8w9
pHuhFTUAWUsB+IpA+MO5JsAoNQChZistV3b/TV/hfzzfjNJXsJNnG2GVH8+3
jjPNX01BGRhFGSVGaScqUbYoo5w4JrzQjNCk0YkhkNTDaNPJ82AATGlVUPM/
YBeaUMD46D8AqBcnzyOrTFY72RKl2V9pVnqKevT/xXCy4yiDDDW0nKpv/irU
KDO23RcRjDIVlfIJwHgy/CfgH8kwKbv+Uzg5/5Ghi+OE4tHchrqtACBJhdo2
Tkq80pefGpoUNDaKFMZLLWcuK4YUOQ/tmJ3j0xGmHonJ2LG90Dx5iTFVKADt
jgOQMI5HEslqtFs/MX0yALH/X4AxUkasoeU/RpXaLkzyd5Lvk4UKfxEa932M
HwujooqiNxdaG6GkQ/GEFkr3WKu4ZJFqNi5EGSV//op0nKDbWt8ovXC1A3ho
z11uQ+XAX26S1zcCuPVSi6yhqQP4i81SBaD9YmP7paaOxrbOq63SS01tjW2y
Ky0dQMCA/HKzFORNrbKW9k6gxhZpc7ussQ2EHc0dnYBpape3SDtbpZ3tHQgA
kACYoDY5SNpkXe3yzg6pXCrrAeqQdsnkPR2dPSAHAlibvKdd3i2VdUs7kKHO
rj55Zy/AEGFXLyBRAgAIoQUMAFAGAChGKuuUSuWIRIaoAgDwSursUlAnohCd
OJkUajtlCg0Ka8cAqJ5Oea9MijDyzu6urh50FNU/GQA2oPLJhOpBGGm3tLMP
dURpPOqpktBRxGuIg7S7q7NvzNOOLrmsRy7vQp1FdEq7EVIqB1XyXgBMuC8b
s3/cfWQhcB+JakenUq4M1LglYxFGPPonYHKrXEUZapRBdxbttrXLkZgoJDKF
NuCRrrR7Aiwd23EAoDsOXSCIgJLQmLR0yM9cuNjZOwDJ1q4IEVCrIn8gIDDa
MzBcUVPX3T8EvHJuq2Irx0La1VtZexQ0IHJQogC0Acm6lAlWe+R4X/8w2AYh
mlCCpre8u6tvsLLqSG/fEOrIZCOVSqrrjiNGKmxAYSgShlAlAOgdvNbY2jEZ
gJ4CZGe7+yTVR2AhsBw8ndDQ0dnWLm2Wd0MOl9ee6Ozta0YkSK6i+4UmcBPS
lZfVHB+4NgJHGNkFWZcyjABokYKRXUdOngY9cOjQA4gS2AyRv9oqBxv2JqcP
Dl1HTn2HvHUc0NGF5vCAtLsvOuHQ9ZFbbVIkwq3jSzTLkSxt7ejp6O2PPZQ+
cu0mlIsm2UQkmzqRHZd1DV9uk+5KSrt96/6VpvaWzokYXpXJQYO0c+iqrHNf
ZgEsgdQceadyHzvkg12d/b1D3c0d3TtT8u8O34ZFkXTtGZR19cP5auzqaoFj
2D94tr5VUnO0p6enubsfySg4Pt0DAOvp6pfLYAdu1v1w4cQPZ682NXbK+5rk
va0KDGjokfW1dvXcvHG3+vipq1c7+vuuXZEhyXPr3sPb9x/defD4+oNHj+7d
v9gqO5iSeezYsZ7ro/Ud8kdPniYkJh86nLEtKmZ7ROSWiMjAsK3QDd0bs3GG
xWp19VM/nt3k47s3MTE1K6uwuCApM3VH9PbvwwPcbWxTKaRDGL2VKnpRcbuS
M9LScrKC/PzXbVwVEh/r/o1NHhnvY6S9xUw/3VinuLg0JGb7lvDQzZv9Y9LS
fVc7pBsbb6USRCoqrmqqe2i0tMLc6rqj4aHb/HfvdHP6LgVnEk2nfKOqMneq
/koVTSddtW1bYta5eQTHbPX2XJNtoJXNIa1S1zxAx7lqayzWVluprrJtc4h/
1JbwnaEpZEI+kxFiovv91OnBBlOSGWQ3LY1VanrBIf6eAe6HmYxDFFwYziSV
bL5Df/oWw+mbp0+LZhId1dRdAzftZ9NKLNkhpiYpRINDVLMdRkZReP0wE/3t
JlP3MWjJltw86rS9XE6EscleOiOXR4nAYvdgCfuM9MOmawZPnZ5LMNnNoqTw
iQfMiSl0ymEOaTfWJI1OzDQzjzXTDdXVicDqxxKxuRbUOIxRNodWKGDvxWOz
2ORMGn6P+dR9JsY7CCb7hYRCLiceY5TFpkoseXEY0xwuOY9OSiQbJePMD2Ox
qWximUCQRMSAhjIubT8JB5aUsakHyIa5DEomi3CYQSoWcw5ijfIFrGOWnAS8
eR6fWsYkJrMwRWxaIsHoMBsr4TMSzQ0LhOyjYiYAikXsai4tnUss5tDTiYRU
Fq7cmpuIMy0UcKtFlCQKscSCVytkptKJZXxWPpmUzWPViLn7MIZFPO7JecL9
OBwgJVx6Go1cLuJk03AZIjrYfJCIzaEza2yZB/D4EgG/2pKXTMBXWvLzOeRM
HjUGY7QTZ5ZGxZUwyWVUcjGLXCagVjDxZVasQhquWEA/RCHmMCgFHEa5gC3h
U0t45FIWJY+AKZ/FBkA5j56Gw5WwKeBUDZ9VyqdkcwkFXFoq3rRczCygYwuF
1ESSeQmXAROPiRgVInYeny6ZwYMQSYS8bDYOACl4JCaFQkqFkFImZEp4rFoL
bgodVyTk5DDMiy3oqVQ8JFu5FV8iZJVySBCEChE/kYQrF7PzWLhSIS0Va5bB
IUss+FVifhEdX86hFVnyUyi4KpECIGIexuOKudxiJrXUhlPEpZczGWXW3AwG
DvQU0ahlIkEi1biYwyzmMSQW7CIOqYxLqRGxsohmEElQWGbBSqKYlvLopQJG
pRW7lE+V8GlHrLiZZNMSISOfCUvQUylm5UJ6CY8iETFQQK0lJ5NqBnHIoxNK
Rex0sgnEtpxDAVgxh1rKoVZZsjMUgHwGEcKbQcYU8ylVPFq1BRhJhThXWfFS
qZgSPr2Iha0U0NKoJOCruIwKAZhKg3yrEHOSiKYSIaeMZV7FIx+mEcCeKg4V
7AdVEi4V3EnAG1Ra8MqZuGouNYVuVsSnHBWxq0SMIh5JwqNUz+DuJxiWc2Gz
CBDADCaxkEWuFtGKeKwcHrGCQzluw9+LN8uz4OXT8OUCZhYLB1Gq4lBKBRzY
/QIW4bgVN4GCK+CzilgY2MFsOrmUx6zkUqs5LPClmEs+IebEkTFVAk4RkwDB
yWbjIUNg16oErAIuqZxHrbJmxhBNYZtyFambwyPATlUJGFXWEGqKhE6sncna
TcDk8kkQKFgXjCxn0or4tJoZrBI2CZar5pFD8XAYKcVMOnQzmdgsJiVZAHlL
yLdgHGSScrlkJ9PpKZAYVLMKHq2Ez87lMA8RsHXW3Bw6OYtK38PABuAoiVRy
NgWfxyPVWbALaObpFAwcBDiPlRaCH20tMy2Zu6gUAJRw8NXWfIheLgVbI2ZX
8BiFXCakbpKAGE+nZTNNCpmsajH1CIcGWw+nuIzPkPA4x8XcVAFpD4cBpzKP
g4cEK+WQU4kmkMZwLuCMnLQR5lrS9lNIpTR8Lgtfa8sD79LI5hJLTjmy44xj
ltw0Hj6RTi1gIFlXY8uvZpLhrFXOFAImn0UDQIaYEksn5nOI+Wx8lTWnhElM
w5vVzBCUClh5fGbtTMFhMTWWRChl4HPYlEpbbiWfnoQ3Kf9GWGbJy+cx6yz5
GSJqPIVUziDnITbwK7jYfIzJkUWzamcLi2gm1Ta8LAteCNW8hIXLp5JrrDll
HBIscWyOGHIpm0U9NldYOZMdSaGUcgnFZPIRKw4c22Qirs5aAKmezqEeteZW
WbIi8DjIz2IaDs4RbHo6wbTKSlBiyc9jk44ImFVWoi0UfBWbnEfF1Fqyi/ns
fLJhjQ1bIhIVsJjVFsxqG0EAlVzNxWWRzSENSoXUPKJpnRWrTsjK47CLxawK
S1YQCV/FJ2aRcdUzOJUCUg4O2axaa2qhkF5mKagSc2MhtnxaLskcjkk1m5pP
MJHMYBcpkgoSoNKSm4Q1quBzMyimUHyqYAkyBiZC/YEKUyziVluxd1NwUI0z
qOYVNvxqPiULioCIVw0ApFawKqxZeym4Sg49j4xkGgAyaRg46dUWLCgmsOOQ
XXtJWDitmSQsnIJqAQnqNiRSlYgJOVPCpVVa8w6Q8VBPMshYiRVdwiPlUQjF
FsxKIQOWKBHSIKqH6ORKPjObhKmwZFYKKHkkYokVE44PHOoiEfWohSCVSUEi
TDKrsOLWCmk5JFK5NVQAJlxAJQISHMwMNr2Kz8skGNdY8I8IGHD7QJWD6gQb
V8EnVwo4kDmwZRk0U7hxoDjnE82h8hwVcyRiRgWfCqGGwlhuQYcSVyXk1vDo
cEEAAAJYasks4hDh1IO1EhE9DYqVQFDLp+eQzSEOcOUBrJBHRtYSMSCeGUQz
idgCcgYqJ1wEhTz6EbEAyi+kVqk1q9qamYE3KREJAQlnEwyDxKizFAIAbACv
ayxpmTijYhEftiCThJFYcIuELDgaUBXBGHAfAPkk02IxD2osxBwpRCJ2mRWn
RECFjIISVCUmFZJNCoT0qhlCyJwsOgFiC+cI8qTCVnCYSTgi5hSRzOAYwklJ
xRrlMHFlYmqhtUUa3IBWlFpbmxO2Mw4SMSk8+gkrYSaRksokHbVgAGAHEfM/
K+E+Kj7R2PgA1gweJ+Fk43BT80QGOYmCiScQd2FxcWYYT13tEjIxm0WWcJnZ
WBN4SFSwzbOpZplk5FZKgXuTw4U8hCpazaeDL4UM3EkuTkIxhaStoJuWMwi5
DAIEB+4X2JpCEgbqVYUFM5toDLUaSlkVl1PDIGeZm6JlPJuOKaHj4LBnUk0L
2QQoTRk8QpEFOYNoXsAklfMJeRRSMRtXxWbmY3ElNKqEw4YV4Z2QTzSQsPBV
kNtMDNyD5VxiIQlbSidByS1kEyVsQhbJEPgaJiMX7hcmRcImpZsawFMBXgKF
NEI1k5SDR0ySsJjpVBO4yyQMQpapoYRFhZKVT0WuIUhIKEHldCoAihmkErp5
Gt6kgEtB3hU0ElxYWQSjQjq2jE5IoxjDdQk1DQCFPGoxiwAXRAkdn4M1LIUL
lEmEcwd3CjzAsvG4EhYNni5ldFIJDZOOM8hjYCsYlBwqPPngccJMppLyhLws
NhHOrISCyTSfnsvEVbJYiTRc6ZxZ+bbiRAq1bPasAlt+OoMApyMdpwNvniJL
UYaN+DB/1r6F6/J3Juy3XbzXkBikqZmpopeLwZeIxWkMRgJrYU70wZauwbbR
GyVFpT8WldafPHlGUpNjZHSAKc4O29fa3PHo9euenr5LVy7Lezv7BvrPtbY2
9/XHLthw8VTj8INngzdvt7d2dDS1tPf2wJdM+9mr9Wca4ANj9PHjayP9rW2N
HfBR2t3bp/irAnz+wFfJ4Ohof39va3vbxbaOAfloP/KnBnmLrA2+aTpk7YMj
13r7ewDd19nW0yuXywfgW7JH1gtKBoeu9ff2yaWdXd39A/0j8O1zqb2tDT4s
+7oGBoZ6ewb7uofA4P7+wevDt64N3+7q6e7p6x0aHhkcHBweHhkaujY0eB2+
wkav3xm5dguor3+wf2BIARgGun79xo3rt+Gbbmhw9NbN+/DFN9B/7dbNe8ND
ozB9dPQmjI4M37h14+6N0Tuj12/DVxV89MG63V39jx4+gS6AYfTenYewyt07
D0F45UpjW6sMfB8cGAEYmAOrw9w7tx8AuKcXMQ3CC97dufsQ1F4bvnl95DYQ
4IeGR0F4996jgcGRX359ev/BL/fuP4butZFbN27ee/jo6fPfXj96/PTxL88e
Pnpy89a923ce3Lp9H9onT18+/uX5r09e3H3wK3zowULgOKz45OmLZ89fA929
9/jW7QcPHj4BAg0wHVQ9fQaznv3y63PQDHNByS+//vbbizdv3v4OQtAMqwMG
JNCCkhcv37189e7V6/cwd/TGnWfPX40PvXrx8i20KP/rk98AAENAr998gCkw
Ci10oUUl0ILww+9/Ag/09t0foBbWff/hE9C79x9RDNgPOkEhzAX8m7cAQ4Sg
HzUDhcF0oNdvfn/67BXYCTCQw+j7d5/++vvLu7d/vH/38d2b3//48PHj758+
ffz7/Yc/37/7/PHDl+d//vHL29fvv3x+/uWv3778/eLLl8cff3/25a+nf39+
9MeHl1/+TqJR9pDwBwSMA2xyEpsCFTWBhj/IoSTxKAk0bCqPfNBQ97CZQbLx
tMMmeof0tdNNpmeYGkCRycBMTzfRyzHX9yfg/fDmQVjzIJxxgJlRIMYkFI+D
bqA5JgSHCTU3S+dwU7icTAvBYQt6tg0/w4KTYcXLtBKki3kZFtx0ATufR0du
W3jz85hw98EHRaUFB15rcLPA/VXBZx+3FME7tsyCAVcn3BTwqKuz5MKHUqWY
Ce9/4P83Q9A931I636Z1nrDPYUbzXK5sJvuGg237LPbIAivZDKauirqhnpGp
1lSiti5Fd5qJrg5BT09saGYzzdTGAGOgpqqqoYP8j7GaioqmtoqqhoqqmoaG
FtJXVVNX1wRGQ0ddQ1VXDX4qWuoaOmrq2prAqGgAo6aqpaGmra46XV1VS0tF
DZkDjZqqirqqhoaGrqqGprqGioaqipaeipr2FA1VLe2pqqrqWioampra6opV
NDS1NdQ0VVUBM0VFA1aFVltDXUdNFWk1taaqTtFXV9HWhHXV1NRV9VRVNDU0
daaoaSFmampPUZ2iAhM0dcFUlNTUEOWABwKwOpinppiuqgWj4Bq0ANBQn4IK
gQHAWKuhhQxpaCEwxSwUhgJQXktrCjodhFqaukDoWsBMxkzwCjkw2lpT1ZFQ
ToG4oYCv9AMSBQBpIPGBVkfR6sIUVK6mPgXlkeCra6MATYVmlFdV0wJGFYmP
NhDMhVEgEAIp9SAwdR0FIZZAF9WGECyhqqUkiCFKyi5Yi7QQTECqaQABr62t
g+ypOmyl+phHimBCFwgwAEDBqH7YNeDRUUgDZHPV0SxUg+kG0030phoYG5sa
GhpjMFhgsFhojU1NMdP1jc1Mcbo6+qBfX98AloAW+GnTpkHK6U2bDr5oT9ED
DTraujgz06nTdI2NDfX19YyMjAAD4Ck6U/WnG+rq6k7V0dXR0AUNOjpTp0zR
hQ1CSUVVE0lUdTVDQ0N9PUMDAyNdXT1op06dBlahNE3PUCC0BDMg3Hp6epBS
oFxLS8vAwEBHRwckwI9cvzVFZxq4BqPgHUhU/vk7/r8TPAF34UK72bPnAolE
Yjs7h5kzv3F2Xrt8+YrFi5ecu3D+7dvXQ0MDt27dGB4eHBm91tXT+dPpU4PD
A82tTSMjw03N7QMDA+fO/XD0WGXDxdP1l05XHyn76cyJqtrSI8cqTvyvJrc4
H0KKMTKHNILDCCdUVUVFVXG8URt27Y1DjqGaNvzMzc1NTEzAa1NTiLwhi8Xi
8/ln6s9KuzovXb4K9y9cfgNDg8Mj15pamqVy2cjo9XsP7u/bn1BSVnr2/LlT
P/9UXiEBp46dOF5dW3NK8auoqLhx48aTJ0+uX79+8+bNnp6eY8eOlZWV5eTk
7NixIzQ01MvL66/Pn778/QX9/fnnn5OZv/9GBhDfR0Z64crt7YV3C6wOT47+
wYErjVebW1vkXZ11x47UnTheWVdbd+woGFBYXFReVVl77GhphaSipvr4Dye7
unsbLl5tbum4cOlyw5WrVxubm1vaGhsbZfDrlINrsMyvT57BjfzoydNPf8Ld
glgENnz48OHly5fvPrz/5cmv9+4/fPP2/V3w+cGjO/fugkng0cOHD4eGhrq7
u/ft25d4KCk2Pi48YtuBxIP7Dx6Ii4tLSkpKT08vKCiQSCSvXr14/fr10+fP
7t+//+DBg/fv3z9X/N68efP582dw88GDe0+fwj39G7SPHz989OjRvXv3oAsG
vHr16s6dO7//DpPef/z48d3b16Dt06c/3r178/Tp0xcvXgAMLPn8+RNEDPg/
APnuzfv3b//6C3EBpnz6hAzduHvzy5e/WltbpbKWR6N379y9//y3N5++fHr7
+s0ff314eOfBqUsNsh7pD0ePNzc333p4q6au/MdTP9+4MXCh4by0ubm0MKOi
Jr+uojgyLODFq5dnL50t2Btx+tyJPVHbTl/4+eezPxyKColyX1iZGZUUvSnI
Y/UGDk6yfV1CQtD2xVb5sQF5yfH5Ma6Fu3zjvWbHus1M9Vy2229lhu/sPZ4L
IhdxE70WHorZkOprF+q26JCPwwEvuz3ha7dvsItxnx3//Ypot1k7XGaHrZkb
5mTl8x0vaKl458b5u4OXezrNi3T7JsJ1dsTGhbvdF8d7z48PdAp2XOgym+c0
gxUb6LTDb13Emrnpoeu3blq2cc2CoJWWoS72oZ4r3RbxvB0tk7e57dq2eruX
XU60j6vTnCWzON9/Z7MvYm3MVv/5fNpya25ykOvKb0WLrOg+K+aGuy9M3eyc
GLgmK2HzFu/1Hsu/i3JbnxDr47N+8WZ350An+4DVs2P8lydu9wz3Xh0T7BQe
5Hxwu8vB0HXeTt9+7+oY4rF249I5W9c7+C2x9V06K2iZ7S4/16y4wNQIT3fH
eTysEd/c0HutXbT/ykNbXHf5rSyLC92xbvHhcPfcpKitwWtjQ1yivVcFrXdw
ni/2clrg4+2YHOWfFu0bsm5BclzwVtcFhwJW7nCz3+A4d4PzMt/1Tk7fWEds
Wp62wz3Kd9nuSNdY31VBqxZ4Os6LCXT3dlvm7elkP1MU5O3o7bTA08V+s9ui
cA+HjctnbHVamLLdIzbY2XWmeFd0QLC3k9uyOX4bV/lutP/OVrDJeZGPi4PT
IptNy+eFuC6Lj9kS5mG/1c0uYZvP3hAP//VLPVYu9XReumQuK3iT/ZagVYE+
jpE+K/du9gBAdMCaHf6rfFYt8VznuH2ze7DzEicLTuT36+L81+8L996zdUOU
h2Pw2vnRYS6H4/wPRoftCg+sTos6GOXlYisMclnuv3bBmuWzwp0WeqxYsD3E
ed/mNbDRdcn+e4KW7QtwBomv6+ygDUuLdgXEBPju2ewV4+Xgt2ZearRXqLOD
/+KZQe5Lw9yX7I0LT9sfcmCHd2ykU5j30ihf1/iwVTuDnEO87CGkKwR0D/t5
IRscEDMC1vguFcGi8SEr9m9xjwx08l0y09N5kavdgj3h7nH+a6P93T3d7Fcs
tAxZNTPGc9nab6191tn7bnTy99mQEe+fGPf9zm2Bfq6r1syf4bl6hs9qm02O
izYume26en5iTHBGpHt0kKOXk91ia6GfvU1swBJXO9ECFiZgjijUZdYm51me
i8UhrrOdHazWrF282cths8f8ZbYWYZu+S4nyPBC9zsWOD5kQvHrO2vmC1d/N
27DUYt0CIcfMLHLz2rD19hsXW7ssEkaFOfutmj2bYui72sHD0crDYY7LWjvv
1TM9HIQbV84DQOS6WTEbF29YbBO3cdXuzc4eyxdud5m3xW1emOOcKJ9V0Su/
9XSyjPZdvD/QKSl07YFdXiHuS31d5oW62+0OXJ8c45sU63MwyjXBb8X2jfYH
A532BKze6mIX5mkf6OKwbeuGPX7OCYEuKds3xfqs9necF+Y8L27Lum1ey+J9
HH3X2G2ytwle/+1ejxWZCUFpSVvDXB2CHWdkHfCryIhM81oa6bs62mfFLr8V
ieEb9ke6Je7x3+xq52qDjfdemBLrcTBiTfwWt8QItwjPxZuWzPFbtXCt/UwH
PsnXTrDemuiybGZA8Lr92zeFb0TKiK/TsiD3tW6rlzmIWF7LbL5fZGvH5woo
lP8DhMzsiw==
                    "], {{0, 319}, {11, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.0013691128148959474`}}, 
               AspectRatio -> Full, ImagePadding -> None], {39., 0.}, {
              Left, Bottom}, {1., 0.0013691128148959474`}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{40., 0.0013691128148959474`}]}}},
           
           ImageSizeCache->{{336.1119162896524, 347.16253590404557`}, {
            113.45298340982426`, 121.43116908858488`}}],
          StatusArea[#, {1, 
            Rational[5, 3652]}]& ,
          TagBoxNote->"{1, 5/3652}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["5", "3652"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[5, 3652]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9WQdYVMmynkRGEMkTmJwjUV3TVcGsKBkMCAiC4IIoYg5rVhTJOafVu7pv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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.000547645125958379}}, AspectRatio -> 
               Full, ImagePadding -> None], {40., 0.}, {Left, Bottom}, {1., 
              0.000547645125958379}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{41., 0.000547645125958379}]}}},
           
           ImageSizeCache->{{344.14566269924785`, 355.196282313641}, {
            116.426806224337, 121.41808049584124`}}],
          StatusArea[#, {1, 
            Rational[1, 1826]}]& ,
          TagBoxNote->"{1, 1/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFenVcVdn39qFRui4XbnfTYowxFrYoggEqSCONgMGYY406SneXY4w6toJB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                    "], {{0, 319}, {11, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.000547645125958379}}, AspectRatio -> 
               Full, ImagePadding -> None], {41., 0.}, {Left, Bottom}, {1., 
              0.000547645125958379}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{42., 0.000547645125958379}]}}},
           
           ImageSizeCache->{{352.1794091088433, 363.23002872323644`}, {
            116.426806224337, 121.41808049584124`}}],
          StatusArea[#, {1, 
            Rational[1, 1826]}]& ,
          TagBoxNote->"{1, 1/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJx9VwdYVEfXXmsUiSggbXuvLGCLiX5qLEgCFrCgIL1YaNLFQosFAREEpC11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                    "], {{0, 319}, {11, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.000547645125958379}}, AspectRatio -> 
               Full, ImagePadding -> None], {42., 0.}, {Left, Bottom}, {1., 
              0.000547645125958379}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{43., 0.000547645125958379}]}}},
           
           ImageSizeCache->{{360.2131555184387, 371.2637751328319}, {
            116.426806224337, 121.41808049584124`}}],
          StatusArea[#, {1, 
            Rational[1, 1826]}]& ,
          TagBoxNote->"{1, 1/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 1826]}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {{}, {
              Opacity[0], 
              PointBox[{44., 0.}]}}},
           
           ImageSizeCache->{{376.29752154242726`, 379.29752154242726`}, {
            118.40935476734549`, 121.40935476734549`}}],
          StatusArea[#, {1, 0}]& ,
          TagBoxNote->"{1, 0}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 0}, {
           GrayLevel[0]}], "Tooltip"]& ]}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], {
             InsetBox[
              GraphicsBox[
               GeometricTransformationBox[
                InsetBox[
                 BoxData[
                  FormBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJyFWAdYlMfW3tgLIiJ9YdnCsoCYxJt4TWKMokiCVEEB6Z2lSEepggUrCiqK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                    "], {{0, 319}, {11, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", ImageSize -> All, 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {11, 319}, 
                    PlotRange -> {{0, 11}, {0, 319}}, ImageSize -> 
                    Magnification[1]], TraditionalForm]], {0, 0}, {
                 Left, Bottom}, {1., 0.0728085757989867}], {{{0., 0.}}}], 
               PlotRange -> {{0, 1.}, {0, 0.000547645125958379}}, AspectRatio -> 
               Full, ImagePadding -> None], {44., 0.}, {Left, Bottom}, {1., 
              0.000547645125958379}, {{1, 0}, {0, 1}}], {
              Opacity[0], 
              PointBox[{45., 0.000547645125958379}]}}},
           
           ImageSizeCache->{{376.28064833762954`, 387.3312679520227}, {
            116.426806224337, 121.41808049584124`}}],
          StatusArea[#, {1, 
            Rational[1, 1826]}]& ,
          TagBoxNote->"{1, 1/1826}"],
         StyleBox[
          RowBox[{"{", 
            RowBox[{"1", ",", 
              FractionBox["1", "1826"]}], "}"}], {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[{1, 
           Rational[1, 1826]}, {
           GrayLevel[0]}], 
         "Tooltip"]& ]}}, {}, {}}, {}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, GraphicsGroupBox[
     {GrayLevel[0], 
      StyleBox[{},
       Antialiasing->False]}]}, LineBox[CompressedData["
1:eJxdmnkwFW70/5GoRGSNrNl3Ivs951ruRYkQJUmyL1k/KSJys6+RXZY2u1uy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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0, 0},
  Background->GrayLevel[0.95],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->Automatic,
  ImageSize->432,
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, Automatic}]], "Picture",
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell["", "Spacer"],

Cell[TextData[{
 "In this example we use information from ",
 ButtonBox["WeatherData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeatherData"],
 " and investigate the feasibility of using wind to generate electricity for \
central Illinois. We will also make use of data from ",
 ButtonBox["www.vestas.com/en/wind-power-plants/procurement/turbine-overview/\
v90-1.8/2.0-mw.aspx",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.vestas.com/en/wind-power-plants/procurement/turbine-\
overview/v90-1.8/2.0-mw.aspx#/vestas-univers"], None},
  ButtonNote->
   "http://www.vestas.com/en/wind-power-plants/procurement/turbine-overview/\
v90-1.8/2.0-mw.aspx#/vestas-univers"],
 " in our analysis."
}], "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Time-Series Data: Import and filter data\
\>", "Section"],

Cell["Find the name of a weather station near Bloomington, IL.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<Bloomington\>\"", ",", "\"\<Illinois\>\""}], "}"}], ",", 
   "\"\<StationName\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5008868299319267`*^9, 3.500886869423236*^9}, {
  3.500886972370963*^9, 3.500886978816545*^9}}],

Cell[BoxData["\<\"KBMI\"\>"], "Output"]
}, Open  ]],

Cell["\<\
Get the average daily wind speed for the area beginning in the year 2000.\
\>", "MathCaption",
 CellChangeTimes->{{3.500887691635268*^9, 3.5008877384338713`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wsData", "=", 
   RowBox[{"WeatherData", "[", 
    RowBox[{"\"\<KBMI\>\"", ",", "\"\<MeanWindSpeed\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2000", ",", "1", ",", "1"}], "}"}], ",", 
       RowBox[{"Date", "[", "]"}], ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.500887031749962*^9, 3.500887083850607*^9}, {
  3.500887749166108*^9, 3.500887759237588*^9}}],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{
  "\"\<KBMI\>\"", ",", "\"\<MeanWindSpeed\>\"", ",", "\"\<Units\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.500892317453417*^9, 3.500892320227844*^9}}],

Cell["\<\
See the form of the data entries; for example, here are the first five \
entries.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"wsData", ",", "5"}], "]"}]], "Input"],

Cell["", "Space"],

Cell["\<\
The entries are ordered pairs consisting of the date and the average wind \
speed for the day. We will need to extract the speeds from the data.\
\>", "Text"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Part",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Part"],
 " function to get a list of the daily average speeds, convert to new units, \
and visualize the data in a histogram."
}], "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wndData", "=", 
   RowBox[{"1000", " ", 
    RowBox[{
     RowBox[{"wsData", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], "/", 
     SuperscriptBox["60", "2"]}]}]}], ";"}], "\n", 
 RowBox[{"histplot", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"wndData", ",", "45", ",", "\"\<PDF\>\""}], "]"}]}]}], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Time-Series Data: Estimate a distribution\
\>", "Section"],

Cell[TextData[{
 "Since wind speed can be assumed to vary continuously, we will estimate a \
distribution for our observations using the ",
 ButtonBox["SmoothKernelDistribution",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SmoothKernelDistribution"],
 " function. "
}], "Text"],

Cell["\<\
Find an estimated distribution and visualize the results.\
\>", "MathCaption",
 CellChangeTimes->{{3.500889832731764*^9, 3.500889867050887*^9}, {
  3.5009968609698057`*^9, 3.500996865367896*^9}}],

Cell[BoxData[
 RowBox[{"\[ScriptCapitalD]", "=", 
  RowBox[{"SmoothKernelDistribution", "[", "wndData", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"histplot", ",", "\[IndentingNewLine]", 
    RowBox[{"estplot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"PDF", "[", 
        RowBox[{"\[ScriptCapitalD]", ",", "x"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "13"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "}"}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "An alternate approach would be to assume we know something of the type of \
distribution to model our data with. We will use an ",
 ButtonBox["ExtremeValueDistribution",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ExtremeValueDistribution"],
 "."
}], "Text"],

Cell["\<\
Estimate the distribution parameters and construct the distribution.\
\>", "MathCaption",
 CellChangeTimes->{{3.5008921151281548`*^9, 3.5008921429989967`*^9}}],

Cell[BoxData[
 RowBox[{"params", "=", " ", 
  RowBox[{"FindDistributionParameters", "[", 
   RowBox[{"wndData", ",", 
    RowBox[{"ExtremeValueDistribution", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[ScriptCapitalD]", "=", 
  RowBox[{
   RowBox[{"ExtremeValueDistribution", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "/.", "params"}]}]], "Input"],

Cell["Test to see if our assumptions should be rejected.", "MathCaption",
 CellChangeTimes->{{3.500892157977693*^9, 3.5008921720713654`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tstData", "=", 
   RowBox[{"DistributionFitTest", "[", 
    RowBox[{
    "wndData", ",", "\[ScriptCapitalD]", ",", "\"\<HypothesisTestData\>\""}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"tstData", "[", "\"\<AutomaticTest\>\"", "]"}], ",", 
   RowBox[{"tstData", "[", "\"\<TestConclusion\>\"", "]"}]}], "}"}]], "Input",\

 CellChangeTimes->{{3.500891907292427*^9, 3.500891909596822*^9}, {
   3.500891948439179*^9, 3.500891991870344*^9}, {3.500892030791181*^9, 
   3.500892072503786*^9}, 3.500892237250661*^9}],

Cell["Get the test statistic and p-value for the test.", "MathCaption",
 CellChangeTimes->{{3.500892634747856*^9, 3.5008926482466993`*^9}}],

Cell[BoxData[
 RowBox[{"tstData", "[", "\"\<TestDataTable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.500892579993012*^9, 3.500892608103676*^9}}],

Cell["Visualize our distribution estimate.", "MathCaption",
 CellChangeTimes->{{3.50089218280905*^9, 3.500892194527615*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"histplot", ",", "\[IndentingNewLine]", 
    RowBox[{"estplot", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"PDF", "[", 
        RowBox[{"\[ScriptCapitalD]", ",", "x"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "13"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "}"}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Time-Series Data: Testing the model\
\>", "Section"],

Cell[TextData[{
 "The generator we are using for our analysis here requires 3.5m/s wind speed \
to generate electricity. We can use the ",
 ButtonBox["Probability",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Probability"],
 " function to estimate what proportion of time the generator will be \
contributing to the grid."
}], "Text"],

Cell[TextData[{
 "Based on the data distribution, compute the probability that wind speed is \
greater than the threshold of 3.5m/s; ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", estimate the probability the generator is contributing."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Probability", "[", 
  RowBox[{
   RowBox[{"x", ">", "3.5"}], ",", 
   RowBox[{"x", "\[Distributed]", "\[ScriptCapitalD]"}]}], "]"}]], "Input"],

Cell["Visualize the result.", "MathCaption"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{"\[ScriptCapitalD]", ",", "x"}], "]"}], " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Boole", "[", 
        RowBox[{"x", ">", "3.5"}], "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "13"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"2", "\[Rule]", "Axis"}], "}"}], "}"}]}]}], "]"}]], "Input"],

Cell[TextData[{
 "From the manufacturer\[CloseCurlyQuote]s ",
 StyleBox["spec sheet ",
  FontSlant->"Italic"],
 "for the ",
 ButtonBox["V90-1.8/2.0 MW",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.vestas.com/en/wind-power-plants/procurement/turbine-\
overview/v90-1.8/2.0-mw.aspx#/vestas-univers"], None},
  ButtonNote->
   "http://www.vestas.com/en/wind-power-plants/procurement/turbine-overview/\
v90-1.8/2.0-mw.aspx#/vestas-univers"],
 " generator we can make a chart indicating anticipated performance levels in \
the central Illinois location."
}], "Text"],

Cell[BoxData[
 RowBox[{"DisplayTable", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Wind Speed m/s\>\"", ",", "\"\<SB\>\""}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Probability\>\"", ",", "\"\<SB\>\""}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Estimated Power MW\>\"", ",", "\"\<SB\>\""}], "]"}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<< 3.5\>\"", ",", 
      RowBox[{"Probability", "[", 
       RowBox[{
        RowBox[{"x", "<", "3.5"}], ",", 
        RowBox[{"x", "\[Distributed]", "\[ScriptCapitalD]"}]}], "]"}], ",", 
      "0.0"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<between 3.5 and 7\>\"", ",", 
      RowBox[{"Probability", "[", 
       RowBox[{
        RowBox[{"3.5", "<", "x", "<", "7"}], ",", 
        RowBox[{"x", "\[Distributed]", "\[ScriptCapitalD]"}]}], "]"}], ",", 
      "\"\<0 to .8\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<between 7 and 13\>\"", ",", 
      RowBox[{"Probability", "[", 
       RowBox[{
        RowBox[{"7", "<", "x", "<", "13"}], ",", 
        RowBox[{"x", "\[Distributed]", "\[ScriptCapitalD]"}]}], "]"}], ",", 
      "\"\<.8 to 1.65\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<> 13\>\"", ",", 
      RowBox[{"Probability", "[", 
       RowBox[{
        RowBox[{"13", "<", "x"}], ",", 
        RowBox[{"x", "\[Distributed]", "\[ScriptCapitalD]"}]}], "]"}], ",", 
      "\"\<1.65\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["DXF", "Section"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1W12MXVUVnt877UxnOvfOpR1TQhmoosSQtIQEE8ZzWh8wRh8gGmPCCyQa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   "], {
    {RGBColor[1., 0., 0.], EdgeForm[None], 
     Polygon3DBox[{{1, 2, 3}, {1, 3, 4}, {4, 3, 5}, {4, 5, 6}, {6, 5, 7}, {6, 
      7, 8}, {8, 7, 9}, {8, 9, 10}, {10, 9, 2}, {10, 2, 1}, {1, 4, 6}, {2, 5, 
      3}, {1, 6, 8}, {2, 7, 5}, {1, 8, 10}, {2, 9, 7}, {11, 12, 13}, {11, 13, 
      14}, {14, 13, 15}, {14, 15, 16}, {16, 15, 17}, {16, 17, 18}, {18, 17, 
      19}, {18, 19, 20}, {20, 19, 21}, {20, 21, 22}, {22, 21, 23}, {22, 23, 
      24}, {24, 23, 25}, {24, 25, 26}, {26, 25, 27}, {26, 27, 28}, {28, 27, 
      12}, {28, 12, 11}, {11, 14, 16}, {12, 15, 13}, {11, 16, 18}, {12, 17, 
      15}, {11, 18, 20}, {12, 19, 17}, {11, 20, 22}, {12, 21, 19}, {11, 22, 
      24}, {12, 23, 21}, {11, 24, 26}, {12, 25, 23}, {11, 26, 28}, {12, 27, 
      25}}]}, 
    {RGBColor[1., 1., 0.], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJwB/QQC+yFib1JiAgAAAKQBAAADAAAAHR4fHiAhHiEfICIjICMhIiQjHR8l
HyEmHyYlISMnIScmIyQnHSUoJSYpJSkoJicqJiopJyQqHSgrKCksKCwrKSot
KS0sKiQtHSsuKywvKy8uLC0wLDAvLSQwHS4xLi8yLjIxLzAzLzMyMCQzHTE0
MTI1MTU0MjM2MjY1MyQ2HTQ3NDU4NDg3NTY5NTk4NiQ5HTc6Nzg7Nzs6ODk8
ODw7OSQ8HTo9Ojs+Oj49Ozw/Oz8+PCQ/HT1APT5BPUFAPj9CPkJBPyRCHUBD
QEFEQERDQUJFQUVEQiRFHUNGQ0RHQ0dGREVIREhHRSRIHUZJRkdKRkpJR0hL
R0tKSCRLHUlMSUpNSU1MSktOSk5NSyROHUxPTE1QTFBPTU5RTVFQTiRRHU9S
T1BTT1NSUFFUUFRTUSRUHVJVUlNWUlZVU1RXU1dWVCRXHVVYVVZZVVlYVlda
VlpZVyRaHVgeWFkgWCAeWVoiWSIgWiQiW1xdW11eXl1fXl9gYF9hYGFiYmFj
YmNkZGNlZGVmZmVnZmdoaGdpaGlqamlramtsbGttbG1ubm1vbm9wcG9xcHFy
cnFzcnN0dHN1dHV2dnV3dnd4eHd5eHl6enlcelxbYGJkX2NhYGRmX2VjZmhq
ZWlnZmpsZWtpZmxuZW1rYGZuX21ldHZ4c3d1dHh6c3l3elteeV1cdHpec115
dF5gc19dYG5wX29tYHByX3FvYHJ0X3Nxe3x9e31+fn1/fn+AgH+BgIGCgoGD
goOEhIOFhIWGhoWHhoeIiIeJiImKiomLiouMjIuNjI2Ojo2Pjo+QkI+RkJGS
kpGTkpOUlJOVlJWWlpWXlpeYmJeZmJmampl8mnx7gIKEf4OBgISGf4WDhoiK
hYmHhoqMhYuJhoyOhY2LgIaOf42FlJaYk5eVlJiak5mXmnt+mX18lJp+k32Z
lH6Ak399gI6Qf4+NgJCSf5GPgJKUf5ORm5ydm52enp2fnp+goJ+hoKGioqGj
oqOkpKOlpKWmpqWnpqeoqKepqKmqqqmrqqusrKutrK2urq2vrq+wsK+xsLGy
srGzsrO0tLO1tLW2trW3tre4uLe5uLm6urmcupyboKKkn6OhoKSmn6Wjpqiq
pamnpqqspauppqyupa2roKaun62ltLa4s7e1tLi6s7m3upueuZ2ctLqes525
tJ6gs5+doK6wn6+toLCyn7GvoLK0n7Oxu7y9u72+vr2/vr/AwL/BwMHCwsHD
wsPExMPFxMXGxsXHxsfIyMfJyMnKysnLysvMzMvNzM3Ozs3Pzs/Q0M/R0NHS
0tHT0tPU1NPV1NXW1tXX1tfY2NfZ2Nna2tm82ry7wMLEv8PBwMTGv8XDxsjK
xcnHxsrMxcvJxszOxc3LwMbOv83F1NbY09fV1Nja09nX2ru+2b281Nq+073Z
1L7A07+9wM7Qv8/NwNDSv9HPwNLUv9PR29zd293e3t3f3t/g4N/h4OHi4uHj
4uPk5OPl5OXm5uXn5ufo6Ofp6Onq6unr6uvs7Ovt7O3u7u3v7u/w8O/x8PHy
8vHz8vP09PP19PX29vX39vf4+Pf5+Pn6+vnc+tzb4OLk3+Ph4OTm3+Xj5ujq
5enn5urs5evp5uzu5e3r4Obu3+3l9Pb48/f19Pj68/n3+tve+d3c9Pre8935
9N7g89/d4O7w3+/t4PDy3/Hv4PL03/PxprCpkQ==
      "]]}, 
    {RGBColor[0., 1., 0.], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJxNj1sOwiAABHm1Fe0DegP/PI9H8AB6/9SqbBxSPiY7acMuXB+v+9MZY24F
X9gK78KOKz8g/+JKY//ILa50IPe4MoC8w5U9yLXdkxtbho6dnXoHR4e+e/bq
mUCHt8dbgj26O+4xFE6FiCvPIL/gyhHkE66cQb7gygTyjCtXyGyv5MDWSEek
s95hpiPSOTVnEh1L85bUdGf+/QBmWB86
      "]]}, 
    {RGBColor[0., 1., 1.], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJxNjVsOgkAQBFc9Aoogiiwogg8EjuIRPIDe/8/pWJvsR6UrmZ4Z//6+Pkvn
3GisjGTh3NrYLP6uTEG+xZUZyHNcuYOcWzsygZTumt3wK4u6ObPC2BsHXFmC
/IgrK5B7XFmD51ZNFlDS3bMbflVR1zNrjJNxxpUtyC+4sgN5jyuv0HPrSjbQ
0j2xG351UbdndjPuxgNXDiB/4soR5BOunGHi1kzeYKB7Zzf8GqPuxOwHvrIV
0A==
      "]]}, 
    {RGBColor[0., 0., 1.], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJxNjkkSgkAQBEd9iW8QFUURFdwBBTc8+gD9/82uMCeCQ0YlzEx199/f6tN1
ziVGzxh0nAuMYefvyhHIx7gyBPkEV05BHuHKGUTMmJEDGNER0Ol3COkI6Bzz
f9rqiDibG7GxwJUJyJe4cgXyNa5MQZ7hyg1kzNiQc0joiOn0O6zoiOlc8j9t
dWScbY2dsceVB5AfceUJ5DmuLCCnqyC3cODujrd+1ql1N+esNM7GBVdWIK9x
5RXkN1x5B/kDVz5B3uDKFzTMfpElXjKzYQd/p2Jmww4Xvu9018zyuz15V/NG
Zz+k0jek
      "]]}, 
    {RGBColor[1., 0., 1.], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJw12WWg1/UVgHEEC2WEqIyOAYLAUHrSMEpipMAu3X1lA5UaSI+OISgxDGrS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      "]]}, 
    {RGBColor[0., 0., 0.], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJwtyuEyQlEYheGGK3FLLsH4TSmSJEmOJEmSJEk36qyZ58ee9e1n3oOj08OT
vUqlcly+/fJVy0+tfGe2Xr6Gu8Fj5/5VdmFjTXeTN/RNfezSxlruFm/qW/rY
lY213W3e0rf1sWsb67g7vK3v6GM3NtZ1d3lH39XHbm2s5+7xrr6nj93ZWN/d
5z19Xx+7t7GBe8D7+oE+9mBjhbvgA32hjz3a2NA95IV+qI892djIPeJD/Ugf
e7axsXvMR/qxPvZiYxP3hI/1E33s1cam7imf6Kf62JuNzdwzPtXP9LF3G5u7
53ymn+tjHza2cC/4XL/Qxz5tbOle8oV+qY992djKveJL/Uof+7axtXvNV/q1
PvZjYxv3hq/1G33s18a27i3f6Lf62J+N7dw7vtXv9LGajdXddb7T5/8P+qmh
/g==
      "]]}}],
  ImageSize->{445., Automatic},
  SphericalRegion->True]], "Picture"],

Cell[TextData[{
 ButtonBox["DXF",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/format/DXF"],
 " is a 3D geometry format typically used in CAD programs by architects, \
engineers, and other disciplines that rely on 3D images."
}], "Text"],

Cell[TextData[{
 "The files that we use here are included in the example data that can \
accessed directly in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.4272960485295477`*^9, 3.427296091436541*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["DXF: Importing the image", "Section"],

Cell[TextData[{
 "Importing a ",
 ButtonBox["DXF",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/format/DXF"],
 " file brings an image into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"heliplot", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<ExampleData/helicopter.dxf.gz\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["DXF: Getting the data", "Section"],

Cell["\<\
This extracts and then displays the points that are used to generate the \
image.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vertices", " ", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Import", "[", 
     RowBox[{
     "\"\<ExampleData/helicopter.dxf.gz\>\"", ",", " ", 
      "\"\<VertexData\>\""}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"Point", "/@", "vertices"}], "]"}]], "Input"],

Cell[TextData[{
 "In this example, we will show how to take the vertex set apart to create \
the various components in the image using a ",
 ButtonBox["GraphicsComplex",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphicsComplex"],
 "."
}], "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["DXF: Deconstructing the image", "Section"],

Cell[TextData[{
 "We will break the data into subsets and then construct a ",
 ButtonBox["GraphicsComplex",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphicsComplex"],
 " to represent the same image."
}], "Text"],

Cell[BoxData[
 RowBox[{"Head", "[", "heliplot", "]"}]], "Input"],

Cell["\<\
Each component of the graphics expression is a color specification followed \
by a polygon.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"heliplot", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "5"}], "]"}]], "Input"],

Cell["This extracts the polygons.", "MathCaption"],

Cell[BoxData[
 RowBox[{"polys", "=", 
  RowBox[{"Cases", "[", 
   RowBox[{"heliplot", ",", 
    RowBox[{"{", 
     RowBox[{"_RGBColor", ",", "_Polygon"}], "}"}], ",", "Infinity"}], 
   "]"}]}]], "Input"],

Cell["Partitioning the list by color.", "MathCaption",
 CellChangeTimes->{{3.42729666296017*^9, 3.4272966718139133`*^9}}],

Cell[BoxData[
 RowBox[{"colorPolys", "=", 
  RowBox[{"Split", "[", 
   RowBox[{"polys", ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"#1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
       RowBox[{"#2", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "&"}], ")"}]}], "]"}]}]], "Input"],

Cell["\<\
There are seven sets of polygons which corresponds to the colors in the image.\
\>", "MathCaption",
 CellChangeTimes->{{3.427296681321011*^9, 3.427296709599736*^9}}],

Cell[BoxData[
 RowBox[{"Length", "[", "colorPolys", "]"}]], "Input",
 CellChangeTimes->{{3.427108689021843*^9, 3.427108697892518*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
DXF: Converting to indexed vertices\
\>", "Section"],

Cell["\<\
Pairing the color with the vertices that are required to create polygons of \
the given color.\
\>", "Text",
 CellChangeTimes->{{3.4277024667025557`*^9, 3.427702512573453*^9}}],

Cell[BoxData[
 RowBox[{"colorPolys", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4277479278156767`*^9, 3.4277479389487343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vertexSets", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "1"}], "]"}], "]"}]}], "}"}], "&"}], 
     ",", "colorPolys"}], "]"}]}], ";"}]], "Input"],

Cell["Here is the first set:", "MathCaption"],

Cell[BoxData[
 RowBox[{"vertexSets", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "This creates the information for the second argument of the ",
 ButtonBox["GraphicsComplex",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphicsComplex"],
 "."
}], "Text"],

Cell["Indexing the vertices.", "MathCaption",
 CellChangeTimes->{{3.42770253420865*^9, 3.427702540750875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"parts", "=", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", "]"}], ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"vertices", ",", "#"}], "]"}], "&"}], ")"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], "}"}], "&"}], ",", 
      "vertexSets"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_List", ",", "b_List", ",", "c_List"}], "}"}], 
     "\[RuleDelayed]", " ", 
     RowBox[{"Flatten", "@", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"parts", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "15"}], "]"}]], "Input"],

Cell[TextData[{
 "Here we put the parts together with the points to complete the ",
 ButtonBox["GraphicsComplex",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphicsComplex"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"GraphicsComplex", "[", 
    RowBox[{"vertices", ",", "parts"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"6", " ", "72"}]}], ",", 
   RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
DXF: Looking at parts of the image\
\>", "Section"],

Cell[TextData[{
 "Because of the way we have constructed the ",
 ButtonBox["GraphicsComplex",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphicsComplex"],
 " we can easily extract the components and work with them individually."
}], "Text"],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"Graphics3D", "[", 
         RowBox[{
          RowBox[{"GraphicsComplex", "[", 
           RowBox[{"vertices", ",", "parts"}], "]"}], ",", 
          RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Graphics3D", "[", 
          RowBox[{
           RowBox[{"GraphicsComplex", "[", 
            RowBox[{"vertices", ",", 
             RowBox[{
             "parts", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}]}], "]"}], ",", 
           RowBox[{"SphericalRegion", "\[Rule]", "True"}], ",", 
           RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "7"}], "}"}]}], "]"}]}], "]"}], ",", "3", ",", 
     "3", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["FASTA", "Section"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvV2u68jSbfcZboXum7tkgLCfbwfsbtBwW9JuCP3qZrANLh9BgZFjRqa0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    "], {{0, 368}, {470, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{470, 368},
  PlotRange->{{0, 470}, {0, 368}}]], "Picture",
 CellMargins->{{150, 100}, {20, 20}}],

Cell[TextData[{
 StyleBox["Thermoplasma",
  FontSlant->"Italic"],
 " ",
 StyleBox["acidophilum",
  FontSlant->"Italic"],
 ". ",
 StyleBox["Thermoplasma",
  FontSlant->"Italic"],
 " is a genus of archea, bacteria-like, single-celled organisms that thrive \
in high acid, high temperature environments."
}], "PictureCaption"],

Cell[TextData[{
 "FASTA files are used extensively in genomic research and are basically text \
files containing information on gene and protein sequences. We will compare \
the sequences of two organisms ",
 StyleBox["Thermoplasma acidophilum",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Thermoplasma volcanium",
  FontSlant->"Italic"],
 ". Source information for these files can be found at European \
Bioinformatics Institute, part of the European Molecular Biology Laboratory:"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["www.ebi.ac.uk/2can/genomes/archaea/Thermoplasma_\
acidophilum.html",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www.ebi.ac.uk/2can/genomes/archaea/Thermoplasma_acidophilum.\
html"], None}]], "Item"],

Cell[TextData[ButtonBox["www.ebi.ac.uk/2can/genomes/archaea/Thermoplasma_\
volcanium.html",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www.ebi.ac.uk/2can/genomes/archaea/Thermoplasma_volcanium.\
html"], None}]], "Item"]
}, Open  ]],

Cell["\<\
Copies of the files are included with the download materials in case the web \
files should be unavailable or changed in some way.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["FASTA: Comparing organisms", "Section"],

Cell[TextData[{
 "We begin by importing the file for ",
 StyleBox["Thermoplasma acidophilum",
  FontSlant->"Italic"],
 ". We import it as labeled data to make our work easier when comparing the \
two species."
}], "Text"],

Cell["\<\
Import the data. Bringing the file in as labeled data gives a set of rules \
with the identifier for the sequence on the left of the rule and the sequence \
on the right.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AcidoLblData", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<thermoplasma_acidophilum_gene.fna\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<FASTA\>\"", ",", "\"\<LabeledData\>\""}], "}"}]}], "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.488206451958112*^9, 3.488206455255262*^9}}],

Cell["Looking at the data.", "MathCaption",
 CellChangeTimes->{{3.427619452391508*^9, 3.427619456429221*^9}}],

Cell[BoxData[
 RowBox[{"Length", "[", "AcidoLblData", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"AcidoLblData", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
FASTA: Using edit distance to compare\
\>", "Section"],

Cell[TextData[{
 "Sequences can be compared using ",
 ButtonBox["EditDistance",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EditDistance"],
 ". If we are trying to show close relationships then we are looking for \
small edit distances. If two sequences are of unequal length the difference \
in lengths will be registered in the edit distance."
}], "Text"],

Cell["These two strings differ in 4 positions.", "MathCaption"],

Cell[BoxData[
 RowBox[{"EditDistance", "[", 
  RowBox[{"\"\<abc\>\"", ",", "\"\<abcdefg\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.427619748531617*^9, 3.427619773240943*^9}}],

Cell["\<\
To minimize the differences and save on computing we sort the data according \
to the lengths of the sequences.\
\>", "MathCaption",
 CellChangeTimes->{{3.427619860260933*^9, 3.4276198931873207`*^9}}],

Cell[BoxData[
 RowBox[{"sortAcidoLblData", "=", 
  RowBox[{"SortBy", "[", 
   RowBox[{"AcidoLblData", ",", 
    RowBox[{
     RowBox[{"StringLength", "[", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}], "&"}]}], "]"}]}]], "Input"],

Cell[TextData[{
 "We can view the distribution of sequence lengths using ",
 ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{"Map", "[", 
   RowBox[{"StringLength", ",", 
    RowBox[{"sortAcidoLblData", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "\[IndentingNewLine]",
   "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "FASTA: Import ",
 StyleBox["Thermoplasma volcanium",
  FontSlant->"Italic"]
}], "Section"],

Cell[TextData[{
 "We repeat the process for the ",
 StyleBox["Thermoplasma volcanium",
  FontSlant->"Italic"],
 " data."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"volcanLblData", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<thermoplasma_volcanium_gene.fna\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<FASTA\>\"", ",", "\"\<LabeledData\>\""}], "}"}]}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Take", "[", 
  RowBox[{"volcanLblData", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.488206473088913*^9, 3.488206516761491*^9}}],

Cell["Sorting the data by sequence length.", "MathCaption",
 CellChangeTimes->{{3.427620472952159*^9, 3.42762048339016*^9}}],

Cell[BoxData[
 RowBox[{"sortVolcanLblData", "=", 
  RowBox[{"SortBy", "[", 
   RowBox[{"volcanLblData", ",", 
    RowBox[{
     RowBox[{"StringLength", "[", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}], "&"}]}], "]"}]}]], "Input"],

Cell["Looking at the distribution of sequence lengths.", "MathCaption",
 CellChangeTimes->{{3.42762049138486*^9, 3.427620506471299*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{"Map", "[", 
   RowBox[{"StringLength", ",", 
    RowBox[{"sortVolcanLblData", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "\[IndentingNewLine]",
   "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["FASTA: Comparing organisms", "Section"],

Cell[TextData[{
 "We select a number of sequences from the ",
 StyleBox["volcanium",
  FontSlant->"Italic"],
 " data and compare them with the first sequence from the ",
 StyleBox["acidophilum",
  FontSlant->"Italic"],
 " data."
}], "Text"],

Cell["Edit counts for the sequences.", "MathCaption"],

Cell[BoxData[
 RowBox[{"editCounts", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"EditDistance", "[", 
      RowBox[{
       RowBox[{"sortAcidoLblData", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "#"}], "]"}], "&"}], ",", 
    RowBox[{"sortVolcanLblData", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"1", ";;", "25"}], ",", "2"}], "]"}], "]"}]}], 
   "]"}]}]], "Input"],

Cell["Selecting the smallest edit distance and formatting.", "MathCaption",
 CellChangeTimes->{{3.427621838115325*^9, 3.42762185559129*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Min", "[", "editCounts", "]"}], ",", 
   RowBox[{"sortAcidoLblData", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"Extract", "[", 
    RowBox[{"sortVolcanLblData", ",", 
     RowBox[{"Position", "[", 
      RowBox[{"editCounts", ",", 
       RowBox[{"Min", "[", "editCounts", "]"}]}], "]"}]}], "]"}]}], 
  "}"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
FASTA: Comparing organisms \[Dash] results\
\>", "Section"],

Cell[TextData[{
 "Now that we have our model we compare the first 25 sequences from ",
 StyleBox["acidophilum",
  FontSlant->"Italic"],
 " with the first 35 from ",
 StyleBox["volcanium",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell["\<\
Running the comparisons and formatting the results in a table.\
\>", "MathCaption",
 CellChangeTimes->{{3.427621930212966*^9, 3.427621948031996*^9}}],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"fullData", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"editCounts", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"EditDistance", "[", 
            RowBox[{
             RowBox[{"sortAcidoLblData", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], ",", "#1"}],
             "]"}], "&"}], ")"}], "/@", 
         RowBox[{"sortVolcanLblData", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"1", ";;", "35"}], ",", "2"}], 
          "\[RightDoubleBracket]"}]}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Min", "[", "editCounts", "]"}], ",", 
         RowBox[{
         "sortAcidoLblData", "\[LeftDoubleBracket]", "i", 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{"Extract", "[", 
          RowBox[{"sortVolcanLblData", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"editCounts", ",", 
             RowBox[{"Min", "[", "editCounts", "]"}]}], "]"}]}], "]"}]}], 
        "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "25"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell["\<\
Here is the mean of the set of edit distances for these two organisms.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"N", "@", 
  RowBox[{"Mean", "[", 
   RowBox[{"fullData", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4275343545487213`*^9, 3.427534379159646*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Further Resources", "Section"],

Cell[CellGroupData[{

Cell["Tutorials", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["Importing and Exporting Data",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/ImportingAndExportingData"]], "Item",
 CellID->138871290],

Cell[TextData[ButtonBox["Importing and Exporting Files",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/ImportingAndExportingFiles"]], "Item",
 CellID->15579],

Cell[TextData[ButtonBox["Files, Streams, and External Operations",
 BaseStyle->"Link",
 ButtonData->
  "paclet:tutorial/FilesStreamsAndExternalOperationsOverview"]], "Item",
 CellID->73377947],

Cell[TextData[ButtonBox["Guide page on Importing and Exporting",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/ImportingAndExporting"]], "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wolfram Education Group Seminars and Courses", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[{
 " ",
 ButtonBox["S18: Import and Export Data Formats in ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s18.html"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s18.html"], None}],
  FontSlant->"Italic"]
}], "Item",
 CellChangeTimes->{{3.511108460609384*^9, 3.511108462648005*^9}}],

Cell[TextData[{
 ButtonBox["S20: Statistics and Data Analysis with ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s20.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s20.html"],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s20.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s20.html"],
  FontSlant->"Italic"]
}], "Item"],

Cell[TextData[{
 ButtonBox["S41: Statistical Visualization with ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s41.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s41.html"],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s41.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s41.html"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s41.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s41.html"]
}], "Item"],

Cell[TextData[{
 ButtonBox["M215: Applied Statistical Analysis with ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m215.html"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m215.html"], None}],
  FontSlant->"Italic"]
}], "Item"],

Cell[TextData[{
 ButtonBox["M221: Introduction to Programming in ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m221.html"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m221.html"], None}],
  FontSlant->"Italic"]
}], "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Resources on the Web", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[{
 "Wolfram Demonstrations Project: ",
 ButtonBox["demonstrations.wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com"], None}]
}], "Item"],

Cell[TextData[{
 "Wolfram Library Archive: ",
 ButtonBox["library.wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://library.wolfram.com"], None}]
}], "Item"],

Cell[TextData[{
 "Training from Wolfram Education Group: ",
 ButtonBox["www.wolfram.com/weg",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/"], None}]
}], "Item"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->True],

Cell[CellGroupData[{

Cell["DisplayTable", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplayTable", "[", 
   RowBox[{"lis_List", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "Grid", "]"}]}]}], "]"}], ":=", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{
     RowBox[{"Grid", "[", 
      RowBox[{"lis", ",", "opts", ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Menu\>\"", ",", "19"}], "}"}]}], ",", 
       RowBox[{"Alignment", "\[Rule]", 
        RowBox[{"{", "Left", "}"}]}], ",", 
       RowBox[{"Background", "\[Rule]", "LightYellow"}], ",", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"False", ",", "All"}], "}"}]}], ",", 
       RowBox[{"Spacings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"2", ",", "0.62"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ShowStringCharacters", "\[Rule]", "False"}], ",", 
     "\"\<DisplayFormula\>\""}], "]"}], "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Overview Mouseover", "MoreExamplesSection",
 CellChangeTimes->{{3.49896919710295*^9, 3.498969204966164*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m8red", "[", "a_", "]"}], ":=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.811765", ",", "0.117647", ",", "0.145098", ",", "a"}], "]"}]}],
   ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OverviewMouseover", "[", 
   RowBox[{"header_", ",", "subs_"}], "]"}], ":=", 
  RowBox[{"CellPrint", "@", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"BoxData", "[", 
      RowBox[{"ToBoxes", "@", 
       RowBox[{"Mouseover", "[", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"header", ",", "\"\<OverviewSection\>\""}], "]"}], ",", 
           RowBox[{"FrameMargins", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"15", ",", "15"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
           RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "@", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"subs", "\[Equal]", "\"\<\>\""}], ",", 
            RowBox[{"Framed", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
               "]"}], ",", 
              RowBox[{"FrameMargins", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"15", ",", "15"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
              RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
              RowBox[{"Background", "\[Rule]", 
               RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
                  "]"}], ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
               "\"\< \[RightGuillemet] \>\"", ",", 
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"subs", ",", "\"\<OverviewSection\>\""}], "]"}], 
                 ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}], ",", 
                 RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}],
              "]"}]}], "]"}]}]}], "]"}]}], "]"}], ",", 
     "\"\<OverviewSection\>\""}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"MapThread", "[", 
     RowBox[{"OverviewMouseover", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<XLS\>\"", ",", "\"\<Excel spreadsheets\>\""}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Text\>\"", ",", "\"\<Comma or tab separated format\>\""}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"\"\<CSV\>\"", ",", "\"\<Comma separated format\>\""}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<HDF\>\"", ",", 
           "\"\<Hierarchical Data Format, typically for multidimensional \
datasets\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"\"\<DXF\>\"", ",", "\"\<3D geometry, CAD format\>\""}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<FASTA\>\"", ",", 
           "\"\<molecular biology format for genomic research\>\""}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"\"\<WeatherData\>\"", ",", "\"\<Time series data\>\""}], 
          "}"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], "]"}], ";"}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.5309624178276243`*^9, 3.53096249134966*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Lastly", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
Saveable->True,
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{1064, 754},
WindowMargins->{{Automatic, 162}, {Automatic, 36}},
WindowTitle->"S24 Working with Imported Data",
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, 
                    With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefnitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> Plain, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{80, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> Plain, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontColor -> RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"], FontSize -> 21], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], ShowCellBracket -> Automatic, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[0.786999, 0.0386053, 0.0571756]}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 16, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 19, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "SlideShow"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          StyleData["DialogStyle"], FontSize -> 17], 
         Cell[
          StyleData["TooltipLabel"], CellFrame -> 1., CellFrameMargins :> 
          CurrentValue["TooltipFrameMargins"], CellFrameColor :> 
          CurrentValue[{"SystemColor", "TooltipFrame"}], TextAlignment -> 
          Left, TextJustification -> 0., ShowStringCharacters -> False, 
          FontFamily :> CurrentValue["TooltipFontFamily"], FontSize :> 
          CurrentValue["TooltipFontSize"], FontWeight -> "Plain", FontSlant -> 
          "Plain", Magnification -> 1.5, FontColor :> 
          CurrentValue[{"SystemColor", "TooltipText"}], FontOpacity -> 1., 
          Background :> CurrentValue[{"SystemColor", "Tooltip"}]]}, Open]]}, 
     Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, 2011)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[611, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1546, 63, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[12154, 347, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[13114, 386, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[15294, 472, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[16731, 526, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[204306, 3626, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[206337, 3703, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[210546, 3856, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[213888, 3968, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[217338, 4058, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[219614, 4131, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[222377, 4201, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[231146, 4387, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[233110, 4458, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[236862, 4587, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[242815, 4758, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[429788, 7860, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[440657, 8187, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[442335, 8253, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[445617, 8367, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[447684, 8434, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1101885, 19945, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1104450, 20040, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1108438, 20166, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1112241, 20284, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1125098, 20523, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1125765, 20554, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1126671, 20594, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1128461, 20663, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1131554, 20779, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1133129, 20833, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1218758, 22276, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1220003, 22323, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1221768, 22387, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1223405, 22447, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1224886, 22504, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1227112, 22582, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1231513, 22741, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 1273295, 23692}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[611, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[678, 26, 43, 0, 312, "Title"],
Cell[724, 28, 169, 6, 196, "Subtitle"],
Cell[896, 36, 191, 5, 235, "Subsubtitle"],
Cell[1090, 43, 419, 15, 79, "DateSection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1546, 63, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1635, 68, 27, 0, 123, "Section"],
Cell[1665, 70, 357, 7, 167, "Text"],
Cell[2025, 79, 103, 3, 58, "Text"],
Cell[2131, 84, 1441, 35, 76, "OverviewSection"],
Cell[3575, 121, 1455, 35, 76, "OverviewSection"],
Cell[5033, 158, 1448, 34, 76, "OverviewSection"],
Cell[6484, 194, 1341, 33, 76, "OverviewSection"],
Cell[7828, 229, 1293, 32, 76, "OverviewSection"],
Cell[9124, 263, 1320, 32, 76, "OverviewSection"],
Cell[10447, 297, 1304, 32, 76, "OverviewSection"],
Cell[11754, 331, 246, 6, 154, "MathCaption"],
Cell[12003, 339, 102, 2, 45, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12154, 347, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[12243, 352, 36, 0, 123, "Section"],
Cell[12282, 354, 593, 16, 205, "Text"],
Cell[12878, 372, 49, 1, 45, "Input"],
Cell[12930, 375, 40, 0, 45, "Input"],
Cell[12973, 377, 49, 1, 45, "Input"],
Cell[13025, 380, 40, 0, 45, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13114, 386, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[13203, 391, 60, 0, 123, "Section"],
Cell[13266, 393, 169, 6, 60, "Text"],
Cell[CellGroupData[{
Cell[13460, 403, 149, 4, 100, "Item"],
Cell[13612, 409, 142, 4, 58, "Item"]
}, Open  ]],
Cell[13769, 416, 294, 5, 154, "MathCaption"],
Cell[14066, 423, 276, 7, 45, "Input"],
Cell[14345, 432, 306, 11, 119, "MathCaption"],
Cell[14654, 445, 378, 10, 75, "Input"],
Cell[15035, 457, 121, 4, 82, "MathCaption"],
Cell[15159, 463, 65, 1, 45, "Input"],
Cell[15227, 466, 18, 0, 25, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15294, 472, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[15383, 477, 68, 2, 123, "Section"],
Cell[15454, 481, 407, 11, 135, "Text"],
Cell[15864, 494, 171, 3, 81, "MathCaption"],
Cell[16038, 499, 104, 2, 45, "Input"],
Cell[16145, 503, 18, 0, 25, "Spacer"],
Cell[16166, 505, 495, 13, 95, "Text"],
Cell[16664, 520, 18, 0, 25, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16731, 526, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[16820, 531, 37, 0, 123, "Section"],
Cell[16860, 533, 186766, 3068, 440, "Picture"],
Cell[203629, 3603, 18, 0, 25, "Spacer"],
Cell[203650, 3605, 452, 10, 169, "Text"],
Cell[204105, 3617, 152, 3, 95, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[204306, 3626, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[204395, 3631, 48, 0, 123, "Section"],
Cell[204446, 3633, 465, 14, 170, "Text"],
Cell[204914, 3649, 75, 0, 81, "MathCaption"],
Cell[204992, 3651, 310, 9, 131, "Input"],
Cell[205305, 3662, 180, 6, 83, "MathCaption"],
Cell[205488, 3670, 139, 2, 45, "Input"],
Cell[205630, 3674, 174, 6, 118, "MathCaption"],
Cell[205807, 3682, 91, 2, 45, "Input"],
Cell[205901, 3686, 290, 6, 155, "MathCaption"],
Cell[206194, 3694, 73, 1, 45, "Input"],
Cell[206270, 3697, 18, 0, 25, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[206337, 3703, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[206426, 3708, 65, 2, 123, "Section"],
Cell[206494, 3712, 158, 3, 95, "Text"],
Cell[206655, 3717, 160, 6, 84, "MathCaption"],
Cell[206818, 3725, 124, 3, 45, "Input"],
Cell[206945, 3730, 115, 3, 118, "MathCaption"],
Cell[207063, 3735, 328, 10, 74, "Input"],
Cell[207394, 3747, 260, 6, 131, "Text"],
Cell[207657, 3755, 408, 11, 75, "Input"],
Cell[208068, 3768, 36, 0, 81, "MathCaption"],
Cell[208107, 3770, 167, 4, 45, "Input"],
Cell[208277, 3776, 192, 4, 118, "MathCaption"],
Cell[208472, 3782, 765, 23, 189, "Input"],
Cell[209240, 3807, 167, 3, 118, "MathCaption"],
Cell[209410, 3812, 419, 14, 74, "Input"],
Cell[209832, 3828, 48, 0, 81, "MathCaption"],
Cell[209883, 3830, 593, 18, 186, "Input"],
Cell[210479, 3850, 18, 0, 25, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[210546, 3856, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[210635, 3861, 76, 2, 184, "Section"],
Cell[210714, 3865, 63, 0, 58, "Text"],
Cell[210780, 3867, 251, 6, 74, "Input"],
Cell[211034, 3875, 401, 10, 157, "MathCaption"],
Cell[211438, 3887, 420, 13, 94, "Input"],
Cell[211861, 3902, 72, 1, 45, "Input"],
Cell[211936, 3905, 485, 12, 158, "Input"],
Cell[212424, 3919, 168, 3, 81, "MathCaption"],
Cell[212595, 3924, 657, 18, 131, "Input"],
Cell[213255, 3944, 112, 3, 81, "MathCaption"],
Cell[213370, 3949, 215, 5, 45, "Input"],
Cell[213588, 3956, 71, 0, 81, "MathCaption"],
Cell[213662, 3958, 156, 2, 45, "Input"],
Cell[213821, 3962, 18, 0, 25, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[213888, 3968, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[213977, 3973, 179, 2, 123, "Section"],
Cell[214159, 3977, 628, 13, 167, "Text"],
Cell[214790, 3992, 139, 1, 81, "MathCaption"],
Cell[214932, 3995, 541, 12, 103, "Input"],
Cell[215476, 4009, 275, 5, 131, "Text"],
Cell[215754, 4016, 123, 1, 81, "MathCaption"],
Cell[215880, 4019, 997, 22, 131, "Input"],
Cell[216880, 4043, 273, 5, 81, "MathCaption"],
Cell[217156, 4050, 133, 2, 45, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[217338, 4058, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[217427, 4063, 106, 1, 123, "Section"],
Cell[217536, 4066, 183, 4, 95, "Text"],
Cell[217722, 4072, 128, 1, 81, "MathCaption"],
Cell[217853, 4075, 346, 9, 45, "Input"],
Cell[218202, 4086, 140, 1, 81, "MathCaption"],
Cell[218345, 4089, 447, 13, 45, "Input"],
Cell[218795, 4104, 227, 4, 95, "Text"],
Cell[219025, 4110, 540, 15, 45, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[219614, 4131, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[219703, 4136, 115, 1, 123, "Section"],
Cell[219821, 4139, 127, 1, 101, "MathCaption"],
Cell[219951, 4142, 210, 3, 56, "Input"],
Cell[220164, 4147, 241, 4, 118, "Text"],
Cell[220408, 4153, 180, 4, 147, "MathCaption"],
Cell[220591, 4159, 1737, 36, 407, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[222377, 4201, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[222466, 4206, 29, 0, 108, "Section"],
Cell[222498, 4208, 7228, 136, 658, "Picture"],
Cell[229729, 4346, 18, 0, 31, "Spacer"],
Cell[229750, 4348, 556, 10, 232, "Text"],
Cell[230309, 4360, 451, 10, 88, "Text"],
Cell[230763, 4372, 334, 9, 88, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[231146, 4387, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[231235, 4392, 61, 2, 108, "Section"],
Cell[231299, 4396, 106, 1, 52, "Text"],
Cell[231408, 4399, 243, 6, 50, "Input"],
Cell[231654, 4407, 240, 7, 108, "MathCaption"],
Cell[231897, 4416, 240, 4, 50, "Input"],
Cell[232140, 4422, 222, 4, 50, "Input"],
Cell[232365, 4428, 222, 5, 196, "MathCaption"],
Cell[232590, 4435, 89, 2, 110, "Input"],
Cell[232682, 4439, 101, 2, 196, "MathCaption"],
Cell[232786, 4443, 254, 7, 110, "Input"],
Cell[233043, 4452, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[233110, 4458, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[233199, 4463, 44, 0, 296, "Section"],
Cell[233246, 4465, 217, 6, 145, "Text"],
Cell[233466, 4473, 64, 1, 110, "Input"],
Cell[233533, 4476, 260, 8, 145, "Text"],
Cell[233796, 4486, 221, 6, 181, "DisplayFormula"],
Cell[234020, 4494, 125, 3, 196, "MathCaption"],
Cell[234148, 4499, 267, 6, 110, "Input"],
Cell[234418, 4507, 267, 6, 110, "Input"],
Cell[234688, 4515, 188, 6, 200, "MathCaption"],
Cell[234879, 4523, 991, 27, 322, "Input"],
Cell[235873, 4552, 133, 3, 196, "MathCaption"],
Cell[236009, 4557, 783, 22, 322, "Input"],
Cell[236795, 4581, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[236862, 4587, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[236951, 4592, 68, 2, 296, "Section"],
Cell[237022, 4596, 440, 8, 226, "Text"],
Cell[237465, 4606, 69, 0, 196, "MathCaption"],
Cell[237537, 4608, 393, 12, 116, "Input"],
Cell[237933, 4622, 205, 6, 200, "MathCaption"],
Cell[238141, 4630, 4604, 120, 1171, "Input"],
Cell[242748, 4752, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[242815, 4758, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[242904, 4763, 22, 0, 296, "Section"],
Cell[242929, 4765, 185992, 3066, 1346, "Picture"],
Cell[428924, 7833, 18, 0, 58, "Spacer"],
Cell[428945, 7835, 500, 10, 316, "Text"],
Cell[429448, 7847, 291, 7, 228, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[429788, 7860, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[429877, 7865, 42, 0, 297, "Section"],
Cell[429922, 7867, 75, 0, 140, "Text"],
Cell[CellGroupData[{
Cell[430022, 7871, 156, 3, 181, "Input"],
Cell[430181, 7876, 824, 16, 1416, "Output"]
}, Closed]],
Cell[431020, 7895, 95, 2, 102, "MathCaption"],
Cell[CellGroupData[{
Cell[431140, 7901, 312, 8, 252, "Input"],
Cell[431455, 7911, 161, 3, 262, "Output"]
}, Closed]],
Cell[431631, 7917, 461, 12, 213, "MathCaption"],
Cell[CellGroupData[{
Cell[432117, 7933, 385, 10, 321, "Input"],
Cell[432505, 7945, 6520, 178, 606, "Output"]
}, Open  ]],
Cell[439040, 8126, 62, 0, 196, "MathCaption"],
Cell[439105, 8128, 69, 1, 108, "Input"],
Cell[439177, 8131, 57, 0, 196, "MathCaption"],
Cell[439237, 8133, 268, 7, 108, "Input"],
Cell[439508, 8142, 18, 0, 58, "Spacer"],
Cell[CellGroupData[{
Cell[439551, 8146, 56, 0, 171, "MoreExamplesSection"],
Cell[439610, 8148, 62, 0, 312, "Text"],
Cell[439675, 8150, 304, 7, 246, "Input"],
Cell[439982, 8159, 113, 3, 345, "MathCaption"],
Cell[440098, 8164, 405, 11, 246, "Input"],
Cell[440506, 8177, 69, 1, 246, "Input"],
Cell[440578, 8180, 18, 0, 135, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[440657, 8187, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[440746, 8192, 43, 0, 297, "Section"],
Cell[440792, 8194, 127, 1, 140, "Text"],
Cell[440922, 8197, 262, 8, 108, "Input"],
Cell[441187, 8207, 79, 0, 196, "MathCaption"],
Cell[441269, 8209, 167, 4, 108, "Input"],
Cell[441439, 8215, 32, 1, 71, "Space"],
Cell[441474, 8218, 210, 4, 140, "Text"],
Cell[441687, 8224, 84, 2, 197, "MathCaption"],
Cell[441774, 8228, 153, 4, 108, "Input"],
Cell[441930, 8234, 84, 2, 197, "MathCaption"],
Cell[442017, 8238, 248, 7, 108, "Input"],
Cell[442268, 8247, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[442335, 8253, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[442424, 8258, 49, 0, 297, "Section"],
Cell[442476, 8260, 147, 3, 141, "Text"],
Cell[442626, 8265, 176, 5, 112, "Input"],
Cell[442805, 8272, 133, 2, 108, "Input"],
Cell[442941, 8276, 422, 11, 288, "MathCaption"],
Cell[443366, 8289, 257, 8, 112, "Input"],
Cell[443626, 8299, 154, 3, 285, "MathCaption"],
Cell[443783, 8304, 641, 15, 385, "Input"],
Cell[444427, 8321, 17, 0, 58, "Space"],
Cell[444447, 8323, 196, 4, 140, "Text"],
Cell[444646, 8329, 223, 6, 196, "MathCaption"],
Cell[444872, 8337, 675, 22, 181, "Input"],
Cell[445550, 8361, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[445617, 8367, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[445706, 8372, 81, 2, 301, "Section"],
Cell[445790, 8376, 407, 9, 322, "Text"],
Cell[446200, 8387, 1414, 39, 570, "Input"],
Cell[447617, 8428, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[447684, 8434, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[447773, 8439, 35, 0, 297, "Section"],
Cell[447811, 8441, 653260, 11475, 765, 545752, 9711, "CachedBoxData", \
"BoxData", "Picture"],
Cell[1101074, 19918, 18, 0, 58, "Spacer"],
Cell[1101095, 19920, 720, 17, 325, "Text"],
Cell[1101818, 19939, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1101885, 19945, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1101974, 19950, 67, 2, 297, "Section"],
Cell[1102044, 19954, 72, 0, 140, "Text"],
Cell[CellGroupData[{
Cell[1102141, 19958, 308, 7, 108, "Input"],
Cell[1102452, 19967, 39, 0, 108, "Output"]
}, Open  ]],
Cell[1102506, 19970, 172, 3, 196, "MathCaption"],
Cell[1102681, 19975, 469, 12, 108, "Input"],
Cell[1103153, 19989, 212, 5, 108, "Input"],
Cell[1103368, 19996, 112, 3, 196, "MathCaption"],
Cell[1103483, 20001, 85, 2, 108, "Input"],
Cell[1103571, 20005, 17, 0, 58, "Space"],
Cell[1103591, 20007, 168, 3, 228, "Text"],
Cell[1103762, 20012, 240, 7, 291, "MathCaption"],
Cell[1104005, 20021, 375, 11, 206, "Input"],
Cell[1104383, 20034, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1104450, 20040, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1104539, 20045, 68, 2, 297, "Section"],
Cell[1104610, 20049, 280, 7, 235, "Text"],
Cell[1104893, 20058, 205, 4, 196, "MathCaption"],
Cell[1105101, 20064, 122, 2, 108, "Input"],
Cell[1105226, 20068, 541, 14, 315, "Input"],
Cell[1105770, 20084, 18, 0, 58, "Spacer"],
Cell[1105791, 20086, 279, 7, 235, "Text"],
Cell[1106073, 20095, 169, 3, 196, "MathCaption"],
Cell[1106245, 20100, 234, 5, 108, "Input"],
Cell[1106482, 20107, 184, 4, 108, "Input"],
Cell[1106669, 20113, 141, 1, 196, "MathCaption"],
Cell[1106813, 20116, 212, 6, 108, "Input"],
Cell[1107028, 20124, 373, 8, 108, "Input"],
Cell[1107404, 20134, 139, 1, 196, "MathCaption"],
Cell[1107546, 20137, 146, 2, 108, "Input"],
Cell[1107695, 20141, 124, 1, 196, "MathCaption"],
Cell[1107822, 20144, 546, 14, 315, "Input"],
Cell[1108371, 20160, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1108438, 20166, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1108527, 20171, 62, 2, 297, "Section"],
Cell[1108592, 20175, 337, 8, 235, "Text"],
Cell[1108932, 20185, 257, 6, 285, "MathCaption"],
Cell[1109192, 20193, 166, 4, 108, "Input"],
Cell[1109361, 20199, 44, 0, 196, "MathCaption"],
Cell[1109408, 20201, 531, 16, 108, "Input"],
Cell[1109942, 20219, 579, 15, 233, "Text"],
Cell[1110524, 20236, 1647, 40, 588, "Input"],
Cell[1112174, 20278, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1112241, 20284, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1112330, 20289, 22, 0, 296, "Section"],
Cell[1112355, 20291, 12182, 207, 1477, "Picture"],
Cell[1124540, 20500, 239, 6, 233, "Text"],
Cell[1124782, 20508, 246, 7, 137, "Text"],
Cell[1125031, 20517, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1125098, 20523, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1125187, 20528, 43, 0, 296, "Section"],
Cell[1125233, 20530, 209, 9, 145, "Text"],
Cell[1125445, 20541, 250, 5, 110, "Input"],
Cell[1125698, 20548, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1125765, 20554, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1125854, 20559, 40, 0, 296, "Section"],
Cell[1125897, 20561, 105, 3, 137, "Text"],
Cell[1126005, 20566, 240, 7, 110, "Input"],
Cell[1126248, 20575, 98, 2, 110, "Input"],
Cell[1126349, 20579, 252, 7, 233, "Text"],
Cell[1126604, 20588, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1126671, 20594, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1126760, 20599, 48, 0, 296, "Section"],
Cell[1126811, 20601, 218, 6, 145, "Text"],
Cell[1127032, 20609, 64, 1, 110, "Input"],
Cell[1127099, 20612, 122, 3, 196, "MathCaption"],
Cell[1127224, 20617, 142, 4, 110, "Input"],
Cell[1127369, 20623, 50, 0, 196, "MathCaption"],
Cell[1127422, 20625, 203, 6, 116, "Input"],
Cell[1127628, 20633, 121, 1, 196, "MathCaption"],
Cell[1127752, 20636, 324, 10, 110, "Input"],
Cell[1128079, 20648, 175, 3, 196, "MathCaption"],
Cell[1128257, 20653, 134, 2, 110, "Input"],
Cell[1128394, 20657, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1128461, 20663, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1128550, 20668, 62, 2, 296, "Section"],
Cell[1128615, 20672, 186, 4, 137, "Text"],
Cell[1128804, 20678, 180, 4, 110, "Input"],
Cell[1128987, 20684, 425, 14, 110, "Input"],
Cell[1129415, 20700, 45, 0, 196, "MathCaption"],
Cell[1129463, 20702, 86, 2, 110, "Input"],
Cell[1129552, 20706, 18, 0, 58, "Spacer"],
Cell[1129573, 20708, 193, 6, 145, "Text"],
Cell[1129769, 20716, 110, 1, 196, "MathCaption"],
Cell[1129882, 20719, 964, 29, 187, "Input"],
Cell[1130849, 20750, 140, 4, 110, "Input"],
Cell[1130992, 20756, 203, 6, 200, "MathCaption"],
Cell[1131198, 20764, 286, 7, 110, "Input"],
Cell[1131487, 20773, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1131554, 20779, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1131643, 20784, 61, 2, 296, "Section"],
Cell[1131707, 20788, 245, 6, 233, "Text"],
Cell[1131955, 20796, 1104, 29, 322, "Input"],
Cell[1133062, 20827, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1133129, 20833, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1133218, 20838, 24, 0, 296, "Section"],
Cell[1133245, 20840, 83977, 1382, 1243, "Picture"],
Cell[1217225, 22224, 323, 11, 206, "PictureCaption"],
Cell[1217551, 22237, 495, 11, 312, "Text"],
Cell[CellGroupData[{
Cell[1218071, 22252, 235, 5, 137, "Item"],
Cell[1218309, 22259, 231, 5, 137, "Item"]
}, Open  ]],
Cell[1218555, 22267, 154, 3, 137, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1218758, 22276, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1218847, 22281, 45, 0, 296, "Section"],
Cell[1218895, 22283, 221, 6, 226, "Text"],
Cell[1219119, 22291, 201, 4, 283, "MathCaption"],
Cell[1219323, 22297, 334, 8, 116, "Input"],
Cell[1219660, 22307, 109, 1, 196, "MathCaption"],
Cell[1219772, 22310, 70, 1, 110, "Input"],
Cell[1219845, 22313, 88, 2, 110, "Input"],
Cell[1219936, 22317, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1220003, 22323, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1220092, 22328, 64, 2, 296, "Section"],
Cell[1220159, 22332, 360, 8, 233, "Text"],
Cell[1220522, 22342, 63, 0, 196, "MathCaption"],
Cell[1220588, 22344, 178, 3, 110, "Input"],
Cell[1220769, 22349, 210, 4, 196, "MathCaption"],
Cell[1220982, 22355, 254, 7, 110, "Input"],
Cell[1221239, 22364, 181, 6, 200, "MathCaption"],
Cell[1221423, 22372, 275, 7, 253, "Input"],
Cell[1221701, 22381, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1221768, 22387, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1221857, 22392, 108, 4, 296, "Section"],
Cell[1221968, 22398, 132, 5, 137, "Text"],
Cell[1222103, 22405, 428, 10, 187, "Input"],
Cell[1222534, 22417, 124, 1, 196, "MathCaption"],
Cell[1222661, 22420, 256, 7, 110, "Input"],
Cell[1222920, 22429, 136, 1, 196, "MathCaption"],
Cell[1223059, 22432, 276, 7, 253, "Input"],
Cell[1223338, 22441, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1223405, 22447, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1223494, 22452, 45, 0, 296, "Section"],
Cell[1223542, 22454, 240, 8, 137, "Text"],
Cell[1223785, 22464, 53, 0, 196, "MathCaption"],
Cell[1223841, 22466, 441, 14, 110, "Input"],
Cell[1224285, 22482, 140, 1, 196, "MathCaption"],
Cell[1224428, 22485, 388, 11, 183, "Input"],
Cell[1224819, 22498, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1224886, 22504, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1224975, 22509, 69, 2, 297, "Section"],
Cell[1225047, 22513, 228, 8, 137, "Text"],
Cell[1225278, 22523, 159, 3, 196, "MathCaption"],
Cell[1225440, 22528, 1258, 34, 520, "Input"],
Cell[1226701, 22564, 101, 2, 196, "MathCaption"],
Cell[1226805, 22568, 237, 6, 108, "Input"],
Cell[1227045, 22576, 18, 0, 58, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227112, 22582, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1227201, 22587, 36, 0, 297, "Section"],
Cell[CellGroupData[{
Cell[1227262, 22591, 40, 0, 171, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[1227327, 22595, 163, 3, 145, "Item",
 CellID->138871290],
Cell[1227493, 22600, 161, 3, 145, "Item",
 CellID->15579],
Cell[1227657, 22605, 192, 4, 145, "Item",
 CellID->73377947],
Cell[1227852, 22611, 145, 2, 145, "Item"]
}, Open  ]],
Cell[1228012, 22616, 18, 0, 58, "Spacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1228067, 22621, 75, 0, 171, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[1228167, 22625, 455, 12, 137, "Item"],
Cell[1228625, 22639, 543, 14, 137, "Item"],
Cell[1229171, 22655, 758, 20, 137, "Item"],
Cell[1229932, 22677, 384, 10, 137, "Item"],
Cell[1230319, 22689, 381, 10, 137, "Item"]
}, Open  ]],
Cell[1230715, 22702, 18, 0, 58, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[1230770, 22707, 51, 0, 145, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[1230846, 22711, 200, 6, 137, "Item"],
Cell[1231049, 22719, 179, 6, 137, "Item"],
Cell[1231231, 22727, 209, 6, 137, "Item"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1231513, 22741, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1231602, 22746, 61, 1, 191, "Section",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[1231688, 22751, 43, 0, 71, "MoreExamplesSection"],
Cell[1231734, 22753, 946, 24, 385, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1232717, 22782, 114, 1, 60, "MoreExamplesSection"],
Cell[1232834, 22785, 207, 6, 72, "Input"],
Cell[1233044, 22793, 3800, 87, 947, "Input"],
Cell[1236847, 22882, 1532, 36, 683, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1238416, 22923, 37, 0, 60, "MoreExamplesSection"],
Cell[1238456, 22925, 71, 2, 246, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
